﻿from typing import List, Optional, Dict, Iterable
import aspose.pycore
import aspose.pydrawing
import aspose.slides
import aspose.slides.animation
import aspose.slides.charts
import aspose.slides.dom.ole
import aspose.slides.effects
import aspose.slides.export
import aspose.slides.export.web
import aspose.slides.export.xaml
import aspose.slides.importing
import aspose.slides.ink
import aspose.slides.lowcode
import aspose.slides.mathtext
import aspose.slides.slideshow
import aspose.slides.smartart
import aspose.slides.spreadsheet
import aspose.slides.theme
import aspose.slides.util
import aspose.slides.vba
import aspose.slides.warnings

class AdjustValue:
    '''Represents a geometry shape's adjustment value.
                These values affect shape's form.'''
    @property
    def raw_value(self) -> int:
        ...

    @raw_value.setter
    def raw_value(self, value: int):
        ...

    @property
    def angle_value(self) -> float:
        ...

    @angle_value.setter
    def angle_value(self, value: float):
        ...

    @property
    def name(self) -> string:
        ...

    ...

class AdjustValueCollection:
    '''Reprasents a collection of shape's adjustments.'''
    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IAdjustValue
        '''Returns adjustment by index.'''
        ...

    ...

class Audio:
    '''Represents an embedded audio file.'''
    def get_stream(self) -> System.IO.Stream:
        '''Returns Stream stream for reading.
                    Use 'using' or close stream after using.
        :returns: Stream for reading.'''
        ...

    @property
    def content_type(self) -> string:
        ...

    @content_type.setter
    def content_type(self, value: string):
        ...

    @property
    def binary_data(self) -> bytes:
        ...

    ...

class AudioCollection:
    '''Represents a collection of embedded audio files.'''
    @overload
    def add_audio(self, audio: IAudio) -> IAudio:
        '''Adds a copy of an audio file from an another presentation.
        :param audio: Source audio.
        :returns: Added audio.'''
        ...

    @overload
    def add_audio(self, stream: System.IO.Stream) -> IAudio:
        '''Creates and adds a audio to a presentation from stream.
        :param stream: Stream to add audio from.
        :returns: Added audio.'''
        ...

    @overload
    def add_audio(self, stream: System.IO.Stream, loading_stream_behavior: LoadingStreamBehavior) -> IAudio:
        '''Creates and adds a audio to a presentation from stream.
        :param stream: Stream to add video audio from.
        :param loading_stream_behavior: The behavior which will be applied to the stream.
        :returns: Added audio.'''
        ...

    @overload
    def add_audio(self, audio_data: bytes) -> IAudio:
        '''Creates and adds a audio to a presentation from byte array.
        :param audio_data: Audio bytes.
        :returns: Added audio.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IAudio
        '''Gets the element at the specified index.
                    Read-only :py:class:`aspose.slides.IAudio`.'''
        ...

    ...

class AudioFrame(PictureFrame):
    '''Represents an audio clip on a slide.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    def get_geometry_paths(self) -> List[IGeometryPath]:
        '''Returns the copy of path of the geometry shape. Coordinates are relative to the left top corner of the shape.
        :returns: Array of :py:class:`aspose.slides.IGeometryPath`'''
        ...

    def set_geometry_path(self, geometry_path: IGeometryPath) -> None:
        '''Updates shape geometry from :py:class:`aspose.slides.IGeometryPath` object. Coordinates must be relative to the left
                     top corner of the shape.
                     Changes the type of the shape (:py:attr:`aspose.slides.GeometryShape.shape_type`) to :py:attr:`aspose.slides.ShapeType.CUSTOM`.
        :param geometry_path: Geometry path'''
        ...

    def set_geometry_paths(self, geometry_paths: List[IGeometryPath]) -> None:
        '''Updates shape geometry from array of :py:class:`aspose.slides.IGeometryPath`. Coordinates must be relative to the left
                     top corner of the shape.
                     Changes the type of the shape (:py:attr:`aspose.slides.GeometryShape.shape_type`) to :py:attr:`aspose.slides.ShapeType.CUSTOM`.
        :param geometry_paths: Array geometry paths'''
        ...

    def create_shape_elements(self) -> List[IShapeElement]:
        '''Creates and returns array of shape's elements.
        :returns: Array of :py:class:`aspose.slides.ShapeElement`'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IPictureFrameLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def shape_style(self) -> IShapeStyle:
        ...

    @property
    def shape_type(self) -> ShapeType:
        ...

    @shape_type.setter
    def shape_type(self, value: ShapeType):
        ...

    @property
    def adjustments(self) -> IAdjustValueCollection:
        ...

    @property
    def picture_frame_lock(self) -> IPictureFrameLock:
        ...

    @property
    def picture_format(self) -> IPictureFillFormat:
        ...

    @property
    def relative_scale_height(self) -> float:
        ...

    @relative_scale_height.setter
    def relative_scale_height(self, value: float):
        ...

    @property
    def relative_scale_width(self) -> float:
        ...

    @relative_scale_width.setter
    def relative_scale_width(self, value: float):
        ...

    @property
    def audio_cd_start_track(self) -> int:
        ...

    @audio_cd_start_track.setter
    def audio_cd_start_track(self, value: int):
        ...

    @property
    def audio_cd_start_track_time(self) -> int:
        ...

    @audio_cd_start_track_time.setter
    def audio_cd_start_track_time(self, value: int):
        ...

    @property
    def audio_cd_end_track(self) -> int:
        ...

    @audio_cd_end_track.setter
    def audio_cd_end_track(self, value: int):
        ...

    @property
    def audio_cd_end_track_time(self) -> int:
        ...

    @audio_cd_end_track_time.setter
    def audio_cd_end_track_time(self, value: int):
        ...

    @property
    def volume(self) -> AudioVolumeMode:
        ...

    @volume.setter
    def volume(self, value: AudioVolumeMode):
        ...

    @property
    def play_mode(self) -> AudioPlayModePreset:
        ...

    @play_mode.setter
    def play_mode(self, value: AudioPlayModePreset):
        ...

    @property
    def hide_at_showing(self) -> bool:
        ...

    @hide_at_showing.setter
    def hide_at_showing(self, value: bool):
        ...

    @property
    def play_loop_mode(self) -> bool:
        ...

    @play_loop_mode.setter
    def play_loop_mode(self, value: bool):
        ...

    @property
    def play_across_slides(self) -> bool:
        ...

    @play_across_slides.setter
    def play_across_slides(self, value: bool):
        ...

    @property
    def rewind_audio(self) -> bool:
        ...

    @rewind_audio.setter
    def rewind_audio(self, value: bool):
        ...

    @property
    def embedded(self) -> bool:
        ...

    @property
    def link_path_long(self) -> string:
        ...

    @link_path_long.setter
    def link_path_long(self, value: string):
        ...

    @property
    def embedded_audio(self) -> IAudio:
        ...

    @embedded_audio.setter
    def embedded_audio(self, value: IAudio):
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def as_i_geometry_shape(self) -> IGeometryShape:
        ...

    @property
    def as_i_picture_frame(self) -> IPictureFrame:
        ...

    ...

class AutoShape(GeometryShape):
    '''Represents an AutoShape.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    def get_geometry_paths(self) -> List[IGeometryPath]:
        '''Returns the copy of path of the geometry shape. Coordinates are relative to the left top corner of the shape.
        :returns: Array of :py:class:`aspose.slides.IGeometryPath`'''
        ...

    def set_geometry_path(self, geometry_path: IGeometryPath) -> None:
        '''Updates shape geometry from :py:class:`aspose.slides.IGeometryPath` object. Coordinates must be relative to the left
                     top corner of the shape.
                     Changes the type of the shape (:py:attr:`aspose.slides.GeometryShape.shape_type`) to :py:attr:`aspose.slides.ShapeType.CUSTOM`.
        :param geometry_path: Geometry path'''
        ...

    def set_geometry_paths(self, geometry_paths: List[IGeometryPath]) -> None:
        '''Updates shape geometry from array of :py:class:`aspose.slides.IGeometryPath`. Coordinates must be relative to the left
                     top corner of the shape.
                     Changes the type of the shape (:py:attr:`aspose.slides.GeometryShape.shape_type`) to :py:attr:`aspose.slides.ShapeType.CUSTOM`.
        :param geometry_paths: Array geometry paths'''
        ...

    def create_shape_elements(self) -> List[IShapeElement]:
        '''Creates and returns array of shape's elements.
        :returns: Array of :py:class:`aspose.slides.ShapeElement`'''
        ...

    def add_text_frame(self, text: string) -> ITextFrame:
        '''Adds a new TextFrame to a shape.
                    If shape already has TextFrame then simply changes its text.
        :param text: Default text for a new TextFrame.'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IAutoShapeLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def shape_style(self) -> IShapeStyle:
        ...

    @property
    def shape_type(self) -> ShapeType:
        ...

    @shape_type.setter
    def shape_type(self, value: ShapeType):
        ...

    @property
    def adjustments(self) -> IAdjustValueCollection:
        ...

    @property
    def auto_shape_lock(self) -> IAutoShapeLock:
        ...

    @property
    def text_frame(self) -> ITextFrame:
        ...

    @property
    def use_background_fill(self) -> bool:
        ...

    @use_background_fill.setter
    def use_background_fill(self, value: bool):
        ...

    @property
    def is_text_box(self) -> bool:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def as_i_geometry_shape(self) -> IGeometryShape:
        ...

    ...

class AutoShapeLock(BaseShapeLock):
    '''Determines which operations are disabled on the parent AutoshapeEx.'''
    @property
    def no_locks(self) -> bool:
        ...

    @property
    def grouping_locked(self) -> bool:
        ...

    @grouping_locked.setter
    def grouping_locked(self, value: bool):
        ...

    @property
    def select_locked(self) -> bool:
        ...

    @select_locked.setter
    def select_locked(self, value: bool):
        ...

    @property
    def rotate_locked(self) -> bool:
        ...

    @rotate_locked.setter
    def rotate_locked(self, value: bool):
        ...

    @property
    def aspect_ratio_locked(self) -> bool:
        ...

    @aspect_ratio_locked.setter
    def aspect_ratio_locked(self, value: bool):
        ...

    @property
    def position_locked(self) -> bool:
        ...

    @position_locked.setter
    def position_locked(self, value: bool):
        ...

    @property
    def size_locked(self) -> bool:
        ...

    @size_locked.setter
    def size_locked(self, value: bool):
        ...

    @property
    def edit_points_locked(self) -> bool:
        ...

    @edit_points_locked.setter
    def edit_points_locked(self, value: bool):
        ...

    @property
    def adjust_handles_locked(self) -> bool:
        ...

    @adjust_handles_locked.setter
    def adjust_handles_locked(self, value: bool):
        ...

    @property
    def arrowheads_locked(self) -> bool:
        ...

    @arrowheads_locked.setter
    def arrowheads_locked(self, value: bool):
        ...

    @property
    def shape_type_locked(self) -> bool:
        ...

    @shape_type_locked.setter
    def shape_type_locked(self, value: bool):
        ...

    @property
    def text_locked(self) -> bool:
        ...

    @text_locked.setter
    def text_locked(self, value: bool):
        ...

    @property
    def as_i_base_shape_lock(self) -> IBaseShapeLock:
        ...

    ...

class Backdrop3DScene(PVIObject):
    '''Defines a plane in which effects, such as glow and shadow, are applied in relation to the shape they are being applied to.'''
    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def normal_vector(self) -> List[float]:
        ...

    @normal_vector.setter
    def normal_vector(self, value: List[float]):
        ...

    @property
    def anchor_point(self) -> List[float]:
        ...

    @anchor_point.setter
    def anchor_point(self, value: List[float]):
        ...

    @property
    def up_vector(self) -> List[float]:
        ...

    @up_vector.setter
    def up_vector(self, value: List[float]):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class Background(PVIObject):
    '''Represents background of a slide.'''
    def get_effective(self) -> IBackgroundEffectiveData:
        '''Gets effective background data with the inheritance applied.
        :returns: A :py:class:`aspose.slides.IBackgroundEffectiveData`.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def type(self) -> BackgroundType:
        ...

    @type.setter
    def type(self, value: BackgroundType):
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def style_color(self) -> IColorFormat:
        ...

    @property
    def style_index(self) -> int:
        ...

    @style_index.setter
    def style_index(self, value: int):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class BaseHandoutNotesSlideHeaderFooterManager(BaseSlideHeaderFooterManager):
    '''Represents manager which holds behavior of the placeholders, including header placeholder for all types handout and notes slides.'''
    def set_footer_visibility(self, is_visible: bool) -> None:
        '''Changes slide footer placeholder visibility.
        :param is_visible: true - makes a footer placeholder visible, otherwise - hides it.'''
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        '''Changes slide page number placeholder visibility.
        :param is_visible: true - makes a page number placeholder visible, otherwise - hides it.'''
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        '''Changes slide date-time placeholder visibility.
        :param is_visible: true - makes a date-time placeholder visible, otherwise - hides it.'''
        ...

    def set_footer_text(self, text: string) -> None:
        '''Sets text to slide footer placeholder.
        :param text: Text to set.'''
        ...

    def set_date_time_text(self, text: string) -> None:
        '''Sets text to slide date-time placeholder.
        :param text: Text to set.'''
        ...

    def set_header_visibility(self, is_visible: bool) -> None:
        '''Changes slide header placeholder visibility.
        :param is_visible: true - makes a header placeholder visible, otherwise - hides it.'''
        ...

    def set_header_text(self, text: string) -> None:
        '''Sets text to slide header placeholder.
        :param text: Text to set.'''
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def is_header_visible(self) -> bool:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class BaseHeaderFooterManager:
    '''Represents manager which holds behavior of the footer, date-time, page number placeholders for all slide types.'''
    ...

class BasePortionFormat(PVIObject):
    '''Common text portion formatting properties.'''
    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def highlight_color(self) -> IColorFormat:
        ...

    @property
    def underline_line_format(self) -> ILineFormat:
        ...

    @property
    def underline_fill_format(self) -> IFillFormat:
        ...

    @property
    def font_bold(self) -> NullableBool:
        ...

    @font_bold.setter
    def font_bold(self, value: NullableBool):
        ...

    @property
    def font_italic(self) -> NullableBool:
        ...

    @font_italic.setter
    def font_italic(self, value: NullableBool):
        ...

    @property
    def kumimoji(self) -> NullableBool:
        ...

    @kumimoji.setter
    def kumimoji(self, value: NullableBool):
        ...

    @property
    def normalise_height(self) -> NullableBool:
        ...

    @normalise_height.setter
    def normalise_height(self, value: NullableBool):
        ...

    @property
    def proof_disabled(self) -> NullableBool:
        ...

    @proof_disabled.setter
    def proof_disabled(self, value: NullableBool):
        ...

    @property
    def font_underline(self) -> TextUnderlineType:
        ...

    @font_underline.setter
    def font_underline(self, value: TextUnderlineType):
        ...

    @property
    def text_cap_type(self) -> TextCapType:
        ...

    @text_cap_type.setter
    def text_cap_type(self, value: TextCapType):
        ...

    @property
    def strikethrough_type(self) -> TextStrikethroughType:
        ...

    @strikethrough_type.setter
    def strikethrough_type(self, value: TextStrikethroughType):
        ...

    @property
    def is_hard_underline_line(self) -> NullableBool:
        ...

    @is_hard_underline_line.setter
    def is_hard_underline_line(self, value: NullableBool):
        ...

    @property
    def is_hard_underline_fill(self) -> NullableBool:
        ...

    @is_hard_underline_fill.setter
    def is_hard_underline_fill(self, value: NullableBool):
        ...

    @property
    def font_height(self) -> float:
        ...

    @font_height.setter
    def font_height(self, value: float):
        ...

    @property
    def latin_font(self) -> IFontData:
        ...

    @latin_font.setter
    def latin_font(self, value: IFontData):
        ...

    @property
    def east_asian_font(self) -> IFontData:
        ...

    @east_asian_font.setter
    def east_asian_font(self, value: IFontData):
        ...

    @property
    def complex_script_font(self) -> IFontData:
        ...

    @complex_script_font.setter
    def complex_script_font(self, value: IFontData):
        ...

    @property
    def symbol_font(self) -> IFontData:
        ...

    @symbol_font.setter
    def symbol_font(self, value: IFontData):
        ...

    @property
    def escapement(self) -> float:
        ...

    @escapement.setter
    def escapement(self, value: float):
        ...

    @property
    def kerning_minimal_size(self) -> float:
        ...

    @kerning_minimal_size.setter
    def kerning_minimal_size(self, value: float):
        ...

    @property
    def language_id(self) -> string:
        ...

    @language_id.setter
    def language_id(self, value: string):
        ...

    @property
    def alternative_language_id(self) -> string:
        ...

    @alternative_language_id.setter
    def alternative_language_id(self, value: string):
        ...

    @property
    def spacing(self) -> float:
        ...

    @spacing.setter
    def spacing(self, value: float):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class BaseShapeLock:
    '''Represents a base class for locks (disabled operation).'''
    @property
    def no_locks(self) -> bool:
        ...

    ...

class BaseSlide:
    '''Represents common data for all slide types.'''
    @overload
    def join_portions_with_same_formatting(self) -> None:
        '''Joins runs with same formatting in all paragraphs all acceptable shapes.'''
        ...

    @overload
    def join_portions_with_same_formatting(self, collection: IShapeCollection) -> None:
        '''Joins runs with same formatting in all paragraphs in all acceptable shapes.'''
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        '''Determines whether the two IBaseSlide instances are equal.
                    Returning value is calculated based on slide's structure and static content.
                    Two slides are equal if all shapes, styles, texts, animation and other settings. etc. are equal. The comparison doesn't take into account unique identifier values, e.g. SlideId and dynamic content, e.g. current date value in Date Placeholder.
        :param slide: The IBaseSlide to compare with the current IBaseSlide.
        :returns: **true** if the specified IBaseSlide is equal to the current IBaseSlide; 
                    otherwise, **false**.'''
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        '''Returns an effective theme for this slide.'''
        ...

    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        '''Finds first occurrence of a shape with the specified alternative text.
        :param alt_text: Alternative text.
        :returns: Shape object or null.'''
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_themeable(self) -> aspose.slides.theme.IThemeable:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    ...

class BaseSlideHeaderFooterManager(BaseHeaderFooterManager):
    '''Represents manager which holds behavior of the footer, date-time, page number placeholders for all slide types.'''
    def set_footer_visibility(self, is_visible: bool) -> None:
        '''Changes slide footer placeholder visibility.
        :param is_visible: true - makes a footer placeholder visible, otherwise - hides it.'''
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        '''Changes slide page number placeholder visibility.
        :param is_visible: true - makes a page number placeholder visible, otherwise - hides it.'''
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        '''Changes slide date-time placeholder visibility.
        :param is_visible: true - makes a date-time placeholder visible, otherwise - hides it.'''
        ...

    def set_footer_text(self, text: string) -> None:
        '''Sets text to slide footer placeholder.
        :param text: Text to set.'''
        ...

    def set_date_time_text(self, text: string) -> None:
        '''Sets text to slide date-time placeholder.
        :param text: Text to set.'''
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    ...

class BlobManagementOptions:
    '''Represents options which can be used to manage BLOB handling rules and other BLOB settings.'''
    def __init__(self):
        '''Creates new default blob management options.'''
        ...

    @property
    def presentation_locking_behavior(self) -> PresentationLockingBehavior:
        ...

    @presentation_locking_behavior.setter
    def presentation_locking_behavior(self, value: PresentationLockingBehavior):
        ...

    @property
    def is_temporary_files_allowed(self) -> bool:
        ...

    @is_temporary_files_allowed.setter
    def is_temporary_files_allowed(self, value: bool):
        ...

    @property
    def temp_files_root_path(self) -> string:
        ...

    @temp_files_root_path.setter
    def temp_files_root_path(self, value: string):
        ...

    @property
    def max_blobs_bytes_in_memory(self) -> int:
        ...

    @max_blobs_bytes_in_memory.setter
    def max_blobs_bytes_in_memory(self, value: int):
        ...

    ...

class BrowsedAtKiosk(SlideShowType):
    '''Browsed at a kiosk (full screen)'''
    def __init__(self):
        '''Initializes a new instance of the BrowsedAtKiosk class.'''
        ...

    ...

class BrowsedByIndividual(SlideShowType):
    '''Browsed by individual (window)'''
    def __init__(self):
        '''Initializes a new instance of the BrowsedByIndividual class.'''
        ...

    @property
    def show_scrollbar(self) -> bool:
        ...

    @show_scrollbar.setter
    def show_scrollbar(self, value: bool):
        ...

    ...

class BuildVersionInfo:
    '''Contains information about version of Aspose.Slides.'''
    @classmethod
    @property
    def ASSEMBLY_VERSION(cls) -> string:
        ...

    @classmethod
    @property
    def FILE_VERSION(cls) -> string:
        ...

    @classmethod
    @property
    def PRODUCT(cls) -> string:
        ...

    @classmethod
    @property
    def PRODUCT_MAJOR(cls) -> int:
        ...

    @classmethod
    @property
    def PRODUCT_MINOR(cls) -> int:
        ...

    @classmethod
    @property
    def RELEASE_DATE(cls) -> DateTime:
        ...

    ...

class BulletFormat(PVIObject):
    '''Represents paragraph bullet formatting properties.'''
    def apply_default_paragraph_indents_shifts(self) -> None:
        '''Sets default non-zero shifts for effective paragraph Indent and MarginLeft when bullets is enabled (like PowerPoint do if enable paragraph bullets/numbering in it). If bullets is disabled then just reset paragraph Indent and MarginLeft (like PowerPoint do if disable paragraph bullets/numbering in it). Indents shifts are applied in regard to current bullet context - IBulletFormat.Type, .NumberedBulletStyle and FontHeight of first portion. Non-zero indents shifts are applied to effective Indent and MarginLeft of current paragraph (make result values to be local values).'''
        ...

    def get_effective(self) -> IBulletFormatEffectiveData:
        '''Gets effective bullet formatting data with the inheritance applied.
        :returns: A :py:class:`aspose.slides.IBulletFormatEffectiveData`.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def type(self) -> BulletType:
        ...

    @type.setter
    def type(self, value: BulletType):
        ...

    @property
    def char(self) -> char:
        ...

    @char.setter
    def char(self, value: char):
        ...

    @property
    def font(self) -> IFontData:
        ...

    @font.setter
    def font(self, value: IFontData):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def color(self) -> IColorFormat:
        ...

    @property
    def numbered_bullet_start_with(self) -> int:
        ...

    @numbered_bullet_start_with.setter
    def numbered_bullet_start_with(self, value: int):
        ...

    @property
    def numbered_bullet_style(self) -> NumberedBulletStyle:
        ...

    @numbered_bullet_style.setter
    def numbered_bullet_style(self, value: NumberedBulletStyle):
        ...

    @property
    def is_bullet_hard_color(self) -> NullableBool:
        ...

    @is_bullet_hard_color.setter
    def is_bullet_hard_color(self, value: NullableBool):
        ...

    @property
    def is_bullet_hard_font(self) -> NullableBool:
        ...

    @is_bullet_hard_font.setter
    def is_bullet_hard_font(self, value: NullableBool):
        ...

    @property
    def picture(self) -> ISlidesPicture:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class Camera(PVIObject):
    '''Represents Camera.'''
    def set_rotation(self, latitude: float, longitude: float, revolution: float) -> None:
        '''A rotation is defined through the use of a latitude
                    coordinate, a longitude coordinate, and a revolution about the axis 
                    as the latitude and longitude coordinates.
                    If any of coordinate value is float.NaN, all rotation is undefined.'''
        ...

    def get_rotation(self) -> List[float]:
        '''A rotation is defined through the use of a latitude
                    coordinate, a longitude coordinate, and a revolution about the axis 
                    as the latitude and longitude coordinates.
                    first element in return array - latitude, second - longitude, third - revolution.
                    Returns null if no rotation defined.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def camera_type(self) -> CameraPresetType:
        ...

    @camera_type.setter
    def camera_type(self, value: CameraPresetType):
        ...

    @property
    def field_of_view_angle(self) -> float:
        ...

    @field_of_view_angle.setter
    def field_of_view_angle(self, value: float):
        ...

    @property
    def zoom(self) -> float:
        ...

    @zoom.setter
    def zoom(self, value: float):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class Cell:
    '''Represents a cell of a table.'''
    def split_by_col_span(self, index: int) -> None:
        '''Splits the cell to two cells by index of column.
        :param index: Index of column.'''
        ...

    def split_by_row_span(self, index: int) -> None:
        '''Splits the cell to two cells by index of row.
        :param index: Index of row.'''
        ...

    def split_by_height(self, height: float) -> None:
        '''Splits the cell by height.
        :param height: Height of a row.'''
        ...

    def split_by_width(self, width: float) -> None:
        '''Splits the cell by width.
        :param width: Width of a column.'''
        ...

    @property
    def offset_x(self) -> float:
        ...

    @property
    def offset_y(self) -> float:
        ...

    @property
    def first_row_index(self) -> int:
        ...

    @property
    def first_column_index(self) -> int:
        ...

    @property
    def width(self) -> float:
        ...

    @property
    def height(self) -> float:
        ...

    @property
    def minimal_height(self) -> float:
        ...

    @property
    def margin_left(self) -> float:
        ...

    @margin_left.setter
    def margin_left(self, value: float):
        ...

    @property
    def margin_right(self) -> float:
        ...

    @margin_right.setter
    def margin_right(self, value: float):
        ...

    @property
    def margin_top(self) -> float:
        ...

    @margin_top.setter
    def margin_top(self, value: float):
        ...

    @property
    def margin_bottom(self) -> float:
        ...

    @margin_bottom.setter
    def margin_bottom(self, value: float):
        ...

    @property
    def text_vertical_type(self) -> TextVerticalType:
        ...

    @text_vertical_type.setter
    def text_vertical_type(self, value: TextVerticalType):
        ...

    @property
    def text_anchor_type(self) -> TextAnchorType:
        ...

    @text_anchor_type.setter
    def text_anchor_type(self, value: TextAnchorType):
        ...

    @property
    def anchor_center(self) -> bool:
        ...

    @anchor_center.setter
    def anchor_center(self, value: bool):
        ...

    @property
    def first_row(self) -> IRow:
        ...

    @property
    def first_column(self) -> IColumn:
        ...

    @property
    def col_span(self) -> int:
        ...

    @property
    def row_span(self) -> int:
        ...

    @property
    def text_frame(self) -> ITextFrame:
        ...

    @property
    def table(self) -> ITable:
        ...

    @property
    def is_merged_cell(self) -> bool:
        ...

    @property
    def cell_format(self) -> ICellFormat:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    ...

class CellCollection:
    '''Represents a collection of cells.'''
    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ICell
        '''Returns a cell by it's position.
                    Read-only :py:class:`aspose.slides.Cell`.'''
        ...

    ...

class CellFormat(PVIObject):
    '''Represents format of a table cell.'''
    def get_effective(self) -> ICellFormatEffectiveData:
        '''Gets effective table cell formatting properties with inheritance and table styles applied.
        :returns: A :py:class:`aspose.slides.ICellFormatEffectiveData`.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def border_left(self) -> ILineFormat:
        ...

    @property
    def border_top(self) -> ILineFormat:
        ...

    @property
    def border_right(self) -> ILineFormat:
        ...

    @property
    def border_bottom(self) -> ILineFormat:
        ...

    @property
    def border_diagonal_down(self) -> ILineFormat:
        ...

    @property
    def border_diagonal_up(self) -> ILineFormat:
        ...

    @property
    def transparency(self) -> float:
        ...

    @transparency.setter
    def transparency(self, value: float):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class ColorFormat(PVIObject):
    '''Represents a color used in a presentation.'''
    def to_string(self, format: ColorStringFormat) -> string:
        '''Returns a :py:class:`System.String` that represents the current color format.
        :param format: A type of color string format.
        :returns: A string that represents the current color format.'''
        ...

    def copy_from(self, color: IColorFormat) -> None:
        '''Copy color format from "color".'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def color_type(self) -> ColorType:
        ...

    @color_type.setter
    def color_type(self, value: ColorType):
        ...

    @property
    def color(self) -> aspose.pydrawing.Color:
        ...

    @color.setter
    def color(self, value: aspose.pydrawing.Color):
        ...

    @property
    def preset_color(self) -> PresetColor:
        ...

    @preset_color.setter
    def preset_color(self, value: PresetColor):
        ...

    @property
    def system_color(self) -> SystemColor:
        ...

    @system_color.setter
    def system_color(self, value: SystemColor):
        ...

    @property
    def scheme_color(self) -> SchemeColor:
        ...

    @scheme_color.setter
    def scheme_color(self, value: SchemeColor):
        ...

    @property
    def r(self) -> int:
        ...

    @r.setter
    def r(self, value: int):
        ...

    @property
    def g(self) -> int:
        ...

    @g.setter
    def g(self, value: int):
        ...

    @property
    def b(self) -> int:
        ...

    @b.setter
    def b(self, value: int):
        ...

    @property
    def float_r(self) -> float:
        ...

    @float_r.setter
    def float_r(self, value: float):
        ...

    @property
    def float_g(self) -> float:
        ...

    @float_g.setter
    def float_g(self, value: float):
        ...

    @property
    def float_b(self) -> float:
        ...

    @float_b.setter
    def float_b(self, value: float):
        ...

    @property
    def hue(self) -> float:
        ...

    @hue.setter
    def hue(self, value: float):
        ...

    @property
    def saturation(self) -> float:
        ...

    @saturation.setter
    def saturation(self, value: float):
        ...

    @property
    def luminance(self) -> float:
        ...

    @luminance.setter
    def luminance(self, value: float):
        ...

    @property
    def color_transform(self) -> IColorOperationCollection:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class ColorOperation:
    '''Represents different color operations used for color transformations.
                Immutable object.'''
    def __init__(self, op: ColorTransformOperation):
        '''Creates new color transform operation.
        :param op: Operation type.'''
        ...

    def __init__(self, op: ColorTransformOperation, parameter: float):
        '''Creates new color transform operation.
        :param op: Operation type.
        :param parameter: Operation parameter.'''
        ...

    @property
    def operation_type(self) -> ColorTransformOperation:
        ...

    @property
    def parameter(self) -> float:
        ...

    ...

class ColorOperationCollection:
    '''Represents a collection of color transform operations.'''
    @overload
    def add(self, operation: ColorTransformOperation, parameter: float) -> IColorOperation:
        '''Adds a new operation to the end of collection.
        :param operation: Operation type.
        :param parameter: Operation's parameter.
        :returns: Added operation.'''
        ...

    @overload
    def add(self, operation: ColorTransformOperation) -> IColorOperation:
        '''Adds a new operation to the end of collection.
        :param operation: Operation type.
        :returns: Added operation.'''
        ...

    @overload
    def insert(self, position: int, operation: ColorTransformOperation, parameter: float) -> IColorOperation:
        '''Inserts the new operation to a collection.
        :param position: The index at which the operation will be inserted.
        :param operation: Operation type.
        :param parameter: Operation's parameter.
        :returns: Inserted operation.'''
        ...

    @overload
    def insert(self, position: int, operation: ColorTransformOperation) -> IColorOperation:
        '''Inserts the new operation to a collection.
        :param position: The index at which the operation will be inserted.
        :param operation: Operation type.
        :returns: Inserted operation.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the color operation from a collection.
        :param index: Index of a color operation to remove.'''
        ...

    def clear(self) -> None:
        '''Removes all color operations.'''
        ...

    def clone(self) -> any:
        '''Creates a copy of a ColorOperationCollection collection.
        :returns: New :py:class:`aspose.slides.ColorOperationCollection` collection.'''
        ...

    def clone_t(self) -> IColorOperationCollection:
        '''Clones current object
        :returns: Clone'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IColorOperation
        '''Returns or sets the operation at the specified index.
                    Read/write :py:class:`aspose.slides.ColorOperation`.'''
        ...

    def __setitem__(self, key: int, value: IColorOperation
        ...

    ...

class Column(CellCollection):
    '''Represents a column in a table.'''
    @overload
    def set_text_format(self, source: IPortionFormat) -> None:
        '''Sets defined portion format properties to all column cells' portions.
        :param source: IPortionFormat object with necessary properties set.'''
        ...

    @overload
    def set_text_format(self, source: IParagraphFormat) -> None:
        '''Sets defined paragraph format properties to all column cells' paragraphs.
        :param source: IParagraphFormat object with necessary properties set.'''
        ...

    @overload
    def set_text_format(self, source: ITextFrameFormat) -> None:
        '''Sets defined text frame format properties to all column cells' text frames.
        :param source: ITextFrameFormat object with necessary properties set.'''
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def column_format(self) -> IColumnFormat:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    @property
    def as_i_cell_collection(self) -> ICellCollection:
        ...

    @property
    def as_i_bulk_text_formattable(self) -> IBulkTextFormattable:
        ...

    def __getitem__(self, key: int) -> ICell
        ...

    ...

class ColumnCollection:
    '''Represents collection of columns in a table.'''
    def add_clone(self, templ: IColumn, with_attached_columns: bool) -> List[IColumn]:
        '''Creates a copy of the specified template row and inserts it at the bottom of a table.
        :param templ: Column which is used as a template.
        :param with_attached_columns: True to copy also all columns attached to the template row.
        :returns: Added columns.'''
        ...

    def insert_clone(self, index: int, templ: IColumn, with_attached_columns: bool) -> List[IColumn]:
        '''Creates a copy of the specified template column and insert it at the specified position in a table.
        :param index: Index of a new column.
        :param templ: Column which is used as a template.
        :param with_attached_columns: True to copy also all columns attached to the template column.
        :returns: Inserted columns.'''
        ...

    def remove_at(self, first_column_index: int, with_attached_rows: bool) -> None:
        '''Removes a column at the specified position from a table.
        :param first_column_index: Index of a column to delete.
        :param with_attached_rows: True to delete also all attached columns.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IColumn
        '''Returns the column at the specified index.
                    Read-only :py:class:`aspose.slides.Column`.'''
        ...

    ...

class ColumnFormat:
    '''Represents format of a table column.'''
    def get_effective(self) -> IColumnFormatEffectiveData:
        '''Gets effective table column formatting properties with inheritance and table styles applied.
        :returns: A :py:class:`aspose.slides.IColumnFormatEffectiveData`.'''
        ...

    ...

class Comment:
    '''Represents a comment on a slide.'''
    def remove(self) -> None:
        '''Removes comment and all its replies from the parent collection.'''
        ...

    @property
    def text(self) -> string:
        ...

    @text.setter
    def text(self, value: string):
        ...

    @property
    def created_time(self) -> DateTime:
        ...

    @created_time.setter
    def created_time(self, value: DateTime):
        ...

    @property
    def slide(self) -> ISlide:
        ...

    @property
    def author(self) -> ICommentAuthor:
        ...

    @property
    def position(self) -> aspose.pydrawing.PointF:
        ...

    @position.setter
    def position(self, value: aspose.pydrawing.PointF):
        ...

    @property
    def parent_comment(self) -> IComment:
        ...

    @parent_comment.setter
    def parent_comment(self, value: IComment):
        ...

    ...

class CommentAuthor:
    '''Represents an author of comments.'''
    def remove(self) -> None:
        '''Removes the author from the parent collection.'''
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def initials(self) -> string:
        ...

    @initials.setter
    def initials(self, value: string):
        ...

    @property
    def comments(self) -> ICommentCollection:
        ...

    ...

class CommentAuthorCollection:
    '''Represents a collection of comment authors.'''
    def add_author(self, name: string, initials: string) -> ICommentAuthor:
        '''Add new author at the end of a collection.
        :param name: Name of a new author.
        :param initials: Initials of a new author.
        :returns: New :py:class:`aspose.slides.ICommentAuthor` object.'''
        ...

    def to_array(self) -> List[ICommentAuthor]:
        '''Creates and returns an array with all authors.
        :returns: Array of :py:class:`aspose.slides.ICommentAuthor`'''
        ...

    def find_by_name(self, name: string) -> List[ICommentAuthor]:
        '''Find author in a collection by name.
        :param name: Name of an author to find.
        :returns: Author or null.'''
        ...

    def find_by_name_and_initials(self, name: string, initials: string) -> List[ICommentAuthor]:
        '''Find author in a collection by name and initials.
        :param name: Name of an author to find.
        :param initials: Initials of an author to find.
        :returns: Author or null.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the author at the specified index of the collection.
        :param index: The zero-based index of the element to remove.'''
        ...

    def remove(self, author: ICommentAuthor) -> None:
        '''Removes the first occurrence of the specified author in a collection.
        :param author: The author to remove from a collection.'''
        ...

    def clear(self) -> None:
        '''Removes all authors from a collection.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ICommentAuthor
        '''Gets the element at the specified index.
                    Read-only :py:class:`aspose.slides.ICommentAuthor`.'''
        ...

    ...

class CommentCollection:
    '''Represents a collection of comments of one author.'''
    @overload
    def to_array(self) -> List[IComment]:
        '''Creates and returns an array with all comments.
        :returns: Array of :py:class:`aspose.slides.Comment`.'''
        ...

    @overload
    def to_array(self, start_index: int, count: int) -> List[IComment]:
        '''Creates and returns an array with all comments from the specified range.
        :param start_index: An index of a first comment to return.
        :param count: A number of comments to return.
        :returns: Array of :py:class:`aspose.slides.Comment`.'''
        ...

    def add_comment(self, text: string, slide: ISlide, position: aspose.pydrawing.PointF, creation_time: DateTime) -> IComment:
        '''Add new comment at the end of a collection.
        :param text: Plain text of a new comment.
        :param slide: Slide in a presentation where to add a new comment.
        :param position: Position on a slide where to add a new comment.
        :param creation_time: Time of a comment creation.
        :returns: Added comment.'''
        ...

    def add_modern_comment(self, text: string, slide: ISlide, shape: IShape, position: aspose.pydrawing.PointF, creation_time: DateTime) -> IModernComment:
        '''Add new modern comment at the end of a collection.
        :param text: Plain text of a new modern comment.
        :param slide: Slide in a presentation where to add a new modern comment.
        :param shape: Shape on a slide to which a new modern comment is associated.
        :param position: Position on a slide where to add a new modern comment.
        :param creation_time: Time of a modern comment creation.
        :returns: Added modern comment.'''
        ...

    def insert_comment(self, index: int, text: string, slide: ISlide, position: aspose.pydrawing.PointF, creation_time: DateTime) -> IComment:
        '''Insert new comment to a collection at the specified index.
        :param index: Index of the element in a collection at which comment should be inserted.
        :param text: Plain text of a new comment.
        :param slide: Slide in a presentation where to add a new comment.
        :param position: Position on a slide where to add a new comment.
        :param creation_time: Time of a comment creation.
        :returns: Inserted comment.'''
        ...

    def insert_modern_comment(self, index: int, text: string, slide: ISlide, shape: IShape, position: aspose.pydrawing.PointF, creation_time: DateTime) -> IModernComment:
        '''Insert new modern comment to a collection at the specified index.
        :param index: Index of the element in a collection at which modern comment should be inserted.
        :param text: Plain text of a new modern comment.
        :param slide: Slide in a presentation where to add a new modern comment.
        :param shape: Shape on a slide to which a new modern comment is associated.
        :param position: Position on a slide where to add a new modern comment.
        :param creation_time: Time of a modern comment creation.
        :returns: Inserted modern comment.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the element at the specified index in a collection.
        :param index: The zero-based index of the element to remove.'''
        ...

    def remove(self, comment: IComment) -> None:
        '''Removes the first occurrence of the specified comment in a collection.
        :param comment: The comment to remove from a collection.'''
        ...

    def clear(self) -> None:
        '''Removes all comments from a collection.'''
        ...

    def find_comment_by_idx(self, idx: int) -> IComment:
        '''Finds a comment in the collection by index.
        :param idx: Unique index of a comment to find :py:class:`int`.
        :returns: Found comment or null :py:class:`aspose.slides.IComment`.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IComment
        '''Gets the element at the specified index.
                    Read-only :py:class:`aspose.slides.Comment`.'''
        ...

    ...

class CommonSlideViewProperties:
    '''Represents common slide view properties.'''
    @property
    def scale(self) -> int:
        ...

    @scale.setter
    def scale(self, value: int):
        ...

    @property
    def variable_scale(self) -> bool:
        ...

    @variable_scale.setter
    def variable_scale(self, value: bool):
        ...

    ...

class Connector(GeometryShape):
    '''Represents a connector.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    def get_geometry_paths(self) -> List[IGeometryPath]:
        '''Returns the copy of path of the geometry shape. Coordinates are relative to the left top corner of the shape.
        :returns: Array of :py:class:`aspose.slides.IGeometryPath`'''
        ...

    def set_geometry_path(self, geometry_path: IGeometryPath) -> None:
        '''Updates shape geometry from :py:class:`aspose.slides.IGeometryPath` object. Coordinates must be relative to the left
                     top corner of the shape.
                     Changes the type of the shape (:py:attr:`aspose.slides.GeometryShape.shape_type`) to :py:attr:`aspose.slides.ShapeType.CUSTOM`.
        :param geometry_path: Geometry path'''
        ...

    def set_geometry_paths(self, geometry_paths: List[IGeometryPath]) -> None:
        '''Updates shape geometry from array of :py:class:`aspose.slides.IGeometryPath`. Coordinates must be relative to the left
                     top corner of the shape.
                     Changes the type of the shape (:py:attr:`aspose.slides.GeometryShape.shape_type`) to :py:attr:`aspose.slides.ShapeType.CUSTOM`.
        :param geometry_paths: Array geometry paths'''
        ...

    def create_shape_elements(self) -> List[IShapeElement]:
        '''Creates and returns array of shape's elements.
        :returns: Array of :py:class:`aspose.slides.ShapeElement`'''
        ...

    def reroute(self) -> None:
        '''Reroutes connector so that it take the shortest possible path between the shapes it connect.'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IConnectorLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def shape_style(self) -> IShapeStyle:
        ...

    @property
    def shape_type(self) -> ShapeType:
        ...

    @shape_type.setter
    def shape_type(self, value: ShapeType):
        ...

    @property
    def adjustments(self) -> IAdjustValueCollection:
        ...

    @property
    def connector_lock(self) -> IConnectorLock:
        ...

    @property
    def start_shape_connected_to(self) -> IShape:
        ...

    @start_shape_connected_to.setter
    def start_shape_connected_to(self, value: IShape):
        ...

    @property
    def end_shape_connected_to(self) -> IShape:
        ...

    @end_shape_connected_to.setter
    def end_shape_connected_to(self, value: IShape):
        ...

    @property
    def start_shape_connection_site_index(self) -> int:
        ...

    @start_shape_connection_site_index.setter
    def start_shape_connection_site_index(self, value: int):
        ...

    @property
    def end_shape_connection_site_index(self) -> int:
        ...

    @end_shape_connection_site_index.setter
    def end_shape_connection_site_index(self, value: int):
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def as_i_geometry_shape(self) -> IGeometryShape:
        ...

    ...

class ConnectorLock(BaseShapeLock):
    '''Determines which operations are disabled on the parent Connector.'''
    @property
    def no_locks(self) -> bool:
        ...

    @property
    def grouping_locked(self) -> bool:
        ...

    @grouping_locked.setter
    def grouping_locked(self, value: bool):
        ...

    @property
    def select_locked(self) -> bool:
        ...

    @select_locked.setter
    def select_locked(self, value: bool):
        ...

    @property
    def rotate_locked(self) -> bool:
        ...

    @rotate_locked.setter
    def rotate_locked(self, value: bool):
        ...

    @property
    def aspect_ratio_locked(self) -> bool:
        ...

    @aspect_ratio_locked.setter
    def aspect_ratio_locked(self, value: bool):
        ...

    @property
    def position_move(self) -> bool:
        ...

    @position_move.setter
    def position_move(self, value: bool):
        ...

    @property
    def size_locked(self) -> bool:
        ...

    @size_locked.setter
    def size_locked(self, value: bool):
        ...

    @property
    def edit_points_locked(self) -> bool:
        ...

    @edit_points_locked.setter
    def edit_points_locked(self, value: bool):
        ...

    @property
    def adjust_handles_locked(self) -> bool:
        ...

    @adjust_handles_locked.setter
    def adjust_handles_locked(self, value: bool):
        ...

    @property
    def arrowheads_locked(self) -> bool:
        ...

    @arrowheads_locked.setter
    def arrowheads_locked(self, value: bool):
        ...

    @property
    def shape_type_locked(self) -> bool:
        ...

    @shape_type_locked.setter
    def shape_type_locked(self, value: bool):
        ...

    @property
    def as_i_base_shape_lock(self) -> IBaseShapeLock:
        ...

    ...

class Control:
    '''Represents an ActiveX control.'''
    @property
    def persistence(self) -> PersistenceType:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def class_id(self) -> Guid:
        ...

    @class_id.setter
    def class_id(self, value: Guid):
        ...

    @property
    def substitute_picture_format(self) -> IPictureFillFormat:
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def properties(self) -> IControlPropertiesCollection:
        ...

    @property
    def active_x_control_binary(self) -> bytes:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class ControlCollection:
    '''A collection of ActiveX controls.'''
    def add_control(self, control_type: ControlType, x: float, y: float, width: float, height: float) -> IControl:
        '''Creates and adds a new control to the collection.
        :param control_type: Type of a control to add.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param width: The width of shape's frame.
        :param height: The height of shape's frame.
        :returns: Created control.'''
        ...

    def remove(self, item: IControl) -> None:
        '''Removes an ActiveX control from the collection.
        :param item: A control to remove.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes an ActiveX control stored at specified position from the collection.
        :param index: Index of a control to remove.'''
        ...

    def clear(self) -> None:
        '''Removes all controls from the collection.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IControl
        '''Returns a control at the specified position.'''
        ...

    ...

class ControlPropertiesCollection:
    '''A collection of AcitveX properties.'''
    def add(self, name: string, value: string) -> None:
        '''Adds a property to the collection.
        :param name: The name of the property.
        :param value: The alue of the property.'''
        ...

    def remove(self, name: string) -> None:
        '''Removes a property with the specified name.
        :param name: The name of property to remove.'''
        ...

    def clear(self) -> None:
        '''Removes all properties.'''
        ...

    @property
    def names_of_properties(self) -> list:
        ...

    @property
    def count(self) -> int:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    ...

class CustomData:
    '''Represents container for custom data.'''
    @property
    def tags(self) -> ITagCollection:
        ...

    @property
    def custom_xml_parts(self) -> ICustomXmlPartCollection:
        ...

    ...

class CustomXmlPart:
    '''Represents custom xml part.'''
    def remove(self) -> None:
        '''Removes the custom xml part from the presentation.'''
        ...

    @property
    def xml_data(self) -> bytes:
        ...

    @xml_data.setter
    def xml_data(self, value: bytes):
        ...

    @property
    def xml_as_string(self) -> string:
        ...

    @xml_as_string.setter
    def xml_as_string(self, value: string):
        ...

    @property
    def item_id(self) -> Guid:
        ...

    @item_id.setter
    def item_id(self, value: Guid):
        ...

    @property
    def namespace_schemas(self) -> List[string]:
        ...

    ...

class CustomXmlPartCollection:
    '''Represents collection of custom xml parts.'''
    @overload
    def add(self, xml_string: string) -> ICustomXmlPart:
        '''Adds new custom xml part.
        :param xml_string: The xml string of new part to be added.
        :returns: Created custom xml part.'''
        ...

    @overload
    def add(self, xml_data: bytes) -> ICustomXmlPart:
        '''Adds new custom xml part.
        :param xml_data: The xml data of new part to be added.
        :returns: Created custom xml part.'''
        ...

    @overload
    def add(self, input_stream: System.IO.Stream) -> ICustomXmlPart:
        '''Adds new custom xml part.
        :param input_stream: The inputStream with xml data of new part to be added.
        :returns: Created custom xml part.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes custom xml part at the specified index.
        :param index: The zero-based index of the element to remove.'''
        ...

    def remove(self, item: ICustomXmlPart) -> bool:
        '''Removes the first occurrence of a specific object from the collection.
        :param item: The custom xml part to remove.
        :returns: ``true`` if item is successfully removed; otherwise, ``false``.'''
        ...

    def clear(self) -> None:
        '''Removes all items from the collection.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ICustomXmlPart
        '''Returns the element at the specified index.'''
        ...

    ...

class DigitalSignature:
    '''Digital signature in signed file.'''
    def __init__(self, certificate: System.Security.Cryptography.X509Certificates.X509Certificate2):
        '''Creates a new DigitalSignature object with the specified certificate.
        :param certificate: Certificate that will be used to sign the presentation.'''
        ...

    def __init__(self, file_path: string, password: string):
        '''Creates a new DigitalSignature object with the specified certificate file path and password.
        :param file_path: Path to the file with certificate.
        :param password: Password required to access certificate.'''
        ...

    @property
    def certificate(self) -> System.Security.Cryptography.X509Certificates.X509Certificate2:
        ...

    @property
    def is_valid(self) -> bool:
        ...

    @property
    def sign_time(self) -> DateTime:
        ...

    @property
    def comments(self) -> string:
        ...

    @comments.setter
    def comments(self, value: string):
        ...

    ...

class DigitalSignatureCollection:
    '''Represents a collection of digital signatures attached to a document.'''
    def add(self, signature: IDigitalSignature) -> None:
        '''Adds the signature at the end of collection.
        :param signature: Signature to add.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the signature at the specified index.
        :param index: Index of the signature that should be deleted.'''
        ...

    def clear(self) -> None:
        '''Removes all signatures from collection.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IDigitalSignature
        '''Returns the signature by index.'''
        ...

    ...

class DocumentProperties:
    '''Represents properties of a presentation.'''
    def __init__(self):
        '''Initializes new instance of class :py:class:`aspose.slides.DocumentProperties`.'''
        ...

    @overload
    def get_custom_property_value(self, name: string, value: Any) -> None:
        '''Gets a named boolean value from the custom properties.
        :param name: Name of the custom property to get
        :param value: Custom property value'''
        ...

    @overload
    def get_custom_property_value(self, name: string, value: Any) -> None:
        '''Gets a named integer value from the custom properties.
        :param name: Name of the custom property to get
        :param value: Custom property value'''
        ...

    @overload
    def get_custom_property_value(self, name: string, value: Any) -> None:
        '''Gets a named DateTime value from the custom properties.
        :param name: Name of the custom property to get
        :param value: Custom property value'''
        ...

    @overload
    def get_custom_property_value(self, name: string, value: Any) -> None:
        ...

    @overload
    def get_custom_property_value(self, name: string, value: Any) -> None:
        ...

    @overload
    def get_custom_property_value(self, name: string, value: Any) -> None:
        ...

    @overload
    def set_custom_property_value(self, name: string, value: bool) -> None:
        '''Sets a named boolean custom property.
        :param name: Name of the custom property to set
        :param value: Custom property value'''
        ...

    @overload
    def set_custom_property_value(self, name: string, value: int) -> None:
        '''Sets a named integer custom property.
        :param name: Name of the custom property to set
        :param value: Custom property value'''
        ...

    @overload
    def set_custom_property_value(self, name: string, value: DateTime) -> None:
        '''Sets a named DateTime custom property.
        :param name: Name of the custom property to set
        :param value: Custom property value'''
        ...

    @overload
    def set_custom_property_value(self, name: string, value: string) -> None:
        '''Sets a named string custom property.
        :param name: Name of the custom property to set
        :param value: Custom property value'''
        ...

    @overload
    def set_custom_property_value(self, name: string, value: float) -> None:
        '''Sets a named float custom property.
        :param name: Name of the custom property to set
        :param value: Custom property value'''
        ...

    @overload
    def set_custom_property_value(self, name: string, value: float) -> None:
        '''Sets a named double custom property.
        :param name: Name of the custom property to set
        :param value: Custom property value'''
        ...

    def get_custom_property_name(self, index: int) -> string:
        '''Return a custom property name at the specified index.
        :param index: The zero-based index of a custom property to get.
        :returns: Custom property name at the specified index.'''
        ...

    def remove_custom_property(self, name: string) -> bool:
        '''Remove a custom property associated with a specified name.
        :param name: Name of a custom property to remove.
        :returns: Return true if a property was removed, false overwise.'''
        ...

    def contains_custom_property(self, name: string) -> bool:
        '''Check presents of a custom property with a specified name.
        :param name: Name of a custom property to check.
        :returns: Return true if property exists, false overwise.'''
        ...

    def clear_custom_properties(self) -> None:
        '''Removes all custom properties.'''
        ...

    def clear_built_in_properties(self) -> None:
        '''Clears and sets default values for all builtIn properties.'''
        ...

    def clone(self) -> any:
        '''Clones current object
        :returns: Clone'''
        ...

    def clone_t(self) -> IDocumentProperties:
        '''Clones current object
        :returns: Clone'''
        ...

    @property
    def app_version(self) -> string:
        ...

    @property
    def name_of_application(self) -> string:
        ...

    @name_of_application.setter
    def name_of_application(self, value: string):
        ...

    @property
    def company(self) -> string:
        ...

    @company.setter
    def company(self, value: string):
        ...

    @property
    def manager(self) -> string:
        ...

    @manager.setter
    def manager(self, value: string):
        ...

    @property
    def presentation_format(self) -> string:
        ...

    @presentation_format.setter
    def presentation_format(self, value: string):
        ...

    @property
    def shared_doc(self) -> bool:
        ...

    @shared_doc.setter
    def shared_doc(self, value: bool):
        ...

    @property
    def application_template(self) -> string:
        ...

    @application_template.setter
    def application_template(self, value: string):
        ...

    @property
    def total_editing_time(self) -> TimeSpan:
        ...

    @total_editing_time.setter
    def total_editing_time(self, value: TimeSpan):
        ...

    @property
    def title(self) -> string:
        ...

    @title.setter
    def title(self, value: string):
        ...

    @property
    def subject(self) -> string:
        ...

    @subject.setter
    def subject(self, value: string):
        ...

    @property
    def author(self) -> string:
        ...

    @author.setter
    def author(self, value: string):
        ...

    @property
    def keywords(self) -> string:
        ...

    @keywords.setter
    def keywords(self, value: string):
        ...

    @property
    def comments(self) -> string:
        ...

    @comments.setter
    def comments(self, value: string):
        ...

    @property
    def category(self) -> string:
        ...

    @category.setter
    def category(self, value: string):
        ...

    @property
    def created_time(self) -> DateTime:
        ...

    @created_time.setter
    def created_time(self, value: DateTime):
        ...

    @property
    def last_saved_time(self) -> DateTime:
        ...

    @last_saved_time.setter
    def last_saved_time(self, value: DateTime):
        ...

    @property
    def last_printed(self) -> DateTime:
        ...

    @last_printed.setter
    def last_printed(self, value: DateTime):
        ...

    @property
    def last_saved_by(self) -> string:
        ...

    @last_saved_by.setter
    def last_saved_by(self, value: string):
        ...

    @property
    def revision_number(self) -> int:
        ...

    @revision_number.setter
    def revision_number(self, value: int):
        ...

    @property
    def content_status(self) -> string:
        ...

    @content_status.setter
    def content_status(self, value: string):
        ...

    @property
    def content_type(self) -> string:
        ...

    @content_type.setter
    def content_type(self, value: string):
        ...

    @property
    def hyperlink_base(self) -> string:
        ...

    @hyperlink_base.setter
    def hyperlink_base(self, value: string):
        ...

    @property
    def count_of_custom_properties(self) -> int:
        ...

    ...

class EffectFormat(PVIObject):
    '''Represents effect properties of shape.'''
    def set_blur_effect(self, radius: float, grow: bool) -> None:
        '''Sets blur effect.
        :param radius: Radius.
        :param grow: Grow.'''
        ...

    def enable_fill_overlay_effect(self) -> None:
        '''Enables fill overlay effect.'''
        ...

    def enable_glow_effect(self) -> None:
        '''Enables glow effect.'''
        ...

    def enable_inner_shadow_effect(self) -> None:
        '''Enables inner shadow effect.'''
        ...

    def enable_outer_shadow_effect(self) -> None:
        '''Enables outer shadow effect.'''
        ...

    def enable_preset_shadow_effect(self) -> None:
        '''Enables preset shadows effect.'''
        ...

    def enable_reflection_effect(self) -> None:
        '''Enables reflection effect.'''
        ...

    def enable_soft_edge_effect(self) -> None:
        '''Enables soft edge effect.'''
        ...

    def disable_blur_effect(self) -> None:
        '''Disables blur effect.'''
        ...

    def disable_fill_overlay_effect(self) -> None:
        '''Disables fill overlay effect.'''
        ...

    def disable_glow_effect(self) -> None:
        '''Disable glow effect.'''
        ...

    def disable_inner_shadow_effect(self) -> None:
        '''Disables inner shadow effect.'''
        ...

    def disable_outer_shadow_effect(self) -> None:
        '''Disables outer shadow effect.'''
        ...

    def disable_preset_shadow_effect(self) -> None:
        '''Disables preset shadow effect.'''
        ...

    def disable_reflection_effect(self) -> None:
        '''Disables reflection effect.'''
        ...

    def disable_soft_edge_effect(self) -> None:
        '''Disables soft edge effect.'''
        ...

    def get_effective(self) -> IEffectFormatEffectiveData:
        '''Gets effective effect formatting data with the inheritance applied.
        :returns: A :py:class:`aspose.slides.IEffectFormatEffectiveData`.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def is_no_effects(self) -> bool:
        ...

    @property
    def blur_effect(self) -> aspose.slides.effects.IBlur:
        ...

    @blur_effect.setter
    def blur_effect(self, value: aspose.slides.effects.IBlur):
        ...

    @property
    def fill_overlay_effect(self) -> aspose.slides.effects.IFillOverlay:
        ...

    @fill_overlay_effect.setter
    def fill_overlay_effect(self, value: aspose.slides.effects.IFillOverlay):
        ...

    @property
    def glow_effect(self) -> aspose.slides.effects.IGlow:
        ...

    @glow_effect.setter
    def glow_effect(self, value: aspose.slides.effects.IGlow):
        ...

    @property
    def inner_shadow_effect(self) -> aspose.slides.effects.IInnerShadow:
        ...

    @inner_shadow_effect.setter
    def inner_shadow_effect(self, value: aspose.slides.effects.IInnerShadow):
        ...

    @property
    def outer_shadow_effect(self) -> aspose.slides.effects.IOuterShadow:
        ...

    @outer_shadow_effect.setter
    def outer_shadow_effect(self, value: aspose.slides.effects.IOuterShadow):
        ...

    @property
    def preset_shadow_effect(self) -> aspose.slides.effects.IPresetShadow:
        ...

    @preset_shadow_effect.setter
    def preset_shadow_effect(self, value: aspose.slides.effects.IPresetShadow):
        ...

    @property
    def reflection_effect(self) -> aspose.slides.effects.IReflection:
        ...

    @reflection_effect.setter
    def reflection_effect(self, value: aspose.slides.effects.IReflection):
        ...

    @property
    def soft_edge_effect(self) -> aspose.slides.effects.ISoftEdge:
        ...

    @soft_edge_effect.setter
    def soft_edge_effect(self, value: aspose.slides.effects.ISoftEdge):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_effect_param_source(self) -> IEffectParamSource:
        ...

    ...

class Field:
    '''Represents a field.'''
    @property
    def type(self) -> IFieldType:
        ...

    @type.setter
    def type(self, value: IFieldType):
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class FieldType:
    '''Represents a type of field. 
                This value determines which text will be set to the field portion when it will be updated.'''
    def __init__(self, str: string):
        '''Initializes a new instance of FieldType class.'''
        ...

    @property
    def internal_string(self) -> string:
        ...

    @internal_string.setter
    def internal_string(self, value: string):
        ...

    @classmethod
    @property
    def slide_number(cls) -> FieldType:
        ...

    @classmethod
    @property
    def footer(cls) -> FieldType:
        ...

    @classmethod
    @property
    def header(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time1(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time2(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time3(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time4(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time5(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time6(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time7(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time8(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time9(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time10(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time11(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time12(cls) -> FieldType:
        ...

    @classmethod
    @property
    def date_time13(cls) -> FieldType:
        ...

    ...

class FillFormat(PVIObject):
    '''Represents a fill formatting options.'''
    def get_effective(self) -> IFillFormatEffectiveData:
        '''Gets effective fill formatting data with the inheritance applied.
        :returns: A :py:class:`aspose.slides.IFillFormatEffectiveData`.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def fill_type(self) -> FillType:
        ...

    @fill_type.setter
    def fill_type(self, value: FillType):
        ...

    @property
    def solid_fill_color(self) -> IColorFormat:
        ...

    @property
    def gradient_format(self) -> IGradientFormat:
        ...

    @property
    def pattern_format(self) -> IPatternFormat:
        ...

    @property
    def picture_fill_format(self) -> IPictureFillFormat:
        ...

    @property
    def rotate_with_shape(self) -> NullableBool:
        ...

    @rotate_with_shape.setter
    def rotate_with_shape(self, value: NullableBool):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class FontData:
    '''Represents a font definition. Immutable.'''
    def __init__(self, font_name: string):
        '''Creates a new FontData object with the specified font name.
        :param font_name: Font name.'''
        ...

    def get_font_name(self, theme: aspose.slides.theme.IThemeEffectiveData) -> string:
        '''Returns the font name, replacing theme referrence with an actual font used.
        :param theme: Theme from which themed font name should be taken. Its up to caller to provide a correct value. See :py:func:`aspose.slides.theme.IThemeable.create_theme_effective`
        :returns: Font name.'''
        ...

    @property
    def font_name(self) -> string:
        ...

    ...

class FontDataFactory:
    '''FontData factory'''
    def __init__(self):
        ...

    def create_font_data(self, font_name: string) -> IFontData:
        '''Creates FontData with specified font name.
        :param font_name: Font name
        :returns: FontData'''
        ...

    ...

class FontFallBackRule:
    '''Represents font fallback rule'''
    def __init__(self, start_index: int, end_index: int, font_names: string):
        '''Creates new instance.
        :param start_index: Start index of unicode range
        :param end_index: End index of unicode range
        :param font_names: Font's name or names (delimited by comma) for FallBack'''
        ...

    def __init__(self, start_index: int, end_index: int, font_names: List[string]):
        '''Creates new instance.
        :param start_index: Start index of unicode range
        :param end_index: End index of unicode range
        :param font_names: Font's name or names (delimited by comma) for FallBack'''
        ...

    @overload
    def add_fall_back_fonts(self, font_name: string) -> None:
        '''Adds a new font(s) to the list of FallBack fonts.
        :param font_name: Font's name or names (delimited by comma) for FallBack'''
        ...

    @overload
    def add_fall_back_fonts(self, font_names: List[string]) -> None:
        '''Adds a new fonts to the list of FallBack fonts.
        :param font_names: Font's name or names (delimited by comma) for FallBack'''
        ...

    @overload
    def to_array(self) -> List[string]:
        '''Creates and returns an array with all FallBack fonts for this rule.
        :returns: Array of :py:class:`System.String`'''
        ...

    @overload
    def to_array(self, start_index: int, count: int) -> List[string]:
        '''Creates and returns an array with all FallBack fonts from the specified range in list.
        :param start_index: An index of a first font to add.
        :param count: A number of fonts to add.
        :returns: Array of :py:class:`System.String`'''
        ...

    def clear(self) -> None:
        '''Removes all fonts from the list.'''
        ...

    def remove(self, font_name: string) -> None:
        '''Removes the first occurrence of a specific FallBack font from the list.
        :param font_name: The font's name to remove from the list.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the FallBack font at the specified index of the list.
        :param index: The zero-based index of the font to remove.'''
        ...

    def index_of(self, font_name: string) -> int:
        '''Returns an index of the specified rule in the collection.
        :param font_name: Font's name to find.
        :returns: Index of a font or -1 if font not found in list.'''
        ...

    @property
    def range_start_index(self) -> int:
        ...

    @range_start_index.setter
    def range_start_index(self, value: int):
        ...

    @property
    def range_end_index(self) -> int:
        ...

    @range_end_index.setter
    def range_end_index(self, value: int):
        ...

    @property
    def count(self) -> int:
        ...

    def __getitem__(self, key: int) -> string
        '''Gets the font name at the specified index.
                    Read-only :py:class:`aspose.slides.IFontFallBackRule`.'''
        ...

    ...

class FontFallBackRulesCollection:
    '''Represents a collection of FontFallBack rules, defined by user'''
    def __init__(self):
        ...

    def add(self, source_rule: IFontFallBackRule) -> None:
        '''Add a specified FallBack rule to the end of the collection.
        :param source_rule: Specified rule for adding'''
        ...

    def remove(self, target_rule: IFontFallBackRule) -> None:
        '''Removes the first occurrence of a specific FallBack rule from the collection.
        :param target_rule: The rule to remove from the collection.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IFontFallBackRule
        '''Gets the rule at the specified index.
                    Read-only :py:class:`aspose.slides.IFontFallBackRule`.'''
        ...

    ...

class FontSources:
    '''Provides file and memory sources for external fonts.'''
    def __init__(self):
        '''Creates new default font options.'''
        ...

    @property
    def font_folders(self) -> List[string]:
        ...

    @font_folders.setter
    def font_folders(self, value: List[string]):
        ...

    @property
    def memory_fonts(self) -> List[bytes]:
        ...

    @memory_fonts.setter
    def memory_fonts(self, value: List[bytes]):
        ...

    ...

class FontSubstRule:
    '''Represents font subtituition information'''
    def __init__(self, source_font: IFontData, dest_font: IFontData):
        '''Creates new instance.
        :param source_font: Source font.
        :param dest_font: Destination font.'''
        ...

    def __init__(self, source_font: IFontData, dest_font: IFontData, font_subst_rule: FontSubstCondition):
        '''Creates new instance.
        :param source_font: Source font.
        :param dest_font: Destination font.
        :param font_subst_rule: Font subst rule.'''
        ...

    @property
    def source_font(self) -> IFontData:
        ...

    @property
    def dest_font(self) -> IFontData:
        ...

    @property
    def replace_font_condition(self) -> FontSubstCondition:
        ...

    ...

class FontSubstRuleCollection:
    '''Represents collection of fonts substitution.'''
    def __init__(self):
        ...

    def add(self, value: IFontSubstRule) -> None:
        '''Adds the new font substitution rule to the collection'''
        ...

    def remove(self, value: IFontSubstRule) -> None:
        '''Removes the first occurrence of a specific object from the collection.
        :param value: The font substitution rule to remove from the collection.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IFontSubstRule
        '''Gets the element at the specified index.'''
        ...

    ...

class FontSubstitutionInfo:
    def __init__(self, origin_font_name: string, subst_font_name: string):
        ...

    @property
    def original_font_name(self) -> string:
        ...

    @property
    def substituted_font_name(self) -> string:
        ...

    ...

class Fonts:
    '''Fonts collection.'''
    @property
    def latin_font(self) -> IFontData:
        ...

    @latin_font.setter
    def latin_font(self, value: IFontData):
        ...

    @property
    def east_asian_font(self) -> IFontData:
        ...

    @east_asian_font.setter
    def east_asian_font(self, value: IFontData):
        ...

    @property
    def complex_script_font(self) -> IFontData:
        ...

    @complex_script_font.setter
    def complex_script_font(self, value: IFontData):
        ...

    ...

class FontsLoader:
    '''Class for loading custom fonts defined by user.
                Should be used before creating any presentation objects.'''
    @staticmethod
    def load_external_fonts(directories: List[string]) -> None:
        '''Adds additional folders to seek fonts.
        :param directories: Directories to read additional fonts.'''
        ...

    @staticmethod
    def load_external_font(data: bytes) -> None:
        '''Adds font from the binary data
        :param data: Font's data'''
        ...

    @staticmethod
    def get_font_folders() -> List[string]:
        '''Gets font folders. Returns folders that have been added with LoadExternalFonts method as well as system font folders
        :returns: array containing folder names'''
        ...

    @staticmethod
    def clear_cache() -> None:
        '''Releases all custom fonts defined by user'''
        ...

    ...

class FontsManager:
    '''Manages fonts across the presentation.'''
    @overload
    def add_embedded_font(self, font_data: IFontData, embed_font_rule: aspose.slides.export.EmbedFontCharacters) -> None:
        '''Adds the embedded font'''
        ...

    @overload
    def add_embedded_font(self, font_data: bytes, embed_font_rule: aspose.slides.export.EmbedFontCharacters) -> None:
        '''Adds the embedded font'''
        ...

    @overload
    def replace_font(self, source_font: IFontData, dest_font: IFontData) -> None:
        '''Replace font in presentation
        :param source_font: Source font
        :param dest_font: Destination font'''
        ...

    @overload
    def replace_font(self, subst_rule: IFontSubstRule) -> None:
        '''Replace font in presentation using information provided in :py:class:`aspose.slides.FontSubstRule`
        :param subst_rule: Font substitution info'''
        ...

    @overload
    def replace_font(self, subst_rules: IFontSubstRuleCollection) -> None:
        '''Replace font in presentation using information provided in collection of :py:class:`aspose.slides.FontSubstRule`
        :param subst_rules: Font substitution rules collection'''
        ...

    def get_fonts(self) -> List[IFontData]:
        '''Returns the fonts used in the presentation
        :returns: An array of fonts'''
        ...

    def get_substitutions(self) -> Iterable[FontSubstitutionInfo]:
        '''Gets the information about fonts that will be replaced on the presentation's rendering.
        :returns: Collection of all fonts substitution :py:class:`aspose.slides.FontSubstitutionInfo`.'''
        ...

    def get_embedded_fonts(self) -> List[IFontData]:
        '''Returns the fonts embedded in the presentation'''
        ...

    def remove_embedded_font(self, font_data: IFontData) -> None:
        '''Removes the embedded font'''
        ...

    @property
    def font_subst_rule_list(self) -> IFontSubstRuleCollection:
        ...

    @font_subst_rule_list.setter
    def font_subst_rule_list(self, value: IFontSubstRuleCollection):
        ...

    @property
    def font_fall_back_rules_collection(self) -> IFontFallBackRulesCollection:
        ...

    @font_fall_back_rules_collection.setter
    def font_fall_back_rules_collection(self, value: IFontFallBackRulesCollection):
        ...

    ...

class FormatFactory:
    '''Allows to create formats via COM interface.'''
    def __init__(self):
        ...

    def create_portion_format(self) -> IPortionFormat:
        '''Creates new :py:class:`aspose.slides.IPortionFormat`.
        :returns: New portion format.'''
        ...

    def create_paragraph_format(self) -> IParagraphFormat:
        '''Creates new :py:class:`aspose.slides.IParagraphFormat`.
        :returns: New paragraph format.'''
        ...

    def create_text_frame_format(self) -> ITextFrameFormat:
        '''Creates new :py:class:`aspose.slides.ITextFrameFormat`.
        :returns: New text frame format.'''
        ...

    @classmethod
    @property
    def instance(cls) -> FormatFactory:
        ...

    ...

class GeometryPath:
    '''Represents geometry path of GeometryShape'''
    def __init__(self):
        '''Creates instance of GeometryPath'''
        ...

    @overload
    def line_to(self, point: aspose.pydrawing.PointF) -> None:
        '''Adds line to the end of the path
        :param point: End point of the line'''
        ...

    @overload
    def line_to(self, x: float, y: float) -> None:
        '''Adds line to the end of the path
        :param x: X coordinate of the end point of the line
        :param y: Y coordinate of the end point of the line'''
        ...

    @overload
    def line_to(self, point: aspose.pydrawing.PointF, index: int) -> None:
        '''Adds line to the specified place of the path
        :param point: End point
        :param index: Index of segment in PathData'''
        ...

    @overload
    def line_to(self, x: float, y: float, index: int) -> None:
        '''Adds line to the specified place of the path
        :param x: X coordinate of the point
        :param y: Y coordinate of the point
        :param index: Index of segment in PathData'''
        ...

    @overload
    def cubic_bezier_to(self, point1: aspose.pydrawing.PointF, point2: aspose.pydrawing.PointF, point3: aspose.pydrawing.PointF) -> None:
        '''Adds cubic Bezier curve at the end the path
        :param point1: First direction point
        :param point2: Second direction point
        :param point3: End point'''
        ...

    @overload
    def cubic_bezier_to(self, x1: float, y1: float, x2: float, y2: float, x3: float, y3: float) -> None:
        '''Adds cubic Bezier curve at the end the path
        :param x1: X coordinate of first direction point
        :param y1: Y coordinate of first direction point
        :param x2: X coordinate of second direction point
        :param y2: Y coordinate of second direction point
        :param x3: X coordinate of end point
        :param y3: Y coordinate of end point'''
        ...

    @overload
    def cubic_bezier_to(self, point1: aspose.pydrawing.PointF, point2: aspose.pydrawing.PointF, point3: aspose.pydrawing.PointF, index: int) -> None:
        '''Adds cubic Bezier curve to the specified place of the path
        :param point1: First direction point
        :param point2: Second direction point
        :param point3: End point
        :param index: Index of segment in PathData'''
        ...

    @overload
    def cubic_bezier_to(self, x1: float, y1: float, x2: float, y2: float, x3: float, y3: float, index: int) -> None:
        '''Adds cubic Bezier curve to the specified place of the path
        :param x1: X coordinate of first direction point
        :param y1: Y coordinate of first direction point
        :param x2: X coordinate of second direction point
        :param y2: Y coordinate of second direction point
        :param x3: X coordinate of end point
        :param y3: Y coordinate of end point
        :param index: Index of segment in PathData'''
        ...

    @overload
    def quadratic_bezier_to(self, point1: aspose.pydrawing.PointF, point2: aspose.pydrawing.PointF) -> None:
        '''Adds quadratic Bezier curve at the end the path
        :param point1: Direction point
        :param point2: End point'''
        ...

    @overload
    def quadratic_bezier_to(self, x1: float, y1: float, x2: float, y2: float) -> None:
        '''Adds quadratic Bezier curve at the end the path
        :param x1: X coordinate of direction point
        :param y1: Y coordinate of direction point
        :param x2: X coordinate of end point
        :param y2: Y coordinate of end point'''
        ...

    @overload
    def quadratic_bezier_to(self, point1: aspose.pydrawing.PointF, point2: aspose.pydrawing.PointF, index: int) -> None:
        '''Adds quadratic Bezier curve to the specified place of the path
        :param point1: Direction point
        :param point2: End point
        :param index: Index of segment in PathData'''
        ...

    @overload
    def quadratic_bezier_to(self, x1: float, y1: float, x2: float, y2: float, index: int) -> None:
        '''Adds quadratic Bezier curve to the specified place of the path
        :param x1: X coordinate of direction point
        :param y1: Y coordinate of direction point
        :param x2: X coordinate of end point
        :param y2: Y coordinate of end point
        :param index: Index of segment in PathData'''
        ...

    @overload
    def move_to(self, point: aspose.pydrawing.PointF) -> None:
        '''Sets next point position.
        :param point: Point position'''
        ...

    @overload
    def move_to(self, x: float, y: float) -> None:
        '''Sets next point position.
        :param x: X coordinate of the point
        :param y: Y Coordinate of the point'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes segment at the specified index of the geometry path.'''
        ...

    def close_figure(self) -> None:
        '''Closes the current figure of this path'''
        ...

    def arc_to(self, width: float, heigth: float, start_angle: float, sweep_angle: float) -> None:
        '''Appends the specified arc to the path.
        :param width: Width of the rectangle
        :param heigth: Height of the rectangle
        :param start_angle: Start angle.
        :param sweep_angle: Sweep angle/'''
        ...

    @property
    def path_data(self) -> List[IPathSegment]:
        ...

    @property
    def fill_mode(self) -> PathFillModeType:
        ...

    @fill_mode.setter
    def fill_mode(self, value: PathFillModeType):
        ...

    @property
    def stroke(self) -> bool:
        ...

    @stroke.setter
    def stroke(self, value: bool):
        ...

    ...

class GeometryShape(Shape):
    '''Represents the parent class for all geometric shapes.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    def get_geometry_paths(self) -> List[IGeometryPath]:
        '''Returns the copy of path of the geometry shape. Coordinates are relative to the left top corner of the shape.
        :returns: Array of :py:class:`aspose.slides.IGeometryPath`'''
        ...

    def set_geometry_path(self, geometry_path: IGeometryPath) -> None:
        '''Updates shape geometry from :py:class:`aspose.slides.IGeometryPath` object. Coordinates must be relative to the left
                     top corner of the shape.
                     Changes the type of the shape (:py:attr:`aspose.slides.GeometryShape.shape_type`) to :py:attr:`aspose.slides.ShapeType.CUSTOM`.
        :param geometry_path: Geometry path'''
        ...

    def set_geometry_paths(self, geometry_paths: List[IGeometryPath]) -> None:
        '''Updates shape geometry from array of :py:class:`aspose.slides.IGeometryPath`. Coordinates must be relative to the left
                     top corner of the shape.
                     Changes the type of the shape (:py:attr:`aspose.slides.GeometryShape.shape_type`) to :py:attr:`aspose.slides.ShapeType.CUSTOM`.
        :param geometry_paths: Array geometry paths'''
        ...

    def create_shape_elements(self) -> List[IShapeElement]:
        '''Creates and returns array of shape's elements.
        :returns: Array of :py:class:`aspose.slides.ShapeElement`'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IBaseShapeLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def shape_style(self) -> IShapeStyle:
        ...

    @property
    def shape_type(self) -> ShapeType:
        ...

    @shape_type.setter
    def shape_type(self, value: ShapeType):
        ...

    @property
    def adjustments(self) -> IAdjustValueCollection:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    ...

class GlobalLayoutSlideCollection(LayoutSlideCollection):
    '''Represents a collection of all layout slides in presentation.
                Extends LayoutSlideCollection class with methods for adding/cloning 
                layout slides in context of uniting of the individual collections of master's layout slides.'''
    @overload
    def add_clone(self, source_layout: ILayoutSlide) -> ILayoutSlide:
        '''Adds a copy of a specified layout slide to the presentation.
        :param source_layout: Slide to clone.
        :returns: Added slide.'''
        ...

    @overload
    def add_clone(self, source_layout: ILayoutSlide, dest_master: IMasterSlide) -> ILayoutSlide:
        '''Adds a copy of a specified layout slide to the presentation.
        :param source_layout: Slide to clone.
        :param dest_master: Master slide for a new layout.
        :returns: Added slide.'''
        ...

    def get_by_type(self, type: SlideLayoutType) -> ILayoutSlide:
        '''Returns the first layout slide of specified type.'''
        ...

    def remove(self, value: ILayoutSlide) -> None:
        '''Removes a layout from the collection.
        :param value: The layout slide to remove from the collection.'''
        ...

    def remove_unused(self) -> None:
        '''Removes unused layout slides (layout slides whose HasDependingSlides is false).'''
        ...

    def add(self, master: IMasterSlide, layout_type: SlideLayoutType, layout_name: string) -> ILayoutSlide:
        '''Adds a new layout slide to the presentation.
        :param master: Master slide for a new layout.
        :param layout_type: Layout type for a new layout.
                    Supported layout types: Title, TitleOnly, Blank, TitleAndObject, VerticalText, VerticalTitleAndText, TwoObjects, SectionHeader, TwoTextAndTwoObjects, TitleObjectAndCaption, PictureAndCaption, Custom.
                    Other layout types are not supported now: Text, TwoColumnText, Table, TextAndChart, ChartAndText, Diagram, Chart, TextAndClipArt, ClipArtAndText, TextAndObject, ObjectAndText, Object, TextAndMedia, MediaAndText, ObjectOverText, TextOverObject, TextAndTwoObjects, TwoObjectsAndText, TwoObjectsOverText, FourObjects, ClipArtAndVerticalText, VerticalTitleAndTextOverChart, ObjectAndTwoObject, TwoObjectsAndObject.
        :param layout_name: Name for a new layout. If passed name is already in use the ArgumentException will be thrown.
                    If null parameter is passed then name genarated atomatically in regards to passed layout type 
                    (for example "Title Slide" or "1_Title Slide", "2_..", etc.).
        :returns: Added slide.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    @property
    def as_i_layout_slide_collection(self) -> ILayoutSlideCollection:
        ...

    def __getitem__(self, key: int) -> ILayoutSlide
        ...

    ...

class GradientFormat(PVIObject):
    '''Represent a gradient format.'''
    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def tile_flip(self) -> TileFlip:
        ...

    @tile_flip.setter
    def tile_flip(self, value: TileFlip):
        ...

    @property
    def gradient_direction(self) -> GradientDirection:
        ...

    @gradient_direction.setter
    def gradient_direction(self, value: GradientDirection):
        ...

    @property
    def linear_gradient_angle(self) -> float:
        ...

    @linear_gradient_angle.setter
    def linear_gradient_angle(self, value: float):
        ...

    @property
    def linear_gradient_scaled(self) -> NullableBool:
        ...

    @linear_gradient_scaled.setter
    def linear_gradient_scaled(self, value: NullableBool):
        ...

    @property
    def gradient_shape(self) -> GradientShape:
        ...

    @gradient_shape.setter
    def gradient_shape(self, value: GradientShape):
        ...

    @property
    def gradient_stops(self) -> IGradientStopCollection:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class GradientStop(PVIObject):
    '''Represents a gradient format.'''
    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def position(self) -> float:
        ...

    @position.setter
    def position(self, value: float):
        ...

    @property
    def color(self) -> IColorFormat:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class GradientStopCollection(PVIObject):
    '''Represnts a collection of gradient stops.'''
    @overload
    def add(self, position: float, color: aspose.pydrawing.Color) -> IGradientStop:
        '''Creates the new gradient stop and adds it to the end of collection.
        :param position: Position of the new gradient stop.
        :param color: Color of the new radient stop.
        :returns: Index of the new gradient stop in the collection.'''
        ...

    @overload
    def add(self, position: float, preset_color: PresetColor) -> IGradientStop:
        '''Creates the new gradient stop and adds it to the end of collection.
        :param position: Position of the new gradient stop.
        :param preset_color: Color of the new radient stop.
        :returns: Index of the new gradient stop in the collection.'''
        ...

    @overload
    def add(self, position: float, scheme_color: SchemeColor) -> IGradientStop:
        '''Creates the new gradient stop and adds it to the end of collection.
        :param position: Position of the new gradient stop.
        :param scheme_color: Color of the new radient stop.
        :returns: Index of the new gradient stop in the collection.'''
        ...

    @overload
    def insert(self, index: int, position: float, color: aspose.pydrawing.Color) -> None:
        '''Creates the new gradient stop and inserts it at the specified index to the collection.
        :param index: Index in the collection where new gradient stop will be inserted.
        :param position: Position of the new gradient stop.
        :param color: Color of the new radient stop.'''
        ...

    @overload
    def insert(self, index: int, position: float, preset_color: PresetColor) -> None:
        '''Creates the new gradient stop and inserts it at the specified index to the collection.
        :param index: Index in the collection where new gradient stop will be inserted.
        :param position: Position of the new gradient stop.
        :param preset_color: Color of the new radient stop.'''
        ...

    @overload
    def insert(self, index: int, position: float, scheme_color: SchemeColor) -> None:
        '''Creates the new gradient stop and inserts it at the specified index to the collection.
        :param index: Index in the collection where new gradient stop will be inserted.
        :param position: Position of the new gradient stop.
        :param scheme_color: Color of the new radient stop.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes a gradient stop at the specified index.
        :param index: Index of a gradient stop that should be deleted.'''
        ...

    def clear(self) -> None:
        '''Removes all gradient stops from a collection.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IGradientStop
        '''Returns the gradient stop by index.'''
        ...

    ...

class GradientStopCollectionEffectiveData:
    '''Represents a collection of GradientStopData objects.'''
    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IGradientStopEffectiveData
        '''Returns the gradient stop by index.'''
        ...

    ...

class GradientStopEffectiveData:
    '''Immutable object which represents a gradient stop.'''
    @property
    def position(self) -> float:
        ...

    @property
    def color(self) -> aspose.pydrawing.Color:
        ...

    ...

class GraphicalObject(Shape):
    '''Represents abstract graphical object.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    ...

class GraphicalObjectLock(BaseShapeLock):
    '''Determines which operations are disabled on the parent GraphicalObject.'''
    @property
    def no_locks(self) -> bool:
        ...

    @property
    def grouping_locked(self) -> bool:
        ...

    @grouping_locked.setter
    def grouping_locked(self, value: bool):
        ...

    @property
    def drilldown_locked(self) -> bool:
        ...

    @drilldown_locked.setter
    def drilldown_locked(self, value: bool):
        ...

    @property
    def select_locked(self) -> bool:
        ...

    @select_locked.setter
    def select_locked(self, value: bool):
        ...

    @property
    def aspect_ratio_locked(self) -> bool:
        ...

    @aspect_ratio_locked.setter
    def aspect_ratio_locked(self, value: bool):
        ...

    @property
    def position_locked(self) -> bool:
        ...

    @position_locked.setter
    def position_locked(self, value: bool):
        ...

    @property
    def size_locked(self) -> bool:
        ...

    @size_locked.setter
    def size_locked(self, value: bool):
        ...

    @property
    def as_i_base_shape_lock(self) -> IBaseShapeLock:
        ...

    ...

class GroupShape(Shape):
    '''Represents a group of shapes on a slide.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IGroupShapeLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def group_shape_lock(self) -> IGroupShapeLock:
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    ...

class GroupShapeLock(BaseShapeLock):
    '''Determines which operations are disabled on the parent GroupShape.'''
    @property
    def no_locks(self) -> bool:
        ...

    @property
    def grouping_locked(self) -> bool:
        ...

    @grouping_locked.setter
    def grouping_locked(self, value: bool):
        ...

    @property
    def ungrouping_locked(self) -> bool:
        ...

    @ungrouping_locked.setter
    def ungrouping_locked(self, value: bool):
        ...

    @property
    def select_locked(self) -> bool:
        ...

    @select_locked.setter
    def select_locked(self, value: bool):
        ...

    @property
    def rotation_locked(self) -> bool:
        ...

    @rotation_locked.setter
    def rotation_locked(self, value: bool):
        ...

    @property
    def aspect_ratio_locked(self) -> bool:
        ...

    @aspect_ratio_locked.setter
    def aspect_ratio_locked(self, value: bool):
        ...

    @property
    def position_locked(self) -> bool:
        ...

    @position_locked.setter
    def position_locked(self, value: bool):
        ...

    @property
    def size_locked(self) -> bool:
        ...

    @size_locked.setter
    def size_locked(self, value: bool):
        ...

    @property
    def as_i_base_shape_lock(self) -> IBaseShapeLock:
        ...

    ...

class Hyperlink(PVIObject):
    '''Represents a hyperlink.'''
    def __init__(self, url: string):
        '''Creates an instance of a hyperlink.
        :param url: Hyperlink URL.'''
        ...

    def __init__(self, slide: ISlide):
        '''Creates an instance of a hyperlink which points to specific slide.
                    Note: created hyperlink should be assigned to some object from the same presentation, otherwise link will be saved as NoAction.
        :param slide: Target slide.'''
        ...

    def __init__(self, source: Hyperlink, target_frame: string, tooltip: string, history: bool, stop_sounds_on_click: bool, highlight_click: bool):
        '''Creates an instance of a hyperlink using another hyperlink as source, overriding secondary properties.
        :param source: Source hyperlink
        :param target_frame: Target frame
        :param tooltip: Tooltip text'''
        ...

    def equals(self, hlink: IHyperlink) -> bool:
        '''Determines whether the two Hyperlink instances are equal.
        :param hlink: The Hyperlink to compare with the current Hyperlink.
        :returns: **true** if the specified Hyperlink is equal to the current Hyperlink; otherwise, **false**.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @classmethod
    @property
    def no_action(cls) -> Hyperlink:
        ...

    @classmethod
    @property
    def media(cls) -> Hyperlink:
        ...

    @classmethod
    @property
    def next_slide(cls) -> Hyperlink:
        ...

    @classmethod
    @property
    def previous_slide(cls) -> Hyperlink:
        ...

    @classmethod
    @property
    def first_slide(cls) -> Hyperlink:
        ...

    @classmethod
    @property
    def last_slide(cls) -> Hyperlink:
        ...

    @classmethod
    @property
    def last_vieved_slide(cls) -> Hyperlink:
        ...

    @classmethod
    @property
    def end_show(cls) -> Hyperlink:
        ...

    @property
    def action_type(self) -> HyperlinkActionType:
        ...

    @property
    def external_url(self) -> string:
        ...

    @property
    def target_slide(self) -> ISlide:
        ...

    @property
    def external_url_original(self) -> string:
        ...

    @property
    def target_frame(self) -> string:
        ...

    @target_frame.setter
    def target_frame(self, value: string):
        ...

    @property
    def tooltip(self) -> string:
        ...

    @tooltip.setter
    def tooltip(self, value: string):
        ...

    @property
    def history(self) -> bool:
        ...

    @history.setter
    def history(self, value: bool):
        ...

    @property
    def highlight_click(self) -> bool:
        ...

    @highlight_click.setter
    def highlight_click(self, value: bool):
        ...

    @property
    def stop_sound_on_click(self) -> bool:
        ...

    @stop_sound_on_click.setter
    def stop_sound_on_click(self, value: bool):
        ...

    @property
    def sound(self) -> IAudio:
        ...

    @sound.setter
    def sound(self, value: IAudio):
        ...

    @property
    def color_source(self) -> HyperlinkColorSource:
        ...

    @color_source.setter
    def color_source(self, value: HyperlinkColorSource):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class HyperlinkManager:
    '''Provide hyperlinks management (adding, removing).'''
    def set_external_hyperlink_click(self, url: string) -> IHyperlink:
        '''Set external hyperlink on click.
        :param url: Hyperlink URL.'''
        ...

    def set_internal_hyperlink_click(self, target_slide: ISlide) -> IHyperlink:
        '''Sets internal hyperlink on click.
        :param target_slide: Target slide.
        :returns: Hyperlink.'''
        ...

    def remove_hyperlink_click(self) -> None:
        '''Removes hyperlink on click.'''
        ...

    def set_external_hyperlink_mouse_over(self, url: string) -> IHyperlink:
        '''Sets external hyperlink mouse over.
        :param url: Hyperlink URL.
        :returns: Hyperlink.'''
        ...

    def set_internal_hyperlink_mouse_over(self, target_slide: ISlide) -> IHyperlink:
        '''Sets internal hyperlink mouse over.
        :param target_slide: Target slide.
        :returns: Hyperlink.'''
        ...

    def remove_hyperlink_mouse_over(self) -> None:
        '''Removes hyperlink mouse over.'''
        ...

    def set_macro_hyperlink_click(self, macro_name: string) -> IHyperlink:
        '''Set Macro hyperlink on a click.
        :param macro_name: Name of the macro
        :returns: Hyperlink object :py:class:`aspose.slides.IHyperlink`'''
        ...

    ...

class HyperlinkQueries:
    '''Provide easy access to contained hyperlinks.'''
    def get_hyperlink_clicks(self) -> List[IHyperlinkContainer]:
        '''Get all IHyperlinkContainer subobjects that contain not null HyperlinkClick.
                    With given IHyperlinkContainer object you can manage its hyperlink (read, update or remove). See IHyperlinkContainer interface.'''
        ...

    def get_hyperlink_mouse_overs(self) -> List[IHyperlinkContainer]:
        '''Get all IHyperlinkContainer subobjects that contain not null HyperlinkMouseOver.
                    With given IHyperlinkContainer object you can manage its hyperlink (read, update or remove). See IHyperlinkContainer interface.'''
        ...

    def get_any_hyperlinks(self) -> List[IHyperlinkContainer]:
        '''Get all IHyperlinkContainer subobjects that contain not null HyperlinkMouseOver.
                    With given IHyperlinkContainer object you can manage its hyperlink (read, update or remove). See IHyperlinkContainer interface.'''
        ...

    def remove_all_hyperlinks(self) -> None:
        '''Removes all contained HyperlinkClick and HyperlinkMouseOver hyperlinks (in all IHyperlinkContainer subobjects).'''
        ...

    ...

class IAdjustValue:
    @property
    def raw_value(self) -> int:
        ...

    @raw_value.setter
    def raw_value(self, value: int):
        ...

    @property
    def angle_value(self) -> float:
        ...

    @angle_value.setter
    def angle_value(self, value: float):
        ...

    @property
    def name(self) -> string:
        ...

    ...

class IAdjustValueCollection:
    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IAdjustValue
        ...

    ...

class IAnimationTimeLine:
    @property
    def interactive_sequences(self) -> aspose.slides.animation.ISequenceCollection:
        ...

    @property
    def main_sequence(self) -> aspose.slides.animation.ISequence:
        ...

    @property
    def text_animation_collection(self) -> aspose.slides.animation.ITextAnimationCollection:
        ...

    ...

class IAudio:
    def get_stream(self) -> System.IO.Stream:
        ...

    @property
    def content_type(self) -> string:
        ...

    @property
    def binary_data(self) -> bytes:
        ...

    ...

class IAudioCollection:
    @overload
    def add_audio(self, audio: IAudio) -> IAudio:
        ...

    @overload
    def add_audio(self, stream: System.IO.Stream) -> IAudio:
        ...

    @overload
    def add_audio(self, stream: System.IO.Stream, loading_stream_behavior: LoadingStreamBehavior) -> IAudio:
        ...

    @overload
    def add_audio(self, audio_data: bytes) -> IAudio:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IAudio
        ...

    ...

class IAudioFrame:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def get_geometry_paths(self) -> List[IGeometryPath]:
        ...

    def set_geometry_path(self, geometry_path: IGeometryPath) -> None:
        ...

    def set_geometry_paths(self, geometry_paths: List[IGeometryPath]) -> None:
        ...

    def create_shape_elements(self) -> List[IShapeElement]:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def audio_cd_start_track(self) -> int:
        ...

    @audio_cd_start_track.setter
    def audio_cd_start_track(self, value: int):
        ...

    @property
    def audio_cd_start_track_time(self) -> int:
        ...

    @audio_cd_start_track_time.setter
    def audio_cd_start_track_time(self, value: int):
        ...

    @property
    def audio_cd_end_track(self) -> int:
        ...

    @audio_cd_end_track.setter
    def audio_cd_end_track(self, value: int):
        ...

    @property
    def audio_cd_end_track_time(self) -> int:
        ...

    @audio_cd_end_track_time.setter
    def audio_cd_end_track_time(self, value: int):
        ...

    @property
    def volume(self) -> AudioVolumeMode:
        ...

    @volume.setter
    def volume(self, value: AudioVolumeMode):
        ...

    @property
    def play_mode(self) -> AudioPlayModePreset:
        ...

    @play_mode.setter
    def play_mode(self, value: AudioPlayModePreset):
        ...

    @property
    def hide_at_showing(self) -> bool:
        ...

    @hide_at_showing.setter
    def hide_at_showing(self, value: bool):
        ...

    @property
    def play_loop_mode(self) -> bool:
        ...

    @play_loop_mode.setter
    def play_loop_mode(self, value: bool):
        ...

    @property
    def play_across_slides(self) -> bool:
        ...

    @play_across_slides.setter
    def play_across_slides(self, value: bool):
        ...

    @property
    def rewind_audio(self) -> bool:
        ...

    @rewind_audio.setter
    def rewind_audio(self, value: bool):
        ...

    @property
    def embedded(self) -> bool:
        ...

    @property
    def link_path_long(self) -> string:
        ...

    @link_path_long.setter
    def link_path_long(self, value: string):
        ...

    @property
    def embedded_audio(self) -> IAudio:
        ...

    @embedded_audio.setter
    def embedded_audio(self, value: IAudio):
        ...

    @property
    def as_i_picture_frame(self) -> IPictureFrame:
        ...

    @property
    def shape_lock(self) -> IPictureFrameLock:
        ...

    @property
    def picture_frame_lock(self) -> IPictureFrameLock:
        ...

    @property
    def picture_format(self) -> IPictureFillFormat:
        ...

    @property
    def relative_scale_height(self) -> float:
        ...

    @relative_scale_height.setter
    def relative_scale_height(self, value: float):
        ...

    @property
    def relative_scale_width(self) -> float:
        ...

    @relative_scale_width.setter
    def relative_scale_width(self, value: float):
        ...

    @property
    def as_i_geometry_shape(self) -> IGeometryShape:
        ...

    @property
    def shape_style(self) -> IShapeStyle:
        ...

    @property
    def shape_type(self) -> ShapeType:
        ...

    @shape_type.setter
    def shape_type(self, value: ShapeType):
        ...

    @property
    def adjustments(self) -> IAdjustValueCollection:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IAutoShape:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def add_text_frame(self, text: string) -> ITextFrame:
        ...

    def get_geometry_paths(self) -> List[IGeometryPath]:
        ...

    def set_geometry_path(self, geometry_path: IGeometryPath) -> None:
        ...

    def set_geometry_paths(self, geometry_paths: List[IGeometryPath]) -> None:
        ...

    def create_shape_elements(self) -> List[IShapeElement]:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def shape_lock(self) -> IAutoShapeLock:
        ...

    @property
    def auto_shape_lock(self) -> IAutoShapeLock:
        ...

    @property
    def text_frame(self) -> ITextFrame:
        ...

    @property
    def use_background_fill(self) -> bool:
        ...

    @use_background_fill.setter
    def use_background_fill(self, value: bool):
        ...

    @property
    def is_text_box(self) -> bool:
        ...

    @property
    def as_i_geometry_shape(self) -> IGeometryShape:
        ...

    @property
    def shape_style(self) -> IShapeStyle:
        ...

    @property
    def shape_type(self) -> ShapeType:
        ...

    @shape_type.setter
    def shape_type(self, value: ShapeType):
        ...

    @property
    def adjustments(self) -> IAdjustValueCollection:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IAutoShapeLock:
    @property
    def grouping_locked(self) -> bool:
        ...

    @grouping_locked.setter
    def grouping_locked(self, value: bool):
        ...

    @property
    def select_locked(self) -> bool:
        ...

    @select_locked.setter
    def select_locked(self, value: bool):
        ...

    @property
    def rotate_locked(self) -> bool:
        ...

    @rotate_locked.setter
    def rotate_locked(self, value: bool):
        ...

    @property
    def aspect_ratio_locked(self) -> bool:
        ...

    @aspect_ratio_locked.setter
    def aspect_ratio_locked(self, value: bool):
        ...

    @property
    def position_locked(self) -> bool:
        ...

    @position_locked.setter
    def position_locked(self, value: bool):
        ...

    @property
    def size_locked(self) -> bool:
        ...

    @size_locked.setter
    def size_locked(self, value: bool):
        ...

    @property
    def edit_points_locked(self) -> bool:
        ...

    @edit_points_locked.setter
    def edit_points_locked(self, value: bool):
        ...

    @property
    def adjust_handles_locked(self) -> bool:
        ...

    @adjust_handles_locked.setter
    def adjust_handles_locked(self, value: bool):
        ...

    @property
    def arrowheads_locked(self) -> bool:
        ...

    @arrowheads_locked.setter
    def arrowheads_locked(self, value: bool):
        ...

    @property
    def shape_type_locked(self) -> bool:
        ...

    @shape_type_locked.setter
    def shape_type_locked(self, value: bool):
        ...

    @property
    def text_locked(self) -> bool:
        ...

    @text_locked.setter
    def text_locked(self, value: bool):
        ...

    @property
    def as_i_base_shape_lock(self) -> IBaseShapeLock:
        ...

    @property
    def no_locks(self) -> bool:
        ...

    ...

class IBackdrop3DScene:
    @property
    def normal_vector(self) -> List[float]:
        ...

    @normal_vector.setter
    def normal_vector(self, value: List[float]):
        ...

    @property
    def anchor_point(self) -> List[float]:
        ...

    @anchor_point.setter
    def anchor_point(self, value: List[float]):
        ...

    @property
    def up_vector(self) -> List[float]:
        ...

    @up_vector.setter
    def up_vector(self, value: List[float]):
        ...

    ...

class IBackground:
    def get_effective(self) -> IBackgroundEffectiveData:
        ...

    @property
    def type(self) -> BackgroundType:
        ...

    @type.setter
    def type(self, value: BackgroundType):
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def style_color(self) -> IColorFormat:
        ...

    @property
    def style_index(self) -> int:
        ...

    @style_index.setter
    def style_index(self, value: int):
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class IBackgroundEffectiveData:
    @property
    def fill_format(self) -> IFillFormatEffectiveData:
        ...

    @property
    def effect_format(self) -> IEffectFormatEffectiveData:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class IBaseHandoutNotesSlideHeaderFooterManag:
    def set_header_visibility(self, is_visible: bool) -> None:
        ...

    def set_header_text(self, text: string) -> None:
        ...

    def set_footer_visibility(self, is_visible: bool) -> None:
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        ...

    def set_footer_text(self, text: string) -> None:
        ...

    def set_date_time_text(self, text: string) -> None:
        ...

    @property
    def is_header_visible(self) -> bool:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class IBaseHeaderFooterManager:
    ...

class IBasePortionFormat:
    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def highlight_color(self) -> IColorFormat:
        ...

    @property
    def underline_line_format(self) -> ILineFormat:
        ...

    @property
    def underline_fill_format(self) -> IFillFormat:
        ...

    @property
    def font_bold(self) -> NullableBool:
        ...

    @font_bold.setter
    def font_bold(self, value: NullableBool):
        ...

    @property
    def font_italic(self) -> NullableBool:
        ...

    @font_italic.setter
    def font_italic(self, value: NullableBool):
        ...

    @property
    def kumimoji(self) -> NullableBool:
        ...

    @kumimoji.setter
    def kumimoji(self, value: NullableBool):
        ...

    @property
    def normalise_height(self) -> NullableBool:
        ...

    @normalise_height.setter
    def normalise_height(self, value: NullableBool):
        ...

    @property
    def proof_disabled(self) -> NullableBool:
        ...

    @proof_disabled.setter
    def proof_disabled(self, value: NullableBool):
        ...

    @property
    def font_underline(self) -> TextUnderlineType:
        ...

    @font_underline.setter
    def font_underline(self, value: TextUnderlineType):
        ...

    @property
    def text_cap_type(self) -> TextCapType:
        ...

    @text_cap_type.setter
    def text_cap_type(self, value: TextCapType):
        ...

    @property
    def strikethrough_type(self) -> TextStrikethroughType:
        ...

    @strikethrough_type.setter
    def strikethrough_type(self, value: TextStrikethroughType):
        ...

    @property
    def is_hard_underline_line(self) -> NullableBool:
        ...

    @is_hard_underline_line.setter
    def is_hard_underline_line(self, value: NullableBool):
        ...

    @property
    def is_hard_underline_fill(self) -> NullableBool:
        ...

    @is_hard_underline_fill.setter
    def is_hard_underline_fill(self, value: NullableBool):
        ...

    @property
    def font_height(self) -> float:
        ...

    @font_height.setter
    def font_height(self, value: float):
        ...

    @property
    def latin_font(self) -> IFontData:
        ...

    @latin_font.setter
    def latin_font(self, value: IFontData):
        ...

    @property
    def east_asian_font(self) -> IFontData:
        ...

    @east_asian_font.setter
    def east_asian_font(self, value: IFontData):
        ...

    @property
    def complex_script_font(self) -> IFontData:
        ...

    @complex_script_font.setter
    def complex_script_font(self, value: IFontData):
        ...

    @property
    def symbol_font(self) -> IFontData:
        ...

    @symbol_font.setter
    def symbol_font(self, value: IFontData):
        ...

    @property
    def escapement(self) -> float:
        ...

    @escapement.setter
    def escapement(self, value: float):
        ...

    @property
    def kerning_minimal_size(self) -> float:
        ...

    @kerning_minimal_size.setter
    def kerning_minimal_size(self, value: float):
        ...

    @property
    def language_id(self) -> string:
        ...

    @language_id.setter
    def language_id(self, value: string):
        ...

    @property
    def alternative_language_id(self) -> string:
        ...

    @alternative_language_id.setter
    def alternative_language_id(self, value: string):
        ...

    @property
    def spacing(self) -> float:
        ...

    @spacing.setter
    def spacing(self, value: float):
        ...

    ...

class IBasePortionFormatEffectiveData:
    @property
    def line_format(self) -> ILineFormatEffectiveData:
        ...

    @property
    def fill_format(self) -> IFillFormatEffectiveData:
        ...

    @property
    def effect_format(self) -> IEffectFormatEffectiveData:
        ...

    @property
    def highlight_color(self) -> aspose.pydrawing.Color:
        ...

    @property
    def underline_line_format(self) -> ILineFormatEffectiveData:
        ...

    @property
    def underline_fill_format(self) -> IFillFormatEffectiveData:
        ...

    @property
    def font_bold(self) -> bool:
        ...

    @property
    def font_italic(self) -> bool:
        ...

    @property
    def kumimoji(self) -> bool:
        ...

    @property
    def normalise_height(self) -> bool:
        ...

    @property
    def proof_disabled(self) -> bool:
        ...

    @property
    def font_underline(self) -> TextUnderlineType:
        ...

    @property
    def text_cap_type(self) -> TextCapType:
        ...

    @property
    def strikethrough_type(self) -> TextStrikethroughType:
        ...

    @property
    def smart_tag_clean(self) -> bool:
        ...

    @property
    def is_hard_underline_line(self) -> bool:
        ...

    @property
    def is_hard_underline_fill(self) -> bool:
        ...

    @property
    def font_height(self) -> float:
        ...

    @property
    def latin_font(self) -> IFontData:
        ...

    @property
    def east_asian_font(self) -> IFontData:
        ...

    @property
    def complex_script_font(self) -> IFontData:
        ...

    @property
    def symbol_font(self) -> IFontData:
        ...

    @property
    def escapement(self) -> float:
        ...

    @property
    def kerning_minimal_size(self) -> float:
        ...

    @property
    def language_id(self) -> string:
        ...

    @property
    def alternative_language_id(self) -> string:
        ...

    @property
    def spacing(self) -> float:
        ...

    ...

class IBaseShapeLock:
    @property
    def no_locks(self) -> bool:
        ...

    ...

class IBaseSlide:
    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        ...

    def join_portions_with_same_formatting(self) -> None:
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def as_i_themeable(self) -> aspose.slides.theme.IThemeable:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class IBaseSlideHeaderFooterManager:
    def set_footer_visibility(self, is_visible: bool) -> None:
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        ...

    def set_footer_text(self, text: string) -> None:
        ...

    def set_date_time_text(self, text: string) -> None:
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class IBaseTableFormatEffectiveData:
    @property
    def fill_format(self) -> IFillFormatEffectiveData:
        ...

    @property
    def border_left(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_top(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_right(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_bottom(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_diagonal_down(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_diagonal_up(self) -> ILineFormatEffectiveData:
        ...

    ...

class IBlobManagementOptions:
    @property
    def presentation_locking_behavior(self) -> PresentationLockingBehavior:
        ...

    @presentation_locking_behavior.setter
    def presentation_locking_behavior(self, value: PresentationLockingBehavior):
        ...

    @property
    def is_temporary_files_allowed(self) -> bool:
        ...

    @is_temporary_files_allowed.setter
    def is_temporary_files_allowed(self, value: bool):
        ...

    @property
    def temp_files_root_path(self) -> string:
        ...

    @temp_files_root_path.setter
    def temp_files_root_path(self, value: string):
        ...

    @property
    def max_blobs_bytes_in_memory(self) -> int:
        ...

    @max_blobs_bytes_in_memory.setter
    def max_blobs_bytes_in_memory(self, value: int):
        ...

    ...

class IBulkTextFormattable:
    @overload
    def set_text_format(self, source: IPortionFormat) -> None:
        ...

    @overload
    def set_text_format(self, source: IParagraphFormat) -> None:
        ...

    @overload
    def set_text_format(self, source: ITextFrameFormat) -> None:
        ...

    ...

class IBulletFormat:
    def apply_default_paragraph_indents_shifts(self) -> None:
        ...

    def get_effective(self) -> IBulletFormatEffectiveData:
        ...

    @property
    def type(self) -> BulletType:
        ...

    @type.setter
    def type(self, value: BulletType):
        ...

    @property
    def char(self) -> char:
        ...

    @char.setter
    def char(self, value: char):
        ...

    @property
    def font(self) -> IFontData:
        ...

    @font.setter
    def font(self, value: IFontData):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def color(self) -> IColorFormat:
        ...

    @property
    def picture(self) -> ISlidesPicture:
        ...

    @property
    def numbered_bullet_start_with(self) -> int:
        ...

    @numbered_bullet_start_with.setter
    def numbered_bullet_start_with(self, value: int):
        ...

    @property
    def numbered_bullet_style(self) -> NumberedBulletStyle:
        ...

    @numbered_bullet_style.setter
    def numbered_bullet_style(self, value: NumberedBulletStyle):
        ...

    @property
    def is_bullet_hard_color(self) -> NullableBool:
        ...

    @is_bullet_hard_color.setter
    def is_bullet_hard_color(self, value: NullableBool):
        ...

    @property
    def is_bullet_hard_font(self) -> NullableBool:
        ...

    @is_bullet_hard_font.setter
    def is_bullet_hard_font(self, value: NullableBool):
        ...

    ...

class IBulletFormatEffectiveData:
    @property
    def type(self) -> BulletType:
        ...

    @property
    def char(self) -> char:
        ...

    @property
    def actual_bullet_value(self) -> string:
        ...

    @property
    def font(self) -> IFontData:
        ...

    @property
    def height(self) -> float:
        ...

    @property
    def numbered_bullet_start_with(self) -> int:
        ...

    @property
    def numbered_bullet_style(self) -> NumberedBulletStyle:
        ...

    @property
    def is_bullet_hard_color(self) -> bool:
        ...

    @property
    def is_bullet_hard_font(self) -> bool:
        ...

    @property
    def picture(self) -> IPictureEffectiveData:
        ...

    @property
    def fill_format(self) -> IFillFormatEffectiveData:
        ...

    ...

class ICamera:
    def set_rotation(self, latitude: float, longitude: float, revolution: float) -> None:
        ...

    def get_rotation(self) -> List[float]:
        ...

    @property
    def camera_type(self) -> CameraPresetType:
        ...

    @camera_type.setter
    def camera_type(self, value: CameraPresetType):
        ...

    @property
    def field_of_view_angle(self) -> float:
        ...

    @field_of_view_angle.setter
    def field_of_view_angle(self, value: float):
        ...

    @property
    def zoom(self) -> float:
        ...

    @zoom.setter
    def zoom(self, value: float):
        ...

    ...

class ICameraEffectiveData:
    def get_rotation(self) -> List[float]:
        ...

    @property
    def camera_type(self) -> CameraPresetType:
        ...

    @property
    def field_of_view_angle(self) -> float:
        ...

    @property
    def zoom(self) -> float:
        ...

    ...

class ICell:
    def split_by_col_span(self, index: int) -> None:
        ...

    def split_by_row_span(self, index: int) -> None:
        ...

    def split_by_height(self, height: float) -> None:
        ...

    def split_by_width(self, width: float) -> None:
        ...

    @property
    def offset_x(self) -> float:
        ...

    @property
    def offset_y(self) -> float:
        ...

    @property
    def first_row_index(self) -> int:
        ...

    @property
    def first_column_index(self) -> int:
        ...

    @property
    def width(self) -> float:
        ...

    @property
    def height(self) -> float:
        ...

    @property
    def minimal_height(self) -> float:
        ...

    @property
    def margin_left(self) -> float:
        ...

    @margin_left.setter
    def margin_left(self, value: float):
        ...

    @property
    def margin_right(self) -> float:
        ...

    @margin_right.setter
    def margin_right(self, value: float):
        ...

    @property
    def margin_top(self) -> float:
        ...

    @margin_top.setter
    def margin_top(self, value: float):
        ...

    @property
    def margin_bottom(self) -> float:
        ...

    @margin_bottom.setter
    def margin_bottom(self, value: float):
        ...

    @property
    def text_vertical_type(self) -> TextVerticalType:
        ...

    @text_vertical_type.setter
    def text_vertical_type(self, value: TextVerticalType):
        ...

    @property
    def text_anchor_type(self) -> TextAnchorType:
        ...

    @text_anchor_type.setter
    def text_anchor_type(self, value: TextAnchorType):
        ...

    @property
    def anchor_center(self) -> bool:
        ...

    @anchor_center.setter
    def anchor_center(self, value: bool):
        ...

    @property
    def first_column(self) -> IColumn:
        ...

    @property
    def first_row(self) -> IRow:
        ...

    @property
    def col_span(self) -> int:
        ...

    @property
    def row_span(self) -> int:
        ...

    @property
    def text_frame(self) -> ITextFrame:
        ...

    @property
    def table(self) -> ITable:
        ...

    @property
    def is_merged_cell(self) -> bool:
        ...

    @property
    def cell_format(self) -> ICellFormat:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class ICellCollection:
    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ICell
        ...

    ...

class ICellFormat:
    def get_effective(self) -> ICellFormatEffectiveData:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def border_left(self) -> ILineFormat:
        ...

    @property
    def border_top(self) -> ILineFormat:
        ...

    @property
    def border_right(self) -> ILineFormat:
        ...

    @property
    def border_bottom(self) -> ILineFormat:
        ...

    @property
    def border_diagonal_down(self) -> ILineFormat:
        ...

    @property
    def border_diagonal_up(self) -> ILineFormat:
        ...

    @property
    def transparency(self) -> float:
        ...

    @transparency.setter
    def transparency(self, value: float):
        ...

    ...

class ICellFormatEffectiveData:
    @property
    def transparency(self) -> float:
        ...

    @property
    def as_i_base_table_format_effective_data(self) -> IBaseTableFormatEffectiveData:
        ...

    @property
    def fill_format(self) -> IFillFormatEffectiveData:
        ...

    @property
    def border_left(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_top(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_right(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_bottom(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_diagonal_down(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_diagonal_up(self) -> ILineFormatEffectiveData:
        ...

    ...

class IColorFormat:
    def to_string(self, format: ColorStringFormat) -> string:
        ...

    def copy_from(self, color: IColorFormat) -> None:
        ...

    @property
    def color_type(self) -> ColorType:
        ...

    @color_type.setter
    def color_type(self, value: ColorType):
        ...

    @property
    def color(self) -> aspose.pydrawing.Color:
        ...

    @color.setter
    def color(self, value: aspose.pydrawing.Color):
        ...

    @property
    def preset_color(self) -> PresetColor:
        ...

    @preset_color.setter
    def preset_color(self, value: PresetColor):
        ...

    @property
    def system_color(self) -> SystemColor:
        ...

    @system_color.setter
    def system_color(self, value: SystemColor):
        ...

    @property
    def scheme_color(self) -> SchemeColor:
        ...

    @scheme_color.setter
    def scheme_color(self, value: SchemeColor):
        ...

    @property
    def r(self) -> int:
        ...

    @r.setter
    def r(self, value: int):
        ...

    @property
    def g(self) -> int:
        ...

    @g.setter
    def g(self, value: int):
        ...

    @property
    def b(self) -> int:
        ...

    @b.setter
    def b(self, value: int):
        ...

    @property
    def float_r(self) -> float:
        ...

    @float_r.setter
    def float_r(self, value: float):
        ...

    @property
    def float_g(self) -> float:
        ...

    @float_g.setter
    def float_g(self, value: float):
        ...

    @property
    def float_b(self) -> float:
        ...

    @float_b.setter
    def float_b(self, value: float):
        ...

    @property
    def hue(self) -> float:
        ...

    @hue.setter
    def hue(self, value: float):
        ...

    @property
    def saturation(self) -> float:
        ...

    @saturation.setter
    def saturation(self, value: float):
        ...

    @property
    def luminance(self) -> float:
        ...

    @luminance.setter
    def luminance(self, value: float):
        ...

    @property
    def color_transform(self) -> IColorOperationCollection:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class IColorOperation:
    @property
    def operation_type(self) -> ColorTransformOperation:
        ...

    @property
    def parameter(self) -> float:
        ...

    ...

class IColorOperationCollection:
    @overload
    def add(self, operation: ColorTransformOperation, parameter: float) -> IColorOperation:
        ...

    @overload
    def add(self, operation: ColorTransformOperation) -> IColorOperation:
        ...

    @overload
    def insert(self, position: int, operation: ColorTransformOperation, parameter: float) -> IColorOperation:
        ...

    @overload
    def insert(self, position: int, operation: ColorTransformOperation) -> IColorOperation:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def clear(self) -> None:
        ...

    def clone_t(self) -> IColorOperationCollection:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IColorOperation
        ...

    def __setitem__(self, key: int, value: IColorOperation
        ...

    ...

class IColumn:
    @overload
    def set_text_format(self, source: IPortionFormat) -> None:
        ...

    @overload
    def set_text_format(self, source: IParagraphFormat) -> None:
        ...

    @overload
    def set_text_format(self, source: ITextFrameFormat) -> None:
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def column_format(self) -> IColumnFormat:
        ...

    @property
    def as_i_cell_collection(self) -> ICellCollection:
        ...

    @property
    def as_i_bulk_text_formattable(self) -> IBulkTextFormattable:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ICell
        ...

    ...

class IColumnCollection:
    def add_clone(self, templ: IColumn, with_attached_columns: bool) -> List[IColumn]:
        ...

    def insert_clone(self, index: int, templ: IColumn, with_attached_columns: bool) -> List[IColumn]:
        ...

    def remove_at(self, first_column_index: int, with_attached_rows: bool) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IColumn
        ...

    ...

class IColumnFormat:
    def get_effective(self) -> IColumnFormatEffectiveData:
        ...

    ...

class IColumnFormatEffectiveData:
    @property
    def as_i_base_table_format_effective_data(self) -> IBaseTableFormatEffectiveData:
        ...

    @property
    def fill_format(self) -> IFillFormatEffectiveData:
        ...

    @property
    def border_left(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_top(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_right(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_bottom(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_diagonal_down(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_diagonal_up(self) -> ILineFormatEffectiveData:
        ...

    ...

class IComment:
    def remove(self) -> None:
        ...

    @property
    def text(self) -> string:
        ...

    @text.setter
    def text(self, value: string):
        ...

    @property
    def created_time(self) -> DateTime:
        ...

    @created_time.setter
    def created_time(self, value: DateTime):
        ...

    @property
    def slide(self) -> ISlide:
        ...

    @property
    def author(self) -> ICommentAuthor:
        ...

    @property
    def position(self) -> aspose.pydrawing.PointF:
        ...

    @position.setter
    def position(self, value: aspose.pydrawing.PointF):
        ...

    @property
    def parent_comment(self) -> IComment:
        ...

    @parent_comment.setter
    def parent_comment(self, value: IComment):
        ...

    ...

class ICommentAuthor:
    def remove(self) -> None:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def initials(self) -> string:
        ...

    @initials.setter
    def initials(self, value: string):
        ...

    @property
    def comments(self) -> ICommentCollection:
        ...

    ...

class ICommentAuthorCollection:
    def add_author(self, name: string, initials: string) -> ICommentAuthor:
        ...

    def to_array(self) -> List[ICommentAuthor]:
        ...

    def find_by_name(self, name: string) -> List[ICommentAuthor]:
        ...

    def find_by_name_and_initials(self, name: string, initials: string) -> List[ICommentAuthor]:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def remove(self, author: ICommentAuthor) -> None:
        ...

    def clear(self) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ICommentAuthor
        ...

    ...

class ICommentCollection:
    @overload
    def to_array(self) -> List[IComment]:
        ...

    @overload
    def to_array(self, start_index: int, count: int) -> List[IComment]:
        ...

    def add_comment(self, text: string, slide: ISlide, position: aspose.pydrawing.PointF, creation_time: DateTime) -> IComment:
        ...

    def add_modern_comment(self, text: string, slide: ISlide, shape: IShape, position: aspose.pydrawing.PointF, creation_time: DateTime) -> IModernComment:
        ...

    def insert_comment(self, index: int, text: string, slide: ISlide, position: aspose.pydrawing.PointF, creation_time: DateTime) -> IComment:
        ...

    def insert_modern_comment(self, index: int, text: string, slide: ISlide, shape: IShape, position: aspose.pydrawing.PointF, creation_time: DateTime) -> IModernComment:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def remove(self, comment: IComment) -> None:
        ...

    def clear(self) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IComment
        ...

    ...

class ICommonSlideViewProperties:
    @property
    def scale(self) -> int:
        ...

    @scale.setter
    def scale(self, value: int):
        ...

    @property
    def variable_scale(self) -> bool:
        ...

    @variable_scale.setter
    def variable_scale(self, value: bool):
        ...

    ...

class IConnector:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def reroute(self) -> None:
        ...

    def get_geometry_paths(self) -> List[IGeometryPath]:
        ...

    def set_geometry_path(self, geometry_path: IGeometryPath) -> None:
        ...

    def set_geometry_paths(self, geometry_paths: List[IGeometryPath]) -> None:
        ...

    def create_shape_elements(self) -> List[IShapeElement]:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def shape_lock(self) -> IConnectorLock:
        ...

    @property
    def connector_lock(self) -> IConnectorLock:
        ...

    @property
    def start_shape_connected_to(self) -> IShape:
        ...

    @start_shape_connected_to.setter
    def start_shape_connected_to(self, value: IShape):
        ...

    @property
    def end_shape_connected_to(self) -> IShape:
        ...

    @end_shape_connected_to.setter
    def end_shape_connected_to(self, value: IShape):
        ...

    @property
    def start_shape_connection_site_index(self) -> int:
        ...

    @start_shape_connection_site_index.setter
    def start_shape_connection_site_index(self, value: int):
        ...

    @property
    def end_shape_connection_site_index(self) -> int:
        ...

    @end_shape_connection_site_index.setter
    def end_shape_connection_site_index(self, value: int):
        ...

    @property
    def as_i_geometry_shape(self) -> IGeometryShape:
        ...

    @property
    def shape_style(self) -> IShapeStyle:
        ...

    @property
    def shape_type(self) -> ShapeType:
        ...

    @shape_type.setter
    def shape_type(self, value: ShapeType):
        ...

    @property
    def adjustments(self) -> IAdjustValueCollection:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IConnectorLock:
    @property
    def grouping_locked(self) -> bool:
        ...

    @grouping_locked.setter
    def grouping_locked(self, value: bool):
        ...

    @property
    def select_locked(self) -> bool:
        ...

    @select_locked.setter
    def select_locked(self, value: bool):
        ...

    @property
    def rotate_locked(self) -> bool:
        ...

    @rotate_locked.setter
    def rotate_locked(self, value: bool):
        ...

    @property
    def aspect_ratio_locked(self) -> bool:
        ...

    @aspect_ratio_locked.setter
    def aspect_ratio_locked(self, value: bool):
        ...

    @property
    def position_move(self) -> bool:
        ...

    @position_move.setter
    def position_move(self, value: bool):
        ...

    @property
    def size_locked(self) -> bool:
        ...

    @size_locked.setter
    def size_locked(self, value: bool):
        ...

    @property
    def edit_points_locked(self) -> bool:
        ...

    @edit_points_locked.setter
    def edit_points_locked(self, value: bool):
        ...

    @property
    def adjust_handles_locked(self) -> bool:
        ...

    @adjust_handles_locked.setter
    def adjust_handles_locked(self, value: bool):
        ...

    @property
    def arrowheads_locked(self) -> bool:
        ...

    @arrowheads_locked.setter
    def arrowheads_locked(self, value: bool):
        ...

    @property
    def shape_type_locked(self) -> bool:
        ...

    @shape_type_locked.setter
    def shape_type_locked(self, value: bool):
        ...

    @property
    def as_i_base_shape_lock(self) -> IBaseShapeLock:
        ...

    @property
    def no_locks(self) -> bool:
        ...

    ...

class IControl:
    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def class_id(self) -> Guid:
        ...

    @property
    def substitute_picture_format(self) -> IPictureFillFormat:
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def properties(self) -> IControlPropertiesCollection:
        ...

    @property
    def persistence(self) -> PersistenceType:
        ...

    @property
    def active_x_control_binary(self) -> bytes:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class IControlCollection:
    def remove(self, item: IControl) -> None:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def clear(self) -> None:
        ...

    def add_control(self, control_type: ControlType, x: float, y: float, width: float, height: float) -> IControl:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IControl
        ...

    ...

class IControlPropertiesCollection:
    def add(self, name: string, value: string) -> None:
        ...

    def remove(self, name: string) -> None:
        ...

    def clear(self) -> None:
        ...

    @property
    def count(self) -> int:
        ...

    @property
    def names_of_properties(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    ...

class ICustomData:
    @property
    def tags(self) -> ITagCollection:
        ...

    @property
    def custom_xml_parts(self) -> ICustomXmlPartCollection:
        ...

    ...

class ICustomXmlPart:
    def remove(self) -> None:
        ...

    @property
    def xml_as_string(self) -> string:
        ...

    @xml_as_string.setter
    def xml_as_string(self, value: string):
        ...

    @property
    def xml_data(self) -> bytes:
        ...

    @xml_data.setter
    def xml_data(self, value: bytes):
        ...

    @property
    def item_id(self) -> Guid:
        ...

    @item_id.setter
    def item_id(self, value: Guid):
        ...

    @property
    def namespace_schemas(self) -> List[string]:
        ...

    ...

class ICustomXmlPartCollection:
    @overload
    def add(self, xml_data: bytes) -> ICustomXmlPart:
        ...

    @overload
    def add(self, xml_string: string) -> ICustomXmlPart:
        ...

    @overload
    def add(self, input_stream: System.IO.Stream) -> ICustomXmlPart:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def remove(self, item: ICustomXmlPart) -> bool:
        ...

    def clear(self) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ICustomXmlPart
        ...

    ...

class IDigitalSignature:
    @property
    def certificate(self) -> System.Security.Cryptography.X509Certificates.X509Certificate2:
        ...

    @property
    def is_valid(self) -> bool:
        ...

    @property
    def sign_time(self) -> DateTime:
        ...

    @property
    def comments(self) -> string:
        ...

    @comments.setter
    def comments(self, value: string):
        ...

    ...

class IDigitalSignatureCollection:
    def add(self, digital_signature: IDigitalSignature) -> None:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def clear(self) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IDigitalSignature
        ...

    ...

class IDocumentProperties:
    @overload
    def get_custom_property_value(self, name: string, value: Any) -> None:
        ...

    @overload
    def get_custom_property_value(self, name: string, value: Any) -> None:
        ...

    @overload
    def get_custom_property_value(self, name: string, value: Any) -> None:
        ...

    @overload
    def get_custom_property_value(self, name: string, value: Any) -> None:
        ...

    @overload
    def get_custom_property_value(self, name: string, value: Any) -> None:
        ...

    @overload
    def get_custom_property_value(self, name: string, value: Any) -> None:
        ...

    @overload
    def set_custom_property_value(self, name: string, value: bool) -> None:
        ...

    @overload
    def set_custom_property_value(self, name: string, value: int) -> None:
        ...

    @overload
    def set_custom_property_value(self, name: string, value: DateTime) -> None:
        ...

    @overload
    def set_custom_property_value(self, name: string, value: string) -> None:
        ...

    @overload
    def set_custom_property_value(self, name: string, value: float) -> None:
        ...

    @overload
    def set_custom_property_value(self, name: string, value: float) -> None:
        ...

    def get_custom_property_name(self, index: int) -> string:
        ...

    def remove_custom_property(self, name: string) -> bool:
        ...

    def contains_custom_property(self, name: string) -> bool:
        ...

    def clear_custom_properties(self) -> None:
        ...

    def clear_built_in_properties(self) -> None:
        ...

    @property
    def app_version(self) -> string:
        ...

    @property
    def name_of_application(self) -> string:
        ...

    @name_of_application.setter
    def name_of_application(self, value: string):
        ...

    @property
    def company(self) -> string:
        ...

    @company.setter
    def company(self, value: string):
        ...

    @property
    def manager(self) -> string:
        ...

    @manager.setter
    def manager(self, value: string):
        ...

    @property
    def presentation_format(self) -> string:
        ...

    @presentation_format.setter
    def presentation_format(self, value: string):
        ...

    @property
    def shared_doc(self) -> bool:
        ...

    @shared_doc.setter
    def shared_doc(self, value: bool):
        ...

    @property
    def application_template(self) -> string:
        ...

    @application_template.setter
    def application_template(self, value: string):
        ...

    @property
    def total_editing_time(self) -> TimeSpan:
        ...

    @total_editing_time.setter
    def total_editing_time(self, value: TimeSpan):
        ...

    @property
    def title(self) -> string:
        ...

    @title.setter
    def title(self, value: string):
        ...

    @property
    def subject(self) -> string:
        ...

    @subject.setter
    def subject(self, value: string):
        ...

    @property
    def author(self) -> string:
        ...

    @author.setter
    def author(self, value: string):
        ...

    @property
    def keywords(self) -> string:
        ...

    @keywords.setter
    def keywords(self, value: string):
        ...

    @property
    def comments(self) -> string:
        ...

    @comments.setter
    def comments(self, value: string):
        ...

    @property
    def category(self) -> string:
        ...

    @category.setter
    def category(self, value: string):
        ...

    @property
    def created_time(self) -> DateTime:
        ...

    @created_time.setter
    def created_time(self, value: DateTime):
        ...

    @property
    def last_saved_time(self) -> DateTime:
        ...

    @last_saved_time.setter
    def last_saved_time(self, value: DateTime):
        ...

    @property
    def last_printed(self) -> DateTime:
        ...

    @last_printed.setter
    def last_printed(self, value: DateTime):
        ...

    @property
    def last_saved_by(self) -> string:
        ...

    @last_saved_by.setter
    def last_saved_by(self, value: string):
        ...

    @property
    def revision_number(self) -> int:
        ...

    @revision_number.setter
    def revision_number(self, value: int):
        ...

    @property
    def content_status(self) -> string:
        ...

    @content_status.setter
    def content_status(self, value: string):
        ...

    @property
    def content_type(self) -> string:
        ...

    @content_type.setter
    def content_type(self, value: string):
        ...

    @property
    def hyperlink_base(self) -> string:
        ...

    @hyperlink_base.setter
    def hyperlink_base(self, value: string):
        ...

    @property
    def count_of_custom_properties(self) -> int:
        ...

    ...

class IEffectFormat:
    def set_blur_effect(self, radius: float, grow: bool) -> None:
        ...

    def enable_fill_overlay_effect(self) -> None:
        ...

    def enable_glow_effect(self) -> None:
        ...

    def enable_inner_shadow_effect(self) -> None:
        ...

    def enable_outer_shadow_effect(self) -> None:
        ...

    def enable_preset_shadow_effect(self) -> None:
        ...

    def enable_reflection_effect(self) -> None:
        ...

    def enable_soft_edge_effect(self) -> None:
        ...

    def disable_blur_effect(self) -> None:
        ...

    def disable_fill_overlay_effect(self) -> None:
        ...

    def disable_glow_effect(self) -> None:
        ...

    def disable_inner_shadow_effect(self) -> None:
        ...

    def disable_outer_shadow_effect(self) -> None:
        ...

    def disable_preset_shadow_effect(self) -> None:
        ...

    def disable_reflection_effect(self) -> None:
        ...

    def disable_soft_edge_effect(self) -> None:
        ...

    def get_effective(self) -> IEffectFormatEffectiveData:
        ...

    @property
    def is_no_effects(self) -> bool:
        ...

    @property
    def blur_effect(self) -> aspose.slides.effects.IBlur:
        ...

    @blur_effect.setter
    def blur_effect(self, value: aspose.slides.effects.IBlur):
        ...

    @property
    def fill_overlay_effect(self) -> aspose.slides.effects.IFillOverlay:
        ...

    @fill_overlay_effect.setter
    def fill_overlay_effect(self, value: aspose.slides.effects.IFillOverlay):
        ...

    @property
    def glow_effect(self) -> aspose.slides.effects.IGlow:
        ...

    @glow_effect.setter
    def glow_effect(self, value: aspose.slides.effects.IGlow):
        ...

    @property
    def inner_shadow_effect(self) -> aspose.slides.effects.IInnerShadow:
        ...

    @inner_shadow_effect.setter
    def inner_shadow_effect(self, value: aspose.slides.effects.IInnerShadow):
        ...

    @property
    def outer_shadow_effect(self) -> aspose.slides.effects.IOuterShadow:
        ...

    @outer_shadow_effect.setter
    def outer_shadow_effect(self, value: aspose.slides.effects.IOuterShadow):
        ...

    @property
    def preset_shadow_effect(self) -> aspose.slides.effects.IPresetShadow:
        ...

    @preset_shadow_effect.setter
    def preset_shadow_effect(self, value: aspose.slides.effects.IPresetShadow):
        ...

    @property
    def reflection_effect(self) -> aspose.slides.effects.IReflection:
        ...

    @reflection_effect.setter
    def reflection_effect(self, value: aspose.slides.effects.IReflection):
        ...

    @property
    def soft_edge_effect(self) -> aspose.slides.effects.ISoftEdge:
        ...

    @soft_edge_effect.setter
    def soft_edge_effect(self, value: aspose.slides.effects.ISoftEdge):
        ...

    @property
    def as_i_effect_param_source(self) -> IEffectParamSource:
        ...

    ...

class IEffectFormatEffectiveData:
    @property
    def is_no_effects(self) -> bool:
        ...

    @property
    def blur_effect(self) -> aspose.slides.effects.IBlurEffectiveData:
        ...

    @property
    def fill_overlay_effect(self) -> aspose.slides.effects.IFillOverlayEffectiveData:
        ...

    @property
    def glow_effect(self) -> aspose.slides.effects.IGlowEffectiveData:
        ...

    @property
    def inner_shadow_effect(self) -> aspose.slides.effects.IInnerShadowEffectiveData:
        ...

    @property
    def outer_shadow_effect(self) -> aspose.slides.effects.IOuterShadowEffectiveData:
        ...

    @property
    def preset_shadow_effect(self) -> aspose.slides.effects.IPresetShadowEffectiveData:
        ...

    @property
    def reflection_effect(self) -> aspose.slides.effects.IReflectionEffectiveData:
        ...

    @property
    def soft_edge_effect(self) -> aspose.slides.effects.ISoftEdgeEffectiveData:
        ...

    @property
    def as_i_effect_param_source(self) -> IEffectParamSource:
        ...

    ...

class IEffectParamSource:
    ...

class IField:
    @property
    def type(self) -> IFieldType:
        ...

    @type.setter
    def type(self, value: IFieldType):
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class IFieldType:
    @property
    def internal_string(self) -> string:
        ...

    @internal_string.setter
    def internal_string(self, value: string):
        ...

    ...

class IFillFormat:
    def get_effective(self) -> IFillFormatEffectiveData:
        ...

    @property
    def fill_type(self) -> FillType:
        ...

    @fill_type.setter
    def fill_type(self, value: FillType):
        ...

    @property
    def solid_fill_color(self) -> IColorFormat:
        ...

    @property
    def gradient_format(self) -> IGradientFormat:
        ...

    @property
    def pattern_format(self) -> IPatternFormat:
        ...

    @property
    def picture_fill_format(self) -> IPictureFillFormat:
        ...

    @property
    def rotate_with_shape(self) -> NullableBool:
        ...

    @rotate_with_shape.setter
    def rotate_with_shape(self, value: NullableBool):
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class IFillFormatEffectiveData:
    @property
    def fill_type(self) -> FillType:
        ...

    @property
    def solid_fill_color(self) -> aspose.pydrawing.Color:
        ...

    @property
    def gradient_format(self) -> IGradientFormatEffectiveData:
        ...

    @property
    def pattern_format(self) -> IPatternFormatEffectiveData:
        ...

    @property
    def picture_fill_format(self) -> IPictureFillFormatEffectiveData:
        ...

    @property
    def rotate_with_shape(self) -> bool:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class IFillParamSource:
    ...

class IFontData:
    def get_font_name(self, theme: aspose.slides.theme.IThemeEffectiveData) -> string:
        ...

    @property
    def font_name(self) -> string:
        ...

    ...

class IFontDataFactory:
    def create_font_data(self, font_name: string) -> IFontData:
        ...

    ...

class IFontFallBackRule:
    @overload
    def add_fall_back_fonts(self, font_name: string) -> None:
        ...

    @overload
    def add_fall_back_fonts(self, font_names: List[string]) -> None:
        ...

    @overload
    def to_array(self) -> List[string]:
        ...

    @overload
    def to_array(self, start_index: int, count: int) -> List[string]:
        ...

    def clear(self) -> None:
        ...

    def remove(self, font_name: string) -> None:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def index_of(self, font_name: string) -> int:
        ...

    @property
    def range_start_index(self) -> int:
        ...

    @property
    def range_end_index(self) -> int:
        ...

    @property
    def count(self) -> int:
        ...

    def __getitem__(self, key: int) -> string
        ...

    ...

class IFontFallBackRulesCollection:
    def add(self, source_rule: IFontFallBackRule) -> None:
        ...

    def remove(self, target_rule: IFontFallBackRule) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IFontFallBackRule
        ...

    ...

class IFontSources:
    @property
    def font_folders(self) -> List[string]:
        ...

    @font_folders.setter
    def font_folders(self, value: List[string]):
        ...

    @property
    def memory_fonts(self) -> List[bytes]:
        ...

    @memory_fonts.setter
    def memory_fonts(self, value: List[bytes]):
        ...

    ...

class IFontSubstRule:
    @property
    def source_font(self) -> IFontData:
        ...

    @property
    def dest_font(self) -> IFontData:
        ...

    @property
    def replace_font_condition(self) -> FontSubstCondition:
        ...

    ...

class IFontSubstRuleCollection:
    def add(self, value: IFontSubstRule) -> None:
        ...

    def remove(self, value: IFontSubstRule) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IFontSubstRule
        ...

    ...

class IFonts:
    @property
    def latin_font(self) -> IFontData:
        ...

    @latin_font.setter
    def latin_font(self, value: IFontData):
        ...

    @property
    def east_asian_font(self) -> IFontData:
        ...

    @east_asian_font.setter
    def east_asian_font(self, value: IFontData):
        ...

    @property
    def complex_script_font(self) -> IFontData:
        ...

    @complex_script_font.setter
    def complex_script_font(self, value: IFontData):
        ...

    ...

class IFontsEffectiveData:
    @property
    def latin_font(self) -> IFontData:
        ...

    @property
    def east_asian_font(self) -> IFontData:
        ...

    @property
    def complex_script_font(self) -> IFontData:
        ...

    ...

class IFontsLoader:
    ...

class IFontsManager:
    @overload
    def add_embedded_font(self, font_data: IFontData, embed_font_rule: aspose.slides.export.EmbedFontCharacters) -> None:
        ...

    @overload
    def add_embedded_font(self, font_data: bytes, embed_font_rule: aspose.slides.export.EmbedFontCharacters) -> None:
        ...

    @overload
    def replace_font(self, source_font: IFontData, dest_font: IFontData) -> None:
        ...

    @overload
    def replace_font(self, subst_rule: IFontSubstRule) -> None:
        ...

    @overload
    def replace_font(self, subst_rules: IFontSubstRuleCollection) -> None:
        ...

    def get_fonts(self) -> List[IFontData]:
        ...

    def get_substitutions(self) -> Iterable[FontSubstitutionInfo]:
        ...

    def get_embedded_fonts(self) -> List[IFontData]:
        ...

    def remove_embedded_font(self, font_data: IFontData) -> None:
        ...

    @property
    def font_subst_rule_list(self) -> IFontSubstRuleCollection:
        ...

    @font_subst_rule_list.setter
    def font_subst_rule_list(self, value: IFontSubstRuleCollection):
        ...

    @property
    def font_fall_back_rules_collection(self) -> IFontFallBackRulesCollection:
        ...

    @font_fall_back_rules_collection.setter
    def font_fall_back_rules_collection(self, value: IFontFallBackRulesCollection):
        ...

    ...

class IFormatFactory:
    def create_portion_format(self) -> IPortionFormat:
        ...

    def create_paragraph_format(self) -> IParagraphFormat:
        ...

    def create_text_frame_format(self) -> ITextFrameFormat:
        ...

    ...

class IGeometryPath:
    @overload
    def line_to(self, point: aspose.pydrawing.PointF) -> None:
        ...

    @overload
    def line_to(self, x: float, y: float) -> None:
        ...

    @overload
    def line_to(self, point: aspose.pydrawing.PointF, index: int) -> None:
        ...

    @overload
    def line_to(self, x: float, y: float, index: int) -> None:
        ...

    @overload
    def cubic_bezier_to(self, point1: aspose.pydrawing.PointF, point2: aspose.pydrawing.PointF, point3: aspose.pydrawing.PointF) -> None:
        ...

    @overload
    def cubic_bezier_to(self, x1: float, y1: float, x2: float, y2: float, x3: float, y3: float) -> None:
        ...

    @overload
    def cubic_bezier_to(self, point1: aspose.pydrawing.PointF, point2: aspose.pydrawing.PointF, point3: aspose.pydrawing.PointF, index: int) -> None:
        ...

    @overload
    def cubic_bezier_to(self, x1: float, y1: float, x2: float, y2: float, x3: float, y3: float, index: int) -> None:
        ...

    @overload
    def quadratic_bezier_to(self, point1: aspose.pydrawing.PointF, point2: aspose.pydrawing.PointF) -> None:
        ...

    @overload
    def quadratic_bezier_to(self, x1: float, y1: float, x2: float, y2: float) -> None:
        ...

    @overload
    def quadratic_bezier_to(self, point1: aspose.pydrawing.PointF, point2: aspose.pydrawing.PointF, index: int) -> None:
        ...

    @overload
    def quadratic_bezier_to(self, x1: float, y1: float, x2: float, y2: float, index: int) -> None:
        ...

    @overload
    def move_to(self, point: aspose.pydrawing.PointF) -> None:
        ...

    @overload
    def move_to(self, x: float, y: float) -> None:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def close_figure(self) -> None:
        ...

    def arc_to(self, width: float, heigth: float, start_angle: float, sweep_angle: float) -> None:
        ...

    @property
    def path_data(self) -> List[IPathSegment]:
        ...

    @property
    def fill_mode(self) -> PathFillModeType:
        ...

    @fill_mode.setter
    def fill_mode(self, value: PathFillModeType):
        ...

    @property
    def stroke(self) -> bool:
        ...

    @stroke.setter
    def stroke(self, value: bool):
        ...

    ...

class IGeometryShape:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def get_geometry_paths(self) -> List[IGeometryPath]:
        ...

    def set_geometry_path(self, geometry_path: IGeometryPath) -> None:
        ...

    def set_geometry_paths(self, geometry_paths: List[IGeometryPath]) -> None:
        ...

    def create_shape_elements(self) -> List[IShapeElement]:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def shape_style(self) -> IShapeStyle:
        ...

    @property
    def shape_type(self) -> ShapeType:
        ...

    @shape_type.setter
    def shape_type(self, value: ShapeType):
        ...

    @property
    def adjustments(self) -> IAdjustValueCollection:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IBaseShapeLock:
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IGlobalLayoutSlideCollection:
    @overload
    def add_clone(self, source_layout: ILayoutSlide) -> ILayoutSlide:
        ...

    @overload
    def add_clone(self, source_layout: ILayoutSlide, dest_master: IMasterSlide) -> ILayoutSlide:
        ...

    def add(self, master: IMasterSlide, layout_type: SlideLayoutType, layout_name: string) -> ILayoutSlide:
        ...

    def get_by_type(self, type: SlideLayoutType) -> ILayoutSlide:
        ...

    def remove(self, value: ILayoutSlide) -> None:
        ...

    def remove_unused(self) -> None:
        ...

    @property
    def as_i_layout_slide_collection(self) -> ILayoutSlideCollection:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ILayoutSlide
        ...

    ...

class IGradientFormat:
    @property
    def tile_flip(self) -> TileFlip:
        ...

    @tile_flip.setter
    def tile_flip(self, value: TileFlip):
        ...

    @property
    def gradient_direction(self) -> GradientDirection:
        ...

    @gradient_direction.setter
    def gradient_direction(self, value: GradientDirection):
        ...

    @property
    def linear_gradient_angle(self) -> float:
        ...

    @linear_gradient_angle.setter
    def linear_gradient_angle(self, value: float):
        ...

    @property
    def linear_gradient_scaled(self) -> NullableBool:
        ...

    @linear_gradient_scaled.setter
    def linear_gradient_scaled(self, value: NullableBool):
        ...

    @property
    def gradient_shape(self) -> GradientShape:
        ...

    @gradient_shape.setter
    def gradient_shape(self, value: GradientShape):
        ...

    @property
    def gradient_stops(self) -> IGradientStopCollection:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class IGradientFormatEffectiveData:
    @property
    def tile_flip(self) -> TileFlip:
        ...

    @property
    def gradient_direction(self) -> GradientDirection:
        ...

    @property
    def linear_gradient_angle(self) -> float:
        ...

    @property
    def linear_gradient_scaled(self) -> bool:
        ...

    @property
    def gradient_shape(self) -> GradientShape:
        ...

    @property
    def gradient_stops(self) -> IGradientStopCollectionEffectiveData:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class IGradientStop:
    @property
    def position(self) -> float:
        ...

    @position.setter
    def position(self, value: float):
        ...

    @property
    def color(self) -> IColorFormat:
        ...

    ...

class IGradientStopCollection:
    @overload
    def add(self, position: float, color: aspose.pydrawing.Color) -> IGradientStop:
        ...

    @overload
    def add(self, position: float, preset_color: PresetColor) -> IGradientStop:
        ...

    @overload
    def add(self, position: float, scheme_color: SchemeColor) -> IGradientStop:
        ...

    @overload
    def insert(self, index: int, position: float, color: aspose.pydrawing.Color) -> None:
        ...

    @overload
    def insert(self, index: int, position: float, preset_color: PresetColor) -> None:
        ...

    @overload
    def insert(self, index: int, position: float, scheme_color: SchemeColor) -> None:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def clear(self) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IGradientStop
        ...

    ...

class IGradientStopCollectionEffectiveData:
    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IGradientStopEffectiveData
        ...

    ...

class IGradientStopEffectiveData:
    @property
    def position(self) -> float:
        ...

    @property
    def color(self) -> aspose.pydrawing.Color:
        ...

    ...

class IGraphicalObject:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IGraphicalObjectLock:
    @property
    def grouping_locked(self) -> bool:
        ...

    @grouping_locked.setter
    def grouping_locked(self, value: bool):
        ...

    @property
    def drilldown_locked(self) -> bool:
        ...

    @drilldown_locked.setter
    def drilldown_locked(self, value: bool):
        ...

    @property
    def select_locked(self) -> bool:
        ...

    @select_locked.setter
    def select_locked(self, value: bool):
        ...

    @property
    def aspect_ratio_locked(self) -> bool:
        ...

    @aspect_ratio_locked.setter
    def aspect_ratio_locked(self, value: bool):
        ...

    @property
    def position_locked(self) -> bool:
        ...

    @position_locked.setter
    def position_locked(self, value: bool):
        ...

    @property
    def size_locked(self) -> bool:
        ...

    @size_locked.setter
    def size_locked(self, value: bool):
        ...

    @property
    def as_i_base_shape_lock(self) -> IBaseShapeLock:
        ...

    @property
    def no_locks(self) -> bool:
        ...

    ...

class IGroupShape:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def shape_lock(self) -> IGroupShapeLock:
        ...

    @property
    def group_shape_lock(self) -> IGroupShapeLock:
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IGroupShapeLock:
    @property
    def grouping_locked(self) -> bool:
        ...

    @grouping_locked.setter
    def grouping_locked(self, value: bool):
        ...

    @property
    def ungrouping_locked(self) -> bool:
        ...

    @ungrouping_locked.setter
    def ungrouping_locked(self, value: bool):
        ...

    @property
    def select_locked(self) -> bool:
        ...

    @select_locked.setter
    def select_locked(self, value: bool):
        ...

    @property
    def rotation_locked(self) -> bool:
        ...

    @rotation_locked.setter
    def rotation_locked(self, value: bool):
        ...

    @property
    def aspect_ratio_locked(self) -> bool:
        ...

    @aspect_ratio_locked.setter
    def aspect_ratio_locked(self, value: bool):
        ...

    @property
    def position_locked(self) -> bool:
        ...

    @position_locked.setter
    def position_locked(self, value: bool):
        ...

    @property
    def size_locked(self) -> bool:
        ...

    @size_locked.setter
    def size_locked(self, value: bool):
        ...

    @property
    def as_i_base_shape_lock(self) -> IBaseShapeLock:
        ...

    @property
    def no_locks(self) -> bool:
        ...

    ...

class IHyperlink:
    def equals(self, hlink: IHyperlink) -> bool:
        ...

    @property
    def action_type(self) -> HyperlinkActionType:
        ...

    @property
    def external_url(self) -> string:
        ...

    @property
    def external_url_original(self) -> string:
        ...

    @property
    def target_slide(self) -> ISlide:
        ...

    @property
    def target_frame(self) -> string:
        ...

    @target_frame.setter
    def target_frame(self, value: string):
        ...

    @property
    def tooltip(self) -> string:
        ...

    @tooltip.setter
    def tooltip(self, value: string):
        ...

    @property
    def history(self) -> bool:
        ...

    @history.setter
    def history(self, value: bool):
        ...

    @property
    def highlight_click(self) -> bool:
        ...

    @highlight_click.setter
    def highlight_click(self, value: bool):
        ...

    @property
    def stop_sound_on_click(self) -> bool:
        ...

    @stop_sound_on_click.setter
    def stop_sound_on_click(self, value: bool):
        ...

    @property
    def sound(self) -> IAudio:
        ...

    @sound.setter
    def sound(self, value: IAudio):
        ...

    @property
    def color_source(self) -> HyperlinkColorSource:
        ...

    @color_source.setter
    def color_source(self, value: HyperlinkColorSource):
        ...

    ...

class IHyperlinkContainer:
    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IHyperlinkManager:
    def set_external_hyperlink_click(self, url: string) -> IHyperlink:
        ...

    def set_internal_hyperlink_click(self, target_slide: ISlide) -> IHyperlink:
        ...

    def remove_hyperlink_click(self) -> None:
        ...

    def set_external_hyperlink_mouse_over(self, url: string) -> IHyperlink:
        ...

    def set_internal_hyperlink_mouse_over(self, target_slide: ISlide) -> IHyperlink:
        ...

    def remove_hyperlink_mouse_over(self) -> None:
        ...

    def set_macro_hyperlink_click(self, macro_name: string) -> IHyperlink:
        ...

    ...

class IHyperlinkQueries:
    def get_hyperlink_clicks(self) -> List[IHyperlinkContainer]:
        ...

    def get_hyperlink_mouse_overs(self) -> List[IHyperlinkContainer]:
        ...

    def get_any_hyperlinks(self) -> List[IHyperlinkContainer]:
        ...

    def remove_all_hyperlinks(self) -> None:
        ...

    ...

class IImage:
    @overload
    def save(self, filename: string) -> None:
        ...

    @overload
    def save(self, filename: string, format: ImageFormat) -> None:
        ...

    @overload
    def save(self, stream: System.IO.Stream, format: ImageFormat) -> None:
        ...

    @property
    def size(self) -> aspose.pydrawing.Size:
        ...

    @property
    def width(self) -> int:
        ...

    @property
    def height(self) -> int:
        ...

    ...

class IImageCollection:
    @overload
    def add_image(self, image: aspose.pydrawing.Image) -> IPPImage:
        ...

    @overload
    def add_image(self, image: IImage) -> IPPImage:
        ...

    @overload
    def add_image(self, stream: System.IO.Stream) -> IPPImage:
        ...

    @overload
    def add_image(self, stream: System.IO.Stream, loading_stream_behavior: LoadingStreamBehavior) -> IPPImage:
        ...

    @overload
    def add_image(self, buffer: bytes) -> IPPImage:
        ...

    @overload
    def add_image(self, image_source: IPPImage) -> IPPImage:
        ...

    @overload
    def add_image(self, svg_image: ISvgImage) -> IPPImage:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IPPImage
        ...

    ...

class IImageWrapper:
    @overload
    def save(self, file_name: string) -> None:
        ...

    @overload
    def save(self, stream: System.IO.Stream, image_format: PPImageFormat) -> None:
        ...

    @overload
    def save(self, file_name: string, image_format: PPImageFormat) -> None:
        ...

    @property
    def image(self) -> aspose.pydrawing.Image:
        ...

    @property
    def image_source(self) -> IImage:
        ...

    @property
    def size(self) -> aspose.pydrawing.Size:
        ...

    @property
    def as_i_disposable(self) -> IDisposable:
        ...

    ...

class IImageWrapperFactory:
    @overload
    def create_image_wrapper(self, image: aspose.pydrawing.Image) -> IImageWrapper:
        ...

    @overload
    def create_image_wrapper(self, image: IImage) -> IImageWrapper:
        ...

    @overload
    def create_image_wrapper(self, stream: System.IO.Stream) -> IImageWrapper:
        ...

    @overload
    def create_image_wrapper(self, file_name: string) -> IImageWrapper:
        ...

    ...

class IInterruptionToken:
    def throw_if_interruption_requested(self) -> None:
        ...

    @property
    def is_interruption_requested(self) -> bool:
        ...

    ...

class IInterruptionTokenSource:
    def interrupt(self) -> None:
        ...

    @property
    def token(self) -> IInterruptionToken:
        ...

    @property
    def is_interruption_requested(self) -> bool:
        ...

    ...

class ILayoutSlide:
    def get_depending_slides(self) -> List[ISlide]:
        ...

    def remove(self) -> None:
        ...

    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        ...

    def join_portions_with_same_formatting(self) -> None:
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        ...

    @property
    def header_footer_manager(self) -> ILayoutSlideHeaderFooterManager:
        ...

    @property
    def master_slide(self) -> IMasterSlide:
        ...

    @master_slide.setter
    def master_slide(self, value: IMasterSlide):
        ...

    @property
    def layout_type(self) -> SlideLayoutType:
        ...

    @property
    def has_depending_slides(self) -> bool:
        ...

    @property
    def as_i_base_slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_override_themeable(self) -> aspose.slides.theme.IOverrideThemeable:
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def theme_manager(self) -> aspose.slides.theme.IOverrideThemeManager:
        ...

    ...

class ILayoutSlideCollection:
    def get_by_type(self, type: SlideLayoutType) -> ILayoutSlide:
        ...

    def remove(self, value: ILayoutSlide) -> None:
        ...

    def remove_unused(self) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ILayoutSlide
        ...

    ...

class ILayoutSlideHeaderFooterManager:
    def set_footer_and_child_footers_visibility(self, is_visible: bool) -> None:
        ...

    def set_slide_number_and_child_slide_numbers_visibility(self, is_visible: bool) -> None:
        ...

    def set_date_time_and_child_date_times_visibility(self, is_visible: bool) -> None:
        ...

    def set_footer_and_child_footers_text(self, text: string) -> None:
        ...

    def set_date_time_and_child_date_times_text(self, text: string) -> None:
        ...

    def set_footer_visibility(self, is_visible: bool) -> None:
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        ...

    def set_footer_text(self, text: string) -> None:
        ...

    def set_date_time_text(self, text: string) -> None:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class ILegacyDiagram:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def convert_to_smart_art(self) -> aspose.slides.smartart.ISmartArt:
        ...

    def convert_to_group_shape(self) -> IGroupShape:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class ILicense:
    @overload
    def set_license(self, license_name: string) -> None:
        ...

    @overload
    def set_license(self, stream: System.IO.Stream) -> None:
        ...

    def reset_license(self) -> None:
        ...

    def is_licensed(self) -> bool:
        ...

    ...

class ILightRig:
    def set_rotation(self, latitude: float, longitude: float, revolution: float) -> None:
        ...

    def get_rotation(self) -> List[float]:
        ...

    @property
    def direction(self) -> LightingDirection:
        ...

    @direction.setter
    def direction(self, value: LightingDirection):
        ...

    @property
    def light_type(self) -> LightRigPresetType:
        ...

    @light_type.setter
    def light_type(self, value: LightRigPresetType):
        ...

    ...

class ILightRigEffectiveData:
    def get_rotation(self) -> List[float]:
        ...

    @property
    def direction(self) -> LightingDirection:
        ...

    @property
    def light_type(self) -> LightRigPresetType:
        ...

    ...

class ILineFillFormat:
    @property
    def fill_type(self) -> FillType:
        ...

    @fill_type.setter
    def fill_type(self, value: FillType):
        ...

    @property
    def solid_fill_color(self) -> IColorFormat:
        ...

    @property
    def gradient_format(self) -> IGradientFormat:
        ...

    @property
    def pattern_format(self) -> IPatternFormat:
        ...

    @property
    def rotate_with_shape(self) -> NullableBool:
        ...

    @rotate_with_shape.setter
    def rotate_with_shape(self, value: NullableBool):
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class ILineFillFormatEffectiveData:
    @property
    def fill_type(self) -> FillType:
        ...

    @property
    def solid_fill_color(self) -> aspose.pydrawing.Color:
        ...

    @property
    def gradient_format(self) -> IGradientFormatEffectiveData:
        ...

    @property
    def pattern_format(self) -> IPatternFormatEffectiveData:
        ...

    @property
    def rotate_with_shape(self) -> bool:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class ILineFormat:
    def equals(self, line_format: ILineFormat) -> bool:
        ...

    def get_effective(self) -> ILineFormatEffectiveData:
        ...

    @property
    def is_format_not_defined(self) -> bool:
        ...

    @property
    def fill_format(self) -> ILineFillFormat:
        ...

    @property
    def sketch_format(self) -> ISketchFormat:
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def dash_style(self) -> LineDashStyle:
        ...

    @dash_style.setter
    def dash_style(self, value: LineDashStyle):
        ...

    @property
    def custom_dash_pattern(self) -> List[float]:
        ...

    @custom_dash_pattern.setter
    def custom_dash_pattern(self, value: List[float]):
        ...

    @property
    def cap_style(self) -> LineCapStyle:
        ...

    @cap_style.setter
    def cap_style(self, value: LineCapStyle):
        ...

    @property
    def style(self) -> LineStyle:
        ...

    @style.setter
    def style(self, value: LineStyle):
        ...

    @property
    def alignment(self) -> LineAlignment:
        ...

    @alignment.setter
    def alignment(self, value: LineAlignment):
        ...

    @property
    def join_style(self) -> LineJoinStyle:
        ...

    @join_style.setter
    def join_style(self, value: LineJoinStyle):
        ...

    @property
    def miter_limit(self) -> float:
        ...

    @miter_limit.setter
    def miter_limit(self, value: float):
        ...

    @property
    def begin_arrowhead_style(self) -> LineArrowheadStyle:
        ...

    @begin_arrowhead_style.setter
    def begin_arrowhead_style(self, value: LineArrowheadStyle):
        ...

    @property
    def end_arrowhead_style(self) -> LineArrowheadStyle:
        ...

    @end_arrowhead_style.setter
    def end_arrowhead_style(self, value: LineArrowheadStyle):
        ...

    @property
    def begin_arrowhead_width(self) -> LineArrowheadWidth:
        ...

    @begin_arrowhead_width.setter
    def begin_arrowhead_width(self, value: LineArrowheadWidth):
        ...

    @property
    def end_arrowhead_width(self) -> LineArrowheadWidth:
        ...

    @end_arrowhead_width.setter
    def end_arrowhead_width(self, value: LineArrowheadWidth):
        ...

    @property
    def begin_arrowhead_length(self) -> LineArrowheadLength:
        ...

    @begin_arrowhead_length.setter
    def begin_arrowhead_length(self, value: LineArrowheadLength):
        ...

    @property
    def end_arrowhead_length(self) -> LineArrowheadLength:
        ...

    @end_arrowhead_length.setter
    def end_arrowhead_length(self, value: LineArrowheadLength):
        ...

    @property
    def as_i_line_param_source(self) -> ILineParamSource:
        ...

    ...

class ILineFormatEffectiveData:
    def equals(self, lf: ILineFormatEffectiveData) -> bool:
        ...

    @property
    def fill_format(self) -> ILineFillFormatEffectiveData:
        ...

    @property
    def sketch_format(self) -> ISketchFormatEffectiveData:
        ...

    @property
    def width(self) -> float:
        ...

    @property
    def dash_style(self) -> LineDashStyle:
        ...

    @property
    def custom_dash_pattern(self) -> List[float]:
        ...

    @property
    def cap_style(self) -> LineCapStyle:
        ...

    @property
    def style(self) -> LineStyle:
        ...

    @property
    def alignment(self) -> LineAlignment:
        ...

    @property
    def join_style(self) -> LineJoinStyle:
        ...

    @property
    def miter_limit(self) -> float:
        ...

    @property
    def begin_arrowhead_style(self) -> LineArrowheadStyle:
        ...

    @property
    def end_arrowhead_style(self) -> LineArrowheadStyle:
        ...

    @property
    def begin_arrowhead_width(self) -> LineArrowheadWidth:
        ...

    @property
    def end_arrowhead_width(self) -> LineArrowheadWidth:
        ...

    @property
    def begin_arrowhead_length(self) -> LineArrowheadLength:
        ...

    @property
    def end_arrowhead_length(self) -> LineArrowheadLength:
        ...

    @property
    def as_i_line_param_source(self) -> ILineParamSource:
        ...

    ...

class ILineParamSource:
    ...

class ILoadOptions:
    @property
    def load_format(self) -> LoadFormat:
        ...

    @load_format.setter
    def load_format(self, value: LoadFormat):
        ...

    @property
    def default_regular_font(self) -> string:
        ...

    @default_regular_font.setter
    def default_regular_font(self, value: string):
        ...

    @property
    def default_symbol_font(self) -> string:
        ...

    @default_symbol_font.setter
    def default_symbol_font(self, value: string):
        ...

    @property
    def default_asian_font(self) -> string:
        ...

    @default_asian_font.setter
    def default_asian_font(self, value: string):
        ...

    @property
    def password(self) -> string:
        ...

    @password.setter
    def password(self, value: string):
        ...

    @property
    def only_load_document_properties(self) -> bool:
        ...

    @only_load_document_properties.setter
    def only_load_document_properties(self, value: bool):
        ...

    @property
    def warning_callback(self) -> aspose.slides.warnings.IWarningCallback:
        ...

    @warning_callback.setter
    def warning_callback(self, value: aspose.slides.warnings.IWarningCallback):
        ...

    @property
    def blob_management_options(self) -> IBlobManagementOptions:
        ...

    @blob_management_options.setter
    def blob_management_options(self, value: IBlobManagementOptions):
        ...

    @property
    def document_level_font_sources(self) -> IFontSources:
        ...

    @document_level_font_sources.setter
    def document_level_font_sources(self, value: IFontSources):
        ...

    @property
    def interruption_token(self) -> IInterruptionToken:
        ...

    @interruption_token.setter
    def interruption_token(self, value: IInterruptionToken):
        ...

    @property
    def resource_loading_callback(self) -> IResourceLoadingCallback:
        ...

    @resource_loading_callback.setter
    def resource_loading_callback(self, value: IResourceLoadingCallback):
        ...

    @property
    def spreadsheet_options(self) -> ISpreadsheetOptions:
        ...

    @spreadsheet_options.setter
    def spreadsheet_options(self, value: ISpreadsheetOptions):
        ...

    @property
    def default_text_language(self) -> string:
        ...

    @default_text_language.setter
    def default_text_language(self, value: string):
        ...

    ...

class IMasterHandoutSlide:
    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        ...

    def join_portions_with_same_formatting(self) -> None:
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        ...

    @property
    def header_footer_manager(self) -> IMasterHandoutSlideHeaderFooterManager:
        ...

    @property
    def as_i_base_slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_master_themeable(self) -> aspose.slides.theme.IMasterThemeable:
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def theme_manager(self) -> aspose.slides.theme.IMasterThemeManager:
        ...

    ...

class IMasterHandoutSlideHeaderFooterManager:
    def set_header_visibility(self, is_visible: bool) -> None:
        ...

    def set_header_text(self, text: string) -> None:
        ...

    def set_footer_visibility(self, is_visible: bool) -> None:
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        ...

    def set_footer_text(self, text: string) -> None:
        ...

    def set_date_time_text(self, text: string) -> None:
        ...

    @property
    def as_i_base_handout_notes_slide_header_footer_manag(self) -> IBaseHandoutNotesSlideHeaderFooterManag:
        ...

    @property
    def is_header_visible(self) -> bool:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class IMasterHandoutSlideManager:
    def set_default_master_handout_slide(self) -> IMasterHandoutSlide:
        ...

    def remove_master_handout_slide(self) -> None:
        ...

    @property
    def master_handout_slide(self) -> IMasterHandoutSlide:
        ...

    ...

class IMasterLayoutSlideCollection:
    def add_clone(self, source_layout: ILayoutSlide) -> ILayoutSlide:
        ...

    def insert_clone(self, index: int, source_layout: ILayoutSlide) -> ILayoutSlide:
        ...

    def add(self, layout_type: SlideLayoutType, layout_name: string) -> ILayoutSlide:
        ...

    def insert(self, index: int, layout_type: SlideLayoutType, layout_name: string) -> ILayoutSlide:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def reorder(self, index: int, layout_slide: ILayoutSlide) -> None:
        ...

    def get_by_type(self, type: SlideLayoutType) -> ILayoutSlide:
        ...

    def remove(self, value: ILayoutSlide) -> None:
        ...

    def remove_unused(self) -> None:
        ...

    @property
    def as_i_layout_slide_collection(self) -> ILayoutSlideCollection:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ILayoutSlide
        ...

    ...

class IMasterNotesSlide:
    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        ...

    def join_portions_with_same_formatting(self) -> None:
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        ...

    @property
    def header_footer_manager(self) -> IMasterNotesSlideHeaderFooterManager:
        ...

    @property
    def notes_style(self) -> ITextStyle:
        ...

    @property
    def as_i_base_slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_master_themeable(self) -> aspose.slides.theme.IMasterThemeable:
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def theme_manager(self) -> aspose.slides.theme.IMasterThemeManager:
        ...

    ...

class IMasterNotesSlideHeaderFooterManager:
    def set_header_and_child_headers_visibility(self, is_visible: bool) -> None:
        ...

    def set_header_and_child_headers_text(self, text: string) -> None:
        ...

    def set_footer_and_child_footers_visibility(self, is_visible: bool) -> None:
        ...

    def set_slide_number_and_child_slide_numbers_visibility(self, is_visible: bool) -> None:
        ...

    def set_date_time_and_child_date_times_visibility(self, is_visible: bool) -> None:
        ...

    def set_footer_and_child_footers_text(self, text: string) -> None:
        ...

    def set_date_time_and_child_date_times_text(self, text: string) -> None:
        ...

    def set_header_visibility(self, is_visible: bool) -> None:
        ...

    def set_header_text(self, text: string) -> None:
        ...

    def set_footer_visibility(self, is_visible: bool) -> None:
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        ...

    def set_footer_text(self, text: string) -> None:
        ...

    def set_date_time_text(self, text: string) -> None:
        ...

    @property
    def as_i_base_handout_notes_slide_header_footer_manag(self) -> IBaseHandoutNotesSlideHeaderFooterManag:
        ...

    @property
    def is_header_visible(self) -> bool:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class IMasterNotesSlideManager:
    def set_default_master_notes_slide(self) -> IMasterNotesSlide:
        ...

    def remove_master_notes_slide(self) -> None:
        ...

    @property
    def master_notes_slide(self) -> IMasterNotesSlide:
        ...

    ...

class IMasterSlide:
    def apply_external_theme_to_depending_slides(self, fname: string) -> IMasterSlide:
        ...

    def get_depending_slides(self) -> List[ISlide]:
        ...

    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        ...

    def join_portions_with_same_formatting(self) -> None:
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        ...

    @property
    def header_footer_manager(self) -> IMasterSlideHeaderFooterManager:
        ...

    @property
    def title_style(self) -> ITextStyle:
        ...

    @property
    def body_style(self) -> ITextStyle:
        ...

    @property
    def other_style(self) -> ITextStyle:
        ...

    @property
    def layout_slides(self) -> IMasterLayoutSlideCollection:
        ...

    @property
    def preserve(self) -> bool:
        ...

    @preserve.setter
    def preserve(self, value: bool):
        ...

    @property
    def has_depending_slides(self) -> bool:
        ...

    @property
    def as_i_base_slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_master_themeable(self) -> aspose.slides.theme.IMasterThemeable:
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def theme_manager(self) -> aspose.slides.theme.IMasterThemeManager:
        ...

    ...

class IMasterSlideCollection:
    def remove(self, value: IMasterSlide) -> None:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def remove_unused(self, ignore_preserve_field: bool) -> None:
        ...

    def add_clone(self, source_master: IMasterSlide) -> IMasterSlide:
        ...

    def insert_clone(self, index: int, source_master: IMasterSlide) -> IMasterSlide:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IMasterSlide
        ...

    ...

class IMasterSlideHeaderFooterManager:
    def set_footer_and_child_footers_visibility(self, is_visible: bool) -> None:
        ...

    def set_slide_number_and_child_slide_numbers_visibility(self, is_visible: bool) -> None:
        ...

    def set_date_time_and_child_date_times_visibility(self, is_visible: bool) -> None:
        ...

    def set_footer_and_child_footers_text(self, text: string) -> None:
        ...

    def set_date_time_and_child_date_times_text(self, text: string) -> None:
        ...

    def set_footer_visibility(self, is_visible: bool) -> None:
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        ...

    def set_footer_text(self, text: string) -> None:
        ...

    def set_date_time_text(self, text: string) -> None:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class IMetered:
    def set_metered_key(self, public_key: string, private_key: string) -> None:
        ...

    ...

class IModernComment:
    def remove(self) -> None:
        ...

    @property
    def shape(self) -> IShape:
        ...

    @property
    def text_selection_start(self) -> int:
        ...

    @text_selection_start.setter
    def text_selection_start(self, value: int):
        ...

    @property
    def text_selection_length(self) -> int:
        ...

    @text_selection_length.setter
    def text_selection_length(self, value: int):
        ...

    @property
    def status(self) -> ModernCommentStatus:
        ...

    @status.setter
    def status(self, value: ModernCommentStatus):
        ...

    @property
    def as_i_comment(self) -> IComment:
        ...

    @property
    def text(self) -> string:
        ...

    @text.setter
    def text(self, value: string):
        ...

    @property
    def created_time(self) -> DateTime:
        ...

    @created_time.setter
    def created_time(self, value: DateTime):
        ...

    @property
    def slide(self) -> ISlide:
        ...

    @property
    def author(self) -> ICommentAuthor:
        ...

    @property
    def position(self) -> aspose.pydrawing.PointF:
        ...

    @position.setter
    def position(self, value: aspose.pydrawing.PointF):
        ...

    @property
    def parent_comment(self) -> IComment:
        ...

    @parent_comment.setter
    def parent_comment(self, value: IComment):
        ...

    ...

class INormalViewProperties:
    @property
    def show_outline_icons(self) -> bool:
        ...

    @show_outline_icons.setter
    def show_outline_icons(self, value: bool):
        ...

    @property
    def snap_vertical_splitter(self) -> bool:
        ...

    @snap_vertical_splitter.setter
    def snap_vertical_splitter(self, value: bool):
        ...

    @property
    def vertical_bar_state(self) -> SplitterBarStateType:
        ...

    @vertical_bar_state.setter
    def vertical_bar_state(self, value: SplitterBarStateType):
        ...

    @property
    def horizontal_bar_state(self) -> SplitterBarStateType:
        ...

    @horizontal_bar_state.setter
    def horizontal_bar_state(self, value: SplitterBarStateType):
        ...

    @property
    def prefer_single_view(self) -> bool:
        ...

    @prefer_single_view.setter
    def prefer_single_view(self, value: bool):
        ...

    @property
    def restored_left(self) -> INormalViewRestoredProperties:
        ...

    @property
    def restored_top(self) -> INormalViewRestoredProperties:
        ...

    ...

class INormalViewRestoredProperties:
    @property
    def dimension_size(self) -> float:
        ...

    @dimension_size.setter
    def dimension_size(self, value: float):
        ...

    @property
    def auto_adjust(self) -> bool:
        ...

    @auto_adjust.setter
    def auto_adjust(self, value: bool):
        ...

    ...

class INotesSize:
    @property
    def size(self) -> aspose.pydrawing.SizeF:
        ...

    @size.setter
    def size(self, value: aspose.pydrawing.SizeF):
        ...

    ...

class INotesSlide:
    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        ...

    def join_portions_with_same_formatting(self) -> None:
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        ...

    @property
    def header_footer_manager(self) -> INotesSlideHeaderFooterManager:
        ...

    @property
    def notes_text_frame(self) -> ITextFrame:
        ...

    @property
    def parent_slide(self) -> ISlide:
        ...

    @property
    def as_i_base_slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_override_themeable(self) -> aspose.slides.theme.IOverrideThemeable:
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def theme_manager(self) -> aspose.slides.theme.IOverrideThemeManager:
        ...

    ...

class INotesSlideHeaderFooterManager:
    def set_header_visibility(self, is_visible: bool) -> None:
        ...

    def set_header_text(self, text: string) -> None:
        ...

    def set_footer_visibility(self, is_visible: bool) -> None:
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        ...

    def set_footer_text(self, text: string) -> None:
        ...

    def set_date_time_text(self, text: string) -> None:
        ...

    @property
    def as_i_base_handout_notes_slide_header_footer_manag(self) -> IBaseHandoutNotesSlideHeaderFooterManag:
        ...

    @property
    def is_header_visible(self) -> bool:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class INotesSlideManager:
    def add_notes_slide(self) -> INotesSlide:
        ...

    def remove_notes_slide(self) -> None:
        ...

    @property
    def notes_slide(self) -> INotesSlide:
        ...

    ...

class IOleEmbeddedDataInfo:
    @property
    def embedded_file_data(self) -> bytes:
        ...

    @property
    def embedded_file_extension(self) -> string:
        ...

    ...

class IOleObjectFrame:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def set_embedded_data(self, embedded_data: IOleEmbeddedDataInfo) -> None:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def substitute_picture_format(self) -> IPictureFillFormat:
        ...

    @property
    def object_name(self) -> string:
        ...

    @object_name.setter
    def object_name(self, value: string):
        ...

    @property
    def embedded_data(self) -> IOleEmbeddedDataInfo:
        ...

    @property
    def object_prog_id(self) -> string:
        ...

    @object_prog_id.setter
    def object_prog_id(self, value: string):
        ...

    @property
    def link_file_name(self) -> string:
        ...

    @property
    def link_path_long(self) -> string:
        ...

    @link_path_long.setter
    def link_path_long(self, value: string):
        ...

    @property
    def link_path_relative(self) -> string:
        ...

    @property
    def embedded_file_label(self) -> string:
        ...

    @property
    def embedded_file_name(self) -> string:
        ...

    @property
    def is_object_icon(self) -> bool:
        ...

    @is_object_icon.setter
    def is_object_icon(self, value: bool):
        ...

    @property
    def is_object_link(self) -> bool:
        ...

    @property
    def update_automatic(self) -> bool:
        ...

    @update_automatic.setter
    def update_automatic(self, value: bool):
        ...

    @property
    def substitute_picture_title(self) -> string:
        ...

    @substitute_picture_title.setter
    def substitute_picture_title(self, value: string):
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IPPImage:
    @overload
    def replace_image(self, new_image_data: bytes) -> None:
        ...

    @overload
    def replace_image(self, new_image: aspose.pydrawing.Image) -> None:
        ...

    @overload
    def replace_image(self, new_image: IImage) -> None:
        ...

    @overload
    def replace_image(self, new_image: IPPImage) -> None:
        ...

    @property
    def binary_data(self) -> bytes:
        ...

    @property
    def system_image(self) -> aspose.pydrawing.Image:
        ...

    @property
    def image(self) -> IImage:
        ...

    @property
    def svg_image(self) -> ISvgImage:
        ...

    @svg_image.setter
    def svg_image(self, value: ISvgImage):
        ...

    @property
    def content_type(self) -> string:
        ...

    @property
    def width(self) -> int:
        ...

    @property
    def height(self) -> int:
        ...

    @property
    def x(self) -> int:
        ...

    @property
    def y(self) -> int:
        ...

    ...

class IParagraph:
    def join_portions_with_same_formatting(self) -> None:
        ...

    def get_rect(self) -> aspose.pydrawing.RectangleF:
        ...

    def get_lines_count(self) -> int:
        ...

    @property
    def portions(self) -> IPortionCollection:
        ...

    @property
    def paragraph_format(self) -> IParagraphFormat:
        ...

    @property
    def text(self) -> string:
        ...

    @text.setter
    def text(self, value: string):
        ...

    @property
    def end_paragraph_portion_format(self) -> IPortionFormat:
        ...

    @end_paragraph_portion_format.setter
    def end_paragraph_portion_format(self, value: IPortionFormat):
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class IParagraphCollection:
    @overload
    def add(self, value: IParagraph) -> None:
        ...

    @overload
    def add(self, value: IParagraphCollection) -> int:
        ...

    @overload
    def insert(self, index: int, value: IParagraph) -> None:
        ...

    @overload
    def insert(self, index: int, value: IParagraphCollection) -> None:
        ...

    @overload
    def add_from_html(self, text: string) -> None:
        ...

    @overload
    def add_from_html(self, text: string, resolver: aspose.slides.importing.IExternalResourceResolver, uri: string) -> None:
        ...

    def clear(self) -> None:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def remove(self, item: IParagraph) -> bool:
        ...

    def export_to_html(self, first_paragraph_index: int, paragraphs_count: int, options: aspose.slides.export.ITextToHtmlConversionOptions) -> string:
        ...

    @property
    def count(self) -> int:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    def __getitem__(self, key: int) -> IParagraph
        ...

    ...

class IParagraphFactory:
    @overload
    def create_paragraph(self) -> IParagraph:
        ...

    @overload
    def create_paragraph(self, paragraph: IParagraph) -> IParagraph:
        ...

    ...

class IParagraphFormat:
    def get_effective(self) -> IParagraphFormatEffectiveData:
        ...

    @property
    def bullet(self) -> IBulletFormat:
        ...

    @property
    def depth(self) -> int:
        ...

    @depth.setter
    def depth(self, value: int):
        ...

    @property
    def alignment(self) -> TextAlignment:
        ...

    @alignment.setter
    def alignment(self, value: TextAlignment):
        ...

    @property
    def space_within(self) -> float:
        ...

    @space_within.setter
    def space_within(self, value: float):
        ...

    @property
    def space_before(self) -> float:
        ...

    @space_before.setter
    def space_before(self, value: float):
        ...

    @property
    def space_after(self) -> float:
        ...

    @space_after.setter
    def space_after(self, value: float):
        ...

    @property
    def east_asian_line_break(self) -> NullableBool:
        ...

    @east_asian_line_break.setter
    def east_asian_line_break(self, value: NullableBool):
        ...

    @property
    def right_to_left(self) -> NullableBool:
        ...

    @right_to_left.setter
    def right_to_left(self, value: NullableBool):
        ...

    @property
    def latin_line_break(self) -> NullableBool:
        ...

    @latin_line_break.setter
    def latin_line_break(self, value: NullableBool):
        ...

    @property
    def hanging_punctuation(self) -> NullableBool:
        ...

    @hanging_punctuation.setter
    def hanging_punctuation(self, value: NullableBool):
        ...

    @property
    def margin_left(self) -> float:
        ...

    @margin_left.setter
    def margin_left(self, value: float):
        ...

    @property
    def margin_right(self) -> float:
        ...

    @margin_right.setter
    def margin_right(self, value: float):
        ...

    @property
    def indent(self) -> float:
        ...

    @indent.setter
    def indent(self, value: float):
        ...

    @property
    def default_tab_size(self) -> float:
        ...

    @default_tab_size.setter
    def default_tab_size(self, value: float):
        ...

    @property
    def tabs(self) -> ITabCollection:
        ...

    @property
    def font_alignment(self) -> FontAlignment:
        ...

    @font_alignment.setter
    def font_alignment(self, value: FontAlignment):
        ...

    @property
    def default_portion_format(self) -> IPortionFormat:
        ...

    ...

class IParagraphFormatEffectiveData:
    @property
    def bullet(self) -> IBulletFormatEffectiveData:
        ...

    @property
    def depth(self) -> int:
        ...

    @property
    def alignment(self) -> TextAlignment:
        ...

    @property
    def space_within(self) -> float:
        ...

    @property
    def space_before(self) -> float:
        ...

    @property
    def space_after(self) -> float:
        ...

    @property
    def east_asian_line_break(self) -> bool:
        ...

    @property
    def right_to_left(self) -> bool:
        ...

    @property
    def latin_line_break(self) -> bool:
        ...

    @property
    def hanging_punctuation(self) -> bool:
        ...

    @property
    def margin_left(self) -> float:
        ...

    @property
    def margin_right(self) -> float:
        ...

    @property
    def indent(self) -> float:
        ...

    @property
    def default_tab_size(self) -> float:
        ...

    @property
    def tabs(self) -> List[ITabEffectiveData]:
        ...

    @property
    def font_alignment(self) -> FontAlignment:
        ...

    @property
    def default_portion_format(self) -> IPortionFormatEffectiveData:
        ...

    ...

class IPathSegment:
    @property
    def segment_data(self) -> List[float]:
        ...

    @property
    def path_command(self) -> PathCommandType:
        ...

    ...

class IPatternFormat:
    @overload
    def get_tile_image(self, background: aspose.pydrawing.Color, foreground: aspose.pydrawing.Color) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_tile_image(self, style_color: aspose.pydrawing.Color) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_tile(self, background: aspose.pydrawing.Color, foreground: aspose.pydrawing.Color) -> IImage:
        ...

    @overload
    def get_tile(self, style_color: aspose.pydrawing.Color) -> IImage:
        ...

    @property
    def pattern_style(self) -> PatternStyle:
        ...

    @pattern_style.setter
    def pattern_style(self, value: PatternStyle):
        ...

    @property
    def fore_color(self) -> IColorFormat:
        ...

    @property
    def back_color(self) -> IColorFormat:
        ...

    ...

class IPatternFormatEffectiveData:
    def get_tile_image(self, background: aspose.pydrawing.Color, foreground: aspose.pydrawing.Color) -> aspose.pydrawing.Bitmap:
        ...

    def get_tile_i_image(self, background: aspose.pydrawing.Color, foreground: aspose.pydrawing.Color) -> IImage:
        ...

    @property
    def pattern_style(self) -> PatternStyle:
        ...

    @property
    def fore_color(self) -> aspose.pydrawing.Color:
        ...

    @property
    def back_color(self) -> aspose.pydrawing.Color:
        ...

    ...

class IPictureEffectiveData:
    @property
    def image(self) -> IPPImage:
        ...

    @property
    def link_path_long(self) -> string:
        ...

    @property
    def image_transform(self) -> aspose.slides.effects.IImageTransformOCollectionEffectiveData:
        ...

    ...

class IPictureFillFormat:
    def delete_picture_cropped_areas(self) -> IPPImage:
        ...

    @property
    def dpi(self) -> int:
        ...

    @dpi.setter
    def dpi(self, value: int):
        ...

    @property
    def picture_fill_mode(self) -> PictureFillMode:
        ...

    @picture_fill_mode.setter
    def picture_fill_mode(self, value: PictureFillMode):
        ...

    @property
    def picture(self) -> ISlidesPicture:
        ...

    @property
    def crop_left(self) -> float:
        ...

    @crop_left.setter
    def crop_left(self, value: float):
        ...

    @property
    def crop_top(self) -> float:
        ...

    @crop_top.setter
    def crop_top(self, value: float):
        ...

    @property
    def crop_right(self) -> float:
        ...

    @crop_right.setter
    def crop_right(self, value: float):
        ...

    @property
    def crop_bottom(self) -> float:
        ...

    @crop_bottom.setter
    def crop_bottom(self, value: float):
        ...

    @property
    def stretch_offset_left(self) -> float:
        ...

    @stretch_offset_left.setter
    def stretch_offset_left(self, value: float):
        ...

    @property
    def stretch_offset_top(self) -> float:
        ...

    @stretch_offset_top.setter
    def stretch_offset_top(self, value: float):
        ...

    @property
    def stretch_offset_right(self) -> float:
        ...

    @stretch_offset_right.setter
    def stretch_offset_right(self, value: float):
        ...

    @property
    def stretch_offset_bottom(self) -> float:
        ...

    @stretch_offset_bottom.setter
    def stretch_offset_bottom(self, value: float):
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class IPictureFillFormatEffectiveData:
    @property
    def dpi(self) -> int:
        ...

    @property
    def picture_fill_mode(self) -> PictureFillMode:
        ...

    @property
    def picture(self) -> IPictureEffectiveData:
        ...

    @property
    def crop_left(self) -> float:
        ...

    @property
    def crop_top(self) -> float:
        ...

    @property
    def crop_right(self) -> float:
        ...

    @property
    def crop_bottom(self) -> float:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class IPictureFrame:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def get_geometry_paths(self) -> List[IGeometryPath]:
        ...

    def set_geometry_path(self, geometry_path: IGeometryPath) -> None:
        ...

    def set_geometry_paths(self, geometry_paths: List[IGeometryPath]) -> None:
        ...

    def create_shape_elements(self) -> List[IShapeElement]:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def shape_lock(self) -> IPictureFrameLock:
        ...

    @property
    def picture_frame_lock(self) -> IPictureFrameLock:
        ...

    @property
    def picture_format(self) -> IPictureFillFormat:
        ...

    @property
    def relative_scale_height(self) -> float:
        ...

    @relative_scale_height.setter
    def relative_scale_height(self, value: float):
        ...

    @property
    def relative_scale_width(self) -> float:
        ...

    @relative_scale_width.setter
    def relative_scale_width(self, value: float):
        ...

    @property
    def as_i_geometry_shape(self) -> IGeometryShape:
        ...

    @property
    def shape_style(self) -> IShapeStyle:
        ...

    @property
    def shape_type(self) -> ShapeType:
        ...

    @shape_type.setter
    def shape_type(self, value: ShapeType):
        ...

    @property
    def adjustments(self) -> IAdjustValueCollection:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IPictureFrameLock:
    @property
    def grouping_locked(self) -> bool:
        ...

    @grouping_locked.setter
    def grouping_locked(self, value: bool):
        ...

    @property
    def select_locked(self) -> bool:
        ...

    @select_locked.setter
    def select_locked(self, value: bool):
        ...

    @property
    def rotation_locked(self) -> bool:
        ...

    @rotation_locked.setter
    def rotation_locked(self, value: bool):
        ...

    @property
    def aspect_ratio_locked(self) -> bool:
        ...

    @aspect_ratio_locked.setter
    def aspect_ratio_locked(self, value: bool):
        ...

    @property
    def position_locked(self) -> bool:
        ...

    @position_locked.setter
    def position_locked(self, value: bool):
        ...

    @property
    def size_locked(self) -> bool:
        ...

    @size_locked.setter
    def size_locked(self, value: bool):
        ...

    @property
    def edit_points_locked(self) -> bool:
        ...

    @edit_points_locked.setter
    def edit_points_locked(self, value: bool):
        ...

    @property
    def adjust_handles_locked(self) -> bool:
        ...

    @adjust_handles_locked.setter
    def adjust_handles_locked(self, value: bool):
        ...

    @property
    def arrowheads_locked(self) -> bool:
        ...

    @arrowheads_locked.setter
    def arrowheads_locked(self, value: bool):
        ...

    @property
    def shape_type_locked(self) -> bool:
        ...

    @shape_type_locked.setter
    def shape_type_locked(self, value: bool):
        ...

    @property
    def crop_locked(self) -> bool:
        ...

    @crop_locked.setter
    def crop_locked(self, value: bool):
        ...

    @property
    def as_i_base_shape_lock(self) -> IBaseShapeLock:
        ...

    @property
    def no_locks(self) -> bool:
        ...

    ...

class IPlaceholder:
    @property
    def orientation(self) -> Orientation:
        ...

    @property
    def size(self) -> PlaceholderSize:
        ...

    @property
    def type(self) -> PlaceholderType:
        ...

    @property
    def index(self) -> int:
        ...

    ...

class IPortion:
    @overload
    def add_field(self, field_type: IFieldType) -> None:
        ...

    @overload
    def add_field(self, internal_string: string) -> None:
        ...

    def remove_field(self) -> None:
        ...

    def get_rect(self) -> aspose.pydrawing.RectangleF:
        ...

    def get_coordinates(self) -> aspose.pydrawing.PointF:
        ...

    @property
    def portion_format(self) -> IPortionFormat:
        ...

    @property
    def text(self) -> string:
        ...

    @text.setter
    def text(self, value: string):
        ...

    @property
    def field(self) -> IField:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class IPortionCollection:
    def add(self, value: IPortion) -> None:
        ...

    def index_of(self, item: IPortion) -> int:
        ...

    def insert(self, index: int, value: IPortion) -> None:
        ...

    def clear(self) -> None:
        ...

    def contains(self, item: IPortion) -> bool:
        ...

    def remove(self, item: IPortion) -> bool:
        ...

    def remove_at(self, index: int) -> None:
        ...

    @property
    def count(self) -> int:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IPortion
        ...

    ...

class IPortionFactory:
    @overload
    def create_portion(self) -> IPortion:
        ...

    @overload
    def create_portion(self, str: string) -> IPortion:
        ...

    @overload
    def create_portion(self, portion: IPortion) -> IPortion:
        ...

    ...

class IPortionFormat:
    def get_effective(self) -> IPortionFormatEffectiveData:
        ...

    @property
    def bookmark_id(self) -> string:
        ...

    @bookmark_id.setter
    def bookmark_id(self, value: string):
        ...

    @property
    def smart_tag_clean(self) -> bool:
        ...

    @smart_tag_clean.setter
    def smart_tag_clean(self, value: bool):
        ...

    @property
    def as_i_base_portion_format(self) -> IBasePortionFormat:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def highlight_color(self) -> IColorFormat:
        ...

    @property
    def underline_line_format(self) -> ILineFormat:
        ...

    @property
    def underline_fill_format(self) -> IFillFormat:
        ...

    @property
    def font_bold(self) -> NullableBool:
        ...

    @font_bold.setter
    def font_bold(self, value: NullableBool):
        ...

    @property
    def font_italic(self) -> NullableBool:
        ...

    @font_italic.setter
    def font_italic(self, value: NullableBool):
        ...

    @property
    def kumimoji(self) -> NullableBool:
        ...

    @kumimoji.setter
    def kumimoji(self, value: NullableBool):
        ...

    @property
    def normalise_height(self) -> NullableBool:
        ...

    @normalise_height.setter
    def normalise_height(self, value: NullableBool):
        ...

    @property
    def proof_disabled(self) -> NullableBool:
        ...

    @proof_disabled.setter
    def proof_disabled(self, value: NullableBool):
        ...

    @property
    def font_underline(self) -> TextUnderlineType:
        ...

    @font_underline.setter
    def font_underline(self, value: TextUnderlineType):
        ...

    @property
    def text_cap_type(self) -> TextCapType:
        ...

    @text_cap_type.setter
    def text_cap_type(self, value: TextCapType):
        ...

    @property
    def strikethrough_type(self) -> TextStrikethroughType:
        ...

    @strikethrough_type.setter
    def strikethrough_type(self, value: TextStrikethroughType):
        ...

    @property
    def is_hard_underline_line(self) -> NullableBool:
        ...

    @is_hard_underline_line.setter
    def is_hard_underline_line(self, value: NullableBool):
        ...

    @property
    def is_hard_underline_fill(self) -> NullableBool:
        ...

    @is_hard_underline_fill.setter
    def is_hard_underline_fill(self, value: NullableBool):
        ...

    @property
    def font_height(self) -> float:
        ...

    @font_height.setter
    def font_height(self, value: float):
        ...

    @property
    def latin_font(self) -> IFontData:
        ...

    @latin_font.setter
    def latin_font(self, value: IFontData):
        ...

    @property
    def east_asian_font(self) -> IFontData:
        ...

    @east_asian_font.setter
    def east_asian_font(self, value: IFontData):
        ...

    @property
    def complex_script_font(self) -> IFontData:
        ...

    @complex_script_font.setter
    def complex_script_font(self, value: IFontData):
        ...

    @property
    def symbol_font(self) -> IFontData:
        ...

    @symbol_font.setter
    def symbol_font(self, value: IFontData):
        ...

    @property
    def escapement(self) -> float:
        ...

    @escapement.setter
    def escapement(self, value: float):
        ...

    @property
    def kerning_minimal_size(self) -> float:
        ...

    @kerning_minimal_size.setter
    def kerning_minimal_size(self, value: float):
        ...

    @property
    def language_id(self) -> string:
        ...

    @language_id.setter
    def language_id(self, value: string):
        ...

    @property
    def alternative_language_id(self) -> string:
        ...

    @alternative_language_id.setter
    def alternative_language_id(self, value: string):
        ...

    @property
    def spacing(self) -> float:
        ...

    @spacing.setter
    def spacing(self, value: float):
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IPortionFormatEffectiveData:
    @property
    def bookmark_id(self) -> string:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @property
    def as_i_base_portion_format_effective_data(self) -> IBasePortionFormatEffectiveData:
        ...

    @property
    def line_format(self) -> ILineFormatEffectiveData:
        ...

    @property
    def fill_format(self) -> IFillFormatEffectiveData:
        ...

    @property
    def effect_format(self) -> IEffectFormatEffectiveData:
        ...

    @property
    def highlight_color(self) -> aspose.pydrawing.Color:
        ...

    @property
    def underline_line_format(self) -> ILineFormatEffectiveData:
        ...

    @property
    def underline_fill_format(self) -> IFillFormatEffectiveData:
        ...

    @property
    def font_bold(self) -> bool:
        ...

    @property
    def font_italic(self) -> bool:
        ...

    @property
    def kumimoji(self) -> bool:
        ...

    @property
    def normalise_height(self) -> bool:
        ...

    @property
    def proof_disabled(self) -> bool:
        ...

    @property
    def font_underline(self) -> TextUnderlineType:
        ...

    @property
    def text_cap_type(self) -> TextCapType:
        ...

    @property
    def strikethrough_type(self) -> TextStrikethroughType:
        ...

    @property
    def smart_tag_clean(self) -> bool:
        ...

    @property
    def is_hard_underline_line(self) -> bool:
        ...

    @property
    def is_hard_underline_fill(self) -> bool:
        ...

    @property
    def font_height(self) -> float:
        ...

    @property
    def latin_font(self) -> IFontData:
        ...

    @property
    def east_asian_font(self) -> IFontData:
        ...

    @property
    def complex_script_font(self) -> IFontData:
        ...

    @property
    def symbol_font(self) -> IFontData:
        ...

    @property
    def escapement(self) -> float:
        ...

    @property
    def kerning_minimal_size(self) -> float:
        ...

    @property
    def language_id(self) -> string:
        ...

    @property
    def alternative_language_id(self) -> string:
        ...

    @property
    def spacing(self) -> float:
        ...

    ...

class IPresentation:
    @overload
    def save(self, fname: string, format: aspose.slides.export.SaveFormat) -> None:
        ...

    @overload
    def save(self, stream: System.IO.Stream, format: aspose.slides.export.SaveFormat) -> None:
        ...

    @overload
    def save(self, fname: string, format: aspose.slides.export.SaveFormat, options: aspose.slides.export.ISaveOptions) -> None:
        ...

    @overload
    def save(self, stream: System.IO.Stream, format: aspose.slides.export.SaveFormat, options: aspose.slides.export.ISaveOptions) -> None:
        ...

    @overload
    def save(self, fname: string, slides: List[int], format: aspose.slides.export.SaveFormat) -> None:
        ...

    @overload
    def save(self, fname: string, slides: List[int], format: aspose.slides.export.SaveFormat, options: aspose.slides.export.ISaveOptions) -> None:
        ...

    @overload
    def save(self, stream: System.IO.Stream, slides: List[int], format: aspose.slides.export.SaveFormat) -> None:
        ...

    @overload
    def save(self, stream: System.IO.Stream, slides: List[int], format: aspose.slides.export.SaveFormat, options: aspose.slides.export.ISaveOptions) -> None:
        ...

    @overload
    def save(self, options: aspose.slides.export.xaml.IXamlOptions) -> None:
        ...

    @overload
    def get_thumbnails(self, options: aspose.slides.export.IRenderingOptions) -> List[aspose.pydrawing.Bitmap]:
        ...

    @overload
    def get_thumbnails(self, options: aspose.slides.export.IRenderingOptions, slides: List[int]) -> List[aspose.pydrawing.Bitmap]:
        ...

    @overload
    def get_thumbnails(self, options: aspose.slides.export.IRenderingOptions, scale_x: float, scale_y: float) -> List[aspose.pydrawing.Bitmap]:
        ...

    @overload
    def get_thumbnails(self, options: aspose.slides.export.IRenderingOptions, slides: List[int], scale_x: float, scale_y: float) -> List[aspose.pydrawing.Bitmap]:
        ...

    @overload
    def get_thumbnails(self, options: aspose.slides.export.IRenderingOptions, image_size: aspose.pydrawing.Size) -> List[aspose.pydrawing.Bitmap]:
        ...

    @overload
    def get_thumbnails(self, options: aspose.slides.export.IRenderingOptions, slides: List[int], image_size: aspose.pydrawing.Size) -> List[aspose.pydrawing.Bitmap]:
        ...

    @overload
    def get_images(self, options: aspose.slides.export.IRenderingOptions) -> List[IImage]:
        ...

    @overload
    def get_images(self, options: aspose.slides.export.IRenderingOptions, slides: List[int]) -> List[IImage]:
        ...

    @overload
    def get_images(self, options: aspose.slides.export.IRenderingOptions, scale_x: float, scale_y: float) -> List[IImage]:
        ...

    @overload
    def get_images(self, options: aspose.slides.export.IRenderingOptions, slides: List[int], scale_x: float, scale_y: float) -> List[IImage]:
        ...

    @overload
    def get_images(self, options: aspose.slides.export.IRenderingOptions, image_size: aspose.pydrawing.Size) -> List[IImage]:
        ...

    @overload
    def get_images(self, options: aspose.slides.export.IRenderingOptions, slides: List[int], image_size: aspose.pydrawing.Size) -> List[IImage]:
        ...

    @overload
    def print(self) -> None:
        ...

    @overload
    def print(self, printer_settings: aspose.pydrawing.Printing.PrinterSettings) -> None:
        ...

    @overload
    def print(self, printer_name: string) -> None:
        ...

    @overload
    def print(self, printer_settings: aspose.pydrawing.Printing.PrinterSettings, pres_name: string) -> None:
        ...

    def get_slide_by_id(self, id: int) -> IBaseSlide:
        ...

    def join_portions_with_same_formatting(self) -> None:
        ...

    @property
    def current_date_time(self) -> DateTime:
        ...

    @current_date_time.setter
    def current_date_time(self, value: DateTime):
        ...

    @property
    def header_footer_manager(self) -> IPresentationHeaderFooterManager:
        ...

    @property
    def protection_manager(self) -> IProtectionManager:
        ...

    @property
    def slides(self) -> ISlideCollection:
        ...

    @property
    def sections(self) -> ISectionCollection:
        ...

    @property
    def slide_size(self) -> ISlideSize:
        ...

    @property
    def notes_size(self) -> INotesSize:
        ...

    @property
    def layout_slides(self) -> IGlobalLayoutSlideCollection:
        ...

    @property
    def masters(self) -> IMasterSlideCollection:
        ...

    @property
    def master_notes_slide_manager(self) -> IMasterNotesSlideManager:
        ...

    @property
    def master_handout_slide_manager(self) -> IMasterHandoutSlideManager:
        ...

    @property
    def fonts_manager(self) -> IFontsManager:
        ...

    @property
    def default_text_style(self) -> ITextStyle:
        ...

    @property
    def comment_authors(self) -> ICommentAuthorCollection:
        ...

    @property
    def document_properties(self) -> IDocumentProperties:
        ...

    @property
    def images(self) -> IImageCollection:
        ...

    @property
    def audios(self) -> IAudioCollection:
        ...

    @property
    def videos(self) -> IVideoCollection:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def vba_project(self) -> aspose.slides.vba.IVbaProject:
        ...

    @vba_project.setter
    def vba_project(self, value: aspose.slides.vba.IVbaProject):
        ...

    @property
    def source_format(self) -> SourceFormat:
        ...

    @property
    def master_theme(self) -> aspose.slides.theme.IMasterTheme:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def view_properties(self) -> IViewProperties:
        ...

    @property
    def first_slide_number(self) -> int:
        ...

    @first_slide_number.setter
    def first_slide_number(self, value: int):
        ...

    @property
    def all_custom_xml_parts(self) -> List[ICustomXmlPart]:
        ...

    @property
    def digital_signatures(self) -> IDigitalSignatureCollection:
        ...

    @property
    def as_i_disposable(self) -> IDisposable:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class IPresentationComponent:
    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class IPresentationFactory:
    @overload
    def create_presentation(self) -> IPresentation:
        ...

    @overload
    def create_presentation(self, options: ILoadOptions) -> IPresentation:
        ...

    @overload
    def get_presentation_info(self, file: string) -> IPresentationInfo:
        ...

    @overload
    def get_presentation_info(self, stream: System.IO.Stream) -> IPresentationInfo:
        ...

    @overload
    def read_presentation(self, data: bytes) -> IPresentation:
        ...

    @overload
    def read_presentation(self, data: bytes, options: ILoadOptions) -> IPresentation:
        ...

    @overload
    def read_presentation(self, stream: System.IO.Stream) -> IPresentation:
        ...

    @overload
    def read_presentation(self, stream: System.IO.Stream, options: ILoadOptions) -> IPresentation:
        ...

    @overload
    def read_presentation(self, file: string) -> IPresentation:
        ...

    @overload
    def read_presentation(self, file: string, options: ILoadOptions) -> IPresentation:
        ...

    @overload
    def get_presentation_text(self, file: string, mode: TextExtractionArrangingMode) -> IPresentationText:
        ...

    @overload
    def get_presentation_text(self, stream: System.IO.Stream, mode: TextExtractionArrangingMode) -> IPresentationText:
        ...

    @overload
    def get_presentation_text(self, stream: System.IO.Stream, mode: TextExtractionArrangingMode, options: ILoadOptions) -> IPresentationText:
        ...

    ...

class IPresentationHeaderFooterManager:
    def set_all_headers_visibility(self, is_visible: bool) -> None:
        ...

    def set_all_footers_visibility(self, is_visible: bool) -> None:
        ...

    def set_all_slide_numbers_visibility(self, is_visible: bool) -> None:
        ...

    def set_all_date_times_visibility(self, is_visible: bool) -> None:
        ...

    def set_all_headers_text(self, text: string) -> None:
        ...

    def set_all_footers_text(self, text: string) -> None:
        ...

    def set_all_date_times_text(self, text: string) -> None:
        ...

    def set_visibility_on_all_title_slides(self, is_visible: bool) -> None:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class IPresentationInfo:
    @overload
    def write_binded_presentation(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_binded_presentation(self, file: string) -> None:
        ...

    def check_password(self, password: string) -> bool:
        ...

    def check_write_protection(self, password: string) -> bool:
        ...

    def read_document_properties(self) -> IDocumentProperties:
        ...

    def update_document_properties(self, document_properties: IDocumentProperties) -> None:
        ...

    @property
    def is_encrypted(self) -> bool:
        ...

    @property
    def is_password_protected(self) -> bool:
        ...

    @property
    def is_write_protected(self) -> NullableBool:
        ...

    @property
    def load_format(self) -> LoadFormat:
        ...

    ...

class IPresentationText:
    @property
    def slides_text(self) -> List[ISlideText]:
        ...

    ...

class IProgressCallback:
    def reporting(self, progress_value: float) -> None:
        ...

    ...

class IProtectionManager:
    def encrypt(self, encryption_password: string) -> None:
        ...

    def remove_encryption(self) -> None:
        ...

    def set_write_protection(self, password: string) -> None:
        ...

    def remove_write_protection(self) -> None:
        ...

    def check_write_protection(self, password: string) -> bool:
        ...

    @property
    def encrypt_document_properties(self) -> bool:
        ...

    @encrypt_document_properties.setter
    def encrypt_document_properties(self, value: bool):
        ...

    @property
    def is_encrypted(self) -> bool:
        ...

    @property
    def is_only_document_properties_loaded(self) -> bool:
        ...

    @property
    def is_write_protected(self) -> bool:
        ...

    @property
    def encryption_password(self) -> string:
        ...

    @property
    def read_only_recommended(self) -> bool:
        ...

    @read_only_recommended.setter
    def read_only_recommended(self, value: bool):
        ...

    ...

class IResourceLoadingArgs:
    def set_data(self, data: bytes) -> None:
        ...

    @property
    def original_uri(self) -> string:
        ...

    @property
    def uri(self) -> string:
        ...

    @uri.setter
    def uri(self, value: string):
        ...

    ...

class IResourceLoadingCallback:
    def resource_loading(self, args: IResourceLoadingArgs) -> ResourceLoadingAction:
        ...

    ...

class IRow:
    @overload
    def set_text_format(self, source: IPortionFormat) -> None:
        ...

    @overload
    def set_text_format(self, source: IParagraphFormat) -> None:
        ...

    @overload
    def set_text_format(self, source: ITextFrameFormat) -> None:
        ...

    @property
    def height(self) -> float:
        ...

    @property
    def minimal_height(self) -> float:
        ...

    @minimal_height.setter
    def minimal_height(self, value: float):
        ...

    @property
    def row_format(self) -> IRowFormat:
        ...

    @property
    def as_i_cell_collection(self) -> ICellCollection:
        ...

    @property
    def as_i_bulk_text_formattable(self) -> IBulkTextFormattable:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ICell
        ...

    ...

class IRowCollection:
    def add_clone(self, templ: IRow, with_attached_rows: bool) -> List[IRow]:
        ...

    def insert_clone(self, index: int, templ: IRow, with_attached_rows: bool) -> List[IRow]:
        ...

    def remove_at(self, first_row_index: int, with_attached_rows: bool) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IRow
        ...

    ...

class IRowFormat:
    def get_effective(self) -> IRowFormatEffectiveData:
        ...

    ...

class IRowFormatEffectiveData:
    @property
    def as_i_base_table_format_effective_data(self) -> IBaseTableFormatEffectiveData:
        ...

    @property
    def fill_format(self) -> IFillFormatEffectiveData:
        ...

    @property
    def border_left(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_top(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_right(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_bottom(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_diagonal_down(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_diagonal_up(self) -> ILineFormatEffectiveData:
        ...

    ...

class ISection:
    def get_slides_list_of_section(self) -> ISectionSlideCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def section_id(self) -> Guid:
        ...

    @property
    def started_from_slide(self) -> ISlide:
        ...

    ...

class ISectionCollection:
    def add_section(self, name: string, started_from_slide: ISlide) -> ISection:
        ...

    def add_empty_section(self, name: string, index: int) -> ISection:
        ...

    def remove_section_with_slides(self, section: ISection) -> None:
        ...

    def remove_section(self, section: ISection) -> None:
        ...

    def reorder_section_with_slides(self, section: ISection, index: int) -> None:
        ...

    def append_empty_section(self, name: string) -> ISection:
        ...

    def index_of(self, section: ISection) -> int:
        ...

    def clear(self) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ISection
        ...

    ...

class ISectionSlideCollection:
    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ISlide
        ...

    ...

class ISectionZoomFrame:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def target_section(self) -> ISection:
        ...

    @target_section.setter
    def target_section(self, value: ISection):
        ...

    @property
    def as_i_zoom_object(self) -> IZoomObject:
        ...

    @property
    def image_type(self) -> ZoomImageType:
        ...

    @image_type.setter
    def image_type(self, value: ZoomImageType):
        ...

    @property
    def return_to_parent(self) -> bool:
        ...

    @return_to_parent.setter
    def return_to_parent(self, value: bool):
        ...

    @property
    def show_background(self) -> bool:
        ...

    @show_background.setter
    def show_background(self, value: bool):
        ...

    @property
    def zoom_image(self) -> IPPImage:
        ...

    @zoom_image.setter
    def zoom_image(self, value: IPPImage):
        ...

    @property
    def transition_duration(self) -> float:
        ...

    @transition_duration.setter
    def transition_duration(self, value: float):
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IShape:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IBaseShapeLock:
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IShapeBevel:
    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def bevel_type(self) -> BevelPresetType:
        ...

    @bevel_type.setter
    def bevel_type(self, value: BevelPresetType):
        ...

    ...

class IShapeBevelEffectiveData:
    @property
    def width(self) -> float:
        ...

    @property
    def height(self) -> float:
        ...

    @property
    def bevel_type(self) -> BevelPresetType:
        ...

    ...

class IShapeCollection:
    @overload
    def add_chart(self, type: aspose.slides.charts.ChartType, x: float, y: float, width: float, height: float) -> aspose.slides.charts.IChart:
        ...

    @overload
    def add_chart(self, type: aspose.slides.charts.ChartType, x: float, y: float, width: float, height: float, init_with_sample: bool) -> aspose.slides.charts.IChart:
        ...

    @overload
    def insert_chart(self, type: aspose.slides.charts.ChartType, x: float, y: float, width: float, height: float, index: int) -> aspose.slides.charts.IChart:
        ...

    @overload
    def insert_chart(self, type: aspose.slides.charts.ChartType, x: float, y: float, width: float, height: float, index: int, init_with_sample: bool) -> aspose.slides.charts.IChart:
        ...

    @overload
    def add_ole_object_frame(self, x: float, y: float, width: float, height: float, data_info: IOleEmbeddedDataInfo) -> IOleObjectFrame:
        ...

    @overload
    def add_ole_object_frame(self, x: float, y: float, width: float, height: float, class_name: string, path: string) -> IOleObjectFrame:
        ...

    @overload
    def insert_ole_object_frame(self, index: int, x: float, y: float, width: float, height: float, data_info: IOleEmbeddedDataInfo) -> IOleObjectFrame:
        ...

    @overload
    def insert_ole_object_frame(self, index: int, x: float, y: float, width: float, height: float, class_name: string, path: string) -> IOleObjectFrame:
        ...

    @overload
    def add_zoom_frame(self, x: float, y: float, width: float, height: float, slide: ISlide) -> IZoomFrame:
        ...

    @overload
    def add_zoom_frame(self, x: float, y: float, width: float, height: float, slide: ISlide, image: IPPImage) -> IZoomFrame:
        ...

    @overload
    def insert_zoom_frame(self, index: int, x: float, y: float, width: float, height: float, slide: ISlide) -> IZoomFrame:
        ...

    @overload
    def insert_zoom_frame(self, index: int, x: float, y: float, width: float, height: float, slide: ISlide, image: IPPImage) -> IZoomFrame:
        ...

    @overload
    def add_section_zoom_frame(self, x: float, y: float, width: float, height: float, section: ISection) -> ISectionZoomFrame:
        ...

    @overload
    def add_section_zoom_frame(self, x: float, y: float, width: float, height: float, section: ISection, image: IPPImage) -> ISectionZoomFrame:
        ...

    @overload
    def insert_section_zoom_frame(self, index: int, x: float, y: float, width: float, height: float, section: ISection) -> ISectionZoomFrame:
        ...

    @overload
    def insert_section_zoom_frame(self, index: int, x: float, y: float, width: float, height: float, section: ISection, image: IPPImage) -> ISectionZoomFrame:
        ...

    @overload
    def add_video_frame(self, x: float, y: float, width: float, height: float, fname: string) -> IVideoFrame:
        ...

    @overload
    def add_video_frame(self, x: float, y: float, width: float, height: float, video: IVideo) -> IVideoFrame:
        ...

    @overload
    def add_audio_frame_embedded(self, x: float, y: float, width: float, height: float, audio_stream: System.IO.Stream) -> IAudioFrame:
        ...

    @overload
    def add_audio_frame_embedded(self, x: float, y: float, width: float, height: float, audio: IAudio) -> IAudioFrame:
        ...

    @overload
    def insert_audio_frame_embedded(self, index: int, x: float, y: float, width: float, height: float, audio_stream: System.IO.Stream) -> IAudioFrame:
        ...

    @overload
    def insert_audio_frame_embedded(self, index: int, x: float, y: float, width: float, height: float, audio: IAudio) -> IAudioFrame:
        ...

    @overload
    def to_array(self) -> List[IShape]:
        ...

    @overload
    def to_array(self, start_index: int, count: int) -> List[IShape]:
        ...

    @overload
    def reorder(self, index: int, shape: IShape) -> None:
        ...

    @overload
    def reorder(self, index: int, shapes: List[IShape]) -> None:
        ...

    @overload
    def add_auto_shape(self, shape_type: ShapeType, x: float, y: float, width: float, height: float) -> IAutoShape:
        ...

    @overload
    def add_auto_shape(self, shape_type: ShapeType, x: float, y: float, width: float, height: float, create_from_template: bool) -> IAutoShape:
        ...

    @overload
    def insert_auto_shape(self, index: int, shape_type: ShapeType, x: float, y: float, width: float, height: float) -> IAutoShape:
        ...

    @overload
    def insert_auto_shape(self, index: int, shape_type: ShapeType, x: float, y: float, width: float, height: float, create_from_template: bool) -> IAutoShape:
        ...

    @overload
    def add_group_shape(self) -> IGroupShape:
        ...

    @overload
    def add_group_shape(self, svg_image: ISvgImage, x: float, y: float, width: float, height: float) -> IGroupShape:
        ...

    @overload
    def add_connector(self, shape_type: ShapeType, x: float, y: float, width: float, height: float) -> IConnector:
        ...

    @overload
    def add_connector(self, shape_type: ShapeType, x: float, y: float, width: float, height: float, create_from_template: bool) -> IConnector:
        ...

    @overload
    def insert_connector(self, index: int, shape_type: ShapeType, x: float, y: float, width: float, height: float) -> IConnector:
        ...

    @overload
    def insert_connector(self, index: int, shape_type: ShapeType, x: float, y: float, width: float, height: float, create_from_template: bool) -> IConnector:
        ...

    @overload
    def add_clone(self, source_shape: IShape, x: float, y: float, width: float, height: float) -> IShape:
        ...

    @overload
    def add_clone(self, source_shape: IShape, x: float, y: float) -> IShape:
        ...

    @overload
    def add_clone(self, source_shape: IShape) -> IShape:
        ...

    @overload
    def insert_clone(self, index: int, source_shape: IShape, x: float, y: float, width: float, height: float) -> IShape:
        ...

    @overload
    def insert_clone(self, index: int, source_shape: IShape, x: float, y: float) -> IShape:
        ...

    @overload
    def insert_clone(self, index: int, source_shape: IShape) -> IShape:
        ...

    def add_smart_art(self, x: float, y: float, width: float, height: float, layout_type: aspose.slides.smartart.SmartArtLayoutType) -> aspose.slides.smartart.ISmartArt:
        ...

    def add_summary_zoom_frame(self, x: float, y: float, width: float, height: float) -> ISummaryZoomFrame:
        ...

    def insert_summary_zoom_frame(self, index: int, x: float, y: float, width: float, height: float) -> ISummaryZoomFrame:
        ...

    def insert_video_frame(self, index: int, x: float, y: float, width: float, height: float, fname: string) -> IVideoFrame:
        ...

    def add_audio_frame_cd(self, x: float, y: float, width: float, height: float) -> IAudioFrame:
        ...

    def insert_audio_frame_cd(self, index: int, x: float, y: float, width: float, height: float) -> IAudioFrame:
        ...

    def add_audio_frame_linked(self, x: float, y: float, width: float, height: float, fname: string) -> IAudioFrame:
        ...

    def insert_audio_frame_linked(self, index: int, x: float, y: float, width: float, height: float, fname: string) -> IAudioFrame:
        ...

    def index_of(self, shape: IShape) -> int:
        ...

    def add_math_shape(self, x: float, y: float, width: float, height: float) -> IAutoShape:
        ...

    def insert_group_shape(self, index: int) -> IGroupShape:
        ...

    def add_picture_frame(self, shape_type: ShapeType, x: float, y: float, width: float, height: float, image: IPPImage) -> IPictureFrame:
        ...

    def insert_picture_frame(self, index: int, shape_type: ShapeType, x: float, y: float, width: float, height: float, image: IPPImage) -> IPictureFrame:
        ...

    def add_table(self, x: float, y: float, column_widths: List[float], row_heights: List[float]) -> ITable:
        ...

    def insert_table(self, index: int, x: float, y: float, column_widths: List[float], row_heights: List[float]) -> ITable:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def remove(self, shape: IShape) -> None:
        ...

    def clear(self) -> None:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IShape
        ...

    ...

class IShapeElement:
    ...

class IShapeFrame:
    def clone_t(self) -> IShapeFrame:
        ...

    @property
    def x(self) -> float:
        ...

    @property
    def y(self) -> float:
        ...

    @property
    def width(self) -> float:
        ...

    @property
    def height(self) -> float:
        ...

    @property
    def rotation(self) -> float:
        ...

    @property
    def center_x(self) -> float:
        ...

    @property
    def center_y(self) -> float:
        ...

    @property
    def flip_h(self) -> NullableBool:
        ...

    @property
    def flip_v(self) -> NullableBool:
        ...

    @property
    def rectangle(self) -> aspose.pydrawing.RectangleF:
        ...

    ...

class IShapeStyle:
    @property
    def line_color(self) -> IColorFormat:
        ...

    @property
    def line_style_index(self) -> int:
        ...

    @line_style_index.setter
    def line_style_index(self, value: int):
        ...

    @property
    def fill_color(self) -> IColorFormat:
        ...

    @property
    def fill_style_index(self) -> int:
        ...

    @fill_style_index.setter
    def fill_style_index(self, value: int):
        ...

    @property
    def effect_color(self) -> IColorFormat:
        ...

    @property
    def effect_style_index(self) -> int:
        ...

    @effect_style_index.setter
    def effect_style_index(self, value: int):
        ...

    @property
    def font_color(self) -> IColorFormat:
        ...

    @property
    def font_collection_index(self) -> FontCollectionIndex:
        ...

    @font_collection_index.setter
    def font_collection_index(self, value: FontCollectionIndex):
        ...

    ...

class ISketchFormat:
    @property
    def sketch_type(self) -> LineSketchType:
        ...

    @sketch_type.setter
    def sketch_type(self, value: LineSketchType):
        ...

    ...

class ISketchFormatEffectiveData:
    @property
    def sketch_type(self) -> LineSketchType:
        ...

    ...

class ISlide:
    @overload
    def get_thumbnail(self, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, image_size: aspose.pydrawing.Size) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, options: aspose.slides.export.ITiffOptions) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, options: aspose.slides.export.IRenderingOptions) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, options: aspose.slides.export.IRenderingOptions, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, options: aspose.slides.export.IRenderingOptions, image_size: aspose.pydrawing.Size) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, image_size: aspose.pydrawing.Size) -> IImage:
        ...

    @overload
    def get_image(self, options: aspose.slides.export.ITiffOptions) -> IImage:
        ...

    @overload
    def get_image(self, options: aspose.slides.export.IRenderingOptions) -> IImage:
        ...

    @overload
    def get_image(self, options: aspose.slides.export.IRenderingOptions, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def get_image(self, options: aspose.slides.export.IRenderingOptions, image_size: aspose.pydrawing.Size) -> IImage:
        ...

    @overload
    def render_to_graphics(self, options: aspose.slides.export.IRenderingOptions, graphics: aspose.pydrawing.Graphics) -> None:
        ...

    @overload
    def render_to_graphics(self, options: aspose.slides.export.IRenderingOptions, graphics: aspose.pydrawing.Graphics, scale_x: float, scale_y: float) -> None:
        ...

    @overload
    def render_to_graphics(self, options: aspose.slides.export.IRenderingOptions, graphics: aspose.pydrawing.Graphics, rendering_size: aspose.pydrawing.Size) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def get_slide_comments(self, author: ICommentAuthor) -> List[IComment]:
        ...

    def remove(self) -> None:
        ...

    def reset(self) -> None:
        ...

    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        ...

    def join_portions_with_same_formatting(self) -> None:
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        ...

    @property
    def header_footer_manager(self) -> ISlideHeaderFooterManager:
        ...

    @property
    def slide_number(self) -> int:
        ...

    @slide_number.setter
    def slide_number(self, value: int):
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def layout_slide(self) -> ILayoutSlide:
        ...

    @layout_slide.setter
    def layout_slide(self, value: ILayoutSlide):
        ...

    @property
    def notes_slide_manager(self) -> INotesSlideManager:
        ...

    @property
    def as_i_base_slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_override_themeable(self) -> aspose.slides.theme.IOverrideThemeable:
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def theme_manager(self) -> aspose.slides.theme.IOverrideThemeManager:
        ...

    ...

class ISlideCollection:
    @overload
    def add_clone(self, source_slide: ISlide) -> ISlide:
        ...

    @overload
    def add_clone(self, source_slide: ISlide, section: ISection) -> ISlide:
        ...

    @overload
    def add_clone(self, source_slide: ISlide, dest_layout: ILayoutSlide) -> ISlide:
        ...

    @overload
    def add_clone(self, source_slide: ISlide, dest_master: IMasterSlide, allow_clone_missing_layout: bool) -> ISlide:
        ...

    @overload
    def insert_clone(self, index: int, source_slide: ISlide) -> ISlide:
        ...

    @overload
    def insert_clone(self, index: int, source_slide: ISlide, dest_layout: ILayoutSlide) -> ISlide:
        ...

    @overload
    def insert_clone(self, index: int, source_slide: ISlide, dest_master: IMasterSlide, allow_clone_missing_layout: bool) -> ISlide:
        ...

    @overload
    def to_array(self) -> List[ISlide]:
        ...

    @overload
    def to_array(self, start_index: int, count: int) -> List[ISlide]:
        ...

    @overload
    def reorder(self, index: int, slide: ISlide) -> None:
        ...

    @overload
    def reorder(self, index: int, slides: List[ISlide]) -> None:
        ...

    @overload
    def add_from_pdf(self, path: string) -> List[ISlide]:
        ...

    @overload
    def add_from_pdf(self, path: string, pdf_import_options: aspose.slides.importing.PdfImportOptions) -> List[ISlide]:
        ...

    @overload
    def add_from_pdf(self, pdf_stream: System.IO.Stream, pdf_import_options: aspose.slides.importing.PdfImportOptions) -> List[ISlide]:
        ...

    @overload
    def add_from_pdf(self, pdf_stream: System.IO.Stream) -> List[ISlide]:
        ...

    @overload
    def add_from_html(self, html_text: string, resolver: aspose.slides.importing.IExternalResourceResolver, uri: string) -> List[ISlide]:
        ...

    @overload
    def add_from_html(self, html_text: string) -> List[ISlide]:
        ...

    @overload
    def add_from_html(self, html_stream: System.IO.Stream, resolver: aspose.slides.importing.IExternalResourceResolver, uri: string) -> List[ISlide]:
        ...

    @overload
    def add_from_html(self, html_stream: System.IO.Stream) -> List[ISlide]:
        ...

    @overload
    def insert_from_html(self, index: int, html_text: string, resolver: aspose.slides.importing.IExternalResourceResolver, uri: string) -> List[ISlide]:
        ...

    @overload
    def insert_from_html(self, index: int, html_text: string) -> List[ISlide]:
        ...

    @overload
    def insert_from_html(self, index: int, html_stream: System.IO.Stream, resolver: aspose.slides.importing.IExternalResourceResolver, uri: string) -> List[ISlide]:
        ...

    @overload
    def insert_from_html(self, index: int, html_stream: System.IO.Stream) -> List[ISlide]:
        ...

    def add_empty_slide(self, layout: ILayoutSlide) -> ISlide:
        ...

    def insert_empty_slide(self, index: int, layout: ILayoutSlide) -> ISlide:
        ...

    def remove(self, value: ISlide) -> None:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def index_of(self, slide: ISlide) -> int:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ISlide
        ...

    ...

class ISlideComponent:
    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class ISlideHeaderFooterManager:
    def set_footer_visibility(self, is_visible: bool) -> None:
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        ...

    def set_footer_text(self, text: string) -> None:
        ...

    def set_date_time_text(self, text: string) -> None:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class ISlideShowTransition:
    @property
    def sound(self) -> IAudio:
        ...

    @sound.setter
    def sound(self, value: IAudio):
        ...

    @property
    def sound_mode(self) -> aspose.slides.slideshow.TransitionSoundMode:
        ...

    @sound_mode.setter
    def sound_mode(self, value: aspose.slides.slideshow.TransitionSoundMode):
        ...

    @property
    def sound_loop(self) -> bool:
        ...

    @sound_loop.setter
    def sound_loop(self, value: bool):
        ...

    @property
    def advance_on_click(self) -> bool:
        ...

    @advance_on_click.setter
    def advance_on_click(self, value: bool):
        ...

    @property
    def advance_after(self) -> bool:
        ...

    @advance_after.setter
    def advance_after(self, value: bool):
        ...

    @property
    def advance_after_time(self) -> int:
        ...

    @advance_after_time.setter
    def advance_after_time(self, value: int):
        ...

    @property
    def speed(self) -> aspose.slides.slideshow.TransitionSpeed:
        ...

    @speed.setter
    def speed(self, value: aspose.slides.slideshow.TransitionSpeed):
        ...

    @property
    def value(self) -> aspose.slides.slideshow.ITransitionValueBase:
        ...

    @property
    def type(self) -> aspose.slides.slideshow.TransitionType:
        ...

    @type.setter
    def type(self, value: aspose.slides.slideshow.TransitionType):
        ...

    @property
    def sound_is_built_in(self) -> bool:
        ...

    @sound_is_built_in.setter
    def sound_is_built_in(self, value: bool):
        ...

    @property
    def sound_name(self) -> string:
        ...

    @sound_name.setter
    def sound_name(self, value: string):
        ...

    ...

class ISlideSize:
    @overload
    def set_size(self, type: SlideSizeType, scale_type: SlideSizeScaleType) -> None:
        ...

    @overload
    def set_size(self, width: float, height: float, scale_type: SlideSizeScaleType) -> None:
        ...

    @property
    def size(self) -> aspose.pydrawing.SizeF:
        ...

    @property
    def type(self) -> SlideSizeType:
        ...

    @property
    def orientation(self) -> SlideOrientation:
        ...

    @orientation.setter
    def orientation(self, value: SlideOrientation):
        ...

    ...

class ISlideText:
    @property
    def text(self) -> string:
        ...

    @property
    def master_text(self) -> string:
        ...

    @property
    def layout_text(self) -> string:
        ...

    @property
    def notes_text(self) -> string:
        ...

    ...

class ISlidesPicture:
    @property
    def image(self) -> IPPImage:
        ...

    @image.setter
    def image(self, value: IPPImage):
        ...

    @property
    def link_path_long(self) -> string:
        ...

    @link_path_long.setter
    def link_path_long(self, value: string):
        ...

    @property
    def image_transform(self) -> aspose.slides.effects.IImageTransformOperationCollection:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class ISpreadsheetOptions:
    @property
    def recover_workbook_from_chart_cache(self) -> bool:
        ...

    @recover_workbook_from_chart_cache.setter
    def recover_workbook_from_chart_cache(self, value: bool):
        ...

    ...

class IStreamWrapper:
    def close(self) -> None:
        ...

    def flush(self) -> None:
        ...

    def read(self, buffer: bytes, offset: int, count: int) -> None:
        ...

    def read_byte(self) -> int:
        ...

    def seek(self, offset: int, origin: System.IO.SeekOrigin) -> int:
        ...

    def write(self, buffer: bytes, offset: int, count: int) -> None:
        ...

    def write_byte(self, value: int) -> None:
        ...

    @property
    def stream(self) -> System.IO.Stream:
        ...

    @property
    def can_read(self) -> bool:
        ...

    @property
    def can_seek(self) -> bool:
        ...

    @property
    def can_write(self) -> bool:
        ...

    @property
    def length(self) -> int:
        ...

    @property
    def position(self) -> int:
        ...

    @property
    def as_i_disposable(self) -> IDisposable:
        ...

    ...

class IStreamWrapperFactory:
    @overload
    def create_memory_stream_wrapper(self) -> IStreamWrapper:
        ...

    @overload
    def create_memory_stream_wrapper(self, buffer: bytes) -> IStreamWrapper:
        ...

    @overload
    def create_file_stream_wrapper(self, file_name: string, file_mode: System.IO.FileMode) -> IStreamWrapper:
        ...

    @overload
    def create_file_stream_wrapper(self, file_name: string, file_mode: System.IO.FileMode, file_access: System.IO.FileAccess) -> IStreamWrapper:
        ...

    ...

class ISummaryZoomFrame:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def layout(self) -> ZoomLayout:
        ...

    @property
    def summary_zoom_collection(self) -> ISummaryZoomSectionCollection:
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class ISummaryZoomSection:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def title(self) -> string:
        ...

    @title.setter
    def title(self, value: string):
        ...

    @property
    def description(self) -> string:
        ...

    @description.setter
    def description(self, value: string):
        ...

    @property
    def as_i_section_zoom_frame(self) -> ISectionZoomFrame:
        ...

    @property
    def target_section(self) -> ISection:
        ...

    @target_section.setter
    def target_section(self, value: ISection):
        ...

    @property
    def as_i_zoom_object(self) -> IZoomObject:
        ...

    @property
    def image_type(self) -> ZoomImageType:
        ...

    @image_type.setter
    def image_type(self, value: ZoomImageType):
        ...

    @property
    def return_to_parent(self) -> bool:
        ...

    @return_to_parent.setter
    def return_to_parent(self, value: bool):
        ...

    @property
    def show_background(self) -> bool:
        ...

    @show_background.setter
    def show_background(self, value: bool):
        ...

    @property
    def zoom_image(self) -> IPPImage:
        ...

    @zoom_image.setter
    def zoom_image(self, value: IPPImage):
        ...

    @property
    def transition_duration(self) -> float:
        ...

    @transition_duration.setter
    def transition_duration(self, value: float):
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class ISummaryZoomSectionCollection:
    def add_summary_zoom_section(self, section: ISection) -> ISummaryZoomSection:
        ...

    def get_summary_section(self, section: ISection) -> ISummaryZoomSection:
        ...

    def remove_summary_zoom_section(self, section: ISection) -> None:
        ...

    def index_of(self, summary_zoom_section: ISummaryZoomSection) -> int:
        ...

    def clear(self) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ISummaryZoomSection
        ...

    ...

class ISvgImage:
    @property
    def svg_content(self) -> string:
        ...

    @property
    def svg_data(self) -> bytes:
        ...

    @property
    def external_resource_resolver(self) -> aspose.slides.importing.IExternalResourceResolver:
        ...

    @property
    def base_uri(self) -> string:
        ...

    ...

class ITab:
    @property
    def position(self) -> float:
        ...

    @position.setter
    def position(self, value: float):
        ...

    @property
    def alignment(self) -> TabAlignment:
        ...

    @alignment.setter
    def alignment(self, value: TabAlignment):
        ...

    ...

class ITabCollection:
    @overload
    def add(self, position: float, align: TabAlignment) -> ITab:
        ...

    @overload
    def add(self, value: ITab) -> int:
        ...

    def clear(self) -> None:
        ...

    def remove_at(self, index: int) -> None:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ITab
        ...

    ...

class ITabEffectiveData:
    @property
    def position(self) -> float:
        ...

    @property
    def alignment(self) -> TabAlignment:
        ...

    ...

class ITabFactory:
    def create_tab(self, position: float, align: TabAlignment) -> ITab:
        ...

    ...

class ITable:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    @overload
    def set_text_format(self, source: IPortionFormat) -> None:
        ...

    @overload
    def set_text_format(self, source: IParagraphFormat) -> None:
        ...

    @overload
    def set_text_format(self, source: ITextFrameFormat) -> None:
        ...

    def merge_cells(self, cell1: ICell, cell2: ICell, allow_splitting: bool) -> ICell:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def rows(self) -> IRowCollection:
        ...

    @property
    def columns(self) -> IColumnCollection:
        ...

    @property
    def table_format(self) -> ITableFormat:
        ...

    @property
    def style_preset(self) -> TableStylePreset:
        ...

    @style_preset.setter
    def style_preset(self, value: TableStylePreset):
        ...

    @property
    def right_to_left(self) -> bool:
        ...

    @right_to_left.setter
    def right_to_left(self, value: bool):
        ...

    @property
    def first_row(self) -> bool:
        ...

    @first_row.setter
    def first_row(self, value: bool):
        ...

    @property
    def first_col(self) -> bool:
        ...

    @first_col.setter
    def first_col(self, value: bool):
        ...

    @property
    def last_row(self) -> bool:
        ...

    @last_row.setter
    def last_row(self, value: bool):
        ...

    @property
    def last_col(self) -> bool:
        ...

    @last_col.setter
    def last_col(self, value: bool):
        ...

    @property
    def horizontal_banding(self) -> bool:
        ...

    @horizontal_banding.setter
    def horizontal_banding(self, value: bool):
        ...

    @property
    def vertical_banding(self) -> bool:
        ...

    @vertical_banding.setter
    def vertical_banding(self, value: bool):
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def as_i_bulk_text_formattable(self) -> IBulkTextFormattable:
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class ITableFormat:
    def get_effective(self) -> ITableFormatEffectiveData:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def transparency(self) -> float:
        ...

    @transparency.setter
    def transparency(self, value: float):
        ...

    ...

class ITableFormatEffectiveData:
    @property
    def transparency(self) -> float:
        ...

    @property
    def as_i_base_table_format_effective_data(self) -> IBaseTableFormatEffectiveData:
        ...

    @property
    def fill_format(self) -> IFillFormatEffectiveData:
        ...

    @property
    def border_left(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_top(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_right(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_bottom(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_diagonal_down(self) -> ILineFormatEffectiveData:
        ...

    @property
    def border_diagonal_up(self) -> ILineFormatEffectiveData:
        ...

    ...

class ITagCollection:
    def add(self, name: string, value: string) -> int:
        ...

    def remove(self, name: string) -> None:
        ...

    def index_of_name(self, name: string) -> int:
        ...

    def remove_at(self, index: int) -> None:
        ...

    def clear(self) -> None:
        ...

    def get_value_by_index(self, index: int) -> string:
        ...

    def get_name_by_index(self, index: int) -> string:
        ...

    def get_names_of_tags(self) -> List[string]:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    ...

class ITextFrame:
    @overload
    def highlight_text(self, text: string, highlight_color: aspose.pydrawing.Color) -> None:
        ...

    @overload
    def highlight_text(self, text: string, highlight_color: aspose.pydrawing.Color, options: ITextHighlightingOptions) -> None:
        ...

    def join_portions_with_same_formatting(self) -> None:
        ...

    def highlight_regex(self, regex: string, highlight_color: aspose.pydrawing.Color, options: ITextHighlightingOptions) -> None:
        ...

    @property
    def paragraphs(self) -> IParagraphCollection:
        ...

    @property
    def text(self) -> string:
        ...

    @text.setter
    def text(self, value: string):
        ...

    @property
    def text_frame_format(self) -> ITextFrameFormat:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class ITextFrameFormat:
    def get_effective(self) -> ITextFrameFormatEffectiveData:
        ...

    @property
    def text_style(self) -> ITextStyle:
        ...

    @property
    def margin_left(self) -> float:
        ...

    @margin_left.setter
    def margin_left(self, value: float):
        ...

    @property
    def margin_right(self) -> float:
        ...

    @margin_right.setter
    def margin_right(self, value: float):
        ...

    @property
    def margin_top(self) -> float:
        ...

    @margin_top.setter
    def margin_top(self, value: float):
        ...

    @property
    def margin_bottom(self) -> float:
        ...

    @margin_bottom.setter
    def margin_bottom(self, value: float):
        ...

    @property
    def wrap_text(self) -> NullableBool:
        ...

    @wrap_text.setter
    def wrap_text(self, value: NullableBool):
        ...

    @property
    def anchoring_type(self) -> TextAnchorType:
        ...

    @anchoring_type.setter
    def anchoring_type(self, value: TextAnchorType):
        ...

    @property
    def center_text(self) -> NullableBool:
        ...

    @center_text.setter
    def center_text(self, value: NullableBool):
        ...

    @property
    def text_vertical_type(self) -> TextVerticalType:
        ...

    @text_vertical_type.setter
    def text_vertical_type(self, value: TextVerticalType):
        ...

    @property
    def autofit_type(self) -> TextAutofitType:
        ...

    @autofit_type.setter
    def autofit_type(self, value: TextAutofitType):
        ...

    @property
    def column_count(self) -> int:
        ...

    @column_count.setter
    def column_count(self, value: int):
        ...

    @property
    def column_spacing(self) -> float:
        ...

    @column_spacing.setter
    def column_spacing(self, value: float):
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def keep_text_flat(self) -> bool:
        ...

    @keep_text_flat.setter
    def keep_text_flat(self, value: bool):
        ...

    @property
    def rotation_angle(self) -> float:
        ...

    @rotation_angle.setter
    def rotation_angle(self, value: float):
        ...

    @property
    def transform(self) -> TextShapeType:
        ...

    @transform.setter
    def transform(self, value: TextShapeType):
        ...

    ...

class ITextFrameFormatEffectiveData:
    @property
    def text_style(self) -> ITextStyleEffectiveData:
        ...

    @property
    def margin_left(self) -> float:
        ...

    @property
    def margin_right(self) -> float:
        ...

    @property
    def margin_top(self) -> float:
        ...

    @property
    def margin_bottom(self) -> float:
        ...

    @property
    def wrap_text(self) -> bool:
        ...

    @property
    def anchoring_type(self) -> TextAnchorType:
        ...

    @property
    def center_text(self) -> bool:
        ...

    @property
    def text_vertical_type(self) -> TextVerticalType:
        ...

    @property
    def autofit_type(self) -> TextAutofitType:
        ...

    @property
    def column_count(self) -> int:
        ...

    @property
    def column_spacing(self) -> float:
        ...

    ...

class ITextHighlightingOptions:
    @property
    def case_sensitive(self) -> bool:
        ...

    @case_sensitive.setter
    def case_sensitive(self, value: bool):
        ...

    @property
    def whole_words_only(self) -> bool:
        ...

    @whole_words_only.setter
    def whole_words_only(self, value: bool):
        ...

    ...

class ITextStyle:
    def get_level(self, index: int) -> IParagraphFormat:
        ...

    def get_effective(self) -> ITextStyleEffectiveData:
        ...

    @property
    def default_paragraph_format(self) -> IParagraphFormat:
        ...

    ...

class ITextStyleEffectiveData:
    def get_level(self, index: int) -> IParagraphFormatEffectiveData:
        ...

    @property
    def default_paragraph_format(self) -> IParagraphFormatEffectiveData:
        ...

    ...

class IThreeDFormat:
    def get_effective(self) -> IThreeDFormatEffectiveData:
        ...

    @property
    def contour_width(self) -> float:
        ...

    @contour_width.setter
    def contour_width(self, value: float):
        ...

    @property
    def extrusion_height(self) -> float:
        ...

    @extrusion_height.setter
    def extrusion_height(self, value: float):
        ...

    @property
    def depth(self) -> float:
        ...

    @depth.setter
    def depth(self, value: float):
        ...

    @property
    def bevel_top(self) -> IShapeBevel:
        ...

    @property
    def bevel_bottom(self) -> IShapeBevel:
        ...

    @property
    def contour_color(self) -> IColorFormat:
        ...

    @property
    def extrusion_color(self) -> IColorFormat:
        ...

    @property
    def camera(self) -> ICamera:
        ...

    @property
    def light_rig(self) -> ILightRig:
        ...

    @property
    def material(self) -> MaterialPresetType:
        ...

    @material.setter
    def material(self, value: MaterialPresetType):
        ...

    @property
    def as_i_three_d_param_source(self) -> IThreeDParamSource:
        ...

    ...

class IThreeDFormatEffectiveData:
    @property
    def contour_width(self) -> float:
        ...

    @property
    def extrusion_height(self) -> float:
        ...

    @property
    def depth(self) -> float:
        ...

    @property
    def bevel_top(self) -> IShapeBevelEffectiveData:
        ...

    @property
    def bevel_bottom(self) -> IShapeBevelEffectiveData:
        ...

    @property
    def contour_color(self) -> aspose.pydrawing.Color:
        ...

    @property
    def extrusion_color(self) -> aspose.pydrawing.Color:
        ...

    @property
    def camera(self) -> ICameraEffectiveData:
        ...

    @property
    def light_rig(self) -> ILightRigEffectiveData:
        ...

    @property
    def material(self) -> MaterialPresetType:
        ...

    @property
    def as_i_three_d_param_source(self) -> IThreeDParamSource:
        ...

    ...

class IThreeDParamSource:
    ...

class IVideo:
    def get_stream(self) -> System.IO.Stream:
        ...

    @property
    def content_type(self) -> string:
        ...

    @property
    def binary_data(self) -> bytes:
        ...

    ...

class IVideoCollection:
    @overload
    def add_video(self, video: IVideo) -> IVideo:
        ...

    @overload
    def add_video(self, stream: System.IO.Stream) -> IVideo:
        ...

    @overload
    def add_video(self, stream: System.IO.Stream, loading_stream_behavior: LoadingStreamBehavior) -> IVideo:
        ...

    @overload
    def add_video(self, video_data: bytes) -> IVideo:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IVideo
        ...

    ...

class IVideoFrame:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def get_geometry_paths(self) -> List[IGeometryPath]:
        ...

    def set_geometry_path(self, geometry_path: IGeometryPath) -> None:
        ...

    def set_geometry_paths(self, geometry_paths: List[IGeometryPath]) -> None:
        ...

    def create_shape_elements(self) -> List[IShapeElement]:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def rewind_video(self) -> bool:
        ...

    @rewind_video.setter
    def rewind_video(self, value: bool):
        ...

    @property
    def play_loop_mode(self) -> bool:
        ...

    @play_loop_mode.setter
    def play_loop_mode(self, value: bool):
        ...

    @property
    def hide_at_showing(self) -> bool:
        ...

    @hide_at_showing.setter
    def hide_at_showing(self, value: bool):
        ...

    @property
    def volume(self) -> AudioVolumeMode:
        ...

    @volume.setter
    def volume(self, value: AudioVolumeMode):
        ...

    @property
    def play_mode(self) -> VideoPlayModePreset:
        ...

    @play_mode.setter
    def play_mode(self, value: VideoPlayModePreset):
        ...

    @property
    def full_screen_mode(self) -> bool:
        ...

    @full_screen_mode.setter
    def full_screen_mode(self, value: bool):
        ...

    @property
    def link_path_long(self) -> string:
        ...

    @link_path_long.setter
    def link_path_long(self, value: string):
        ...

    @property
    def embedded_video(self) -> IVideo:
        ...

    @embedded_video.setter
    def embedded_video(self, value: IVideo):
        ...

    @property
    def trim_from_start(self) -> float:
        ...

    @trim_from_start.setter
    def trim_from_start(self, value: float):
        ...

    @property
    def trim_from_end(self) -> float:
        ...

    @trim_from_end.setter
    def trim_from_end(self, value: float):
        ...

    @property
    def as_i_picture_frame(self) -> IPictureFrame:
        ...

    @property
    def shape_lock(self) -> IPictureFrameLock:
        ...

    @property
    def picture_frame_lock(self) -> IPictureFrameLock:
        ...

    @property
    def picture_format(self) -> IPictureFillFormat:
        ...

    @property
    def relative_scale_height(self) -> float:
        ...

    @relative_scale_height.setter
    def relative_scale_height(self, value: float):
        ...

    @property
    def relative_scale_width(self) -> float:
        ...

    @relative_scale_width.setter
    def relative_scale_width(self, value: float):
        ...

    @property
    def as_i_geometry_shape(self) -> IGeometryShape:
        ...

    @property
    def shape_style(self) -> IShapeStyle:
        ...

    @property
    def shape_type(self) -> ShapeType:
        ...

    @shape_type.setter
    def shape_type(self, value: ShapeType):
        ...

    @property
    def adjustments(self) -> IAdjustValueCollection:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IViewProperties:
    @property
    def last_view(self) -> ViewType:
        ...

    @last_view.setter
    def last_view(self, value: ViewType):
        ...

    @property
    def show_comments(self) -> NullableBool:
        ...

    @show_comments.setter
    def show_comments(self, value: NullableBool):
        ...

    @property
    def slide_view_properties(self) -> ICommonSlideViewProperties:
        ...

    @property
    def notes_view_properties(self) -> ICommonSlideViewProperties:
        ...

    @property
    def normal_view_properties(self) -> INormalViewProperties:
        ...

    ...

class IZoomFrame:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def target_slide(self) -> ISlide:
        ...

    @target_slide.setter
    def target_slide(self, value: ISlide):
        ...

    @property
    def as_i_zoom_object(self) -> IZoomObject:
        ...

    @property
    def image_type(self) -> ZoomImageType:
        ...

    @image_type.setter
    def image_type(self, value: ZoomImageType):
        ...

    @property
    def return_to_parent(self) -> bool:
        ...

    @return_to_parent.setter
    def return_to_parent(self, value: bool):
        ...

    @property
    def show_background(self) -> bool:
        ...

    @show_background.setter
    def show_background(self, value: bool):
        ...

    @property
    def zoom_image(self) -> IPPImage:
        ...

    @zoom_image.setter
    def zoom_image(self, value: IPPImage):
        ...

    @property
    def transition_duration(self) -> float:
        ...

    @transition_duration.setter
    def transition_duration(self, value: float):
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class IZoomObject:
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        ...

    @overload
    def get_image(self) -> IImage:
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        ...

    def remove_placeholder(self) -> None:
        ...

    def get_base_placeholder(self) -> IShape:
        ...

    @property
    def image_type(self) -> ZoomImageType:
        ...

    @image_type.setter
    def image_type(self, value: ZoomImageType):
        ...

    @property
    def return_to_parent(self) -> bool:
        ...

    @return_to_parent.setter
    def return_to_parent(self, value: bool):
        ...

    @property
    def show_background(self) -> bool:
        ...

    @show_background.setter
    def show_background(self, value: bool):
        ...

    @property
    def zoom_image(self) -> IPPImage:
        ...

    @zoom_image.setter
    def zoom_image(self, value: IPPImage):
        ...

    @property
    def transition_duration(self) -> float:
        ...

    @transition_duration.setter
    def transition_duration(self, value: float):
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    ...

class ImageCollection:
    '''Represents collection of PPImage.'''
    @overload
    def add_image(self, image_source: IPPImage) -> IPPImage:
        '''Adds a copy of an image from an another presentation.
        :param image_source: Source image.
        :returns: Added image.'''
        ...

    @overload
    def add_image(self, image: aspose.pydrawing.Image) -> IPPImage:
        '''Add an image to a presentation.
        :param image: Image to add.
        :returns: Added image.'''
        ...

    @overload
    def add_image(self, image: IImage) -> IPPImage:
        '''Add an image to a presentation.
        :param image: Image to add.
        :returns: Added image.'''
        ...

    @overload
    def add_image(self, stream: System.IO.Stream) -> IPPImage:
        '''Add an image to a presentation from stream.
        :param stream: Stream to add image from.
        :returns: Added image.'''
        ...

    @overload
    def add_image(self, stream: System.IO.Stream, loading_stream_behavior: LoadingStreamBehavior) -> IPPImage:
        '''Creates and adds an image to a presentation from stream.
        :param stream: Stream to add image file from.
        :param loading_stream_behavior: The behavior which will be applied to the stream.
        :returns: Added :py:class:`aspose.slides.IPPImage`.'''
        ...

    @overload
    def add_image(self, buffer: bytes) -> IPPImage:
        '''Adds an image to a presentation from specified buffer.
        :param buffer: Buffer.
        :returns: Added image.'''
        ...

    @overload
    def add_image(self, svg_image: ISvgImage) -> IPPImage:
        '''Add an image to a presentation from Svg object.
        :param svg_image: Svg image object :py:class:`aspose.slides.ISvgImage`
        :returns: Added image.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IPPImage
        '''Gets the element at the specified index.
                    Read-only :py:class:`aspose.slides.IPPImage`.'''
        ...

    ...

class ImageWrapper:
    '''System.Drawing.Image wrapper for COM interface.'''
    @overload
    def save(self, file_name: string) -> None:
        '''Saves Image to the specified file'''
        ...

    @overload
    def save(self, stream: System.IO.Stream, image_format: PPImageFormat) -> None:
        '''Saves the Image to the specified stream in the specified format.'''
        ...

    @overload
    def save(self, file_name: string, image_format: PPImageFormat) -> None:
        '''Saves the Image to the specified file in the specified format.'''
        ...

    @property
    def image(self) -> aspose.pydrawing.Image:
        ...

    @property
    def image_source(self) -> IImage:
        ...

    @property
    def size(self) -> aspose.pydrawing.Size:
        ...

    @property
    def as_i_disposable(self) -> IDisposable:
        ...

    ...

class ImageWrapperFactory:
    '''This class allows to initialize IBitmapWrapper.'''
    def __init__(self):
        ...

    @overload
    def create_image_wrapper(self, image: aspose.pydrawing.Image) -> IImageWrapper:
        '''Initializes a new instance of the BitmapWrapper class from the specified existing image.'''
        ...

    @overload
    def create_image_wrapper(self, image: IImage) -> IImageWrapper:
        '''Initializes a new instance of the ImageWrapper class from the specified existing image.'''
        ...

    @overload
    def create_image_wrapper(self, stream: System.IO.Stream) -> IImageWrapper:
        '''Initializes a new instance of the BitmapWrapper class from the specified data stream.'''
        ...

    @overload
    def create_image_wrapper(self, file_name: string) -> IImageWrapper:
        '''Initializes a new instance of the BitmapWrapper class from the specified file.'''
        ...

    ...

class Images:
    '''Methods to instantiate and work with :py:class:`aspose.slides.IImage`.'''
    @overload
    @staticmethod
    def from_file(filename: string) -> IImage:
        '''Create an image from the file .'''
        ...

    @overload
    @staticmethod
    def from_file(filename: string, use_embedded_color_management: bool) -> IImage:
        '''Create an image from the file'''
        ...

    @overload
    @staticmethod
    def from_stream(stream: System.IO.Stream) -> IImage:
        '''Create an image from the stream.'''
        ...

    @overload
    @staticmethod
    def from_stream(stream: System.IO.Stream, use_embedded_color_management: bool) -> IImage:
        '''Create an image from the stream.'''
        ...

    @overload
    @staticmethod
    def from_stream(stream: System.IO.Stream, use_embedded_color_management: bool, validate_image_data: bool) -> IImage:
        '''Create an image from the stream.'''
        ...

    ...

class InterruptionToken:
    '''This class represents the token to use for signaling long running tasks whether the interruption was requested.'''
    def throw_if_interruption_requested(self) -> None:
        '''Throws an  if
                    interruption was requested.'''
        ...

    @classmethod
    @property
    def none(cls) -> InterruptionToken:
        ...

    @property
    def is_interruption_requested(self) -> bool:
        ...

    ...

class InterruptionTokenSource:
    '''Represents the source of :py:class:`aspose.slides.InterruptionToken`.'''
    def __init__(self):
        '''Creates a new :py:class:`aspose.slides.InterruptionTokenSource`.'''
        ...

    def interrupt(self) -> None:
        '''Intialize request for interruption.'''
        ...

    @property
    def token(self) -> IInterruptionToken:
        ...

    @property
    def is_interruption_requested(self) -> bool:
        ...

    ...

class InvalidPasswordException:
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class LayoutSlide(BaseSlide):
    '''Represents a layout slide.'''
    @overload
    def join_portions_with_same_formatting(self) -> None:
        '''Joins runs with same formatting in all paragraphs all acceptable shapes.'''
        ...

    @overload
    def join_portions_with_same_formatting(self, collection: IShapeCollection) -> None:
        '''Joins runs with same formatting in all paragraphs in all acceptable shapes.'''
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        '''Determines whether the two IBaseSlide instances are equal.
                    Returning value is calculated based on slide's structure and static content.
                    Two slides are equal if all shapes, styles, texts, animation and other settings. etc. are equal. The comparison doesn't take into account unique identifier values, e.g. SlideId and dynamic content, e.g. current date value in Date Placeholder.
        :param slide: The IBaseSlide to compare with the current IBaseSlide.
        :returns: **true** if the specified IBaseSlide is equal to the current IBaseSlide; 
                    otherwise, **false**.'''
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        '''Returns an effective theme for this slide.'''
        ...

    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        '''Finds first occurrence of a shape with the specified alternative text.
        :param alt_text: Alternative text.
        :returns: Shape object or null.'''
        ...

    def remove(self) -> None:
        '''Removes layout from presentation.'''
        ...

    def get_depending_slides(self) -> List[ISlide]:
        '''Returns an array with all slides, which depend on this layout slide.'''
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def header_footer_manager(self) -> ILayoutSlideHeaderFooterManager:
        ...

    @property
    def master_slide(self) -> IMasterSlide:
        ...

    @master_slide.setter
    def master_slide(self, value: IMasterSlide):
        ...

    @property
    def theme_manager(self) -> aspose.slides.theme.IOverrideThemeManager:
        ...

    @property
    def layout_type(self) -> SlideLayoutType:
        ...

    @property
    def has_depending_slides(self) -> bool:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_base_slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_override_themeable(self) -> aspose.slides.theme.IOverrideThemeable:
        ...

    ...

class LayoutSlideCollection:
    '''Represents a base class for collection of a layout slides.'''
    def get_by_type(self, type: SlideLayoutType) -> ILayoutSlide:
        '''Returns the first layout slide of specified type.'''
        ...

    def remove(self, value: ILayoutSlide) -> None:
        '''Removes a layout from the collection.
        :param value: The layout slide to remove from the collection.'''
        ...

    def remove_unused(self) -> None:
        '''Removes unused layout slides (layout slides whose HasDependingSlides is false).'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ILayoutSlide
        '''Returns the layout slide by index.
                    Read-only :py:class:`aspose.slides.LayoutSlide`.'''
        ...

    ...

class LayoutSlideHeaderFooterManager(BaseSlideHeaderFooterManager):
    '''Represents manager which holds behavior of the layout slide footer, date-time, page number placeholders and all child placeholders.
                Child placeholders mean placeholders are contained on depending slides.
                Depending slides use and depend on layout slide.'''
    def set_footer_visibility(self, is_visible: bool) -> None:
        '''Changes slide footer placeholder visibility.
        :param is_visible: true - makes a footer placeholder visible, otherwise - hides it.'''
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        '''Changes slide page number placeholder visibility.
        :param is_visible: true - makes a page number placeholder visible, otherwise - hides it.'''
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        '''Changes slide date-time placeholder visibility.
        :param is_visible: true - makes a date-time placeholder visible, otherwise - hides it.'''
        ...

    def set_footer_text(self, text: string) -> None:
        '''Sets text to slide footer placeholder.
        :param text: Text to set.'''
        ...

    def set_date_time_text(self, text: string) -> None:
        '''Sets text to slide date-time placeholder.
        :param text: Text to set.'''
        ...

    def set_footer_and_child_footers_visibility(self, is_visible: bool) -> None:
        '''Changes layout slide footer placeholder and all child footer placeholders visibility.
                    Child placeholders mean placeholders are contained on depending slides.
                    Depending slides use and depend on master slide.
        :param is_visible: true - makes a footer placeholders visible, otherwise - hides them.'''
        ...

    def set_slide_number_and_child_slide_numbers_visibility(self, is_visible: bool) -> None:
        '''Changes layout slide page number placeholder and all child page number placeholders visibility.
                    Child placeholders mean placeholders are contained on depending slides.
                    Depending slides use and depend on layout slide.
        :param is_visible: true - makes a page number placeholders visible, otherwise - hides them.'''
        ...

    def set_date_time_and_child_date_times_visibility(self, is_visible: bool) -> None:
        '''Changes layout slide date-time placeholder and all child date-time placeholders visibility.
                    Child placeholders mean placeholders are contained on depending slides.
                    Depending slides use and depend on layout slide.
        :param is_visible: true - makes a date-time placeholders visible, otherwise - hides them.'''
        ...

    def set_footer_and_child_footers_text(self, text: string) -> None:
        '''Sets text to layout slide footer placeholder and all child footer placeholders.
                    Child placeholders mean placeholders are contained on depending slides.
                    Depending slides use and depend on layout slide.
        :param text: Text to set.'''
        ...

    def set_date_time_and_child_date_times_text(self, text: string) -> None:
        '''Sets text to layout slide date-time placeholder and all child date-time placeholders.
                    Child placeholders mean placeholders are contained on depending slides.
                    Depending slides use and depend on layout slide.
        :param text: Text to set.'''
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class LegacyDiagram(GraphicalObject):
    '''Represents a legacy diagram object.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    def convert_to_smart_art(self) -> aspose.slides.smartart.ISmartArt:
        '''Converts legacy digram to editable SmartArt object. 
                    Created SmartArt object adds to parent group shape at the same position.
        :returns: Created SmartArt object.'''
        ...

    def convert_to_group_shape(self) -> IGroupShape:
        '''Converts legacy digram to editable group shape. 
                    Created GroupShape object adds to parent group shape at the same position.
        :returns: Created GroupShape object.'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    ...

class License:
    '''Provides methods to license the component.'''
    def __init__(self):
        '''Initializes a new instance of this class.'''
        ...

    @overload
    def set_license(self, license_name: string) -> None:
        '''Licenses the component.
        :param license_name: Can be a full or short file name or name of an embedded resource.
                    Use an empty string to switch to evaluation mode.'''
        ...

    @overload
    def set_license(self, stream: System.IO.Stream) -> None:
        '''Licenses the component.
        :param stream: A stream that contains the license.'''
        ...

    def reset_license(self) -> None:
        '''Reset the license'''
        ...

    def is_licensed(self) -> bool:
        '''Check if licence is applied to component
        :returns: ``True`` if component is licensed, otherwise ``false``'''
        ...

    ...

class LightRig(PVIObject):
    '''Represents LightRig.'''
    def set_rotation(self, latitude: float, longitude: float, revolution: float) -> None:
        '''A rotation is defined through the use of a latitude
                    coordinate, a longitude coordinate, and a revolution about the axis 
                    as the latitude and longitude coordinates.
                    If any of coordinate value is float.NaN, all rotation is undefined.'''
        ...

    def get_rotation(self) -> List[float]:
        '''A rotation is defined through the use of a latitude
                    coordinate, a longitude coordinate, and a revolution about the axis 
                    as the latitude and longitude coordinates.
                    first element in return array - latitude, second - longitude, third - revolution.
                    Returns null if no rotation defined.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def direction(self) -> LightingDirection:
        ...

    @direction.setter
    def direction(self, value: LightingDirection):
        ...

    @property
    def light_type(self) -> LightRigPresetType:
        ...

    @light_type.setter
    def light_type(self, value: LightRigPresetType):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class LineFillFormat(PVIObject):
    '''Represents properties for lines filling.'''
    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def fill_type(self) -> FillType:
        ...

    @fill_type.setter
    def fill_type(self, value: FillType):
        ...

    @property
    def rotate_with_shape(self) -> NullableBool:
        ...

    @rotate_with_shape.setter
    def rotate_with_shape(self, value: NullableBool):
        ...

    @property
    def solid_fill_color(self) -> IColorFormat:
        ...

    @property
    def gradient_format(self) -> IGradientFormat:
        ...

    @property
    def pattern_format(self) -> IPatternFormat:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class LineFormat(PVIObject):
    '''Represents format of a line.'''
    def equals(self, line_format: ILineFormat) -> bool:
        '''Determines whether the two LineFormat instances are equal.
        :param line_format: The LineFormat to compare with the current LineFormat.
        :returns: **true** if the specified LineFormat is equal to the current LineFormat; 
                    otherwise, **false**.'''
        ...

    def get_effective(self) -> ILineFormatEffectiveData:
        '''Gets effective line formatting data with the inheritance applied.
        :returns: A :py:class:`aspose.slides.ILineFormatEffectiveData`.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def is_format_not_defined(self) -> bool:
        ...

    @property
    def fill_format(self) -> ILineFillFormat:
        ...

    @property
    def sketch_format(self) -> ISketchFormat:
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def dash_style(self) -> LineDashStyle:
        ...

    @dash_style.setter
    def dash_style(self, value: LineDashStyle):
        ...

    @property
    def custom_dash_pattern(self) -> List[float]:
        ...

    @custom_dash_pattern.setter
    def custom_dash_pattern(self, value: List[float]):
        ...

    @property
    def cap_style(self) -> LineCapStyle:
        ...

    @cap_style.setter
    def cap_style(self, value: LineCapStyle):
        ...

    @property
    def style(self) -> LineStyle:
        ...

    @style.setter
    def style(self, value: LineStyle):
        ...

    @property
    def alignment(self) -> LineAlignment:
        ...

    @alignment.setter
    def alignment(self, value: LineAlignment):
        ...

    @property
    def join_style(self) -> LineJoinStyle:
        ...

    @join_style.setter
    def join_style(self, value: LineJoinStyle):
        ...

    @property
    def miter_limit(self) -> float:
        ...

    @miter_limit.setter
    def miter_limit(self, value: float):
        ...

    @property
    def begin_arrowhead_style(self) -> LineArrowheadStyle:
        ...

    @begin_arrowhead_style.setter
    def begin_arrowhead_style(self, value: LineArrowheadStyle):
        ...

    @property
    def end_arrowhead_style(self) -> LineArrowheadStyle:
        ...

    @end_arrowhead_style.setter
    def end_arrowhead_style(self, value: LineArrowheadStyle):
        ...

    @property
    def begin_arrowhead_width(self) -> LineArrowheadWidth:
        ...

    @begin_arrowhead_width.setter
    def begin_arrowhead_width(self, value: LineArrowheadWidth):
        ...

    @property
    def end_arrowhead_width(self) -> LineArrowheadWidth:
        ...

    @end_arrowhead_width.setter
    def end_arrowhead_width(self, value: LineArrowheadWidth):
        ...

    @property
    def begin_arrowhead_length(self) -> LineArrowheadLength:
        ...

    @begin_arrowhead_length.setter
    def begin_arrowhead_length(self, value: LineArrowheadLength):
        ...

    @property
    def end_arrowhead_length(self) -> LineArrowheadLength:
        ...

    @end_arrowhead_length.setter
    def end_arrowhead_length(self, value: LineArrowheadLength):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_line_param_source(self) -> ILineParamSource:
        ...

    ...

class LoadOptions:
    '''Allows to specify additional options (such as format or default font) when loading a presentation.'''
    def __init__(self):
        '''Creates new default load options.'''
        ...

    def __init__(self, load_format: LoadFormat):
        '''Creates new load options.
        :param load_format: Format of a presentation to load.'''
        ...

    @property
    def load_format(self) -> LoadFormat:
        ...

    @load_format.setter
    def load_format(self, value: LoadFormat):
        ...

    @property
    def default_regular_font(self) -> string:
        ...

    @default_regular_font.setter
    def default_regular_font(self, value: string):
        ...

    @property
    def default_symbol_font(self) -> string:
        ...

    @default_symbol_font.setter
    def default_symbol_font(self, value: string):
        ...

    @property
    def default_asian_font(self) -> string:
        ...

    @default_asian_font.setter
    def default_asian_font(self, value: string):
        ...

    @property
    def password(self) -> string:
        ...

    @password.setter
    def password(self, value: string):
        ...

    @property
    def only_load_document_properties(self) -> bool:
        ...

    @only_load_document_properties.setter
    def only_load_document_properties(self, value: bool):
        ...

    @property
    def warning_callback(self) -> aspose.slides.warnings.IWarningCallback:
        ...

    @warning_callback.setter
    def warning_callback(self, value: aspose.slides.warnings.IWarningCallback):
        ...

    @property
    def blob_management_options(self) -> IBlobManagementOptions:
        ...

    @blob_management_options.setter
    def blob_management_options(self, value: IBlobManagementOptions):
        ...

    @property
    def document_level_font_sources(self) -> IFontSources:
        ...

    @document_level_font_sources.setter
    def document_level_font_sources(self, value: IFontSources):
        ...

    @property
    def interruption_token(self) -> IInterruptionToken:
        ...

    @interruption_token.setter
    def interruption_token(self, value: IInterruptionToken):
        ...

    @property
    def resource_loading_callback(self) -> IResourceLoadingCallback:
        ...

    @resource_loading_callback.setter
    def resource_loading_callback(self, value: IResourceLoadingCallback):
        ...

    @property
    def spreadsheet_options(self) -> ISpreadsheetOptions:
        ...

    @spreadsheet_options.setter
    def spreadsheet_options(self, value: ISpreadsheetOptions):
        ...

    @property
    def default_text_language(self) -> string:
        ...

    @default_text_language.setter
    def default_text_language(self, value: string):
        ...

    ...

class MasterHandoutSlide(BaseSlide):
    '''Represents master slide for handouts.'''
    @overload
    def join_portions_with_same_formatting(self) -> None:
        '''Joins runs with same formatting in all paragraphs all acceptable shapes.'''
        ...

    @overload
    def join_portions_with_same_formatting(self, collection: IShapeCollection) -> None:
        '''Joins runs with same formatting in all paragraphs in all acceptable shapes.'''
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        '''Determines whether the two IBaseSlide instances are equal.
                    Returning value is calculated based on slide's structure and static content.
                    Two slides are equal if all shapes, styles, texts, animation and other settings. etc. are equal. The comparison doesn't take into account unique identifier values, e.g. SlideId and dynamic content, e.g. current date value in Date Placeholder.
        :param slide: The IBaseSlide to compare with the current IBaseSlide.
        :returns: **true** if the specified IBaseSlide is equal to the current IBaseSlide; 
                    otherwise, **false**.'''
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        '''Returns an effective theme for this slide.'''
        ...

    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        '''Finds first occurrence of a shape with the specified alternative text.
        :param alt_text: Alternative text.
        :returns: Shape object or null.'''
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def header_footer_manager(self) -> IMasterHandoutSlideHeaderFooterManager:
        ...

    @property
    def theme_manager(self) -> aspose.slides.theme.IMasterThemeManager:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_base_slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_master_themeable(self) -> aspose.slides.theme.IMasterThemeable:
        ...

    ...

class MasterHandoutSlideHeaderFooterManager(BaseHandoutNotesSlideHeaderFooterManager):
    '''Represents manager which holds behavior of the master handout slide placeholders, including header placeholder.'''
    def set_footer_visibility(self, is_visible: bool) -> None:
        '''Changes slide footer placeholder visibility.
        :param is_visible: true - makes a footer placeholder visible, otherwise - hides it.'''
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        '''Changes slide page number placeholder visibility.
        :param is_visible: true - makes a page number placeholder visible, otherwise - hides it.'''
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        '''Changes slide date-time placeholder visibility.
        :param is_visible: true - makes a date-time placeholder visible, otherwise - hides it.'''
        ...

    def set_footer_text(self, text: string) -> None:
        '''Sets text to slide footer placeholder.
        :param text: Text to set.'''
        ...

    def set_date_time_text(self, text: string) -> None:
        '''Sets text to slide date-time placeholder.
        :param text: Text to set.'''
        ...

    def set_header_visibility(self, is_visible: bool) -> None:
        '''Changes slide header placeholder visibility.
        :param is_visible: true - makes a header placeholder visible, otherwise - hides it.'''
        ...

    def set_header_text(self, text: string) -> None:
        '''Sets text to slide header placeholder.
        :param text: Text to set.'''
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def is_header_visible(self) -> bool:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    @property
    def as_i_base_handout_notes_slide_header_footer_manag(self) -> IBaseHandoutNotesSlideHeaderFooterManag:
        ...

    ...

class MasterLayoutSlideCollection(LayoutSlideCollection):
    '''Represents a collections of all layout slides of defined master slide.
                Extends LayoutSlideCollection class with methods for adding/inserting/removing/cloning/reordering 
                layout slides in context of the individual collections of master's layout slides.'''
    def get_by_type(self, type: SlideLayoutType) -> ILayoutSlide:
        '''Returns the first layout slide of specified type.'''
        ...

    def remove(self, value: ILayoutSlide) -> None:
        '''Removes a layout from the collection.
        :param value: The layout slide to remove from the collection.'''
        ...

    def remove_unused(self) -> None:
        '''Removes unused layout slides (layout slides whose HasDependingSlides is false).'''
        ...

    def add_clone(self, source_layout: ILayoutSlide) -> ILayoutSlide:
        '''Adds a copy of a specified layout slide to the end of the collection.
        :param source_layout: Slide to clone.
        :returns: Added slide.'''
        ...

    def insert_clone(self, index: int, source_layout: ILayoutSlide) -> ILayoutSlide:
        '''Inserts a copy of a specified layout slide to specified position of the collection.
        :param index: Index of new slide.
        :param source_layout: Slide to clone.
        :returns: Inserted slide.'''
        ...

    def add(self, layout_type: SlideLayoutType, layout_name: string) -> ILayoutSlide:
        '''Adds a new layout slide to the end of the collection.
        :param layout_type: Layout type for a new layout.
                    Supported layout types: Title, TitleOnly, Blank, TitleAndObject, VerticalText, VerticalTitleAndText, TwoObjects, SectionHeader, TwoTextAndTwoObjects, TitleObjectAndCaption, PictureAndCaption, Custom.
                    Other layout types are not supported now: Text, TwoColumnText, Table, TextAndChart, ChartAndText, Diagram, Chart, TextAndClipArt, ClipArtAndText, TextAndObject, ObjectAndText, Object, TextAndMedia, MediaAndText, ObjectOverText, TextOverObject, TextAndTwoObjects, TwoObjectsAndText, TwoObjectsOverText, FourObjects, ClipArtAndVerticalText, VerticalTitleAndTextOverChart, ObjectAndTwoObject, TwoObjectsAndObject.
        :param layout_name: Name for a new layout. If passed name is already in use the ArgumentException will be thrown.
                    If null parameter is passed then name genarated atomatically in regards to passed layout type 
                    (for example "Title Slide" or "1_Title Slide", "2_..", etc.).
        :returns: Added slide.'''
        ...

    def insert(self, index: int, layout_type: SlideLayoutType, layout_name: string) -> ILayoutSlide:
        '''Inserts a new layout slide to specified position of the collection.
        :param index: Index of new slide.
        :param layout_type: Layout type for a new layout.
                    Supported layout types: Title, TitleOnly, Blank, TitleAndObject, VerticalText, VerticalTitleAndText, TwoObjects, SectionHeader, TwoTextAndTwoObjects, TitleObjectAndCaption, PictureAndCaption, Custom.
                    Other layout types are not supported now: Text, TwoColumnText, Table, TextAndChart, ChartAndText, Diagram, Chart, TextAndClipArt, ClipArtAndText, TextAndObject, ObjectAndText, Object, TextAndMedia, MediaAndText, ObjectOverText, TextOverObject, TextAndTwoObjects, TwoObjectsAndText, TwoObjectsOverText, FourObjects, ClipArtAndVerticalText, VerticalTitleAndTextOverChart, ObjectAndTwoObject, TwoObjectsAndObject.
        :param layout_name: Name for a new layout. If passed name is already in use the ArgumentException will be thrown.
                    If null parameter is passed then name genarated atomatically in regards to passed layout type 
                    (for example "Title Slide" or "1_Title Slide", "2_..", etc.).
        :returns: Inserted slide.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the element at the specified index of the collection.
        :param index: The zero-based index of the element to remove.'''
        ...

    def reorder(self, index: int, layout_slide: ILayoutSlide) -> None:
        '''Moves layout slide from the collection to the specified position.
        :param index: Target index.
        :param layout_slide: Slide to move.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    @property
    def as_i_layout_slide_collection(self) -> ILayoutSlideCollection:
        ...

    def __getitem__(self, key: int) -> ILayoutSlide
        ...

    ...

class MasterNotesSlide(BaseSlide):
    '''Represents master slide for notes.'''
    @overload
    def join_portions_with_same_formatting(self) -> None:
        '''Joins runs with same formatting in all paragraphs all acceptable shapes.'''
        ...

    @overload
    def join_portions_with_same_formatting(self, collection: IShapeCollection) -> None:
        '''Joins runs with same formatting in all paragraphs in all acceptable shapes.'''
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        '''Determines whether the two IBaseSlide instances are equal.
                    Returning value is calculated based on slide's structure and static content.
                    Two slides are equal if all shapes, styles, texts, animation and other settings. etc. are equal. The comparison doesn't take into account unique identifier values, e.g. SlideId and dynamic content, e.g. current date value in Date Placeholder.
        :param slide: The IBaseSlide to compare with the current IBaseSlide.
        :returns: **true** if the specified IBaseSlide is equal to the current IBaseSlide; 
                    otherwise, **false**.'''
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        '''Returns an effective theme for this slide.'''
        ...

    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        '''Finds first occurrence of a shape with the specified alternative text.
        :param alt_text: Alternative text.
        :returns: Shape object or null.'''
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def header_footer_manager(self) -> IMasterNotesSlideHeaderFooterManager:
        ...

    @property
    def theme_manager(self) -> aspose.slides.theme.IMasterThemeManager:
        ...

    @property
    def notes_style(self) -> ITextStyle:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_base_slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_master_themeable(self) -> aspose.slides.theme.IMasterThemeable:
        ...

    ...

class MasterNotesSlideHeaderFooterManager(BaseHandoutNotesSlideHeaderFooterManager):
    '''Represents manager which holds behavior of the master notes slide footer, date-time, page number placeholders and all child placeholders.
                Child placeholders mean placeholders are contained on depending notes slides.
                Depending notes slides use and depend on master notes slide.'''
    def set_footer_visibility(self, is_visible: bool) -> None:
        '''Changes slide footer placeholder visibility.
        :param is_visible: true - makes a footer placeholder visible, otherwise - hides it.'''
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        '''Changes slide page number placeholder visibility.
        :param is_visible: true - makes a page number placeholder visible, otherwise - hides it.'''
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        '''Changes slide date-time placeholder visibility.
        :param is_visible: true - makes a date-time placeholder visible, otherwise - hides it.'''
        ...

    def set_footer_text(self, text: string) -> None:
        '''Sets text to slide footer placeholder.
        :param text: Text to set.'''
        ...

    def set_date_time_text(self, text: string) -> None:
        '''Sets text to slide date-time placeholder.
        :param text: Text to set.'''
        ...

    def set_header_visibility(self, is_visible: bool) -> None:
        '''Changes slide header placeholder visibility.
        :param is_visible: true - makes a header placeholder visible, otherwise - hides it.'''
        ...

    def set_header_text(self, text: string) -> None:
        '''Sets text to slide header placeholder.
        :param text: Text to set.'''
        ...

    def set_header_and_child_headers_visibility(self, is_visible: bool) -> None:
        '''Changes master notes slide header placeholder and all child header placeholders visibility.
                    Child placeholders mean placeholders are contained on depending notes slides.
                    Depending notes slides use and depend on master notes slide.
        :param is_visible: true - makes a header placeholders visible, otherwise - hides them.'''
        ...

    def set_header_and_child_headers_text(self, text: string) -> None:
        '''Sets text to master notes slide header placeholder and all child header placeholders.
                    Child placeholders mean placeholders are contained on depending notes slides.
                    Depending notes slides use and depend on master notes slide.
        :param text: Text to set.'''
        ...

    def set_footer_and_child_footers_visibility(self, is_visible: bool) -> None:
        '''Changes master slide footer placeholder and all child footer placeholders visibility.
                    Child placeholders mean placeholders are contained on depending notes slides.
                    Depending notes slides use and depend on master notes slide.
        :param is_visible: true - makes a footer placeholders visible, otherwise - hides them.'''
        ...

    def set_slide_number_and_child_slide_numbers_visibility(self, is_visible: bool) -> None:
        '''Changes master slide page number placeholder and all child page number placeholders visibility.
                    Child placeholders mean placeholders are contained on depending notes slides.
                    Depending notes slides use and depend on master notes slide.
        :param is_visible: true - makes a page number placeholders visible, otherwise - hides them.'''
        ...

    def set_date_time_and_child_date_times_visibility(self, is_visible: bool) -> None:
        '''Changes master slide date-time placeholder and all child date-time placeholders visibility.
                    Child placeholders mean placeholders are contained on depending notes slides.
                    Depending notes slides use and depend on master notes slide.
        :param is_visible: true - makes a date-time placeholders visible, otherwise - hides them.'''
        ...

    def set_footer_and_child_footers_text(self, text: string) -> None:
        '''Sets text to master slide footer placeholder and all child footer placeholders.
                    Child placeholders mean placeholders are contained on depending notes slides.
                    Depending notes slides use and depend on master notes slide.
        :param text: Text to set.'''
        ...

    def set_date_time_and_child_date_times_text(self, text: string) -> None:
        '''Sets text to master slide date-time placeholder and all child date-time placeholders.
                    Child placeholders mean placeholders are contained on depending notes slides.
                    Depending notes slides use and depend on master notes slide.
        :param text: Text to set.'''
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def is_header_visible(self) -> bool:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    @property
    def as_i_base_handout_notes_slide_header_footer_manag(self) -> IBaseHandoutNotesSlideHeaderFooterManag:
        ...

    ...

class MasterSlide(BaseSlide):
    '''Represents a master slide in a presentation.'''
    @overload
    def join_portions_with_same_formatting(self) -> None:
        '''Joins runs with same formatting in all paragraphs all acceptable shapes.'''
        ...

    @overload
    def join_portions_with_same_formatting(self, collection: IShapeCollection) -> None:
        '''Joins runs with same formatting in all paragraphs in all acceptable shapes.'''
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        '''Determines whether the two IBaseSlide instances are equal.
                    Returning value is calculated based on slide's structure and static content.
                    Two slides are equal if all shapes, styles, texts, animation and other settings. etc. are equal. The comparison doesn't take into account unique identifier values, e.g. SlideId and dynamic content, e.g. current date value in Date Placeholder.
        :param slide: The IBaseSlide to compare with the current IBaseSlide.
        :returns: **true** if the specified IBaseSlide is equal to the current IBaseSlide; 
                    otherwise, **false**.'''
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        '''Returns an effective theme for this slide.'''
        ...

    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        '''Finds first occurrence of a shape with the specified alternative text.
        :param alt_text: Alternative text.
        :returns: Shape object or null.'''
        ...

    def apply_external_theme_to_depending_slides(self, fname: string) -> IMasterSlide:
        '''Creates a new master slide based on the current one, applying an external theme to it 
                    and applies the created master slide to all dependent slides.
        :param fname: Path to the external theme file (.thmx).
        :returns: New themed MasterSlide.'''
        ...

    def get_depending_slides(self) -> List[ISlide]:
        '''Returns an array with all slides, which depend on this master slide.'''
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def header_footer_manager(self) -> IMasterSlideHeaderFooterManager:
        ...

    @property
    def title_style(self) -> ITextStyle:
        ...

    @property
    def body_style(self) -> ITextStyle:
        ...

    @property
    def other_style(self) -> ITextStyle:
        ...

    @property
    def layout_slides(self) -> IMasterLayoutSlideCollection:
        ...

    @property
    def preserve(self) -> bool:
        ...

    @preserve.setter
    def preserve(self, value: bool):
        ...

    @property
    def has_depending_slides(self) -> bool:
        ...

    @property
    def theme_manager(self) -> aspose.slides.theme.IMasterThemeManager:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_base_slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_master_themeable(self) -> aspose.slides.theme.IMasterThemeable:
        ...

    ...

class MasterSlideCollection:
    '''Represents a collection of master slides.'''
    def remove(self, value: IMasterSlide) -> None:
        '''Removes the first occurrence of a specific object from the collection.
        :param value: The master slide to remove from the collection.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the element at the specified index of the collection.
        :param index: The zero-based index of the element to remove.'''
        ...

    def remove_unused(self, ignore_preserve_field: bool) -> None:
        '''Removes unused master slides.
        :param ignore_preserve_field: Determines, whether this method should remove unused master even if its :py:attr:`aspose.slides.MasterSlide.preserve` property is set to true.'''
        ...

    def add_clone(self, source_master: IMasterSlide) -> IMasterSlide:
        '''Adds a copy of a specified master slide to the end of the collection.
                    Linked layout slides will be copied too.
        :param source_master: Slide to clone.
        :returns: Added slide.'''
        ...

    def insert_clone(self, index: int, source_master: IMasterSlide) -> IMasterSlide:
        '''Inserts a copy of a specified master slide to specified position of the collection.
                    Linked layout slides will be copied too.
        :param index: Index of new slide.
        :param source_master: Slide to clone.
        :returns: Inserted master slide.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IMasterSlide
        '''Gets the element at the specified index.
                    Read-only :py:class:`aspose.slides.MasterSlide`.'''
        ...

    ...

class MasterSlideHeaderFooterManager(BaseSlideHeaderFooterManager):
    '''Represents manager which holds behavior of the master slide footer, date-time, page number placeholders and all child placeholders.
                Child placeholders mean placeholders are contained on depending layout slides and depending slides.
                Depending layout slides and slides use and depend on master slide.'''
    def set_footer_visibility(self, is_visible: bool) -> None:
        '''Changes slide footer placeholder visibility.
        :param is_visible: true - makes a footer placeholder visible, otherwise - hides it.'''
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        '''Changes slide page number placeholder visibility.
        :param is_visible: true - makes a page number placeholder visible, otherwise - hides it.'''
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        '''Changes slide date-time placeholder visibility.
        :param is_visible: true - makes a date-time placeholder visible, otherwise - hides it.'''
        ...

    def set_footer_text(self, text: string) -> None:
        '''Sets text to slide footer placeholder.
        :param text: Text to set.'''
        ...

    def set_date_time_text(self, text: string) -> None:
        '''Sets text to slide date-time placeholder.
        :param text: Text to set.'''
        ...

    def set_footer_and_child_footers_visibility(self, is_visible: bool) -> None:
        '''Changes master slide footer placeholder and all child footer placeholders visibility.
                    Child placeholders mean placeholders are contained on depending layout slides and depending slides.
                    Depending layout slides and slides use and depend on master slide.
        :param is_visible: true - makes a footer placeholders visible, otherwise - hides them.'''
        ...

    def set_slide_number_and_child_slide_numbers_visibility(self, is_visible: bool) -> None:
        '''Changes master slide page number placeholder and all child page number placeholders visibility.
                    Child placeholders mean placeholders are contained on depending layout slides and depending slides.
                    Depending layout slides and slides use and depend on master slide.
        :param is_visible: true - makes a page number placeholders visible, otherwise - hides them.'''
        ...

    def set_date_time_and_child_date_times_visibility(self, is_visible: bool) -> None:
        '''Changes master slide date-time placeholder and all child date-time placeholders visibility.
                    Child placeholders mean placeholders are contained on depending layout slides and depending slides.
                    Depending layout slides and slides use and depend on master slide.
        :param is_visible: true - makes a date-time placeholders visible, otherwise - hides them.'''
        ...

    def set_footer_and_child_footers_text(self, text: string) -> None:
        '''Sets text to master slide footer placeholder and all child footer placeholders.
                    Child placeholders mean placeholders are contained on depending layout slides and depending slides.
                    Depending layout slides and slides use and depend on master slide.
        :param text: Text to set.'''
        ...

    def set_date_time_and_child_date_times_text(self, text: string) -> None:
        '''Sets text to master slide date-time placeholder and all child date-time placeholders.
                    Child placeholders mean placeholders are contained on depending layout slides and depending slides.
                    Depending layout slides and slides use and depend on master slide.
        :param text: Text to set.'''
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class Metered:
    '''Provides methods to set metered key.'''
    def __init__(self):
        '''Initializes a new instance of this class.'''
        ...

    def set_metered_key(self, public_key: string, private_key: string) -> None:
        '''Sets metered public and private key
        :param public_key: public key
        :param private_key: private key'''
        ...

    @staticmethod
    def get_consumption_quantity() -> float:
        '''Gets consumption file size
        :returns: consumption quantity'''
        ...

    @staticmethod
    def get_consumption_credit() -> float:
        '''Gets consumption credit
        :returns: consumption quantity'''
        ...

    ...

class ModernComment(Comment):
    '''Represents a comment on a slide.'''
    def remove(self) -> None:
        '''Removes comment and all its replies from the parent collection.'''
        ...

    @property
    def text(self) -> string:
        ...

    @text.setter
    def text(self, value: string):
        ...

    @property
    def created_time(self) -> DateTime:
        ...

    @created_time.setter
    def created_time(self, value: DateTime):
        ...

    @property
    def slide(self) -> ISlide:
        ...

    @property
    def author(self) -> ICommentAuthor:
        ...

    @property
    def position(self) -> aspose.pydrawing.PointF:
        ...

    @position.setter
    def position(self, value: aspose.pydrawing.PointF):
        ...

    @property
    def parent_comment(self) -> IComment:
        ...

    @parent_comment.setter
    def parent_comment(self, value: IComment):
        ...

    @property
    def shape(self) -> IShape:
        ...

    @property
    def text_selection_start(self) -> int:
        ...

    @text_selection_start.setter
    def text_selection_start(self, value: int):
        ...

    @property
    def text_selection_length(self) -> int:
        ...

    @text_selection_length.setter
    def text_selection_length(self, value: int):
        ...

    @property
    def status(self) -> ModernCommentStatus:
        ...

    @status.setter
    def status(self, value: ModernCommentStatus):
        ...

    @property
    def as_i_comment(self) -> IComment:
        ...

    ...

class NormalViewProperties:
    '''Represents normal view properties. The normal view consists of
                three content regions: the slide itself, a side content region, and a bottom content region.'''
    @property
    def show_outline_icons(self) -> bool:
        ...

    @show_outline_icons.setter
    def show_outline_icons(self, value: bool):
        ...

    @property
    def snap_vertical_splitter(self) -> bool:
        ...

    @snap_vertical_splitter.setter
    def snap_vertical_splitter(self, value: bool):
        ...

    @property
    def vertical_bar_state(self) -> SplitterBarStateType:
        ...

    @vertical_bar_state.setter
    def vertical_bar_state(self, value: SplitterBarStateType):
        ...

    @property
    def horizontal_bar_state(self) -> SplitterBarStateType:
        ...

    @horizontal_bar_state.setter
    def horizontal_bar_state(self, value: SplitterBarStateType):
        ...

    @property
    def prefer_single_view(self) -> bool:
        ...

    @prefer_single_view.setter
    def prefer_single_view(self, value: bool):
        ...

    @property
    def restored_left(self) -> INormalViewRestoredProperties:
        ...

    @property
    def restored_top(self) -> INormalViewRestoredProperties:
        ...

    ...

class NormalViewRestoredProperties:
    '''Specifies the sizing of the slide region ((width when a child of restoredTop, height when a
                child of restoredLeft) of the normal view, when the region is of a variable restored size(neither minimized nor maximized).'''
    @property
    def dimension_size(self) -> float:
        ...

    @dimension_size.setter
    def dimension_size(self, value: float):
        ...

    @property
    def auto_adjust(self) -> bool:
        ...

    @auto_adjust.setter
    def auto_adjust(self, value: bool):
        ...

    ...

class NotesSize:
    '''Represents a size of notes slide.'''
    def __init__(self):
        ...

    @property
    def size(self) -> aspose.pydrawing.SizeF:
        ...

    @size.setter
    def size(self, value: aspose.pydrawing.SizeF):
        ...

    ...

class NotesSlide(BaseSlide):
    '''Represents a notes slide in a presentation.'''
    @overload
    def join_portions_with_same_formatting(self) -> None:
        '''Joins runs with same formatting in all paragraphs all acceptable shapes.'''
        ...

    @overload
    def join_portions_with_same_formatting(self, collection: IShapeCollection) -> None:
        '''Joins runs with same formatting in all paragraphs in all acceptable shapes.'''
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        '''Determines whether the two IBaseSlide instances are equal.
                    Returning value is calculated based on slide's structure and static content.
                    Two slides are equal if all shapes, styles, texts, animation and other settings. etc. are equal. The comparison doesn't take into account unique identifier values, e.g. SlideId and dynamic content, e.g. current date value in Date Placeholder.
        :param slide: The IBaseSlide to compare with the current IBaseSlide.
        :returns: **true** if the specified IBaseSlide is equal to the current IBaseSlide; 
                    otherwise, **false**.'''
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        '''Returns an effective theme for this slide.'''
        ...

    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        '''Finds first occurrence of a shape with the specified alternative text.
        :param alt_text: Alternative text.
        :returns: Shape object or null.'''
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def header_footer_manager(self) -> INotesSlideHeaderFooterManager:
        ...

    @property
    def notes_text_frame(self) -> ITextFrame:
        ...

    @property
    def theme_manager(self) -> aspose.slides.theme.IOverrideThemeManager:
        ...

    @property
    def parent_slide(self) -> ISlide:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_base_slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_override_themeable(self) -> aspose.slides.theme.IOverrideThemeable:
        ...

    ...

class NotesSlideHeaderFooterManager(BaseHandoutNotesSlideHeaderFooterManager):
    '''Represents manager which holds behavior of the notes slide placeholders, including header placeholder.'''
    def set_footer_visibility(self, is_visible: bool) -> None:
        '''Changes slide footer placeholder visibility.
        :param is_visible: true - makes a footer placeholder visible, otherwise - hides it.'''
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        '''Changes slide page number placeholder visibility.
        :param is_visible: true - makes a page number placeholder visible, otherwise - hides it.'''
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        '''Changes slide date-time placeholder visibility.
        :param is_visible: true - makes a date-time placeholder visible, otherwise - hides it.'''
        ...

    def set_footer_text(self, text: string) -> None:
        '''Sets text to slide footer placeholder.
        :param text: Text to set.'''
        ...

    def set_date_time_text(self, text: string) -> None:
        '''Sets text to slide date-time placeholder.
        :param text: Text to set.'''
        ...

    def set_header_visibility(self, is_visible: bool) -> None:
        '''Changes slide header placeholder visibility.
        :param is_visible: true - makes a header placeholder visible, otherwise - hides it.'''
        ...

    def set_header_text(self, text: string) -> None:
        '''Sets text to slide header placeholder.
        :param text: Text to set.'''
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def is_header_visible(self) -> bool:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    @property
    def as_i_base_handout_notes_slide_header_footer_manag(self) -> IBaseHandoutNotesSlideHeaderFooterManag:
        ...

    ...

class NotesSlideManager:
    '''Notes slide manager.'''
    def add_notes_slide(self) -> INotesSlide:
        '''Returns the notes slide for the current slide, creating one if there isn't.
        :returns: :py:attr:`aspose.slides.NotesSlideManager.notes_slide` for this slide.'''
        ...

    def remove_notes_slide(self) -> None:
        '''Removes notes slide of the current slide.'''
        ...

    @property
    def notes_slide(self) -> INotesSlide:
        ...

    ...

class OOXMLCorruptFileException(OOXMLException):
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class OOXMLException:
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class OdpException:
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class OdpReadException(OdpException):
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class OleObjectFrame(GraphicalObject):
    '''Represents an OLE object on a slide.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    def set_embedded_data(self, embedded_data: IOleEmbeddedDataInfo) -> None:
        '''Sets information about OLE embedded data.
        :param embedded_data: Embedded data :py:class:`aspose.slides.IOleEmbeddedDataInfo`'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def substitute_picture_format(self) -> IPictureFillFormat:
        ...

    @property
    def substitute_picture_title(self) -> string:
        ...

    @substitute_picture_title.setter
    def substitute_picture_title(self, value: string):
        ...

    @property
    def object_name(self) -> string:
        ...

    @object_name.setter
    def object_name(self, value: string):
        ...

    @property
    def object_prog_id(self) -> string:
        ...

    @object_prog_id.setter
    def object_prog_id(self, value: string):
        ...

    @property
    def link_file_name(self) -> string:
        ...

    @property
    def link_path_long(self) -> string:
        ...

    @link_path_long.setter
    def link_path_long(self, value: string):
        ...

    @property
    def link_path_relative(self) -> string:
        ...

    @property
    def embedded_file_label(self) -> string:
        ...

    @property
    def embedded_file_name(self) -> string:
        ...

    @property
    def embedded_data(self) -> IOleEmbeddedDataInfo:
        ...

    @property
    def is_object_icon(self) -> bool:
        ...

    @is_object_icon.setter
    def is_object_icon(self, value: bool):
        ...

    @property
    def is_object_link(self) -> bool:
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def update_automatic(self) -> bool:
        ...

    @update_automatic.setter
    def update_automatic(self, value: bool):
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    ...

class PPImage:
    '''Represents an image in a presentation.'''
    @overload
    def replace_image(self, new_image_data: bytes) -> None:
        '''Replaces image data.'''
        ...

    @overload
    def replace_image(self, new_image: aspose.pydrawing.Image) -> None:
        '''Replaces image data. Attention: when Image is metafile - it will be rasterized due to restrictions of GDI+. Use ReplaceImage(byte[]) instead'''
        ...

    @overload
    def replace_image(self, new_image: IImage) -> None:
        '''Replaces image data. Attention: when Image is metafile - it will be rasterized. Use ReplaceImage(byte[]) instead'''
        ...

    @overload
    def replace_image(self, new_image: IPPImage) -> None:
        '''Replaces image data.'''
        ...

    @property
    def binary_data(self) -> bytes:
        ...

    @property
    def system_image(self) -> aspose.pydrawing.Image:
        ...

    @property
    def image(self) -> IImage:
        ...

    @property
    def svg_image(self) -> ISvgImage:
        ...

    @svg_image.setter
    def svg_image(self, value: ISvgImage):
        ...

    @property
    def content_type(self) -> string:
        ...

    @property
    def width(self) -> int:
        ...

    @property
    def height(self) -> int:
        ...

    @property
    def x(self) -> int:
        ...

    @property
    def y(self) -> int:
        ...

    ...

class PVIObject:
    '''Encapsulates basic service infrastructure for objects can be a subject of property value inheritance.'''
    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class Paragraph:
    '''Represents a paragraph of text.'''
    def __init__(self):
        '''Initializes a new instance of the Paragraph class with default properties.'''
        ...

    def __init__(self, para: Paragraph):
        '''Copy constructor that initializes a new instance of a Paragraph class.'''
        ...

    def join_portions_with_same_formatting(self) -> None:
        '''Joins runs with same formatting.'''
        ...

    def get_rect(self) -> aspose.pydrawing.RectangleF:
        '''Get coordinates of rect that bounds paragraph. The rect includes all the lines of
                    text in paragraph, including empty ones.'''
        ...

    def get_lines_count(self) -> int:
        '''Get number of lines in a paragraph.
        :returns: Lines count in a paragraph'''
        ...

    @property
    def portions(self) -> IPortionCollection:
        ...

    @property
    def paragraph_format(self) -> IParagraphFormat:
        ...

    @property
    def text(self) -> string:
        ...

    @text.setter
    def text(self, value: string):
        ...

    @property
    def end_paragraph_portion_format(self) -> IPortionFormat:
        ...

    @end_paragraph_portion_format.setter
    def end_paragraph_portion_format(self, value: IPortionFormat):
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class ParagraphCollection:
    '''Represents a collection of a paragraphs.'''
    @overload
    def add(self, value: IParagraph) -> None:
        '''Adds a Paragraph to the end of collection.
        :param value: The Paragraph to be added to the end of the collection.'''
        ...

    @overload
    def add(self, value: IParagraphCollection) -> int:
        '''Adds a content of ParagraphCollection to the end of collection.
        :param value: The ParagraphCollection to be added to the end of the collection.
        :returns: The index at which the Paragraph has been added or -1 if there are nothing to add.'''
        ...

    @overload
    def insert(self, index: int, value: IParagraph) -> None:
        '''Inserts a Paragraph into the collection at the specified index.
        :param index: The zero-based index at which Paragraph should be inserted.
        :param value: The Paragraph to insert.'''
        ...

    @overload
    def insert(self, index: int, value: IParagraphCollection) -> None:
        '''Inserts a content of ParagraphCollection into the collection at the specified index.
        :param index: The zero-based index at which paragraphs should be inserted.
        :param value: The paragraphs to insert.'''
        ...

    @overload
    def add_from_html(self, text: string) -> None:
        '''Adds text from specified html string to the collection.
        :param text: HTML text.'''
        ...

    @overload
    def add_from_html(self, text: string, resolver: aspose.slides.importing.IExternalResourceResolver, uri: string) -> None:
        '''Adds text from specified html string to the collection.
        :param text: HTML text.
        :param resolver: Resolver callback object which resolves URIs and fetches referrenced objects.
        :param uri: URI for adding HTML document. Used for resolving relative links.'''
        ...

    def index_of(self, item: IParagraph) -> int:
        '''Determines the index of a specific item in the :py:class:`System.Collections.Generic.IList`1`.
        :param item: The object to locate in the :py:class:`System.Collections.Generic.IList`1`.
        :returns: The index of ``item`` if found in the list; otherwise, -1.'''
        ...

    def clear(self) -> None:
        '''Removes all elements from the collection.'''
        ...

    def contains(self, item: IParagraph) -> bool:
        '''Determines whether the :py:class:`System.Collections.Generic.ICollection`1` contains a specific value.
        :param item: The object to locate in the :py:class:`System.Collections.Generic.ICollection`1`.
        :returns: true if ``item`` is found in the :py:class:`System.Collections.Generic.ICollection`1`; otherwise, false.'''
        ...

    def copy_to(self, array: List[IParagraph], array_index: int) -> None:
        '''Copies the elements of the :py:class:`System.Collections.Generic.ICollection`1` to an :py:class:`System.Array`, starting at a particular :py:class:`System.Array` index.
        :param array: The one-dimensional :py:class:`System.Array` that is the destination of the elements copied from :py:class:`System.Collections.Generic.ICollection`1`. The :py:class:`System.Array` must have zero-based indexing.
        :param array_index: The zero-based index in ``array`` at which copying begins.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the element at the specified index of the collection.
        :param index: The zero-based index of the element to remove.'''
        ...

    def remove(self, item: IParagraph) -> bool:
        '''Removes the first occurrence of a specific object from the :py:class:`System.Collections.Generic.ICollection`1`.
        :param item: The object to remove from the :py:class:`System.Collections.Generic.ICollection`1`.
        :returns: true if ``item`` was successfully removed from the :py:class:`System.Collections.Generic.ICollection`1`; otherwise, false. This method also returns false if ``item`` is not found in the original :py:class:`System.Collections.Generic.ICollection`1`.'''
        ...

    def export_to_html(self, first_paragraph_index: int, paragraphs_count: int, options: aspose.slides.export.ITextToHtmlConversionOptions) -> string:
        '''Converts specifying paragraphs to the HTML and returns it as String object.
        :param first_paragraph_index: First paragraph index :py:class:`int`
        :param paragraphs_count: Paragraph count :py:class:`int`
        :param options: Convert options :py:class:`aspose.slides.export.ITextToHtmlConversionOptions`
        :returns: Generated HTML.'''
        ...

    @property
    def count(self) -> int:
        ...

    @property
    def is_read_only(self) -> bool:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    def __getitem__(self, key: int) -> IParagraph
        '''Gets the element at the specified index.'''
        ...

    ...

class ParagraphFactory:
    '''Allows to create paragraphs'''
    def __init__(self):
        ...

    @overload
    def create_paragraph(self) -> IParagraph:
        '''Creates a new empty paragraph.
        :returns: Paragraph.'''
        ...

    @overload
    def create_paragraph(self, paragraph: IParagraph) -> IParagraph:
        '''Creates a new paragraph with specified paragraph data using.
        :param paragraph: A paragraph to use data.
        :returns: Paragraph.'''
        ...

    ...

class ParagraphFormat(PVIObject):
    '''This class contains the paragraph formatting properties. Unlike :py:class:`aspose.slides.IParagraphFormatEffectiveData`, all properties of this class are writeable.'''
    def __init__(self):
        '''Initializes a new instance of :py:class:`aspose.slides.ParagraphFormat` class.'''
        ...

    def get_effective(self) -> IParagraphFormatEffectiveData:
        '''Gets effective paragraph formatting data with the inheritance applied.
        :returns: A :py:class:`aspose.slides.IParagraphFormatEffectiveData`.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def alignment(self) -> TextAlignment:
        ...

    @alignment.setter
    def alignment(self, value: TextAlignment):
        ...

    @property
    def space_within(self) -> float:
        ...

    @space_within.setter
    def space_within(self, value: float):
        ...

    @property
    def space_before(self) -> float:
        ...

    @space_before.setter
    def space_before(self, value: float):
        ...

    @property
    def space_after(self) -> float:
        ...

    @space_after.setter
    def space_after(self, value: float):
        ...

    @property
    def east_asian_line_break(self) -> NullableBool:
        ...

    @east_asian_line_break.setter
    def east_asian_line_break(self, value: NullableBool):
        ...

    @property
    def right_to_left(self) -> NullableBool:
        ...

    @right_to_left.setter
    def right_to_left(self, value: NullableBool):
        ...

    @property
    def latin_line_break(self) -> NullableBool:
        ...

    @latin_line_break.setter
    def latin_line_break(self, value: NullableBool):
        ...

    @property
    def hanging_punctuation(self) -> NullableBool:
        ...

    @hanging_punctuation.setter
    def hanging_punctuation(self, value: NullableBool):
        ...

    @property
    def margin_left(self) -> float:
        ...

    @margin_left.setter
    def margin_left(self, value: float):
        ...

    @property
    def margin_right(self) -> float:
        ...

    @margin_right.setter
    def margin_right(self, value: float):
        ...

    @property
    def indent(self) -> float:
        ...

    @indent.setter
    def indent(self, value: float):
        ...

    @property
    def default_tab_size(self) -> float:
        ...

    @default_tab_size.setter
    def default_tab_size(self, value: float):
        ...

    @property
    def tabs(self) -> ITabCollection:
        ...

    @property
    def font_alignment(self) -> FontAlignment:
        ...

    @font_alignment.setter
    def font_alignment(self, value: FontAlignment):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def bullet(self) -> IBulletFormat:
        ...

    @property
    def depth(self) -> int:
        ...

    @depth.setter
    def depth(self, value: int):
        ...

    @property
    def default_portion_format(self) -> IPortionFormat:
        ...

    ...

class PathSegment:
    '''Represents segment of graphics path of GeometryShape'''
    @property
    def segment_data(self) -> List[float]:
        ...

    @property
    def path_command(self) -> PathCommandType:
        ...

    ...

class PatternFormat(PVIObject):
    '''Represents a pattern to fill a shape.'''
    @overload
    def get_tile_image(self, background: aspose.pydrawing.Color, foreground: aspose.pydrawing.Color) -> aspose.pydrawing.Bitmap:
        '''Creates a tile image for the pattern fill with a specified colors.
        :param background: The background :py:class:`aspose.pydrawing.Color` for the pattern.
        :param foreground: The foreground :py:class:`aspose.pydrawing.Color` for the pattern.
        :returns: Tile :py:class:`aspose.pydrawing.Bitmap`.'''
        ...

    @overload
    def get_tile_image(self, style_color: aspose.pydrawing.Color) -> aspose.pydrawing.Bitmap:
        '''Creates a tile image for the pattern fill.
        :param style_color: The default :py:class:`aspose.pydrawing.Color`, 
                    defined in ShapeEx's StyleEx object. Fill's colors can depend on this.
        :returns: Tile :py:class:`aspose.pydrawing.Bitmap`.'''
        ...

    @overload
    def get_tile(self, background: aspose.pydrawing.Color, foreground: aspose.pydrawing.Color) -> IImage:
        '''Creates a tile image for the pattern fill with a specified colors.
        :param background: The background :py:class:`aspose.pydrawing.Color` for the pattern.
        :param foreground: The foreground :py:class:`aspose.pydrawing.Color` for the pattern.
        :returns: Tile :py:class:`aspose.slides.IImage`.'''
        ...

    @overload
    def get_tile(self, style_color: aspose.pydrawing.Color) -> IImage:
        '''Creates a tile image for the pattern fill.
        :param style_color: The default :py:class:`aspose.pydrawing.Color`
        :returns: Tile :py:class:`aspose.slides.IImage`.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def pattern_style(self) -> PatternStyle:
        ...

    @pattern_style.setter
    def pattern_style(self, value: PatternStyle):
        ...

    @property
    def fore_color(self) -> IColorFormat:
        ...

    @property
    def back_color(self) -> IColorFormat:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class Picture:
    '''Represents a picture in a presentation.'''
    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def image(self) -> IPPImage:
        ...

    @image.setter
    def image(self, value: IPPImage):
        ...

    @property
    def link_path_long(self) -> string:
        ...

    @link_path_long.setter
    def link_path_long(self, value: string):
        ...

    @property
    def image_transform(self) -> aspose.slides.effects.IImageTransformOperationCollection:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    ...

class PictureFillFormat(PVIObject):
    '''Represents a picture fill style.'''
    def delete_picture_cropped_areas(self) -> IPPImage:
        '''Delete cropped areas of the fill Picture.
        :returns: Cropped image or origin image if cropping is not necessary.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def dpi(self) -> int:
        ...

    @dpi.setter
    def dpi(self, value: int):
        ...

    @property
    def picture_fill_mode(self) -> PictureFillMode:
        ...

    @picture_fill_mode.setter
    def picture_fill_mode(self, value: PictureFillMode):
        ...

    @property
    def picture(self) -> ISlidesPicture:
        ...

    @property
    def crop_left(self) -> float:
        ...

    @crop_left.setter
    def crop_left(self, value: float):
        ...

    @property
    def crop_top(self) -> float:
        ...

    @crop_top.setter
    def crop_top(self, value: float):
        ...

    @property
    def crop_right(self) -> float:
        ...

    @crop_right.setter
    def crop_right(self, value: float):
        ...

    @property
    def crop_bottom(self) -> float:
        ...

    @crop_bottom.setter
    def crop_bottom(self, value: float):
        ...

    @property
    def stretch_offset_left(self) -> float:
        ...

    @stretch_offset_left.setter
    def stretch_offset_left(self, value: float):
        ...

    @property
    def stretch_offset_top(self) -> float:
        ...

    @stretch_offset_top.setter
    def stretch_offset_top(self, value: float):
        ...

    @property
    def stretch_offset_right(self) -> float:
        ...

    @stretch_offset_right.setter
    def stretch_offset_right(self, value: float):
        ...

    @property
    def stretch_offset_bottom(self) -> float:
        ...

    @stretch_offset_bottom.setter
    def stretch_offset_bottom(self, value: float):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_fill_param_source(self) -> IFillParamSource:
        ...

    ...

class PictureFrame(GeometryShape):
    '''Represents a frame with a picture inside.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    def get_geometry_paths(self) -> List[IGeometryPath]:
        '''Returns the copy of path of the geometry shape. Coordinates are relative to the left top corner of the shape.
        :returns: Array of :py:class:`aspose.slides.IGeometryPath`'''
        ...

    def set_geometry_path(self, geometry_path: IGeometryPath) -> None:
        '''Updates shape geometry from :py:class:`aspose.slides.IGeometryPath` object. Coordinates must be relative to the left
                     top corner of the shape.
                     Changes the type of the shape (:py:attr:`aspose.slides.GeometryShape.shape_type`) to :py:attr:`aspose.slides.ShapeType.CUSTOM`.
        :param geometry_path: Geometry path'''
        ...

    def set_geometry_paths(self, geometry_paths: List[IGeometryPath]) -> None:
        '''Updates shape geometry from array of :py:class:`aspose.slides.IGeometryPath`. Coordinates must be relative to the left
                     top corner of the shape.
                     Changes the type of the shape (:py:attr:`aspose.slides.GeometryShape.shape_type`) to :py:attr:`aspose.slides.ShapeType.CUSTOM`.
        :param geometry_paths: Array geometry paths'''
        ...

    def create_shape_elements(self) -> List[IShapeElement]:
        '''Creates and returns array of shape's elements.
        :returns: Array of :py:class:`aspose.slides.ShapeElement`'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IPictureFrameLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def shape_style(self) -> IShapeStyle:
        ...

    @property
    def shape_type(self) -> ShapeType:
        ...

    @shape_type.setter
    def shape_type(self, value: ShapeType):
        ...

    @property
    def adjustments(self) -> IAdjustValueCollection:
        ...

    @property
    def picture_frame_lock(self) -> IPictureFrameLock:
        ...

    @property
    def picture_format(self) -> IPictureFillFormat:
        ...

    @property
    def relative_scale_height(self) -> float:
        ...

    @relative_scale_height.setter
    def relative_scale_height(self, value: float):
        ...

    @property
    def relative_scale_width(self) -> float:
        ...

    @relative_scale_width.setter
    def relative_scale_width(self, value: float):
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def as_i_geometry_shape(self) -> IGeometryShape:
        ...

    ...

class PictureFrameLock(BaseShapeLock):
    '''Determines which operations are disabled on the parent PictureFrame.'''
    @property
    def no_locks(self) -> bool:
        ...

    @property
    def grouping_locked(self) -> bool:
        ...

    @grouping_locked.setter
    def grouping_locked(self, value: bool):
        ...

    @property
    def select_locked(self) -> bool:
        ...

    @select_locked.setter
    def select_locked(self, value: bool):
        ...

    @property
    def rotation_locked(self) -> bool:
        ...

    @rotation_locked.setter
    def rotation_locked(self, value: bool):
        ...

    @property
    def aspect_ratio_locked(self) -> bool:
        ...

    @aspect_ratio_locked.setter
    def aspect_ratio_locked(self, value: bool):
        ...

    @property
    def position_locked(self) -> bool:
        ...

    @position_locked.setter
    def position_locked(self, value: bool):
        ...

    @property
    def size_locked(self) -> bool:
        ...

    @size_locked.setter
    def size_locked(self, value: bool):
        ...

    @property
    def edit_points_locked(self) -> bool:
        ...

    @edit_points_locked.setter
    def edit_points_locked(self, value: bool):
        ...

    @property
    def adjust_handles_locked(self) -> bool:
        ...

    @adjust_handles_locked.setter
    def adjust_handles_locked(self, value: bool):
        ...

    @property
    def arrowheads_locked(self) -> bool:
        ...

    @arrowheads_locked.setter
    def arrowheads_locked(self, value: bool):
        ...

    @property
    def shape_type_locked(self) -> bool:
        ...

    @shape_type_locked.setter
    def shape_type_locked(self, value: bool):
        ...

    @property
    def crop_locked(self) -> bool:
        ...

    @crop_locked.setter
    def crop_locked(self, value: bool):
        ...

    @property
    def as_i_base_shape_lock(self) -> IBaseShapeLock:
        ...

    ...

class Placeholder:
    '''Represents a placeholder on a slide.'''
    @property
    def orientation(self) -> Orientation:
        ...

    @property
    def size(self) -> PlaceholderSize:
        ...

    @property
    def type(self) -> PlaceholderType:
        ...

    @property
    def index(self) -> int:
        ...

    ...

class Portion:
    '''Represents a portion of text inside a text paragraph.'''
    def __init__(self):
        '''Initializes a new instance of the Portion class.'''
        ...

    def __init__(self, str: string):
        '''Initializes a new instance of the Portion class.'''
        ...

    def __init__(self, portion: Portion):
        '''Initializes a new instance of the Portion class.'''
        ...

    @overload
    def add_field(self, field_type: IFieldType) -> None:
        '''Converts this portion to the automaticaly updated field.'''
        ...

    @overload
    def add_field(self, internal_string: string) -> None:
        '''Converts this portion to the automaticaly updated field.
        :param internal_string: Internal name of FieldType.'''
        ...

    def remove_field(self) -> None:
        '''Converts this field portion to the simple portion.'''
        ...

    def get_rect(self) -> aspose.pydrawing.RectangleF:
        '''Get coordinates of rect that bounds portion. The rect includes all the lines of
                     text in portion, including empty ones.'''
        ...

    def get_coordinates(self) -> aspose.pydrawing.PointF:
        '''Get coordinates of the beginning of the portion. The X coordinate of point represents the 
                    portion beginning from the first character including left side bearing. The Y coordinate 
                    includes top side bearing.'''
        ...

    @property
    def portion_format(self) -> IPortionFormat:
        ...

    @property
    def text(self) -> string:
        ...

    @text.setter
    def text(self, value: string):
        ...

    @property
    def field(self) -> IField:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class PortionCollection:
    '''Represents a collection of portions.'''
    def add(self, value: IPortion) -> None:
        '''Adds a Portion to the end of collection.
        :param value: The Portion to be added to the end of the collection.'''
        ...

    def index_of(self, item: IPortion) -> int:
        '''Determines the index of a specific item in the :py:class:`System.Collections.Generic.IList`1`.
        :param item: The object to locate in the :py:class:`System.Collections.Generic.IList`1`.
        :returns: The index of ``item`` if found in the list; otherwise, -1.'''
        ...

    def insert(self, index: int, value: IPortion) -> None:
        '''Inserts a Portion into the collection at the specified index.
        :param index: The zero-based index at which Portion should be inserted.
        :param value: The Portion to insert.'''
        ...

    def clear(self) -> None:
        '''Removes all elements from the collection.'''
        ...

    def contains(self, item: IPortion) -> bool:
        '''Determines whether the :py:class:`System.Collections.Generic.ICollection`1` contains a specific value.
        :param item: The object to locate in the :py:class:`System.Collections.Generic.ICollection`1`.
        :returns: true if ``item`` is found in the :py:class:`System.Collections.Generic.ICollection`1`; otherwise, false.'''
        ...

    def copy_to(self, array: List[IPortion], array_index: int) -> None:
        '''Copies the elements of the :py:class:`System.Collections.Generic.ICollection`1` to an :py:class:`System.Array`, starting at a particular :py:class:`System.Array` index.
        :param array: The one-dimensional :py:class:`System.Array` that is the destination of the elements copied from :py:class:`System.Collections.Generic.ICollection`1`. The :py:class:`System.Array` must have zero-based indexing.
        :param array_index: The zero-based index in ``array`` at which copying begins.'''
        ...

    def remove(self, item: IPortion) -> bool:
        '''Removes the first occurrence of a specific object from the :py:class:`System.Collections.Generic.ICollection`1`.
        :param item: The object to remove from the :py:class:`System.Collections.Generic.ICollection`1`.
        :returns: true if ``item`` was successfully removed from the :py:class:`System.Collections.Generic.ICollection`1`; otherwise, false. This method also returns false if ``item`` is not found in the original :py:class:`System.Collections.Generic.ICollection`1`.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the element at the specified index of the collection.
        :param index: The zero-based index of the element to remove.'''
        ...

    @property
    def count(self) -> int:
        ...

    @property
    def is_read_only(self) -> bool:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IPortion
        '''Gets the element at the specified index.'''
        ...

    def __setitem__(self, key: int, value: IPortion
        ...

    ...

class PortionFactory:
    '''Allows to create test portions'''
    def __init__(self):
        ...

    @overload
    def create_portion(self) -> IPortion:
        '''Creates an empty text portion.
        :returns: Portion.'''
        ...

    @overload
    def create_portion(self, str: string) -> IPortion:
        '''Creates a text portion from specified string.
        :param str: String.
        :returns: Portion.'''
        ...

    @overload
    def create_portion(self, portion: IPortion) -> IPortion:
        '''Creates a portion with the using of a specified portion data.
        :param portion: A portion to use.
        :returns: Portion.'''
        ...

    ...

class PortionFormat(BasePortionFormat):
    '''This class contains the text portion formatting properties. Unlike :py:class:`aspose.slides.IPortionFormatEffectiveData`, all properties of this class are writeable.'''
    def __init__(self):
        '''Initializes a new instance of :py:class:`aspose.slides.PortionFormat` class.'''
        ...

    def get_effective(self) -> IPortionFormatEffectiveData:
        '''Gets effective portion formatting data with the inheritance applied.
        :returns: A :py:class:`aspose.slides.IPortionFormatEffectiveData`.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def highlight_color(self) -> IColorFormat:
        ...

    @property
    def underline_line_format(self) -> ILineFormat:
        ...

    @property
    def underline_fill_format(self) -> IFillFormat:
        ...

    @property
    def font_bold(self) -> NullableBool:
        ...

    @font_bold.setter
    def font_bold(self, value: NullableBool):
        ...

    @property
    def font_italic(self) -> NullableBool:
        ...

    @font_italic.setter
    def font_italic(self, value: NullableBool):
        ...

    @property
    def kumimoji(self) -> NullableBool:
        ...

    @kumimoji.setter
    def kumimoji(self, value: NullableBool):
        ...

    @property
    def normalise_height(self) -> NullableBool:
        ...

    @normalise_height.setter
    def normalise_height(self, value: NullableBool):
        ...

    @property
    def proof_disabled(self) -> NullableBool:
        ...

    @proof_disabled.setter
    def proof_disabled(self, value: NullableBool):
        ...

    @property
    def font_underline(self) -> TextUnderlineType:
        ...

    @font_underline.setter
    def font_underline(self, value: TextUnderlineType):
        ...

    @property
    def text_cap_type(self) -> TextCapType:
        ...

    @text_cap_type.setter
    def text_cap_type(self, value: TextCapType):
        ...

    @property
    def strikethrough_type(self) -> TextStrikethroughType:
        ...

    @strikethrough_type.setter
    def strikethrough_type(self, value: TextStrikethroughType):
        ...

    @property
    def is_hard_underline_line(self) -> NullableBool:
        ...

    @is_hard_underline_line.setter
    def is_hard_underline_line(self, value: NullableBool):
        ...

    @property
    def is_hard_underline_fill(self) -> NullableBool:
        ...

    @is_hard_underline_fill.setter
    def is_hard_underline_fill(self, value: NullableBool):
        ...

    @property
    def font_height(self) -> float:
        ...

    @font_height.setter
    def font_height(self, value: float):
        ...

    @property
    def latin_font(self) -> IFontData:
        ...

    @latin_font.setter
    def latin_font(self, value: IFontData):
        ...

    @property
    def east_asian_font(self) -> IFontData:
        ...

    @east_asian_font.setter
    def east_asian_font(self, value: IFontData):
        ...

    @property
    def complex_script_font(self) -> IFontData:
        ...

    @complex_script_font.setter
    def complex_script_font(self, value: IFontData):
        ...

    @property
    def symbol_font(self) -> IFontData:
        ...

    @symbol_font.setter
    def symbol_font(self, value: IFontData):
        ...

    @property
    def escapement(self) -> float:
        ...

    @escapement.setter
    def escapement(self, value: float):
        ...

    @property
    def kerning_minimal_size(self) -> float:
        ...

    @kerning_minimal_size.setter
    def kerning_minimal_size(self, value: float):
        ...

    @property
    def language_id(self) -> string:
        ...

    @language_id.setter
    def language_id(self, value: string):
        ...

    @property
    def alternative_language_id(self) -> string:
        ...

    @alternative_language_id.setter
    def alternative_language_id(self, value: string):
        ...

    @property
    def spacing(self) -> float:
        ...

    @spacing.setter
    def spacing(self, value: float):
        ...

    @property
    def bookmark_id(self) -> string:
        ...

    @bookmark_id.setter
    def bookmark_id(self, value: string):
        ...

    @property
    def smart_tag_clean(self) -> bool:
        ...

    @smart_tag_clean.setter
    def smart_tag_clean(self, value: bool):
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_base_portion_format(self) -> IBasePortionFormat:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    ...

class PptCorruptFileException(PptReadException):
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class PptEditException(PptException):
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class PptException:
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class PptReadException(PptException):
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class PptUnsupportedFormatException(PptReadException):
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class PptxEditException(PptxException):
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class PptxException(OOXMLException):
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class PptxReadException(PptxException):
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class PptxUnsupportedFormatException(PptxReadException):
    def __init__(self):
        ...

    def __init__(self, message: string):
        ...

    ...

class Presentation:
    '''Represents a Microsoft PowerPoint presentation.'''
    def __init__(self):
        '''This constructor creates new presentation from scratch.
                    Created presentation has one empty slide.'''
        ...

    def __init__(self, load_options: LoadOptions):
        '''This constructor creates new presentation from scratch.
                    Created presentation has one empty slide.
        :param load_options: Additional load options.'''
        ...

    def __init__(self, stream: System.IO.Stream):
        '''This constructor is the primary mechanism for reading an existing Presentation.
        :param stream: Input stream.'''
        ...

    def __init__(self, stream: System.IO.Stream, load_options: LoadOptions):
        '''This constructor is the primary mechanism for reading an existing Presentation.
        :param stream: Input stream.
        :param load_options: Additional load options.'''
        ...

    def __init__(self, file: string):
        '''This constructor gets a source file path from which
                     the contents of the Presentation are read.
        :param file: Input file.'''
        ...

    def __init__(self, file: string, load_options: LoadOptions):
        '''This constructor gets a source file path from which
                    the contents of the Presentation are read.
        :param file: Input file.
        :param load_options: Additional load options.'''
        ...

    @overload
    def save(self, fname: string, format: aspose.slides.export.SaveFormat) -> None:
        '''Saves all slides of a presentation to a file with the specified format.
        :param fname: Path to the created file.
        :param format: Format of the exported data.'''
        ...

    @overload
    def save(self, stream: System.IO.Stream, format: aspose.slides.export.SaveFormat) -> None:
        '''Saves all slides of a presentation to a stream in the specified format.
        :param stream: Output stream.
        :param format: Format of the exported data.'''
        ...

    @overload
    def save(self, fname: string, format: aspose.slides.export.SaveFormat, options: aspose.slides.export.ISaveOptions) -> None:
        ...

    @overload
    def save(self, stream: System.IO.Stream, format: aspose.slides.export.SaveFormat, options: aspose.slides.export.ISaveOptions) -> None:
        '''Saves all slides of a presentation to a stream in the specified format and with additional options.
        :param stream: Output stream.
        :param format: Format of the exported data.
        :param options: Additional format options.'''
        ...

    @overload
    def save(self, options: aspose.slides.export.xaml.IXamlOptions) -> None:
        '''Saves all slides of a presentation to a set of files representing XAML markup.
        :param options: The XAML format options.'''
        ...

    @overload
    def save(self, fname: string, slides: List[int], format: aspose.slides.export.SaveFormat) -> None:
        '''Saves specified slides of a presentation to a file with the specified format with page number keeping.
        :param fname: Path to the created file.
        :param slides: Array with slide positions, starting from 1.
        :param format: Format of the exported data.'''
        ...

    @overload
    def save(self, fname: string, slides: List[int], format: aspose.slides.export.SaveFormat, options: aspose.slides.export.ISaveOptions) -> None:
        '''Saves specified slides of a presentation to a file with the specified format with page number keeping.
        :param fname: Path to the created file.
        :param slides: Array with slide positions, starting from 1.
        :param format: Format of the exported data.
        :param options: Additional format options.'''
        ...

    @overload
    def save(self, stream: System.IO.Stream, slides: List[int], format: aspose.slides.export.SaveFormat) -> None:
        '''Saves specified slides of a presentation to a stream in the specified format with page number keeping.
        :param stream: Output stream.
        :param slides: Array with slide positions, starting from 1.
        :param format: Format of the exported data.'''
        ...

    @overload
    def save(self, stream: System.IO.Stream, slides: List[int], format: aspose.slides.export.SaveFormat, options: aspose.slides.export.ISaveOptions) -> None:
        '''Saves specified slides of a presentation to a stream in the specified format with page number keeping.
        :param stream: Output stream.
        :param slides: Array with slide positions, starting from 1.
        :param format: Format of the exported data.
        :param options: Additional format options.'''
        ...

    @overload
    def get_thumbnails(self, options: aspose.slides.export.IRenderingOptions) -> List[aspose.pydrawing.Bitmap]:
        '''Returns a Thumbnail Bitmap objects for all slides of a presentation.
        :param options: Tiff options.
        :returns: Bitmap objects.'''
        ...

    @overload
    def get_thumbnails(self, options: aspose.slides.export.IRenderingOptions, slides: List[int]) -> List[aspose.pydrawing.Bitmap]:
        '''Returns a Thumbnail Bitmap objects for specified slides of a presentation.
        :param options: Tiff options.
        :param slides: Array with slide positions, starting from 1.
        :returns: Bitmap objects.'''
        ...

    @overload
    def get_thumbnails(self, options: aspose.slides.export.IRenderingOptions, scale_x: float, scale_y: float) -> List[aspose.pydrawing.Bitmap]:
        '''Returns a Thumbnail Bitmap objects for all slides of a presentation with custom scaling.
        :param options: Tiff options.
        :param scale_x: The value by which to scale this Thumbnail in the x-axis direction.
        :param scale_y: The value by which to scale this Thumbnail in the y-axis direction.
        :returns: Bitmap objects.'''
        ...

    @overload
    def get_thumbnails(self, options: aspose.slides.export.IRenderingOptions, slides: List[int], scale_x: float, scale_y: float) -> List[aspose.pydrawing.Bitmap]:
        '''Returns a Thumbnail Bitmap objects for specified slides of a presentation with custom scaling.
        :param options: Tiff options.
        :param slides: Array with slide positions, starting from 1.
        :param scale_x: The value by which to scale this Thumbnail in the x-axis direction.
        :param scale_y: The value by which to scale this Thumbnail in the y-axis direction.
        :returns: Bitmap objects.'''
        ...

    @overload
    def get_thumbnails(self, options: aspose.slides.export.IRenderingOptions, image_size: aspose.pydrawing.Size) -> List[aspose.pydrawing.Bitmap]:
        '''Returns a Thumbnail Bitmap objects for all slides of a presentation with specified size.
        :param options: Tiff options.
        :param image_size: Size of the image to create.
        :returns: Bitmap objects.'''
        ...

    @overload
    def get_thumbnails(self, options: aspose.slides.export.IRenderingOptions, slides: List[int], image_size: aspose.pydrawing.Size) -> List[aspose.pydrawing.Bitmap]:
        '''Returns a Thumbnail Bitmap objects for specified slides of a presentation with specified size.
        :param options: Tiff options.
        :param slides: Array with slide positions, starting from 1.
        :param image_size: Size of the image to create.
        :returns: Bitmap objects.'''
        ...

    @overload
    def get_images(self, options: aspose.slides.export.IRenderingOptions) -> List[IImage]:
        '''Returns a Image objects for all slides of a presentation.
        :param options: Tiff options.
        :returns: Image objects.'''
        ...

    @overload
    def get_images(self, options: aspose.slides.export.IRenderingOptions, slides: List[int]) -> List[IImage]:
        '''Returns a Thumbnail Image objects for specified slides of a presentation.
        :param options: Tiff options.
        :param slides: Array with slide positions, starting from 1.
        :returns: Image objects.'''
        ...

    @overload
    def get_images(self, options: aspose.slides.export.IRenderingOptions, scale_x: float, scale_y: float) -> List[IImage]:
        '''Returns a Thumbnail Image objects for all slides of a presentation with custom scaling.
        :param options: Tiff options.
        :param scale_x: The value by which to scale this Thumbnail in the x-axis direction.
        :param scale_y: The value by which to scale this Thumbnail in the y-axis direction.
        :returns: Image objects.'''
        ...

    @overload
    def get_images(self, options: aspose.slides.export.IRenderingOptions, slides: List[int], scale_x: float, scale_y: float) -> List[IImage]:
        '''Returns a Thumbnail Image objects for specified slides of a presentation with custom scaling.
        :param options: Tiff options.
        :param slides: Array with slide positions, starting from 1.
        :param scale_x: The value by which to scale this Thumbnail in the x-axis direction.
        :param scale_y: The value by which to scale this Thumbnail in the y-axis direction.
        :returns: Image objects.'''
        ...

    @overload
    def get_images(self, options: aspose.slides.export.IRenderingOptions, image_size: aspose.pydrawing.Size) -> List[IImage]:
        '''Returns a Thumbnail Image objects for all slides of a presentation with specified size.
        :param options: Tiff options.
        :param image_size: Size of the image to create.
        :returns: Image objects.'''
        ...

    @overload
    def get_images(self, options: aspose.slides.export.IRenderingOptions, slides: List[int], image_size: aspose.pydrawing.Size) -> List[IImage]:
        '''Returns a Thumbnail Image objects for specified slides of a presentation with specified size.
        :param options: Tiff options.
        :param slides: Array with slide positions, starting from 1.
        :param image_size: Size of the image to create.
        :returns: Image objects.'''
        ...

    @overload
    def print(self) -> None:
        '''Prints the whole presentation to the default printer.'''
        ...

    @overload
    def print(self, printer_settings: aspose.pydrawing.Printing.PrinterSettings) -> None:
        '''Prints the presentation according to the specified printer settings,
                    using the standard (no User Interface) print controller.
        :param printer_settings: The .NET printer settings to use.'''
        ...

    @overload
    def print(self, printer_name: string) -> None:
        '''Print the whole presentation to the specified printer,
                    using the standard (no User Interface) print controller.
        :param printer_name: The name of the printer.'''
        ...

    @overload
    def print(self, printer_settings: aspose.pydrawing.Printing.PrinterSettings, pres_name: string) -> None:
        '''Prints the document according to the specified printer settings, using
                    the standard (no User Interface) print controller and a presentation name.
        :param printer_settings: The .NET printer settings to use.
        :param pres_name: The presentation name to display (for example, in a print
                    status dialog box or printer queue) while printing the presentation.'''
        ...

    def get_slide_by_id(self, id: int) -> IBaseSlide:
        '''Returns a Slide, MasterSlide or LayoutSlide by Id.
        :param id: Id of a slide.
        :returns: IBaseSlide object.'''
        ...

    def join_portions_with_same_formatting(self) -> None:
        '''Joins runs with same formatting in all paragraphs in all acceptable shapes in all slides.'''
        ...

    @property
    def current_date_time(self) -> DateTime:
        ...

    @current_date_time.setter
    def current_date_time(self, value: DateTime):
        ...

    @property
    def header_footer_manager(self) -> IPresentationHeaderFooterManager:
        ...

    @property
    def protection_manager(self) -> IProtectionManager:
        ...

    @property
    def slides(self) -> ISlideCollection:
        ...

    @property
    def sections(self) -> ISectionCollection:
        ...

    @property
    def slide_size(self) -> ISlideSize:
        ...

    @property
    def notes_size(self) -> INotesSize:
        ...

    @property
    def layout_slides(self) -> IGlobalLayoutSlideCollection:
        ...

    @property
    def masters(self) -> IMasterSlideCollection:
        ...

    @property
    def master_notes_slide_manager(self) -> IMasterNotesSlideManager:
        ...

    @property
    def master_handout_slide_manager(self) -> IMasterHandoutSlideManager:
        ...

    @property
    def fonts_manager(self) -> IFontsManager:
        ...

    @property
    def default_text_style(self) -> ITextStyle:
        ...

    @property
    def comment_authors(self) -> ICommentAuthorCollection:
        ...

    @property
    def document_properties(self) -> IDocumentProperties:
        ...

    @property
    def images(self) -> IImageCollection:
        ...

    @property
    def audios(self) -> IAudioCollection:
        ...

    @property
    def videos(self) -> IVideoCollection:
        ...

    @property
    def slide_show_settings(self) -> SlideShowSettings:
        ...

    @property
    def digital_signatures(self) -> IDigitalSignatureCollection:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def all_custom_xml_parts(self) -> List[ICustomXmlPart]:
        ...

    @property
    def vba_project(self) -> aspose.slides.vba.IVbaProject:
        ...

    @vba_project.setter
    def vba_project(self, value: aspose.slides.vba.IVbaProject):
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def view_properties(self) -> IViewProperties:
        ...

    @property
    def first_slide_number(self) -> int:
        ...

    @first_slide_number.setter
    def first_slide_number(self, value: int):
        ...

    @property
    def source_format(self) -> SourceFormat:
        ...

    @property
    def master_theme(self) -> aspose.slides.theme.IMasterTheme:
        ...

    @property
    def as_i_disposable(self) -> IDisposable:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class PresentationFactory:
    '''Allows to create presentation via COM interface'''
    def __init__(self):
        ...

    @overload
    def create_presentation(self) -> IPresentation:
        '''Creates new presentation.
        :returns: New presentation'''
        ...

    @overload
    def create_presentation(self, options: ILoadOptions) -> IPresentation:
        '''Creates new presentation with additional load options
        :param options: Load options
        :returns: New presentation'''
        ...

    @overload
    def get_presentation_info(self, file: string) -> IPresentationInfo:
        '''Creates new PresentationInfo object from file and binds presentation to it.
        :param file: Presentation file.
        :returns: Presentation info binded to presentation.'''
        ...

    @overload
    def get_presentation_info(self, stream: System.IO.Stream) -> IPresentationInfo:
        '''Creates new PresentationInfo object from stream and binds presentation to it.
                    Gets info about presentation in specified stream.
        :param stream: Presentation stream.
        :returns: Presentation info binded to presentation.'''
        ...

    @overload
    def read_presentation(self, data: bytes) -> IPresentation:
        '''Reads an existing presentation from array
        :param data: Array to read
        :returns: Read presentation'''
        ...

    @overload
    def read_presentation(self, data: bytes, options: ILoadOptions) -> IPresentation:
        '''Reads an existing presentation from array with additional load options
        :param data: Array to read
        :param options: Load options
        :returns: Read presentation'''
        ...

    @overload
    def read_presentation(self, stream: System.IO.Stream) -> IPresentation:
        '''Reads an existing presentation from stream
        :param stream: Input stream to read
        :returns: Read presentation'''
        ...

    @overload
    def read_presentation(self, stream: System.IO.Stream, options: ILoadOptions) -> IPresentation:
        '''Reads an existing presentation from stream with additional load options
        :param stream: Input stream to read
        :param options: Load options
        :returns: Read presentation'''
        ...

    @overload
    def read_presentation(self, file: string) -> IPresentation:
        '''Reads an existing presentation from file
        :param file: File name
        :returns: Read presentation'''
        ...

    @overload
    def read_presentation(self, file: string, options: ILoadOptions) -> IPresentation:
        '''Reads an existing presentation from stream with additional load options
        :param file: File name
        :param options: Load options
        :returns: Read presentation'''
        ...

    @overload
    def get_presentation_text(self, file: string, mode: TextExtractionArrangingMode) -> IPresentationText:
        '''Retrieves the raw text from the slides
        :param file: Input file
        :param mode: Extraction mode
        :returns: The instance of PresentationText containing the SlideText array representing the raw slides text'''
        ...

    @overload
    def get_presentation_text(self, stream: System.IO.Stream, mode: TextExtractionArrangingMode) -> IPresentationText:
        '''Retrieves the raw text from the slides
        :param stream: Input stream
        :param mode: Extraction mode
        :returns: The instance of PresentationText containing the SlideText array representing the raw slides text'''
        ...

    @overload
    def get_presentation_text(self, stream: System.IO.Stream, mode: TextExtractionArrangingMode, options: ILoadOptions) -> IPresentationText:
        '''Retrieves the raw text from the slides
        :param stream: Input stream
        :param mode: Extraction mode
        :param options: Load options
        :returns: The instance of PresentationText containing the SlideText array representing the raw slides text'''
        ...

    @classmethod
    @property
    def instance(cls) -> PresentationFactory:
        ...

    ...

class PresentationHeaderFooterManager(BaseHeaderFooterManager):
    '''Represents manager which holds behavior of all footer, date-time and page number placeholders of presentation.'''
    def set_all_headers_visibility(self, is_visible: bool) -> None:
        '''Changes all header placeholders visibility, including notes master, notes slides and handout master.
        :param is_visible: true - makes a header placeholders visible, otherwise - hides them.'''
        ...

    def set_all_footers_visibility(self, is_visible: bool) -> None:
        '''Changes all footer placeholders visibility, including master slides, layout slides, slides, 
                    notes master, notes slides and handout master.
        :param is_visible: true - makes a footer placeholders visible, otherwise - hides them.'''
        ...

    def set_all_slide_numbers_visibility(self, is_visible: bool) -> None:
        '''Changes all page number placeholders visibility, including master slides, layout slides, slides, 
                    notes master, notes slides and handout master.
        :param is_visible: true - makes a page number placeholders visible, otherwise - hides them.'''
        ...

    def set_all_date_times_visibility(self, is_visible: bool) -> None:
        '''Changes all date-time placeholders visibility, including master slides, layout slides, slides, 
                    notes master, notes slides and handout master.
        :param is_visible: true - makes a date-time placeholders visible, otherwise - hides them.'''
        ...

    def set_all_headers_text(self, text: string) -> None:
        '''Sets text to all header placeholders, including notes master, notes slides and handout master.
        :param text: Text to set.'''
        ...

    def set_all_footers_text(self, text: string) -> None:
        '''Sets text to all footer placeholders, including master slides, layout slides, slides, 
                    notes master, notes slides and handout master.
        :param text: Text to set.'''
        ...

    def set_all_date_times_text(self, text: string) -> None:
        '''Sets text to all date-time placeholders, including master slides, layout slides, slides, 
                    notes master, notes slides and handout master.
        :param text: Text to set.'''
        ...

    def set_visibility_on_all_title_slides(self, is_visible: bool) -> None:
        '''Changes the footer, date-time and page number placeholders visibility for all title slides and for first layout slide.
                    Title slides – slides based on first layout slide (regardless of type of this first layout).
        :param is_visible: true - makes a placeholders visible, otherwise - hides them.'''
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class PresentationInfo:
    '''Information about presentation file'''
    @overload
    def write_binded_presentation(self, stream: System.IO.Stream) -> None:
        '''Writes binded presentation to stream.
        :param stream: The stream must be seekable and writable.'''
        ...

    @overload
    def write_binded_presentation(self, file: string) -> None:
        '''Writes binded presentation to file.
        :param file: Presentation file.'''
        ...

    def check_password(self, password: string) -> bool:
        '''Checks whether a password is correct for a presentation protected with open password.
        :param password: The password to check.
        :returns: True if the presentation is protected with open password and the password is correct and false otherwise.'''
        ...

    def check_write_protection(self, password: string) -> bool:
        '''Checks whether a password to modify is correct for a write protected presentation.
        :param password: The password to check.
        :returns: True if the presentation is write protected and the password is correct. False otherwise.'''
        ...

    def read_document_properties(self) -> IDocumentProperties:
        '''Gets document properties of binded presentation.'''
        ...

    def update_document_properties(self, document_properties: IDocumentProperties) -> None:
        '''Updates properties of binded presentation.'''
        ...

    @property
    def is_encrypted(self) -> bool:
        ...

    @property
    def is_password_protected(self) -> bool:
        ...

    @property
    def is_write_protected(self) -> NullableBool:
        ...

    @property
    def load_format(self) -> LoadFormat:
        ...

    ...

class PresentationText:
    '''Represents the text extracted from the presentation'''
    @property
    def slides_text(self) -> List[ISlideText]:
        ...

    ...

class PresentedBySpeaker(SlideShowType):
    '''Presented by a speaker (full screen)'''
    def __init__(self):
        '''Initializes a new instance of the PresentedBySpeaker class.'''
        ...

    ...

class ProtectionManager:
    '''Presentation password protection management.'''
    def encrypt(self, encryption_password: string) -> None:
        '''Encrypts Presentation with specified password.
        :param encryption_password: The password.'''
        ...

    def remove_encryption(self) -> None:
        '''Removes the encryption.'''
        ...

    def set_write_protection(self, password: string) -> None:
        '''Set write protection for this presentation with specified password.
        :param password: The password.'''
        ...

    def remove_write_protection(self) -> None:
        '''Removes write protection for this presentation.'''
        ...

    def check_write_protection(self, password: string) -> bool:
        '''Determines whether a presentation is a password protected to modify.
        :param password: The password for checking.
        :returns: True if the password is valid; otherwise, false.'''
        ...

    @property
    def encrypt_document_properties(self) -> bool:
        ...

    @encrypt_document_properties.setter
    def encrypt_document_properties(self, value: bool):
        ...

    @property
    def is_encrypted(self) -> bool:
        ...

    @property
    def is_only_document_properties_loaded(self) -> bool:
        ...

    @property
    def is_write_protected(self) -> bool:
        ...

    @property
    def encryption_password(self) -> string:
        ...

    @property
    def read_only_recommended(self) -> bool:
        ...

    @read_only_recommended.setter
    def read_only_recommended(self, value: bool):
        ...

    ...

class Row(CellCollection):
    '''Represents a row in a table.'''
    @overload
    def set_text_format(self, source: IPortionFormat) -> None:
        '''Sets defined portion format properties to all row cells' portions.
        :param source: IPortionFormat object with necessary properties set.'''
        ...

    @overload
    def set_text_format(self, source: IParagraphFormat) -> None:
        '''Sets defined paragraph format properties to all row cells' paragraphs.
        :param source: IParagraphFormat object with necessary properties set.'''
        ...

    @overload
    def set_text_format(self, source: ITextFrameFormat) -> None:
        '''Sets defined text frame format properties to all row cells' text frames.
        :param source: ITextFrameFormat object with necessary properties set.'''
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def height(self) -> float:
        ...

    @property
    def minimal_height(self) -> float:
        ...

    @minimal_height.setter
    def minimal_height(self, value: float):
        ...

    @property
    def row_format(self) -> IRowFormat:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    @property
    def as_i_cell_collection(self) -> ICellCollection:
        ...

    @property
    def as_i_bulk_text_formattable(self) -> IBulkTextFormattable:
        ...

    def __getitem__(self, key: int) -> ICell
        ...

    ...

class RowCollection:
    '''Represents table row collection.'''
    def add_clone(self, templ: IRow, with_attached_rows: bool) -> List[IRow]:
        '''Creates a copy of the specified template row and inserts it at the bottom of a table.
        :param templ: Row which is used as a template.
        :param with_attached_rows: True to copy also all rows attached to the template row.
        :returns: Added rows.'''
        ...

    def insert_clone(self, index: int, templ: IRow, with_attached_rows: bool) -> List[IRow]:
        '''Creates a copy of the specified template row and insert it at the specified position in a table.
        :param index: Index of a new row.
        :param templ: Row which is used as a template.
        :param with_attached_rows: True to copy also all rows attached to the template row.
        :returns: Inserted rows.'''
        ...

    def remove_at(self, first_row_index: int, with_attached_rows: bool) -> None:
        '''Removes a row at the specified position from a table.
        :param first_row_index: Index of a row to delete.
        :param with_attached_rows: True to delete also all attached rows.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IRow
        '''Returns the row at the specified index.
                    Read-only :py:class:`aspose.slides.Row`.'''
        ...

    ...

class RowFormat:
    '''Represents format of a table row.'''
    def get_effective(self) -> IRowFormatEffectiveData:
        '''Gets effective table row formatting properties with inheritance and table styles applied.
        :returns: A :py:class:`aspose.slides.IRowFormatEffectiveData`.'''
        ...

    ...

class Section:
    '''Represents section of slides.'''
    def get_slides_list_of_section(self) -> ISectionSlideCollection:
        '''Returns list of slides in the section.
        :returns: List of slides.'''
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def section_id(self) -> Guid:
        ...

    @property
    def started_from_slide(self) -> ISlide:
        ...

    ...

class SectionCollection:
    '''Represents a collection of sections.'''
    def add_section(self, name: string, started_from_slide: ISlide) -> ISection:
        '''Add slides section started form specific slide.
        :param name: Name of the section
        :param started_from_slide: First slide of section
        :returns: Added section.'''
        ...

    def append_empty_section(self, name: string) -> ISection:
        '''Add empty section to the end of the collection.
        :param name: Name of the section
        :returns: Added section.'''
        ...

    def add_empty_section(self, name: string, index: int) -> ISection:
        '''Add empty section to specified position of the collection.
        :param name: Name of the section
        :param index: Index of new section.
        :returns: Added section.'''
        ...

    def index_of(self, section: ISection) -> int:
        '''Returns an index of the specified section in the collection.
        :param section: Section to find.
        :returns: Index of a section or -1 if section not from this collection.'''
        ...

    def remove_section_with_slides(self, section: ISection) -> None:
        '''Remove section and slides contained in the section.
        :param section: The section to remove from the collection.'''
        ...

    def remove_section(self, section: ISection) -> None:
        '''Remove section. Slides contained in the section will be merged into previous section.
        :param section: The section to remove from the collection.'''
        ...

    def reorder_section_with_slides(self, section: ISection, index: int) -> None:
        '''Moves section and its slides from the collection to the specified position.
        :param index: Target index.
        :param section: Section to move.'''
        ...

    def clear(self) -> None:
        '''Removes all sections from the collection.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ISection
        '''Gets the element at the specified index.
                    Read-only :py:class:`aspose.slides.ISection`.'''
        ...

    ...

class SectionSlideCollection:
    '''Represents a collection of slides in the section.'''
    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ISlide
        '''Gets the element at the specified index.
                    Read-only :py:class:`aspose.slides.ISlide`.'''
        ...

    ...

class SectionZoomFrame(ZoomObject):
    '''Represents a Section Zoom object in a slide.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def image_type(self) -> ZoomImageType:
        ...

    @image_type.setter
    def image_type(self, value: ZoomImageType):
        ...

    @property
    def return_to_parent(self) -> bool:
        ...

    @return_to_parent.setter
    def return_to_parent(self, value: bool):
        ...

    @property
    def show_background(self) -> bool:
        ...

    @show_background.setter
    def show_background(self, value: bool):
        ...

    @property
    def zoom_image(self) -> IPPImage:
        ...

    @zoom_image.setter
    def zoom_image(self, value: IPPImage):
        ...

    @property
    def transition_duration(self) -> float:
        ...

    @transition_duration.setter
    def transition_duration(self, value: float):
        ...

    @property
    def target_section(self) -> ISection:
        ...

    @target_section.setter
    def target_section(self, value: ISection):
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def as_i_zoom_object(self) -> IZoomObject:
        ...

    ...

class Shape:
    '''Represents a shape on a slide.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IBaseShapeLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    ...

class ShapeBevel(PVIObject):
    '''Contains the properties of shape's main face relief.'''
    def __init__(self, b_is_top_bevel: bool):
        '''Creates new instance.
        :param b_is_top_bevel: Is top bevel.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def bevel_type(self) -> BevelPresetType:
        ...

    @bevel_type.setter
    def bevel_type(self, value: BevelPresetType):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class ShapeCollection:
    '''Represents a collection of a shapes.'''
    @overload
    def add_chart(self, type: aspose.slides.charts.ChartType, x: float, y: float, width: float, height: float) -> aspose.slides.charts.IChart:
        '''Creates a new Chart, initialize it with sample series data and settings and adds 
                    it to the end of the collection.
        :param type: Type of chart.
        :param x: X coordinate of a new chart.
        :param y: Y coordinate of a new chart.
        :param width: Chart's width.
        :param height: Chart's height.
        :returns: Created chart.'''
        ...

    @overload
    def add_chart(self, type: aspose.slides.charts.ChartType, x: float, y: float, width: float, height: float, init_with_sample: bool) -> aspose.slides.charts.IChart:
        '''Creates a new Chart and adds it to the end of the collection.
        :param type: Type of chart.
        :param x: X coordinate of a new chart.
        :param y: Y coordinate of a new chart.
        :param width: Chart's width.
        :param height: Chart's height.
        :param init_with_sample: If true then new chart will be initialized with sample series data and settings.
                    If false then new chart will have no series and minimum settings. In this case 
                    chart creation will be more fast.
        :returns: Created chart.'''
        ...

    @overload
    def insert_chart(self, type: aspose.slides.charts.ChartType, x: float, y: float, width: float, height: float, index: int) -> aspose.slides.charts.IChart:
        '''Creates a new Chart, initialize it with sample series data and settings and inserts 
                    it to the specified position in the collection.
        :param type: Type of chart.
        :param x: X coordinate of a new chart.
        :param y: Y coordinate of a new chart.
        :param width: Chart's width.
        :param height: Chart's height.
        :param index: Chart's position in the collection.
        :returns: Created chart.'''
        ...

    @overload
    def insert_chart(self, type: aspose.slides.charts.ChartType, x: float, y: float, width: float, height: float, index: int, init_with_sample: bool) -> aspose.slides.charts.IChart:
        '''Creates a new Chart and inserts it to the specified position in the collection.
        :param type: Type of chart.
        :param x: X coordinate of a new chart.
        :param y: Y coordinate of a new chart.
        :param width: Chart's width.
        :param height: Chart's height.
        :param index: Chart's position in the collection.
        :param init_with_sample: If true then new chart will be initialized with sample series data and settings.
                    If false then new chart will have no series and minimum settings. In this case 
                    chart creation will be more fast.
        :returns: Created chart.'''
        ...

    @overload
    def add_zoom_frame(self, x: float, y: float, width: float, height: float, slide: ISlide) -> IZoomFrame:
        '''Adds a new Zoom object to the end of a collection.
        :param x: X coordinate of a new Zoom frame :py:class:`float`.
        :param y: Y coordinate of a new Zoom frame :py:class:`float`.
        :param width: Width of a new Zoom frame :py:class:`float`.
        :param height: Height of a new Zoom frame :py:class:`float`.
        :param slide: The slide object referenced by the Zoom frame :py:class:`aspose.slides.ISlide`.
        :returns: Created Zoom object :py:class:`aspose.slides.IZoomFrame`.'''
        ...

    @overload
    def add_zoom_frame(self, x: float, y: float, width: float, height: float, slide: ISlide, image: IPPImage) -> IZoomFrame:
        '''Adds a new Zoom object to the end of a collection.
        :param x: X coordinate of a new Zoom frame :py:class:`float`.
        :param y: Y coordinate of a new Zoom frame :py:class:`float`.
        :param width: Width of a new Zoom frame :py:class:`float`.
        :param height: Height of a new Zoom frame :py:class:`float`.
        :param slide: The slide object referenced by the Zoom frame :py:class:`aspose.slides.ISlide`.
        :param image: The image for the referenced slide :py:class:`aspose.slides.IPPImage`
        :returns: Created Zoom object :py:class:`aspose.slides.IZoomFrame`.'''
        ...

    @overload
    def insert_zoom_frame(self, index: int, x: float, y: float, width: float, height: float, slide: ISlide) -> IZoomFrame:
        '''Creates a new Zoom object and inserts it to a collection at the specified index.
        :param index: The zero-based index at which Zoom frame should be inserted.
        :param x: X coordinate of a new Zoom frame :py:class:`float`.
        :param y: Y coordinate of a new Zoom frame :py:class:`float`.
        :param width: Width of a new Zoom frame :py:class:`float`.
        :param height: Height of a new Zoom frame :py:class:`float`.
        :param slide: The slide object referenced by the Zoom frame :py:class:`aspose.slides.ISlide`.
        :returns: Created Zoom object :py:class:`aspose.slides.IZoomFrame`.'''
        ...

    @overload
    def insert_zoom_frame(self, index: int, x: float, y: float, width: float, height: float, slide: ISlide, image: IPPImage) -> IZoomFrame:
        '''Creates a new Zoom object and inserts it to a collection at the specified index.
        :param index: The zero-based index at which Zoom frame should be inserted.
        :param x: X coordinate of a new Zoom frame :py:class:`float`.
        :param y: Y coordinate of a new Zoom frame :py:class:`float`.
        :param width: Width of a new Zoom frame :py:class:`float`.
        :param height: Height of a new Zoom frame :py:class:`float`.
        :param slide: The slide object referenced by the Zoom frame :py:class:`aspose.slides.ISlide`.
        :param image: The image for the referenced slide :py:class:`aspose.slides.IPPImage`
        :returns: Created Zoom object :py:class:`aspose.slides.IZoomFrame`.'''
        ...

    @overload
    def add_section_zoom_frame(self, x: float, y: float, width: float, height: float, section: ISection) -> ISectionZoomFrame:
        '''Adds a new Section Zoom object to the end of a collection.
        :param x: X coordinate of a new Section Zoom frame :py:class:`float`.
        :param y: Y coordinate of a new Section Zoom frame :py:class:`float`.
        :param width: Width of a new Section Zoom frame :py:class:`float`.
        :param height: Height of a new Section Zoom frame :py:class:`float`.
        :param section: The section object referenced by the Section Zoom frame :py:class:`aspose.slides.ISection`.
        :returns: Created Section Zoom object :py:class:`aspose.slides.ISectionZoomFrame`.'''
        ...

    @overload
    def add_section_zoom_frame(self, x: float, y: float, width: float, height: float, section: ISection, image: IPPImage) -> ISectionZoomFrame:
        '''Adds a new Section Zoom object to the end of a collection with a predefined image.
        :param x: X coordinate of a new Section Zoom frame :py:class:`float`.
        :param y: Y coordinate of a new Section Zoom frame :py:class:`float`.
        :param width: Width of a new Section Zoom frame :py:class:`float`.
        :param height: Height of a new Section Zoom frame :py:class:`float`.
        :param section: The section object referenced by the Section Zoom frame :py:class:`aspose.slides.ISection`.
        :param image: The image for the referenced slide :py:class:`aspose.slides.IPPImage`
        :returns: Created Section Zoom object :py:class:`aspose.slides.ISectionZoomFrame`.'''
        ...

    @overload
    def insert_section_zoom_frame(self, index: int, x: float, y: float, width: float, height: float, section: ISection) -> ISectionZoomFrame:
        '''Creates a new Section Zoom object and inserts into to a collection at the specified index.
        :param index: The zero-based index at which Section Zoom frame should be inserted.
        :param x: X coordinate of a new Section Zoom frame :py:class:`float`.
        :param y: Y coordinate of a new Section Zoom frame :py:class:`float`.
        :param width: Width of a new Section Zoom frame :py:class:`float`.
        :param height: Height of a new Section Zoom frame :py:class:`float`.
        :param section: The slide object referenced by the Section Zoom frame :py:class:`aspose.slides.ISection`.
        :returns: Created Section Zoom object :py:class:`aspose.slides.ISectionZoomFrame`.'''
        ...

    @overload
    def insert_section_zoom_frame(self, index: int, x: float, y: float, width: float, height: float, section: ISection, image: IPPImage) -> ISectionZoomFrame:
        '''Creates a new Section Zoom object and inserts it to a collection at the specified index.
        :param index: The zero-based index at which Section Zoom frame should be inserted.
        :param x: X coordinate of a new Section Zoom frame :py:class:`float`.
        :param y: Y coordinate of a new Section Zoom frame :py:class:`float`.
        :param width: Width of a new Section Zoom frame :py:class:`float`.
        :param height: Height of a new Section Zoom frame :py:class:`float`.
        :param section: The slide object referenced by the Section Zoom frame :py:class:`aspose.slides.ISection`.
        :param image: The image for the referenced slide :py:class:`aspose.slides.IPPImage`
        :returns: Created Section Zoom object :py:class:`aspose.slides.ISectionZoomFrame`.'''
        ...

    @overload
    def add_ole_object_frame(self, x: float, y: float, width: float, height: float, data_info: IOleEmbeddedDataInfo) -> IOleObjectFrame:
        '''Adds a new OLE object to the end of a collection.
        :param x: X coordinate of a new OLE frame.
        :param y: Y coordinate of a new OLE frame.
        :param width: Width of a new OLE frame.
        :param height: Height of a new OLE frame.
        :param data_info: Embedded data info :py:class:`aspose.slides.IOleEmbeddedDataInfo`.
        :returns: Created OLE object.'''
        ...

    @overload
    def add_ole_object_frame(self, x: float, y: float, width: float, height: float, class_name: string, path: string) -> IOleObjectFrame:
        '''Adds a new OLE object to the end of a collection.
        :param x: X coordinate of a new OLE frame.
        :param y: Y coordinate of a new OLE frame.
        :param width: Width of a new OLE frame.
        :param height: Height of a new OLE frame.
        :param class_name: Name of an OLE class.
        :param path: Path to the linked file.
        The path is stored in the presentation as is. If a relative path is specified 
                    the corresponding file will be inaccessible when opening the presentation from a different directory.
        :returns: Created OLE object.'''
        ...

    @overload
    def insert_ole_object_frame(self, index: int, x: float, y: float, width: float, height: float, data_info: IOleEmbeddedDataInfo) -> IOleObjectFrame:
        '''Creates a new OLE object and inserts it to a collection at the specified index.
        :param index: The zero-based index at which OLE object should be inserted.
        :param x: X coordinate of a new OLE frame.
        :param y: Y coordinate of a new OLE frame.
        :param width: Width of a new OLE frame.
        :param height: Height of a new OLE frame.
        :param data_info: Embedded data info :py:class:`aspose.slides.IOleEmbeddedDataInfo`.
        :returns: Created OLE object.'''
        ...

    @overload
    def insert_ole_object_frame(self, index: int, x: float, y: float, width: float, height: float, class_name: string, path: string) -> IOleObjectFrame:
        '''Creates a new OLE object and inserts it to a collection at the specified index.
        :param index: The zero-based index at which OLE object should be inserted.
        :param x: X coordinate of a new OLE frame.
        :param y: Y coordinate of a new OLE frame.
        :param width: Width of a new OLE frame.
        :param height: Height of a new OLE frame.
        :param class_name: Name of an OLE class.
        :param path: Path to the linked file.
        :returns: Created OLE object.'''
        ...

    @overload
    def add_video_frame(self, x: float, y: float, width: float, height: float, fname: string) -> IVideoFrame:
        '''Adds a new video frame to the end of a collection.
        :param x: X coordinate of a new video frame.
        :param y: Y coordinate of a new video frame.
        :param width: Width of a new video frame.
        :param height: Height of a new video frame.
        :param fname: Video file name.
        :returns: Created VideoFrame object.'''
        ...

    @overload
    def add_video_frame(self, x: float, y: float, width: float, height: float, video: IVideo) -> IVideoFrame:
        '''Adds a new video frame to the end of a collection.
        :param x: X coordinate of a new video frame.
        :param y: Y coordinate of a new video frame.
        :param width: Width of a new video frame.
        :param height: Height of a new video frame.
        :param video: Video to add.
        :returns: Created VideoFrame object.'''
        ...

    @overload
    def add_audio_frame_embedded(self, x: float, y: float, width: float, height: float, audio_stream: System.IO.Stream) -> IAudioFrame:
        '''Adds a new audio frame with embedded audio file to the end of a collection.
                    Embedded audio file can be a WAV only.
                    It adds new audio into Presentation.Audios list.
        :param x: X coordinate of a new audio frame.
        :param y: Y coordinate of a new audio frame.
        :param width: Width of a new audio frame.
        :param height: Height of a new audio frame.
        :param audio_stream: Inout stream with audio data.
        :returns: Created AudioFrame object.'''
        ...

    @overload
    def add_audio_frame_embedded(self, x: float, y: float, width: float, height: float, audio: IAudio) -> IAudioFrame:
        '''Adds a new audio frame with embedded audio file to the end of a collection.
                    It uses audio file from Presentation.Audios list.
        :param x: X coordinate of a new audio frame.
        :param y: Y coordinate of a new audio frame.
        :param width: Width of a new audio frame.
        :param height: Height of a new audio frame.
        :param audio: Audio from Presentation.Audios list.
        :returns: Created AudioFrame object.'''
        ...

    @overload
    def insert_audio_frame_embedded(self, index: int, x: float, y: float, width: float, height: float, audio_stream: System.IO.Stream) -> IAudioFrame:
        '''Insert an AudioFrame with embedded audio file.
                    Embedded audio file sound can be a WAV only.
        :param index: The zero-based index at which value should be inserted.
        :param x: X coordinate of a new audio frame.
        :param y: Y coordinate of a new audio frame.
        :param width: Width of a new audio frame.
        :param height: Height of a new audio frame.
        :param audio_stream: Audio stream.
        :returns: Created AudioFrame object.'''
        ...

    @overload
    def insert_audio_frame_embedded(self, index: int, x: float, y: float, width: float, height: float, audio: IAudio) -> IAudioFrame:
        '''Insert an AudioFrame with embedded audio file.
                    It uses audio file from Presentation.Audios list.
        :param index: The zero-based index at which value should be inserted.
        :param x: X coordinate of a new audio frame.
        :param y: Y coordinate of a new audio frame.
        :param width: Width of a new audio frame.
        :param height: Height of a new audio frame.
        :param audio: Audio from Presentation.Audios list.
        :returns: Created AudioFrame object.'''
        ...

    @overload
    def to_array(self) -> List[IShape]:
        '''Creates and returns an array with all shapse in it.
        :returns: Array of :py:class:`aspose.slides.Shape`'''
        ...

    @overload
    def to_array(self, start_index: int, count: int) -> List[IShape]:
        '''Creates and returns an array with all shapes from the specified range in it.
        :returns: Array of :py:class:`aspose.slides.Shape`'''
        ...

    @overload
    def reorder(self, index: int, shape: IShape) -> None:
        '''Moves a shape from the collection to the specified position.
        :param index: Target index.
        :param shape: Shape to move.'''
        ...

    @overload
    def reorder(self, index: int, shapes: List[IShape]) -> None:
        '''Moves shapes from the collection to the specified position.
                    Shapes will be placed starting from index in order they appear in list.
        :param index: Target index.
        :param shapes: Shapes to move.'''
        ...

    @overload
    def add_auto_shape(self, shape_type: ShapeType, x: float, y: float, width: float, height: float) -> IAutoShape:
        '''Creates a new AutoShape, tunes it from default template and adds it to the end of the collection.
        :param shape_type: The :py:enum:`aspose.slides.ShapeType` of shape.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param width: The width of shape's frame.
        :param height: The height of shape's frame.
        :returns: Created AutoShape object.'''
        ...

    @overload
    def add_auto_shape(self, shape_type: ShapeType, x: float, y: float, width: float, height: float, create_from_template: bool) -> IAutoShape:
        '''Creates a new AutoShape and adds it to the end of the collection.
        :param shape_type: The :py:enum:`aspose.slides.ShapeType` of shape.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param width: The width of shape's frame.
        :param height: The height of shape's frame.
        :param create_from_template: If true then new shape will be tuned from default template. Not empty name, 
                    simple style, text centered will be assined to the new shape.
                    If false then all values of the properties of the new shape will have default values.
        :returns: Created AutoShape object.'''
        ...

    @overload
    def insert_auto_shape(self, index: int, shape_type: ShapeType, x: float, y: float, width: float, height: float) -> IAutoShape:
        '''Creates a new AutoShape, tunes it from default template and inserts it to 
                    the collection at the specified index.
                    Note: the type of the shape will be determined by the shapeType parameter.
        :param index: The zero-based index at which value should be inserted.
        :param shape_type: An :py:enum:`aspose.slides.ShapeType` of shape.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param width: The width of shape's frame.
        :param height: The height of shape's frame.
        :returns: Created AutoShape object.'''
        ...

    @overload
    def insert_auto_shape(self, index: int, shape_type: ShapeType, x: float, y: float, width: float, height: float, create_from_template: bool) -> IAutoShape:
        '''Creates a new AutoShape and inserts it to the collection at the specified index.
                    Note: the type of the shape will be determined by the shapeType parameter.
        :param index: The zero-based index at which value should be inserted.
        :param shape_type: An :py:enum:`aspose.slides.ShapeType` of shape.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param width: The width of shape's frame.
        :param height: The height of shape's frame.
        :param create_from_template: If true then new shape will be tuned from default template. Not empty name, 
                    simple style, text centered will be assined to the new shape.
                    If false then all values of the properties of the new shape will have default values.
        :returns: Created AutoShape object.'''
        ...

    @overload
    def add_group_shape(self) -> IGroupShape:
        '''Creates a new GroupShape and adds it to the end of the collection.
                    GroupShape frame size and position will be fitted to content when new shape will be added into the GroupShape.
        :returns: Created GroupShape object.'''
        ...

    @overload
    def add_group_shape(self, svg_image: ISvgImage, x: float, y: float, width: float, height: float) -> IGroupShape:
        '''Creates a new GroupShape, fills it with converted shapes from SVG and adds it to the end of the collection.
        :param svg_image: Svg image object :py:class:`aspose.slides.ISvgImage`
        :param x: The X coordinate for the left side of the shape group frame.
        :param y: The Y coordinate for the top side of the shape group frame.
        :param width: The width of the group of the shape group frame.
        :param height: The height of a group of the shape group frame.
        :returns: Created GroupShape object.'''
        ...

    @overload
    def add_connector(self, shape_type: ShapeType, x: float, y: float, width: float, height: float) -> IConnector:
        '''Creates a new Connector, tunes it from default template and adds it to the end of the collection.
        :param shape_type: The :py:enum:`aspose.slides.ShapeType` of shape.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param width: The width of shape's frame.
        :param height: The height of shape's frame.
        :returns: The zero-based index of the created shape.
        :returns: Created Connector object.'''
        ...

    @overload
    def add_connector(self, shape_type: ShapeType, x: float, y: float, width: float, height: float, create_from_template: bool) -> IConnector:
        '''Creates a new Connector and adds it to the end of the collection.
        :param shape_type: The :py:enum:`aspose.slides.ShapeType` of shape.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param width: The width of shape's frame.
        :param height: The height of shape's frame.
        :param create_from_template: If true then new shape will be tuned from default template. Not empty name, 
                    simple style, text centered will be assined to the new shape.
                    If false then all values of the properties of the new shape will have default values.
        :returns: The zero-based index of the created shape.
        :returns: Created Connector object.'''
        ...

    @overload
    def insert_connector(self, index: int, shape_type: ShapeType, x: float, y: float, width: float, height: float) -> IConnector:
        '''Creates a new Connector, tunes it from default template and inserts it to 
                    the collection at the specified index.
        :param index: The zero-based index at which value should be inserted.
        :param shape_type: An :py:enum:`aspose.slides.ShapeType` of shape.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param width: The width of shape's frame.
        :param height: The height of shape's frame.
        :returns: Created Connector object.'''
        ...

    @overload
    def insert_connector(self, index: int, shape_type: ShapeType, x: float, y: float, width: float, height: float, create_from_template: bool) -> IConnector:
        '''Creates a new Connector and inserts it to the collection at the specified index.
        :param index: The zero-based index at which value should be inserted.
        :param shape_type: An :py:enum:`aspose.slides.ShapeType` of shape.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param width: The width of shape's frame.
        :param height: The height of shape's frame.
        :param create_from_template: If true then new shape will be tuned from default template. Not empty name, 
                    simple style, text centered will be assined to the new shape.
                    If false then all values of the properties of the new shape will have default values.
        :returns: Created Connector object.'''
        ...

    @overload
    def add_clone(self, source_shape: IShape, x: float, y: float, width: float, height: float) -> IShape:
        '''Adds a copy of a specified shape to the end of the collection.
        :param source_shape: Shape to clone.
        :param x: X coordinate of a new shape.
        :param y: Y coordinate of a new shape.
        :param width: Width of a new shape.
        :param height: Height of a new shape.
        :returns: New shape.'''
        ...

    @overload
    def add_clone(self, source_shape: IShape, x: float, y: float) -> IShape:
        '''Adds a copy of a specified shape to the end of the collection.
                    Width and Height of the new shape are equal to Width and Height of the ``sourceShape``.
        :param source_shape: Shape to clone.
        :param x: X coordinate of a new shape.
        :param y: Y coordinate of a new shape.
        :returns: New shape.'''
        ...

    @overload
    def add_clone(self, source_shape: IShape) -> IShape:
        '''Adds a copy of a specified shape to the end of the collection.
                    X, Y, Width and Height of the new shape are equal to X, Y, Width and Height of the ``sourceShape``.
        :param source_shape: Shape to clone.
        :returns: New shape.'''
        ...

    @overload
    def insert_clone(self, index: int, source_shape: IShape, x: float, y: float, width: float, height: float) -> IShape:
        '''Inserts a copy of a specified shape to specified position of the collection.
        :param index: Index of new shape.
        :param source_shape: Shape to clone.
        :param x: X coordinate of a new shape.
        :param y: Y coordinate of a new shape.
        :param width: Width of a new shape.
        :param height: Height of a new shape.
        :returns: Inserted shape.'''
        ...

    @overload
    def insert_clone(self, index: int, source_shape: IShape, x: float, y: float) -> IShape:
        '''Inserts a copy of a specified shape to specified position of the collection.
                    Width and Height of the new shape are equal to Width and Height of the ``sourceShape``.
        :param index: Index of new shape.
        :param source_shape: Shape to clone.
        :param x: X coordinate of a new shape.
        :param y: Y coordinate of a new shape.
        :returns: Inserted shape.'''
        ...

    @overload
    def insert_clone(self, index: int, source_shape: IShape) -> IShape:
        '''Inserts a copy of a specified shape to specified position of the collection.
                    X, Y, Width and Height of the new shape are equal to X, Y, Width and Height of the ``sourceShape``.
        :param index: Index of new shape.
        :param source_shape: Shape to clone.
        :returns: Inserted shape.'''
        ...

    def add_smart_art(self, x: float, y: float, width: float, height: float, layout_type: aspose.slides.smartart.SmartArtLayoutType) -> aspose.slides.smartart.ISmartArt:
        '''Add SmartArt diagram.
        :param x: The X-coordinate for a left side of diagram's frame.
        :param y: The Y-coordinate for a left side of diagram's frame.
        :param width: The width of diagram's frame.
        :param height: The height of diagram's frame.
        :param layout_type: The type of SmartArt diagram
        :returns: Create SmartArt diagram'''
        ...

    def add_summary_zoom_frame(self, x: float, y: float, width: float, height: float) -> ISummaryZoomFrame:
        '''Adds a new Summary Zoom object to the end of a collection.
        :param x: X coordinate of a new Section Zoom frame :py:class:`float`.
        :param y: Y coordinate of a new Section Zoom frame :py:class:`float`.
        :param width: Width of a new Section Zoom frame :py:class:`float`.
        :param height: Height of a new Section Zoom frame :py:class:`float`.
        :returns: Created Summary Zoom object :py:class:`aspose.slides.ISummaryZoomFrame`.'''
        ...

    def insert_summary_zoom_frame(self, index: int, x: float, y: float, width: float, height: float) -> ISummaryZoomFrame:
        '''Creates a new Summary Zoom object and inserts it to a collection at the specified index.
        :param index: The zero-based index at which Section Zoom frame should be inserted.
        :param x: X coordinate of a new Section Zoom frame :py:class:`float`.
        :param y: Y coordinate of a new Section Zoom frame :py:class:`float`.
        :param width: Width of a new Section Zoom frame :py:class:`float`.
        :param height: Height of a new Section Zoom frame :py:class:`float`.
        :returns: Created Summary Zoom object :py:class:`aspose.slides.ISummaryZoomFrame`.'''
        ...

    def insert_video_frame(self, index: int, x: float, y: float, width: float, height: float, fname: string) -> IVideoFrame:
        '''Creates a new video frame and inserts it to a collection at the specified index.
        :param index: The zero-based index at which video frame should be inserted.
        :param x: X coordinate of a new video frame.
        :param y: Y coordinate of a new video frame.
        :param width: Width of a new video frame.
        :param height: Height of a new video frame.
        :param fname: Video file name.
        :returns: Created VideoFrame object.'''
        ...

    def add_audio_frame_cd(self, x: float, y: float, width: float, height: float) -> IAudioFrame:
        '''Adds an AudioFrame with CD to the end of collection.
        :param x: X coordinate of a new audio frame.
        :param y: Y coordinate of a new audio frame.
        :param width: Width of a new audio frame.
        :param height: Height of a new audio frame.
        :returns: Created AudioFrame object.'''
        ...

    def insert_audio_frame_cd(self, index: int, x: float, y: float, width: float, height: float) -> IAudioFrame:
        '''Insert an AudioFrame with CD.
        :param index: The zero-based index at which video frame should be inserted.
        :param x: X coordinate of a new audio frame.
        :param y: Y coordinate of a new audio frame.
        :param width: Width of a new audio frame.
        :param height: Height of a new audio frame.
        :returns: Created AudioFrame object.'''
        ...

    def add_audio_frame_linked(self, x: float, y: float, width: float, height: float, fname: string) -> IAudioFrame:
        '''Adds a new audio frame with linked audio file to the end of a collection.
        :param x: X coordinate of a new audio frame.
        :param y: Y coordinate of a new audio frame.
        :param width: Width of a new audio frame.
        :param height: Height of a new audio frame.
        :param fname: Audio file name.
        :returns: Created AudioFrame object.'''
        ...

    def insert_audio_frame_linked(self, index: int, x: float, y: float, width: float, height: float, fname: string) -> IAudioFrame:
        '''Creates a new audio frame with linked audio file and inserts it to a collection at the specified index.
        :param index: The zero-based index at which audio frame should be inserted.
        :param x: X coordinate of a new audio frame.
        :param y: Y coordinate of a new audio frame.
        :param width: Width of a new audio frame.
        :param height: Height of a new audio frame.
        :param fname: Audio file name.
        :returns: Created AudioFrame object.'''
        ...

    def index_of(self, shape: IShape) -> int:
        '''Returns the zero-based index of the first occurrence of a shape in the collection.
        :param shape: The shape to locate in the collection.
        :returns: The zero-based index of the first occurrence of shape within
                    the collection, if found; otherwise, -1.'''
        ...

    def add_math_shape(self, x: float, y: float, width: float, height: float) -> IAutoShape:
        '''Creates a new Autoshape tuned from default template to math content and adds it to the end of the collection.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param width: The width of shape's frame.
        :param height: The height of shape's frame.
        :returns: Created AutoShape object.'''
        ...

    def insert_group_shape(self, index: int) -> IGroupShape:
        '''Creates a new GroupShape and inserts it to the collection at the specified index.
                    GroupShape frame size and position will be fitted to content when new shape will be added into the GroupShape.
        :param index: The zero-based index at which value should be inserted.
        :returns: Created GroupShape object.'''
        ...

    def add_picture_frame(self, shape_type: ShapeType, x: float, y: float, width: float, height: float, image: IPPImage) -> IPictureFrame:
        '''Creates a new PictureFrame and adds it to the end of the collection.
        :param shape_type: The shape contained in the set :py:enum:`aspose.slides.ShapeType`
                    of shapes, except all sorts of lines:
        
            ShapeType.Line,
        
            ShapeType.StraightConnector1,
        
            ShapeType.BentConnector2,
        
            ShapeType.BentConnector3,
        
            ShapeType.BentConnector4,
        
            ShapeType.BentConnector5,
        
            ShapeType.CurvedConnector2,
        
            ShapeType.CurvedConnector3,
        
            ShapeType.CurvedConnector4,
        
            ShapeType.CurvedConnector5.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param width: The width of shape's frame.
        :param height: The height of shape's frame.
        :param image: The image of picture frame.
        :returns: Created PictureFrame object.'''
        ...

    def insert_picture_frame(self, index: int, shape_type: ShapeType, x: float, y: float, width: float, height: float, image: IPPImage) -> IPictureFrame:
        '''Creates a new PictureFrame and inserts it to the collection at the specified index.
        :param index: The zero-based index at which value should be inserted.
        :param shape_type: The shape contained in the set :py:enum:`aspose.slides.ShapeType`
                    of shapes, except all sorts of lines:
        
            ShapeType.Line,
        
            ShapeType.StraightConnector1,
        
            ShapeType.BentConnector2,
        
            ShapeType.BentConnector3,
        
            ShapeType.BentConnector4,
        
            ShapeType.BentConnector5,
        
            ShapeType.CurvedConnector2,
        
            ShapeType.CurvedConnector3,
        
            ShapeType.CurvedConnector4,
        
            ShapeType.CurvedConnector5.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param width: The width of shape's frame.
        :param height: The height of shape's frame.
        :param image: The image of picture frame.
        :returns: Created PictureFrame object.'''
        ...

    def add_table(self, x: float, y: float, column_widths: List[float], row_heights: List[float]) -> ITable:
        '''Creates a new Table and adds it to the end of the collection.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param column_widths: Array of doubles which represents widths of columns in the table.
        :param row_heights: Array of doubles which represents heights of rows in the table.
        :returns: Created Table object.'''
        ...

    def insert_table(self, index: int, x: float, y: float, column_widths: List[float], row_heights: List[float]) -> ITable:
        '''Creates a new Table and inserts it to the collection at the specified index.
        :param index: The zero-based index at which value should be inserted.
        :param x: The X-coordinate for a left side of shape's frame.
        :param y: The Y-coordinate for a top side of shape's frame.
        :param column_widths: Array of doubles which represents widths of columns in the table.
        :param row_heights: Array of doubles which represents heights of rows in the table.
        :returns: Created Table object.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the element at the specified index of the collection.
        :param index: The zero-based index of the element to remove.'''
        ...

    def remove(self, shape: IShape) -> None:
        '''Removes the first occurrence of a specific shape from the collection.
        :param shape: The shape to remove from the collection.'''
        ...

    def clear(self) -> None:
        '''Removes all shapes from the collection.'''
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IShape
        '''Gets the element at the specified index.
                    Read-only :py:class:`aspose.slides.IShape`.'''
        ...

    ...

class ShapeElement:
    '''Represents a part of shape with same outline and fill properties.'''
    @property
    def parent_shape(self) -> Shape:
        ...

    @property
    def graphics_path(self) -> aspose.pydrawing.Drawing2D.GraphicsPath:
        ...

    @property
    def fill_source(self) -> ShapeElementFillSource:
        ...

    @property
    def stroke_source(self) -> ShapeElementStrokeSource:
        ...

    ...

class ShapeFrame:
    '''Represents shape frame's properties.'''
    def __init__(self, x: float, y: float, width: float, height: float, flip_h: NullableBool, flip_v: NullableBool, rotation_angle: float):
        '''Creates new shape frame's properties.
        :param x: X coordinate of a frame.
        :param y: Y coordinate of a frame.
        :param width: Width of a frame.
        :param height: Height of a frame.
        :param flip_h: True if a frame flipped horizontally.
        :param flip_v: True if a frame flipped vertivally.
        :param rotation_angle: Number of degrees a frame is rotated.'''
        ...

    def clone(self) -> any:
        '''Clones
        :returns: Cloned shape frame.'''
        ...

    def clone_t(self) -> IShapeFrame:
        '''Clones.
        :returns: Cloned shape frame.'''
        ...

    def equals(self, value: ShapeFrame) -> bool:
        '''Returns a value indicating whether this instance is equal to a specified object.
        :param value: The ShapeFRameEx to compare with this instance.
        :returns: **True** if value is a ShapeFrame that has the same value as this instance; otherwise, **false**.'''
        ...

    @property
    def x(self) -> float:
        ...

    @property
    def y(self) -> float:
        ...

    @property
    def width(self) -> float:
        ...

    @property
    def height(self) -> float:
        ...

    @property
    def rotation(self) -> float:
        ...

    @property
    def center_x(self) -> float:
        ...

    @property
    def center_y(self) -> float:
        ...

    @property
    def flip_h(self) -> NullableBool:
        ...

    @property
    def flip_v(self) -> NullableBool:
        ...

    @property
    def rectangle(self) -> aspose.pydrawing.RectangleF:
        ...

    ...

class ShapeStyle:
    '''Represent shape's style reference.'''
    @property
    def line_color(self) -> IColorFormat:
        ...

    @property
    def line_style_index(self) -> int:
        ...

    @line_style_index.setter
    def line_style_index(self, value: int):
        ...

    @property
    def fill_color(self) -> IColorFormat:
        ...

    @property
    def fill_style_index(self) -> int:
        ...

    @fill_style_index.setter
    def fill_style_index(self, value: int):
        ...

    @property
    def effect_color(self) -> IColorFormat:
        ...

    @property
    def effect_style_index(self) -> int:
        ...

    @effect_style_index.setter
    def effect_style_index(self, value: int):
        ...

    @property
    def font_color(self) -> IColorFormat:
        ...

    @property
    def font_collection_index(self) -> FontCollectionIndex:
        ...

    @font_collection_index.setter
    def font_collection_index(self, value: FontCollectionIndex):
        ...

    ...

class SketchFormat(PVIObject):
    '''Represents properties for lines sketch format.'''
    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def sketch_type(self) -> LineSketchType:
        ...

    @sketch_type.setter
    def sketch_type(self, value: LineSketchType):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class Slide(BaseSlide):
    '''Represents a slide in a presentation.'''
    @overload
    def join_portions_with_same_formatting(self) -> None:
        '''Joins runs with same formatting in all paragraphs in all acceptable shapes.'''
        ...

    @overload
    def join_portions_with_same_formatting(self, collection: IShapeCollection) -> None:
        '''Joins runs with same formatting in all paragraphs in all acceptable shapes.'''
        ...

    @overload
    def get_thumbnail(self, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns a Thumbnail Bitmap object with custom scaling.
        :param scale_x: The value by which to scale this Thumbnail in the x-axis direction.
        :param scale_y: The value by which to scale this Thumbnail in the y-axis direction.
        :returns: Bitmap object.'''
        ...

    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns a Thumbnail Image object (20% of real size).'''
        ...

    @overload
    def get_thumbnail(self, options: aspose.slides.export.IRenderingOptions) -> aspose.pydrawing.Bitmap:
        '''Returns a Thumbnail Bitmap object.
        :param options: Rendering options.
        :returns: Bitmap objects.'''
        ...

    @overload
    def get_thumbnail(self, image_size: aspose.pydrawing.Size) -> aspose.pydrawing.Bitmap:
        '''Returns a Thumbnail Bitmap object with specified size.
        :param image_size: Size of the image to create.
        :returns: Bitmap object.'''
        ...

    @overload
    def get_thumbnail(self, options: aspose.slides.export.ITiffOptions) -> aspose.pydrawing.Bitmap:
        '''Returns a Thumbnail tiff bitmap object with specified parameters.
        :param options: Tiff options.
        :returns: Bitmap object.'''
        ...

    @overload
    def get_thumbnail(self, options: aspose.slides.export.IRenderingOptions, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns a Thumbnail Bitmap object with custom scaling.
        :param options: Rendering options.
        :param scale_x: The value by which to scale this Thumbnail in the x-axis direction.
        :param scale_y: The value by which to scale this Thumbnail in the y-axis direction.
        :returns: Bitmap objects.'''
        ...

    @overload
    def get_thumbnail(self, options: aspose.slides.export.IRenderingOptions, image_size: aspose.pydrawing.Size) -> aspose.pydrawing.Bitmap:
        '''Returns a Thumbnail Bitmap object with specified size.
        :param options: Rendering options.
        :param image_size: Size of the image to create.
        :returns: Bitmap objects.'''
        ...

    @overload
    def get_image(self, scale_x: float, scale_y: float) -> IImage:
        '''Returns a Thumbnail Image object with custom scaling.
        :param scale_x: The value by which to scale this Thumbnail in the x-axis direction.
        :param scale_y: The value by which to scale this Thumbnail in the y-axis direction.
        :returns: IImage object.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns a Thumbnail Image object (20% of real size).'''
        ...

    @overload
    def get_image(self, image_size: aspose.pydrawing.Size) -> IImage:
        '''Returns a Thumbnail Image object with specified size.
        :param image_size: Size of the image to create.
        :returns: Image object.'''
        ...

    @overload
    def get_image(self, options: aspose.slides.export.ITiffOptions) -> IImage:
        '''Returns a Thumbnail tiff image object with specified parameters.
        :param options: Tiff options.
        :returns: Image object.'''
        ...

    @overload
    def get_image(self, options: aspose.slides.export.IRenderingOptions) -> IImage:
        '''Returns a Thumbnail Image object.
        :param options: Rendering options.
        :returns: Image object.'''
        ...

    @overload
    def get_image(self, options: aspose.slides.export.IRenderingOptions, scale_x: float, scale_y: float) -> IImage:
        '''Returns a Thumbnail Image object with custom scaling.
        :param options: Rendering options.
        :param scale_x: The value by which to scale this Thumbnail in the x-axis direction.
        :param scale_y: The value by which to scale this Thumbnail in the y-axis direction.
        :returns: Bitmap objects.'''
        ...

    @overload
    def get_image(self, options: aspose.slides.export.IRenderingOptions, image_size: aspose.pydrawing.Size) -> IImage:
        '''Returns a Thumbnail Image object with specified size.
        :param options: Rendering options.
        :param image_size: Size of the image to create.
        :returns: Image object.'''
        ...

    @overload
    def render_to_graphics(self, options: aspose.slides.export.IRenderingOptions, graphics: aspose.pydrawing.Graphics) -> None:
        '''Renders certain slide to a Graphics object.
        :param options: Rendering options.
        :param graphics: The object where to render to.'''
        ...

    @overload
    def render_to_graphics(self, options: aspose.slides.export.IRenderingOptions, graphics: aspose.pydrawing.Graphics, scale_x: float, scale_y: float) -> None:
        '''Renders certain slide to a Graphics object with custom scaling.
        :param options: Rendering options.
        :param graphics: The object where to render to.
        :param scale_x: The scale for rendering the slide (1.0 is 100%) in the x-axis direction.
        :param scale_y: The scale for rendering the slide (1.0 is 100%) in the y-axis direction.'''
        ...

    @overload
    def render_to_graphics(self, options: aspose.slides.export.IRenderingOptions, graphics: aspose.pydrawing.Graphics, rendering_size: aspose.pydrawing.Size) -> None:
        '''Renders certain slide to a Graphics object using specified size.
        :param options: Rendering options.
        :param graphics: The object where to render to.
        :param rendering_size: The maximum dimensions (in pixels) that can be occupied by the rendered slide.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of slide as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of slide as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def equals(self, slide: IBaseSlide) -> bool:
        '''Determines whether the two IBaseSlide instances are equal.
                    Returning value is calculated based on slide's structure and static content.
                    Two slides are equal if all shapes, styles, texts, animation and other settings. etc. are equal. The comparison doesn't take into account unique identifier values, e.g. SlideId and dynamic content, e.g. current date value in Date Placeholder.
        :param slide: The IBaseSlide to compare with the current IBaseSlide.
        :returns: **true** if the specified IBaseSlide is equal to the current IBaseSlide; 
                    otherwise, **false**.'''
        ...

    def create_theme_effective(self) -> aspose.slides.theme.IThemeEffectiveData:
        '''Returns an effective theme for this slide.'''
        ...

    def find_shape_by_alt_text(self, alt_text: string) -> IShape:
        '''Finds first occurrence of a shape with the specified alternative text.
        :param alt_text: Alternative text.
        :returns: Shape object or null.'''
        ...

    def remove(self) -> None:
        '''Removes slide from presentation.'''
        ...

    def reset(self) -> None:
        '''Resets position, size and formatting of every shape that has a prototype on LayoutSlide.'''
        ...

    def get_slide_comments(self, author: ICommentAuthor) -> List[IComment]:
        '''Returns all slide comments added by specific author.
        :param author: Author of comments to find or null to return all comments.
        :returns: Array of :py:class:`aspose.slides.Comment`.'''
        ...

    @property
    def shapes(self) -> IShapeCollection:
        ...

    @property
    def controls(self) -> IControlCollection:
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def slide_id(self) -> int:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def timeline(self) -> IAnimationTimeLine:
        ...

    @property
    def slide_show_transition(self) -> ISlideShowTransition:
        ...

    @property
    def background(self) -> IBackground:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def show_master_shapes(self) -> bool:
        ...

    @show_master_shapes.setter
    def show_master_shapes(self, value: bool):
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def header_footer_manager(self) -> ISlideHeaderFooterManager:
        ...

    @property
    def theme_manager(self) -> aspose.slides.theme.IOverrideThemeManager:
        ...

    @property
    def slide_number(self) -> int:
        ...

    @slide_number.setter
    def slide_number(self, value: int):
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def layout_slide(self) -> ILayoutSlide:
        ...

    @layout_slide.setter
    def layout_slide(self, value: ILayoutSlide):
        ...

    @property
    def notes_slide_manager(self) -> INotesSlideManager:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_base_slide(self) -> IBaseSlide:
        ...

    @property
    def as_i_override_themeable(self) -> aspose.slides.theme.IOverrideThemeable:
        ...

    ...

class SlideCollection:
    '''Represents a collection of a slides.'''
    @overload
    def add_clone(self, source_slide: ISlide) -> ISlide:
        '''Adds a copy of a specified slide to the end of the collection.
        :param source_slide: Slide to clone.
        :returns: New slide.'''
        ...

    @overload
    def add_clone(self, source_slide: ISlide, section: ISection) -> ISlide:
        '''Adds a copy of a specified slide to the end of the specified section.
        :param source_slide: Slide to clone.
        :param section: Section for a new slide.
        :returns: New slide.'''
        ...

    @overload
    def add_clone(self, source_slide: ISlide, dest_layout: ILayoutSlide) -> ISlide:
        '''Adds a copy of a specified slide to the end of the collection.
        :param source_slide: Slide to clone.
        :param dest_layout: Layout slide for a new slide.
        :returns: New slide.'''
        ...

    @overload
    def add_clone(self, source_slide: ISlide, dest_master: IMasterSlide, allow_clone_missing_layout: bool) -> ISlide:
        '''Adds a copy of a specified source slide to the end of the collection.
                    Appropriate layout will be selected automatically from the specified 
                    master (appropriate layout is the layout with the same Type or Name as 
                    of layout of the source slide). If there is no appropriate layout then
                    layout of the source slide will be cloned (if allowCloneMissingLayout 
                    is true) or PptxEditException will be thrown (if allowCloneMissingLayout
                    is false).
        :param source_slide: Slide to clone.
        :param dest_master: Master slide for a new slide.
        :param allow_clone_missing_layout: If there is no appropriate layout in specified master then layout of the 
                    source slide will be cloned (if allowCloneMissingLayout is true) or 
                    PptxEditException will be thrown (if allowCloneMissingLayout is false).
        :returns: New slide.'''
        ...

    @overload
    def insert_clone(self, index: int, source_slide: ISlide) -> ISlide:
        '''Inserts a copy of a specified slide to specified position of the collection.
        :param index: Index of new slide.
        :param source_slide: Slide to clone.
        :returns: Inserted slide.'''
        ...

    @overload
    def insert_clone(self, index: int, source_slide: ISlide, dest_layout: ILayoutSlide) -> ISlide:
        '''Inserts a copy of a specified slide to specified position of the collection.
        :param index: Index of new slide.
        :param source_slide: Slide to clone.
        :param dest_layout: Layout slide for a new slide.
        :returns: Inserted slide.'''
        ...

    @overload
    def insert_clone(self, index: int, source_slide: ISlide, dest_master: IMasterSlide, allow_clone_missing_layout: bool) -> ISlide:
        '''Inserts a copy of a specified source slide to specified position of the collection.
                    Appropriate layout will be selected automatically from the specified 
                    master (appropriate layout is the layout with the same Type or Name as 
                    of layout of the source slide). If there is no appropriate layout then
                    layout of the source slide will be cloned (if allowCloneMissingLayout 
                    is true) or PptxEditException will be thrown (if allowCloneMissingLayout
                    is false).
        :param index: Index of new slide.
        :param source_slide: Slide to clone.
        :param dest_master: Master slide for a new slide.
        :param allow_clone_missing_layout: If there is no appropriate layout in specified master then layout of the 
                    source slide will be cloned (if allowCloneMissingLayout is true) or 
                    PptxEditException will be thrown (if allowCloneMissingLayout is false).
        :returns: Inserted slide.'''
        ...

    @overload
    def to_array(self) -> List[ISlide]:
        '''Creates and returns an array with all slides in it.
        :returns: Array of :py:class:`aspose.slides.Slide`'''
        ...

    @overload
    def to_array(self, start_index: int, count: int) -> List[ISlide]:
        '''Creates and returns an array with all slides from the specified range in it.
        :returns: Array of :py:class:`aspose.slides.Slide`'''
        ...

    @overload
    def reorder(self, index: int, slide: ISlide) -> None:
        '''Moves slide from the collection to the specified position.
        :param index: Target index.
        :param slide: Slide to move.'''
        ...

    @overload
    def reorder(self, index: int, slides: List[ISlide]) -> None:
        '''Moves slides from the collection to the specified position.
                    Slides will be placed starting from index in order they appear in list.
        :param index: Target index.
        :param slides: Slides to move.'''
        ...

    @overload
    def add_from_pdf(self, path: string) -> List[ISlide]:
        '''Creates slides from the PDF document and adds them to the end of the collection.
        :param path: A path to the PDF document
        :returns: Added slides'''
        ...

    @overload
    def add_from_pdf(self, path: string, pdf_import_options: aspose.slides.importing.PdfImportOptions) -> List[ISlide]:
        '''Creates slides from the PDF document and adds them to the end of the collection considering the pdf import options.
        :param path: A path to the PDF document
        :param pdf_import_options: Options for pdf import
        :returns: Added slides'''
        ...

    @overload
    def add_from_pdf(self, pdf_stream: System.IO.Stream) -> List[ISlide]:
        '''Creates slides from the PDF document and adds them to the end of the collection.
        :param pdf_stream: A stream which will be used as a source of the PDF document
        :returns: Added slides'''
        ...

    @overload
    def add_from_pdf(self, pdf_stream: System.IO.Stream, pdf_import_options: aspose.slides.importing.PdfImportOptions) -> List[ISlide]:
        '''Creates slides from the PDF document and adds them to the end of the collection.
        :param pdf_stream: A stream which will be used as a source of the PDF document
        :param pdf_import_options: Options for pdf import
        :returns: Added slides'''
        ...

    @overload
    def add_from_html(self, html_text: string, resolver: aspose.slides.importing.IExternalResourceResolver, uri: string) -> List[ISlide]:
        '''Creates slides from HTML text and adds them to the end of the collection.
        :param html_text: Html to add.
        :param resolver: A callback object used to fetch external objects. If this parameter is null all external objects will be ignored.
        :param uri: An URI of the specified HTML. Used to resolve relative links.
        :returns: Added slides.'''
        ...

    @overload
    def add_from_html(self, html_text: string) -> List[ISlide]:
        '''Creates slides from HTML text and adds them to the end of the collection.
        :param html_text: Html to add.
        :returns: Added slides'''
        ...

    @overload
    def add_from_html(self, html_stream: System.IO.Stream, resolver: aspose.slides.importing.IExternalResourceResolver, uri: string) -> List[ISlide]:
        '''Creates slides from HTML text and adds them to the end of the collection.
        :param html_stream: A Stream object which will be used as a source of a HTML file.
        :param resolver: A callback object used to fetch external objects. If this parameter is null all external objects will be ignored.
        :param uri: An URI of the specified HTML. Used to resolve relative links.
        :returns: Added slides.'''
        ...

    @overload
    def add_from_html(self, html_stream: System.IO.Stream) -> List[ISlide]:
        '''Creates slides from HTML text and adds them to the end of the collection.
        :param html_stream: A Stream object which will be used as a source of a HTML file.
        :returns: Added slides'''
        ...

    @overload
    def insert_from_html(self, index: int, html_text: string, resolver: aspose.slides.importing.IExternalResourceResolver, uri: string) -> List[ISlide]:
        '''Creates slides from HTML text and inserts them to the collection at the specified position.
        :param index: Position to insert.
        :param html_text: Html to add.
        :param resolver: A callback object used to fetch external objects. If this parameter is null all external objects will be ignored.
        :param uri: An URI of the specified HTML. Used to resolve relative links.
        :returns: Added slides.'''
        ...

    @overload
    def insert_from_html(self, index: int, html_text: string) -> List[ISlide]:
        '''Creates slides from HTML text and inserts them to the collection at the specified position.
        :param index: Position to insert.
        :param html_text: Html to add.
        :returns: Added slides'''
        ...

    @overload
    def insert_from_html(self, index: int, html_stream: System.IO.Stream, resolver: aspose.slides.importing.IExternalResourceResolver, uri: string) -> List[ISlide]:
        '''Creates slides from HTML text and inserts them to the collection at the specified position.
        :param index: Position to insert.
        :param html_stream: A Stream object which will be used as a source of a HTML file.
        :param resolver: A callback object used to fetch external objects. If this parameter is null all external objects will be ignored.
        :param uri: An URI of the specified HTML. Used to resolve relative links.
        :returns: Added slides.'''
        ...

    @overload
    def insert_from_html(self, index: int, html_stream: System.IO.Stream) -> List[ISlide]:
        '''Creates slides from HTML text and inserts them to the collection at the specified position.
        :param index: Position to insert.
        :param html_stream: A Stream object which will be used as a source of a HTML file.
        :returns: Added slides'''
        ...

    def add_empty_slide(self, layout: ILayoutSlide) -> ISlide:
        '''Adds a new empty slide to the end of the collection.
        :param layout: Layout for a slide.
        :returns: Added slide.'''
        ...

    def insert_empty_slide(self, index: int, layout: ILayoutSlide) -> ISlide:
        '''Inserts a copy of a specified slide to specified position of the collection.
        :param index: Index of a new slide.
        :param layout: Layout for a slide.
        :returns: Inserted slide.'''
        ...

    def remove(self, value: ISlide) -> None:
        '''Removes the first occurrence of a specific object from the collection.
        :param value: The slide to remove from the collection.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the element at the specified index of the collection.
        :param index: The zero-based index of the element to remove.'''
        ...

    def index_of(self, slide: ISlide) -> int:
        '''Returns an index of the specified slide in the collection.
        :param slide: Slide to find.
        :returns: Index of a slide or -1 if slide not from this collection.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ISlide
        '''Gets the element at the specified index.
                    Read-only :py:class:`aspose.slides.Slide`.'''
        ...

    ...

class SlideHeaderFooterManager(BaseSlideHeaderFooterManager):
    '''Represents manager which holds behavior of the slide footer, date-time, page number placeholders.'''
    def set_footer_visibility(self, is_visible: bool) -> None:
        '''Changes slide footer placeholder visibility.
        :param is_visible: true - makes a footer placeholder visible, otherwise - hides it.'''
        ...

    def set_slide_number_visibility(self, is_visible: bool) -> None:
        '''Changes slide page number placeholder visibility.
        :param is_visible: true - makes a page number placeholder visible, otherwise - hides it.'''
        ...

    def set_date_time_visibility(self, is_visible: bool) -> None:
        '''Changes slide date-time placeholder visibility.
        :param is_visible: true - makes a date-time placeholder visible, otherwise - hides it.'''
        ...

    def set_footer_text(self, text: string) -> None:
        '''Sets text to slide footer placeholder.
        :param text: Text to set.'''
        ...

    def set_date_time_text(self, text: string) -> None:
        '''Sets text to slide date-time placeholder.
        :param text: Text to set.'''
        ...

    @property
    def is_footer_visible(self) -> bool:
        ...

    @property
    def is_slide_number_visible(self) -> bool:
        ...

    @property
    def is_date_time_visible(self) -> bool:
        ...

    @property
    def as_i_base_slide_header_footer_manager(self) -> IBaseSlideHeaderFooterManager:
        ...

    @property
    def as_i_base_header_footer_manager(self) -> IBaseHeaderFooterManager:
        ...

    ...

class SlideShowSettings:
    '''Represents the slide show settings for the presentation.'''
    @property
    def slide_show_type(self) -> SlideShowType:
        ...

    @slide_show_type.setter
    def slide_show_type(self, value: SlideShowType):
        ...

    @property
    def loop(self) -> bool:
        ...

    @loop.setter
    def loop(self, value: bool):
        ...

    @property
    def show_narration(self) -> bool:
        ...

    @show_narration.setter
    def show_narration(self, value: bool):
        ...

    @property
    def show_animation(self) -> bool:
        ...

    @show_animation.setter
    def show_animation(self, value: bool):
        ...

    @property
    def pen_color(self) -> IColorFormat:
        ...

    @property
    def slides(self) -> SlidesRange:
        ...

    @slides.setter
    def slides(self, value: SlidesRange):
        ...

    @property
    def use_timings(self) -> bool:
        ...

    @use_timings.setter
    def use_timings(self, value: bool):
        ...

    @property
    def show_media_controls(self) -> bool:
        ...

    @show_media_controls.setter
    def show_media_controls(self, value: bool):
        ...

    ...

class SlideShowType:
    '''Base slide show settings. Ancestors represent types of the slide show:
                 :py:class:`aspose.slides.PresentedBySpeaker` Presented by a speaker (full screen)
                 :py:class:`aspose.slides.BrowsedByIndividual` Browsed by individual (window)
                 :py:class:`aspose.slides.BrowsedAtKiosk` Browsed at a kiosk (full screen)'''
    ...

class SlideSize:
    '''Represents a size of slide.'''
    @overload
    def set_size(self, type: SlideSizeType, scale_type: SlideSizeScaleType) -> None:
        '''Sets the type of slide size and scales content using scale type.
        :param type: Slide size type.
        :param scale_type: Scale type of slide content.'''
        ...

    @overload
    def set_size(self, width: float, height: float, scale_type: SlideSizeScaleType) -> None:
        '''Sets the size in points and scales content using scale type.
        :param width: Width.
        :param height: Height.
        :param scale_type: Scale type of slide content.'''
        ...

    @property
    def size(self) -> aspose.pydrawing.SizeF:
        ...

    @property
    def type(self) -> SlideSizeType:
        ...

    @property
    def orientation(self) -> SlideOrientation:
        ...

    @orientation.setter
    def orientation(self, value: SlideOrientation):
        ...

    ...

class SlidesRange:
    '''Slides range'''
    def __init__(self):
        ...

    @property
    def start(self) -> int:
        ...

    @start.setter
    def start(self, value: int):
        ...

    @property
    def end(self) -> int:
        ...

    @end.setter
    def end(self, value: int):
        ...

    ...

class SpreadsheetOptions:
    '''Represents options which can be used to specify additional spreadsheets behavior.'''
    def __init__(self):
        '''Initializes a new instance of the :py:class:`aspose.slides.SpreadsheetOptions` class.'''
        ...

    @property
    def recover_workbook_from_chart_cache(self) -> bool:
        ...

    @recover_workbook_from_chart_cache.setter
    def recover_workbook_from_chart_cache(self, value: bool):
        ...

    ...

class StreamWrapper:
    '''Aspose.IO.Stream wrapper for COM interface.'''
    def close(self) -> None:
        '''Closes the current stream and releases any resources.'''
        ...

    def flush(self) -> None:
        '''Clears all buffers for this stream and causes any buffered data to be written to the underlying device.'''
        ...

    def read(self, buffer: bytes, offset: int, count: int) -> None:
        '''Reads a sequence of bytes from the current stream and advances the position within the stream by the number of bytes read.'''
        ...

    def read_byte(self) -> int:
        '''Reads a byte from the stream and advances the position within the stream by one byte, or returns -1 if at the end of the stream.'''
        ...

    def seek(self, offset: int, origin: System.IO.SeekOrigin) -> int:
        '''Sets the position within the current stream'''
        ...

    def write(self, buffer: bytes, offset: int, count: int) -> None:
        '''writes a sequence of bytes to the current stream and advances the current position within this stream by the number of bytes written.'''
        ...

    def write_byte(self, value: int) -> None:
        '''Writes a byte to the current position in the stream and advances the position within the stream by one byte.'''
        ...

    @property
    def stream(self) -> System.IO.Stream:
        ...

    @property
    def can_read(self) -> bool:
        ...

    @property
    def can_seek(self) -> bool:
        ...

    @property
    def can_write(self) -> bool:
        ...

    @property
    def length(self) -> int:
        ...

    @property
    def position(self) -> int:
        ...

    @property
    def as_i_disposable(self) -> IDisposable:
        ...

    ...

class StreamWrapperFactory:
    '''Factory of StreamWrappers. For COM interface.'''
    def __init__(self):
        ...

    @overload
    def create_memory_stream_wrapper(self) -> IStreamWrapper:
        '''Creates MemoryStream wrapper.'''
        ...

    @overload
    def create_memory_stream_wrapper(self, buffer: bytes) -> IStreamWrapper:
        '''Creates MemoryStream wrapper based on the specified byte array.'''
        ...

    @overload
    def create_file_stream_wrapper(self, file_name: string, file_mode: System.IO.FileMode) -> IStreamWrapper:
        '''Creates FileStream with the specified path and creation mode.'''
        ...

    @overload
    def create_file_stream_wrapper(self, file_name: string, file_mode: System.IO.FileMode, file_access: System.IO.FileAccess) -> IStreamWrapper:
        '''Creates FileStream with the specified path, creation mode, and read/write permission.'''
        ...

    ...

class SummaryZoomFrame(GraphicalObject):
    '''Represents a Summary Zoom object in a slide.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def layout(self) -> ZoomLayout:
        ...

    @property
    def summary_zoom_collection(self) -> ISummaryZoomSectionCollection:
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    ...

class SummaryZoomSection(SectionZoomFrame):
    '''Represents a Summary Zoom Section object in a Summary Zoom frame.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def image_type(self) -> ZoomImageType:
        ...

    @image_type.setter
    def image_type(self, value: ZoomImageType):
        ...

    @property
    def return_to_parent(self) -> bool:
        ...

    @return_to_parent.setter
    def return_to_parent(self, value: bool):
        ...

    @property
    def show_background(self) -> bool:
        ...

    @show_background.setter
    def show_background(self, value: bool):
        ...

    @property
    def zoom_image(self) -> IPPImage:
        ...

    @zoom_image.setter
    def zoom_image(self, value: IPPImage):
        ...

    @property
    def transition_duration(self) -> float:
        ...

    @transition_duration.setter
    def transition_duration(self, value: float):
        ...

    @property
    def target_section(self) -> ISection:
        ...

    @target_section.setter
    def target_section(self, value: ISection):
        ...

    @property
    def title(self) -> string:
        ...

    @title.setter
    def title(self, value: string):
        ...

    @property
    def description(self) -> string:
        ...

    @description.setter
    def description(self, value: string):
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def as_i_zoom_object(self) -> IZoomObject:
        ...

    @property
    def as_i_section_zoom_frame(self) -> ISectionZoomFrame:
        ...

    ...

class SummaryZoomSectionCollection:
    '''Represents a collection of Summary Zoom Section objects.'''
    def add_summary_zoom_section(self, section: ISection) -> ISummaryZoomSection:
        '''Creates new Summary Zoom Section object and add it to the collection
        :param section: Section for a new Summary Zoom Section element :py:class:`aspose.slides.ISection`
        :returns: Added :py:class:`aspose.slides.ISummaryZoomFrame` element'''
        ...

    def index_of(self, summary_zoom_section: ISummaryZoomSection) -> int:
        '''Returns an index of the specified SummaryZoomSection object.
        :param summary_zoom_section: SummaryZoomSection object to find :py:class:`aspose.slides.ISummaryZoomSection`.
        :returns: Index of a SummaryZoomSection object or -1 if SummaryZoomSection object not from this collection.'''
        ...

    def remove_summary_zoom_section(self, section: ISection) -> None:
        '''Remove Summary Zoom Section object from the collection.
        :param section: Section for which the Summary Zoom Section element is to be removed :py:class:`aspose.slides.ISection`.'''
        ...

    def get_summary_section(self, section: ISection) -> ISummaryZoomSection:
        '''Returns Summary Zoom Section element for the given section.
        :param section: Section to find :py:class:`aspose.slides.ISection`
        :returns: :py:class:`aspose.slides.ISummaryZoomSection` or null if collection does not contains element for the section.'''
        ...

    def clear(self) -> None:
        '''Removes all SummaryZoomSection objects from the collection.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ISummaryZoomSection
        '''Gets the element at the specified index.
                    Read-only :py:class:`aspose.slides.ISummaryZoomSection`.'''
        ...

    ...

class SvgImage:
    '''Represents an SVG image.'''
    def __init__(self, data: bytes):
        '''Creates new SvgImage object.
        :param data: Svg data.'''
        ...

    def __init__(self, svg_content: string):
        '''Creates new SvgImage object.
        :param svg_content: Svg content.'''
        ...

    def __init__(self, stream: System.IO.Stream):
        '''Creates new SvgImage object.
        :param stream: Svg stream.'''
        ...

    def __init__(self, data: bytes, external_res_resolver: aspose.slides.importing.IExternalResourceResolver, base_uri: string):
        '''Creates new SvgImage object.
        :param data: Svg data.
        :param external_res_resolver: A callback object used to fetch external objects. If this parameter is null all external objects will be ignored.
        :param base_uri: Base URI of the specified Svg. Used to resolve relative links.'''
        ...

    def __init__(self, svg_content: string, external_res_resolver: aspose.slides.importing.IExternalResourceResolver, base_uri: string):
        '''Creates new SvgImage object.
        :param svg_content: Svg content.
        :param external_res_resolver: A callback object used to fetch external objects. If this parameter is null all external objects will be ignored.
        :param base_uri: Base URI of the specified Svg. Used to resolve relative links.'''
        ...

    def __init__(self, stream: System.IO.Stream, external_res_resolver: aspose.slides.importing.IExternalResourceResolver, base_uri: string):
        '''Creates new SvgImage object.
        :param stream: Svg stream.
        :param external_res_resolver: A callback object used to fetch external objects. If this parameter is null all external objects will be ignored.
        :param base_uri: Base URI of the specified Svg. Used to resolve relative links.'''
        ...

    @property
    def svg_data(self) -> bytes:
        ...

    @property
    def external_resource_resolver(self) -> aspose.slides.importing.IExternalResourceResolver:
        ...

    @property
    def base_uri(self) -> string:
        ...

    @property
    def svg_content(self) -> string:
        ...

    ...

class Tab(PVIObject):
    '''Represents a tabulation for a text.'''
    def __init__(self, position: float, align: TabAlignment):
        '''Creates new Tab
        :param position: Tab position.
        :param align: Align.'''
        ...

    def compare_to(self, obj: any) -> int:
        '''Compares the current instance with another object of the same type.
        :param obj: An object to compare with this instance.
        :returns: A 32-bit integer that indicates the relative order of the comparands.
                    The return value has these meanings:
                    
        * 
        
        * 
        
        *'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def position(self) -> float:
        ...

    @position.setter
    def position(self, value: float):
        ...

    @property
    def alignment(self) -> TabAlignment:
        ...

    @alignment.setter
    def alignment(self, value: TabAlignment):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class TabCollection:
    '''Represents a collection of tabs.'''
    @overload
    def add(self, position: float, align: TabAlignment) -> ITab:
        '''Adds a Tab to the collection.
        :returns: Added tab.'''
        ...

    @overload
    def add(self, value: ITab) -> int:
        '''Adds a Tab to the collection.
        :param value: The Tab object to be added at the end of the collection.
        :returns: The index at which the tab was added.'''
        ...

    def clear(self) -> None:
        '''Removes all elements from the collection.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the element at the specified index of the collection.
        :param index: The zero-based index of the element to remove.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> ITab
        '''Gets the element at the specified index.
                    Read-only :py:class:`aspose.slides.Tab`.'''
        ...

    ...

class TabFactory:
    '''Allows to create ITab instances'''
    def __init__(self):
        ...

    def create_tab(self, position: float, align: TabAlignment) -> ITab:
        '''Creates a new ITab instance.
        :param position: Tab position.
        :param align: Align.
        :returns: Created tab.'''
        ...

    ...

class Table(GraphicalObject):
    '''Represents a table on a slide.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    @overload
    def set_text_format(self, source: IPortionFormat) -> None:
        '''Sets defined portion format properties to all table cells' portions.
        :param source: IPortionFormat object with necessary properties set.'''
        ...

    @overload
    def set_text_format(self, source: IParagraphFormat) -> None:
        '''Sets defined paragraph format properties to all table cells' paragraphs.
        :param source: IParagraphFormat object with necessary properties set.'''
        ...

    @overload
    def set_text_format(self, source: ITextFrameFormat) -> None:
        '''Sets defined text frame format properties to all table cells' text frames.
        :param source: ITextFrameFormat object with necessary properties set.'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    def merge_cells(self, cell1: ICell, cell2: ICell, allow_splitting: bool) -> ICell:
        '''Merges neighbour cells.
        :param cell1: Cell to merge.
        :param cell2: Cell to merge.
        :param allow_splitting: True to allow cells splitting.
        :returns: Merged cell.'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def rows(self) -> IRowCollection:
        ...

    @property
    def columns(self) -> IColumnCollection:
        ...

    @property
    def table_format(self) -> ITableFormat:
        ...

    @property
    def style_preset(self) -> TableStylePreset:
        ...

    @style_preset.setter
    def style_preset(self, value: TableStylePreset):
        ...

    @property
    def right_to_left(self) -> bool:
        ...

    @right_to_left.setter
    def right_to_left(self, value: bool):
        ...

    @property
    def first_row(self) -> bool:
        ...

    @first_row.setter
    def first_row(self, value: bool):
        ...

    @property
    def first_col(self) -> bool:
        ...

    @first_col.setter
    def first_col(self, value: bool):
        ...

    @property
    def last_row(self) -> bool:
        ...

    @last_row.setter
    def last_row(self, value: bool):
        ...

    @property
    def last_col(self) -> bool:
        ...

    @last_col.setter
    def last_col(self, value: bool):
        ...

    @property
    def horizontal_banding(self) -> bool:
        ...

    @horizontal_banding.setter
    def horizontal_banding(self, value: bool):
        ...

    @property
    def vertical_banding(self) -> bool:
        ...

    @vertical_banding.setter
    def vertical_banding(self, value: bool):
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def as_i_bulk_text_formattable(self) -> IBulkTextFormattable:
        ...

    ...

class TableFormat:
    '''Represents format of a table.'''
    def get_effective(self) -> ITableFormatEffectiveData:
        '''Gets effective table formatting properties with inheritance and table styles applied.
        :returns: A :py:class:`aspose.slides.ITableFormatEffectiveData`.'''
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def transparency(self) -> float:
        ...

    @transparency.setter
    def transparency(self, value: float):
        ...

    ...

class TagCollection:
    '''Represents the collection of tags (user defined pairs of strings)'''
    def add(self, name: string, value: string) -> int:
        '''Adds a new tag to collection.
        :param name: The name of the tag.
        :param value: The value of the tag.
        :returns: The index of the added tag.'''
        ...

    def remove(self, name: string) -> None:
        '''Removes the tag with a specified name from the collection.
        :param name: The name of tag to remove.'''
        ...

    def index_of_name(self, name: string) -> int:
        '''Returns the zero-based index of the specified key in the collection.
        :param name: The name to locate in the collection.
        :returns: The zero-based index of key, if key is found in the collection; otherwise, -1.'''
        ...

    def remove_at(self, index: int) -> None:
        '''Removes the tag at the specified index.
        :param index: The zero-based index of the tag to remove.'''
        ...

    def clear(self) -> None:
        '''Removes all tags from the collection.'''
        ...

    def get_value_by_index(self, index: int) -> string:
        '''Returns value of a tag at the specified index.
        :param index: Index of a tag to return.
        :returns: Value of a tag.'''
        ...

    def get_name_by_index(self, index: int) -> string:
        '''Returns key of a tag at the specified index.
        :param index: Index of a tag to return.
        :returns: Key of a tag.'''
        ...

    def get_names_of_tags(self) -> List[string]:
        '''Returns names of tags.
        :returns: Names of tags.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    ...

class TextFrame:
    '''Represents a TextFrame.'''
    @overload
    def highlight_text(self, text: string, highlight_color: aspose.pydrawing.Color) -> None:
        '''Highlight all matches of sample in text frame text using specified color.
        :param text: Text sample to highlight.
        :param highlight_color: Highlighting color.'''
        ...

    @overload
    def highlight_text(self, text: string, highlight_color: aspose.pydrawing.Color, options: ITextHighlightingOptions) -> None:
        '''Highlight all matches of sample in text frame text using specified color.
        :param text: Text sample to highlight.
        :param highlight_color: Highlighting color.
        :param options: Highlighting options.'''
        ...

    def join_portions_with_same_formatting(self) -> None:
        '''Joins runs with same formatting in all paragraphs.'''
        ...

    def highlight_regex(self, regex: string, highlight_color: aspose.pydrawing.Color, options: ITextHighlightingOptions) -> None:
        '''Highlight all matches of regular expression in text frame text using specified color.
        :param regex: Text of regular expression to get text to highlight.
        :param highlight_color: Highlighting color.
        :param options: Highlighting options.'''
        ...

    @property
    def paragraphs(self) -> IParagraphCollection:
        ...

    @property
    def text(self) -> string:
        ...

    @text.setter
    def text(self, value: string):
        ...

    @property
    def text_frame_format(self) -> ITextFrameFormat:
        ...

    @property
    def hyperlink_queries(self) -> IHyperlinkQueries:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    ...

class TextFrameFormat(PVIObject):
    '''Contains the TextFrame's formatTextFrameFormatting properties.'''
    def __init__(self):
        '''Initializes a new instance of :py:class:`aspose.slides.TextFrameFormat` class.'''
        ...

    def get_effective(self) -> ITextFrameFormatEffectiveData:
        '''Gets effective text frame formatting data with the inheritance applied.
        :returns: A :py:class:`aspose.slides.ITextFrameFormatEffectiveData`.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def margin_left(self) -> float:
        ...

    @margin_left.setter
    def margin_left(self, value: float):
        ...

    @property
    def margin_right(self) -> float:
        ...

    @margin_right.setter
    def margin_right(self, value: float):
        ...

    @property
    def margin_top(self) -> float:
        ...

    @margin_top.setter
    def margin_top(self, value: float):
        ...

    @property
    def margin_bottom(self) -> float:
        ...

    @margin_bottom.setter
    def margin_bottom(self, value: float):
        ...

    @property
    def wrap_text(self) -> NullableBool:
        ...

    @wrap_text.setter
    def wrap_text(self, value: NullableBool):
        ...

    @property
    def anchoring_type(self) -> TextAnchorType:
        ...

    @anchoring_type.setter
    def anchoring_type(self, value: TextAnchorType):
        ...

    @property
    def center_text(self) -> NullableBool:
        ...

    @center_text.setter
    def center_text(self, value: NullableBool):
        ...

    @property
    def text_vertical_type(self) -> TextVerticalType:
        ...

    @text_vertical_type.setter
    def text_vertical_type(self, value: TextVerticalType):
        ...

    @property
    def autofit_type(self) -> TextAutofitType:
        ...

    @autofit_type.setter
    def autofit_type(self, value: TextAutofitType):
        ...

    @property
    def column_count(self) -> int:
        ...

    @column_count.setter
    def column_count(self, value: int):
        ...

    @property
    def column_spacing(self) -> float:
        ...

    @column_spacing.setter
    def column_spacing(self, value: float):
        ...

    @property
    def rotation_angle(self) -> float:
        ...

    @rotation_angle.setter
    def rotation_angle(self, value: float):
        ...

    @property
    def transform(self) -> TextShapeType:
        ...

    @transform.setter
    def transform(self, value: TextShapeType):
        ...

    @property
    def keep_text_flat(self) -> bool:
        ...

    @keep_text_flat.setter
    def keep_text_flat(self, value: bool):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def text_style(self) -> ITextStyle:
        ...

    ...

class TextHighlightingOptions:
    '''Represents options which can be used to highlight text in text frame.'''
    def __init__(self):
        '''Creates new default text highlighting options.'''
        ...

    @property
    def case_sensitive(self) -> bool:
        ...

    @case_sensitive.setter
    def case_sensitive(self, value: bool):
        ...

    @property
    def whole_words_only(self) -> bool:
        ...

    @whole_words_only.setter
    def whole_words_only(self, value: bool):
        ...

    ...

class TextStyle(PVIObject):
    '''This class contains the text style formatting properties.'''
    def get_level(self, index: int) -> IParagraphFormat:
        '''If level of style exist returns it, otherwise returns null.
        :param index: Zero-based index of level. Must lay in 0..8 interval.
        :returns: Formatting of level :py:class:`aspose.slides.IParagraphFormat`.'''
        ...

    def get_effective(self) -> ITextStyleEffectiveData:
        '''Gets effective text style formatting data with the inheritance applied.
        :returns: A :py:class:`aspose.slides.ITextStyleEffectiveData`.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def default_paragraph_format(self) -> IParagraphFormat:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    ...

class ThreeDFormat(PVIObject):
    '''Represents 3-D properties.'''
    def get_effective(self) -> IThreeDFormatEffectiveData:
        '''Gets effective 3-D formatting data with the inheritance applied.
        :returns: A :py:class:`aspose.slides.IThreeDFormatEffectiveData`.'''
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def contour_width(self) -> float:
        ...

    @contour_width.setter
    def contour_width(self, value: float):
        ...

    @property
    def extrusion_height(self) -> float:
        ...

    @extrusion_height.setter
    def extrusion_height(self, value: float):
        ...

    @property
    def depth(self) -> float:
        ...

    @depth.setter
    def depth(self, value: float):
        ...

    @property
    def bevel_top(self) -> IShapeBevel:
        ...

    @property
    def bevel_bottom(self) -> IShapeBevel:
        ...

    @property
    def contour_color(self) -> IColorFormat:
        ...

    @property
    def extrusion_color(self) -> IColorFormat:
        ...

    @property
    def camera(self) -> ICamera:
        ...

    @property
    def light_rig(self) -> ILightRig:
        ...

    @property
    def material(self) -> MaterialPresetType:
        ...

    @material.setter
    def material(self, value: MaterialPresetType):
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def as_i_three_d_param_source(self) -> IThreeDParamSource:
        ...

    ...

class Video:
    '''Represents an image embedded into a presentation.'''
    def get_stream(self) -> System.IO.Stream:
        '''Returns Stream stream for reading.
                    Use 'using' or close stream after using.
        :returns: Stream for reading.'''
        ...

    @property
    def content_type(self) -> string:
        ...

    @property
    def binary_data(self) -> bytes:
        ...

    ...

class VideoCollection:
    '''Represents a collection of Video objects.'''
    @overload
    def add_video(self, video: IVideo) -> IVideo:
        '''Adds a copy of an video file from an another presentation.
        :param video: Source video.
        :returns: Added video.'''
        ...

    @overload
    def add_video(self, stream: System.IO.Stream) -> IVideo:
        '''Creates and adds a video to a presentation from stream.
        :param stream: Stream to add video file from.
        :returns: Added :py:class:`aspose.slides.Video`.'''
        ...

    @overload
    def add_video(self, stream: System.IO.Stream, loading_stream_behavior: LoadingStreamBehavior) -> IVideo:
        '''Creates and adds a video to a presentation from stream.
        :param stream: Stream to add video file from.
        :param loading_stream_behavior: The behavior which will be applied to the stream.
        :returns: Added :py:class:`aspose.slides.IVideo`.'''
        ...

    @overload
    def add_video(self, video_data: bytes) -> IVideo:
        '''Creates and adds a video to a presentation from byte array.
        :param video_data: Video bytes.
        :returns: Added video.'''
        ...

    @property
    def as_i_collection(self) -> list:
        ...

    @property
    def as_i_enumerable(self) -> collections.abc.Iterable:
        ...

    def __getitem__(self, key: int) -> IVideo
        '''Gets the element at the specified index.
                    Read-only :py:class:`aspose.slides.IVideo`.'''
        ...

    ...

class VideoFrame(PictureFrame):
    '''Represents a video clip on a slide.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    def get_geometry_paths(self) -> List[IGeometryPath]:
        '''Returns the copy of path of the geometry shape. Coordinates are relative to the left top corner of the shape.
        :returns: Array of :py:class:`aspose.slides.IGeometryPath`'''
        ...

    def set_geometry_path(self, geometry_path: IGeometryPath) -> None:
        '''Updates shape geometry from :py:class:`aspose.slides.IGeometryPath` object. Coordinates must be relative to the left
                     top corner of the shape.
                     Changes the type of the shape (:py:attr:`aspose.slides.GeometryShape.shape_type`) to :py:attr:`aspose.slides.ShapeType.CUSTOM`.
        :param geometry_path: Geometry path'''
        ...

    def set_geometry_paths(self, geometry_paths: List[IGeometryPath]) -> None:
        '''Updates shape geometry from array of :py:class:`aspose.slides.IGeometryPath`. Coordinates must be relative to the left
                     top corner of the shape.
                     Changes the type of the shape (:py:attr:`aspose.slides.GeometryShape.shape_type`) to :py:attr:`aspose.slides.ShapeType.CUSTOM`.
        :param geometry_paths: Array geometry paths'''
        ...

    def create_shape_elements(self) -> List[IShapeElement]:
        '''Creates and returns array of shape's elements.
        :returns: Array of :py:class:`aspose.slides.ShapeElement`'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IPictureFrameLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def shape_style(self) -> IShapeStyle:
        ...

    @property
    def shape_type(self) -> ShapeType:
        ...

    @shape_type.setter
    def shape_type(self, value: ShapeType):
        ...

    @property
    def adjustments(self) -> IAdjustValueCollection:
        ...

    @property
    def picture_frame_lock(self) -> IPictureFrameLock:
        ...

    @property
    def picture_format(self) -> IPictureFillFormat:
        ...

    @property
    def relative_scale_height(self) -> float:
        ...

    @relative_scale_height.setter
    def relative_scale_height(self, value: float):
        ...

    @property
    def relative_scale_width(self) -> float:
        ...

    @relative_scale_width.setter
    def relative_scale_width(self, value: float):
        ...

    @property
    def rewind_video(self) -> bool:
        ...

    @rewind_video.setter
    def rewind_video(self, value: bool):
        ...

    @property
    def play_loop_mode(self) -> bool:
        ...

    @play_loop_mode.setter
    def play_loop_mode(self, value: bool):
        ...

    @property
    def hide_at_showing(self) -> bool:
        ...

    @hide_at_showing.setter
    def hide_at_showing(self, value: bool):
        ...

    @property
    def volume(self) -> AudioVolumeMode:
        ...

    @volume.setter
    def volume(self, value: AudioVolumeMode):
        ...

    @property
    def play_mode(self) -> VideoPlayModePreset:
        ...

    @play_mode.setter
    def play_mode(self, value: VideoPlayModePreset):
        ...

    @property
    def full_screen_mode(self) -> bool:
        ...

    @full_screen_mode.setter
    def full_screen_mode(self, value: bool):
        ...

    @property
    def link_path_long(self) -> string:
        ...

    @link_path_long.setter
    def link_path_long(self, value: string):
        ...

    @property
    def embedded_video(self) -> IVideo:
        ...

    @embedded_video.setter
    def embedded_video(self, value: IVideo):
        ...

    @property
    def trim_from_start(self) -> float:
        ...

    @trim_from_start.setter
    def trim_from_start(self, value: float):
        ...

    @property
    def trim_from_end(self) -> float:
        ...

    @trim_from_end.setter
    def trim_from_end(self, value: float):
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def as_i_geometry_shape(self) -> IGeometryShape:
        ...

    @property
    def as_i_picture_frame(self) -> IPictureFrame:
        ...

    ...

class ViewProperties:
    '''Presentation wide view properties.'''
    @property
    def last_view(self) -> ViewType:
        ...

    @last_view.setter
    def last_view(self, value: ViewType):
        ...

    @property
    def show_comments(self) -> NullableBool:
        ...

    @show_comments.setter
    def show_comments(self, value: NullableBool):
        ...

    @property
    def normal_view_properties(self) -> INormalViewProperties:
        ...

    @property
    def slide_view_properties(self) -> ICommonSlideViewProperties:
        ...

    @property
    def notes_view_properties(self) -> ICommonSlideViewProperties:
        ...

    ...

class ZoomFrame(ZoomObject):
    '''Represents a Slide Zoom object in a slide.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def image_type(self) -> ZoomImageType:
        ...

    @image_type.setter
    def image_type(self, value: ZoomImageType):
        ...

    @property
    def return_to_parent(self) -> bool:
        ...

    @return_to_parent.setter
    def return_to_parent(self, value: bool):
        ...

    @property
    def show_background(self) -> bool:
        ...

    @show_background.setter
    def show_background(self, value: bool):
        ...

    @property
    def zoom_image(self) -> IPPImage:
        ...

    @zoom_image.setter
    def zoom_image(self, value: IPPImage):
        ...

    @property
    def transition_duration(self) -> float:
        ...

    @transition_duration.setter
    def transition_duration(self, value: float):
        ...

    @property
    def target_slide(self) -> ISlide:
        ...

    @target_slide.setter
    def target_slide(self, value: ISlide):
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    @property
    def as_i_zoom_object(self) -> IZoomObject:
        ...

    ...

class ZoomObject(GraphicalObject):
    '''Represents an Zoom object in a slide.'''
    @overload
    def get_thumbnail(self) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_thumbnail(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> aspose.pydrawing.Bitmap:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def get_image(self) -> IImage:
        '''Returns shape thumbnail.
                    ShapeThumbnailBounds.Shape shape thumbnail bounds type is used by default.
        :returns: Shape thumbnail.'''
        ...

    @overload
    def get_image(self, bounds: ShapeThumbnailBounds, scale_x: float, scale_y: float) -> IImage:
        '''Returns shape thumbnail.
        :param bounds: Shape thumbnail bounds type.
        :param scale_x: X scale
        :param scale_y: Y scale
        :returns: Shape thumbnail or null in case when ShapeThumbnailBounds.Appearance is used and a shape doesn't have visible elements.'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream'''
        ...

    @overload
    def write_as_svg(self, stream: System.IO.Stream, svg_options: aspose.slides.export.ISVGOptions) -> None:
        '''Saves content of Shape as SVG file.
        :param stream: Target stream
        :param svg_options: SVG generation options'''
        ...

    def remove_placeholder(self) -> None:
        '''Defines that this shape isn't a placeholder.'''
        ...

    def add_placeholder(self, placeholder_to_copy_from: IPlaceholder) -> IPlaceholder:
        '''Adds a new placeholder if there is no and sets placeholder properties to a specified one.
        :param placeholder_to_copy_from: Placeholder to copy content from.
        :returns: New :py:attr:`aspose.slides.Shape.placeholder`.'''
        ...

    def get_base_placeholder(self) -> IShape:
        '''Returns a basic placeholder shape (shape from the layout and/or master slide that the current shape is inherited from).'''
        ...

    @property
    def is_text_holder(self) -> bool:
        ...

    @property
    def placeholder(self) -> IPlaceholder:
        ...

    @property
    def custom_data(self) -> ICustomData:
        ...

    @property
    def raw_frame(self) -> IShapeFrame:
        ...

    @raw_frame.setter
    def raw_frame(self, value: IShapeFrame):
        ...

    @property
    def frame(self) -> IShapeFrame:
        ...

    @frame.setter
    def frame(self, value: IShapeFrame):
        ...

    @property
    def line_format(self) -> ILineFormat:
        ...

    @property
    def three_d_format(self) -> IThreeDFormat:
        ...

    @property
    def effect_format(self) -> IEffectFormat:
        ...

    @property
    def fill_format(self) -> IFillFormat:
        ...

    @property
    def hyperlink_click(self) -> IHyperlink:
        ...

    @hyperlink_click.setter
    def hyperlink_click(self, value: IHyperlink):
        ...

    @property
    def hyperlink_mouse_over(self) -> IHyperlink:
        ...

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, value: IHyperlink):
        ...

    @property
    def hyperlink_manager(self) -> IHyperlinkManager:
        ...

    @property
    def hidden(self) -> bool:
        ...

    @hidden.setter
    def hidden(self, value: bool):
        ...

    @property
    def z_order_position(self) -> int:
        ...

    @property
    def connection_site_count(self) -> int:
        ...

    @property
    def rotation(self) -> float:
        ...

    @rotation.setter
    def rotation(self, value: float):
        ...

    @property
    def x(self) -> float:
        ...

    @x.setter
    def x(self, value: float):
        ...

    @property
    def y(self) -> float:
        ...

    @y.setter
    def y(self, value: float):
        ...

    @property
    def width(self) -> float:
        ...

    @width.setter
    def width(self, value: float):
        ...

    @property
    def height(self) -> float:
        ...

    @height.setter
    def height(self, value: float):
        ...

    @property
    def black_white_mode(self) -> BlackWhiteMode:
        ...

    @black_white_mode.setter
    def black_white_mode(self, value: BlackWhiteMode):
        ...

    @property
    def unique_id(self) -> int:
        ...

    @property
    def office_interop_shape_id(self) -> int:
        ...

    @property
    def alternative_text(self) -> string:
        ...

    @alternative_text.setter
    def alternative_text(self, value: string):
        ...

    @property
    def alternative_text_title(self) -> string:
        ...

    @alternative_text_title.setter
    def alternative_text_title(self, value: string):
        ...

    @property
    def name(self) -> string:
        ...

    @name.setter
    def name(self, value: string):
        ...

    @property
    def is_decorative(self) -> bool:
        ...

    @is_decorative.setter
    def is_decorative(self, value: bool):
        ...

    @property
    def shape_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def is_grouped(self) -> bool:
        ...

    @property
    def parent_group(self) -> IGroupShape:
        ...

    @property
    def slide(self) -> IBaseSlide:
        ...

    @property
    def presentation(self) -> IPresentation:
        ...

    @property
    def graphical_object_lock(self) -> IGraphicalObjectLock:
        ...

    @property
    def image_type(self) -> ZoomImageType:
        ...

    @image_type.setter
    def image_type(self, value: ZoomImageType):
        ...

    @property
    def return_to_parent(self) -> bool:
        ...

    @return_to_parent.setter
    def return_to_parent(self, value: bool):
        ...

    @property
    def show_background(self) -> bool:
        ...

    @show_background.setter
    def show_background(self, value: bool):
        ...

    @property
    def zoom_image(self) -> IPPImage:
        ...

    @zoom_image.setter
    def zoom_image(self, value: IPPImage):
        ...

    @property
    def transition_duration(self) -> float:
        ...

    @transition_duration.setter
    def transition_duration(self, value: float):
        ...

    @property
    def as_i_hyperlink_container(self) -> IHyperlinkContainer:
        ...

    @property
    def as_i_slide_component(self) -> ISlideComponent:
        ...

    @property
    def as_i_presentation_component(self) -> IPresentationComponent:
        ...

    @property
    def as_i_shape(self) -> IShape:
        ...

    @property
    def as_i_graphical_object(self) -> IGraphicalObject:
        ...

    ...

class AudioPlayModePreset:
    @classmethod
    @property
    def MIXED(cls) -> AudioPlayModePreset:
        ...

    @classmethod
    @property
    def AUTO(cls) -> AudioPlayModePreset:
        ...

    @classmethod
    @property
    def ON_CLICK(cls) -> AudioPlayModePreset:
        ...

    @classmethod
    @property
    def ALL_SLIDES(cls) -> AudioPlayModePreset:
        ...

    @classmethod
    @property
    def IN_CLICK_SEQUENCE(cls) -> AudioPlayModePreset:
        ...

    ...

class AudioVolumeMode:
    @classmethod
    @property
    def MIXED(cls) -> AudioVolumeMode:
        ...

    @classmethod
    @property
    def MUTE(cls) -> AudioVolumeMode:
        ...

    @classmethod
    @property
    def LOW(cls) -> AudioVolumeMode:
        ...

    @classmethod
    @property
    def MEDIUM(cls) -> AudioVolumeMode:
        ...

    @classmethod
    @property
    def LOUD(cls) -> AudioVolumeMode:
        ...

    ...

class BackgroundType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> BackgroundType:
        ...

    @classmethod
    @property
    def THEMED(cls) -> BackgroundType:
        ...

    @classmethod
    @property
    def OWN_BACKGROUND(cls) -> BackgroundType:
        ...

    ...

class BevelPresetType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> BevelPresetType:
        ...

    @classmethod
    @property
    def ANGLE(cls) -> BevelPresetType:
        ...

    @classmethod
    @property
    def ART_DECO(cls) -> BevelPresetType:
        ...

    @classmethod
    @property
    def CIRCLE(cls) -> BevelPresetType:
        ...

    @classmethod
    @property
    def CONVEX(cls) -> BevelPresetType:
        ...

    @classmethod
    @property
    def COOL_SLANT(cls) -> BevelPresetType:
        ...

    @classmethod
    @property
    def CROSS(cls) -> BevelPresetType:
        ...

    @classmethod
    @property
    def DIVOT(cls) -> BevelPresetType:
        ...

    @classmethod
    @property
    def HARD_EDGE(cls) -> BevelPresetType:
        ...

    @classmethod
    @property
    def RELAXED_INSET(cls) -> BevelPresetType:
        ...

    @classmethod
    @property
    def RIBLET(cls) -> BevelPresetType:
        ...

    @classmethod
    @property
    def SLOPE(cls) -> BevelPresetType:
        ...

    @classmethod
    @property
    def SOFT_ROUND(cls) -> BevelPresetType:
        ...

    ...

class BlackWhiteMode:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> BlackWhiteMode:
        ...

    @classmethod
    @property
    def COLOR(cls) -> BlackWhiteMode:
        ...

    @classmethod
    @property
    def AUTOMATIC(cls) -> BlackWhiteMode:
        ...

    @classmethod
    @property
    def GRAY(cls) -> BlackWhiteMode:
        ...

    @classmethod
    @property
    def LIGHT_GRAY(cls) -> BlackWhiteMode:
        ...

    @classmethod
    @property
    def INVERSE_GRAY(cls) -> BlackWhiteMode:
        ...

    @classmethod
    @property
    def GRAY_WHITE(cls) -> BlackWhiteMode:
        ...

    @classmethod
    @property
    def BLACK_GRAY(cls) -> BlackWhiteMode:
        ...

    @classmethod
    @property
    def BLACK_WHITE(cls) -> BlackWhiteMode:
        ...

    @classmethod
    @property
    def BLACK(cls) -> BlackWhiteMode:
        ...

    @classmethod
    @property
    def WHITE(cls) -> BlackWhiteMode:
        ...

    @classmethod
    @property
    def HIDDEN(cls) -> BlackWhiteMode:
        ...

    ...

class BulletType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> BulletType:
        ...

    @classmethod
    @property
    def NONE(cls) -> BulletType:
        ...

    @classmethod
    @property
    def SYMBOL(cls) -> BulletType:
        ...

    @classmethod
    @property
    def NUMBERED(cls) -> BulletType:
        ...

    @classmethod
    @property
    def PICTURE(cls) -> BulletType:
        ...

    ...

class CameraPresetType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_BOTTOM_DOWN(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_BOTTOM_UP(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_LEFT_DOWN(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_LEFT_UP(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_OFF_AXIS_1_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_OFF_AXIS_1_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_OFF_AXIS_1_TOP(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_OFF_AXIS_2_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_OFF_AXIS_2_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_OFF_AXIS_2_TOP(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_OFF_AXIS_3_BOTTOM(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_OFF_AXIS_3_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_OFF_AXIS_3_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_OFF_AXIS_4_BOTTOM(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_OFF_AXIS_4_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_OFF_AXIS_4_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_RIGHT_DOWN(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_RIGHT_UP(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_TOP_DOWN(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ISOMETRIC_TOP_UP(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_OBLIQUE_BOTTOM(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_OBLIQUE_BOTTOM_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_OBLIQUE_BOTTOM_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_OBLIQUE_FRONT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_OBLIQUE_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_OBLIQUE_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_OBLIQUE_TOP(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_OBLIQUE_TOP_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_OBLIQUE_TOP_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_PERSPECTIVE_BOTTOM(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_PERSPECTIVE_BOTTOM_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_PERSPECTIVE_BOTTOM_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_PERSPECTIVE_FRONT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_PERSPECTIVE_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_PERSPECTIVE_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_PERSPECTIVE_TOP(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_PERSPECTIVE_TOP_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def LEGACY_PERSPECTIVE_TOP_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def OBLIQUE_BOTTOM(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def OBLIQUE_BOTTOM_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def OBLIQUE_BOTTOM_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def OBLIQUE_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def OBLIQUE_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def OBLIQUE_TOP(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def OBLIQUE_TOP_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def OBLIQUE_TOP_RIGHT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def ORTHOGRAPHIC_FRONT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_ABOVE(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_ABOVE_LEFT_FACING(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_ABOVE_RIGHT_FACING(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_BELOW(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_CONTRASTING_LEFT_FACING(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_CONTRASTING_RIGHT_FACING(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_FRONT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_HEROIC_EXTREME_LEFT_FACING(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_HEROIC_EXTREME_RIGHT_FACING(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_HEROIC_LEFT_FACING(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_HEROIC_RIGHT_FACING(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_LEFT(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_RELAXED(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_RELAXED_MODERATELY(cls) -> CameraPresetType:
        ...

    @classmethod
    @property
    def PERSPECTIVE_RIGHT(cls) -> CameraPresetType:
        ...

    ...

class ColorSchemeIndex:
    @classmethod
    @property
    def DARK1(cls) -> ColorSchemeIndex:
        ...

    @classmethod
    @property
    def LIGHT1(cls) -> ColorSchemeIndex:
        ...

    @classmethod
    @property
    def DARK2(cls) -> ColorSchemeIndex:
        ...

    @classmethod
    @property
    def LIGHT2(cls) -> ColorSchemeIndex:
        ...

    @classmethod
    @property
    def ACCENT1(cls) -> ColorSchemeIndex:
        ...

    @classmethod
    @property
    def ACCENT2(cls) -> ColorSchemeIndex:
        ...

    @classmethod
    @property
    def ACCENT3(cls) -> ColorSchemeIndex:
        ...

    @classmethod
    @property
    def ACCENT4(cls) -> ColorSchemeIndex:
        ...

    @classmethod
    @property
    def ACCENT5(cls) -> ColorSchemeIndex:
        ...

    @classmethod
    @property
    def ACCENT6(cls) -> ColorSchemeIndex:
        ...

    @classmethod
    @property
    def HYPERLINK(cls) -> ColorSchemeIndex:
        ...

    @classmethod
    @property
    def FOLLOWED_HYPERLINK(cls) -> ColorSchemeIndex:
        ...

    ...

class ColorStringFormat:
    @classmethod
    @property
    def VML(cls) -> ColorStringFormat:
        ...

    ...

class ColorTransformOperation:
    @classmethod
    @property
    def TINT(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def SHADE(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def COMPLEMENT(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def INVERSE(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def GRAYSCALE(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def SET_ALPHA(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def ADD_ALPHA(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def MULTIPLY_ALPHA(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def SET_HUE(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def ADD_HUE(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def MULTIPLY_HUE(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def SET_SATURATION(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def ADD_SATURATION(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def MULTIPLY_SATURATION(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def SET_LUMINANCE(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def ADD_LUMINANCE(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def MULTIPLY_LUMINANCE(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def SET_RED(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def ADD_RED(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def MULTIPLY_RED(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def SET_GREEN(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def ADD_GREEN(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def MULTIPLY_GREEN(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def SET_BLUE(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def ADD_BLUE(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def MULTIPLY_BLUE(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def GAMMA(cls) -> ColorTransformOperation:
        ...

    @classmethod
    @property
    def INVERSE_GAMMA(cls) -> ColorTransformOperation:
        ...

    ...

class ColorType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> ColorType:
        ...

    @classmethod
    @property
    def RGB(cls) -> ColorType:
        ...

    @classmethod
    @property
    def RGB_PERCENTAGE(cls) -> ColorType:
        ...

    @classmethod
    @property
    def HSL(cls) -> ColorType:
        ...

    @classmethod
    @property
    def SCHEME(cls) -> ColorType:
        ...

    @classmethod
    @property
    def SYSTEM(cls) -> ColorType:
        ...

    @classmethod
    @property
    def PRESET(cls) -> ColorType:
        ...

    ...

class ControlType:
    @classmethod
    @property
    def WINDOWS_MEDIA_PLAYER(cls) -> ControlType:
        ...

    ...

class FillBlendMode:
    @classmethod
    @property
    def DARKEN(cls) -> FillBlendMode:
        ...

    @classmethod
    @property
    def LIGHTEN(cls) -> FillBlendMode:
        ...

    @classmethod
    @property
    def MULTIPLY(cls) -> FillBlendMode:
        ...

    @classmethod
    @property
    def OVERLAY(cls) -> FillBlendMode:
        ...

    @classmethod
    @property
    def SCREEN(cls) -> FillBlendMode:
        ...

    ...

class FillType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> FillType:
        ...

    @classmethod
    @property
    def NO_FILL(cls) -> FillType:
        ...

    @classmethod
    @property
    def SOLID(cls) -> FillType:
        ...

    @classmethod
    @property
    def GRADIENT(cls) -> FillType:
        ...

    @classmethod
    @property
    def PATTERN(cls) -> FillType:
        ...

    @classmethod
    @property
    def PICTURE(cls) -> FillType:
        ...

    @classmethod
    @property
    def GROUP(cls) -> FillType:
        ...

    ...

class FontAlignment:
    @classmethod
    @property
    def DEFAULT(cls) -> FontAlignment:
        ...

    @classmethod
    @property
    def AUTOMATIC(cls) -> FontAlignment:
        ...

    @classmethod
    @property
    def TOP(cls) -> FontAlignment:
        ...

    @classmethod
    @property
    def CENTER(cls) -> FontAlignment:
        ...

    @classmethod
    @property
    def BOTTOM(cls) -> FontAlignment:
        ...

    @classmethod
    @property
    def BASELINE(cls) -> FontAlignment:
        ...

    ...

class FontCollectionIndex:
    @classmethod
    @property
    def NONE(cls) -> FontCollectionIndex:
        ...

    @classmethod
    @property
    def MINOR(cls) -> FontCollectionIndex:
        ...

    @classmethod
    @property
    def MAJOR(cls) -> FontCollectionIndex:
        ...

    ...

class FontSubstCondition:
    @classmethod
    @property
    def WHEN_INACCESSIBLE(cls) -> FontSubstCondition:
        ...

    @classmethod
    @property
    def ALWAYS(cls) -> FontSubstCondition:
        ...

    ...

class GradientDirection:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> GradientDirection:
        ...

    @classmethod
    @property
    def FROM_CORNER1(cls) -> GradientDirection:
        ...

    @classmethod
    @property
    def FROM_CORNER2(cls) -> GradientDirection:
        ...

    @classmethod
    @property
    def FROM_CORNER3(cls) -> GradientDirection:
        ...

    @classmethod
    @property
    def FROM_CORNER4(cls) -> GradientDirection:
        ...

    @classmethod
    @property
    def FROM_CENTER(cls) -> GradientDirection:
        ...

    ...

class GradientShape:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> GradientShape:
        ...

    @classmethod
    @property
    def LINEAR(cls) -> GradientShape:
        ...

    @classmethod
    @property
    def RECTANGLE(cls) -> GradientShape:
        ...

    @classmethod
    @property
    def RADIAL(cls) -> GradientShape:
        ...

    @classmethod
    @property
    def PATH(cls) -> GradientShape:
        ...

    ...

class HyperlinkActionType:
    @classmethod
    @property
    def UNKNOWN(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def NO_ACTION(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def HYPERLINK(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def JUMP_FIRST_SLIDE(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def JUMP_PREVIOUS_SLIDE(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def JUMP_NEXT_SLIDE(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def JUMP_LAST_SLIDE(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def JUMP_END_SHOW(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def JUMP_LAST_VIEWED_SLIDE(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def JUMP_SPECIFIC_SLIDE(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def START_CUSTOM_SLIDE_SHOW(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def OPEN_FILE(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def OPEN_PRESENTATION(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def START_STOP_MEDIA(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def START_MACRO(cls) -> HyperlinkActionType:
        ...

    @classmethod
    @property
    def START_PROGRAM(cls) -> HyperlinkActionType:
        ...

    ...

class HyperlinkColorSource:
    @classmethod
    @property
    def STYLES(cls) -> HyperlinkColorSource:
        ...

    @classmethod
    @property
    def PORTION_FORMAT(cls) -> HyperlinkColorSource:
        ...

    ...

class ImageFormat:
    @classmethod
    @property
    def MEMORY_BMP(cls) -> ImageFormat:
        ...

    @classmethod
    @property
    def BMP(cls) -> ImageFormat:
        ...

    @classmethod
    @property
    def EMF(cls) -> ImageFormat:
        ...

    @classmethod
    @property
    def WMF(cls) -> ImageFormat:
        ...

    @classmethod
    @property
    def GIF(cls) -> ImageFormat:
        ...

    @classmethod
    @property
    def JPEG(cls) -> ImageFormat:
        ...

    @classmethod
    @property
    def PNG(cls) -> ImageFormat:
        ...

    @classmethod
    @property
    def TIFF(cls) -> ImageFormat:
        ...

    @classmethod
    @property
    def EXIF(cls) -> ImageFormat:
        ...

    @classmethod
    @property
    def ICON(cls) -> ImageFormat:
        ...

    ...

class LightRigPresetType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def BALANCED(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def BRIGHT_ROOM(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def CHILLY(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def CONTRASTING(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def FLAT(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def FLOOD(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def FREEZING(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def GLOW(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def HARSH(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def LEGACY_FLAT1(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def LEGACY_FLAT2(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def LEGACY_FLAT3(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def LEGACY_FLAT4(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def LEGACY_HARSH1(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def LEGACY_HARSH2(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def LEGACY_HARSH3(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def LEGACY_HARSH4(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def LEGACY_NORMAL1(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def LEGACY_NORMAL2(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def LEGACY_NORMAL3(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def LEGACY_NORMAL4(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def MORNING(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def SOFT(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def SUNRISE(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def SUNSET(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def THREE_PT(cls) -> LightRigPresetType:
        ...

    @classmethod
    @property
    def TWO_PT(cls) -> LightRigPresetType:
        ...

    ...

class LightingDirection:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> LightingDirection:
        ...

    @classmethod
    @property
    def TOP_LEFT(cls) -> LightingDirection:
        ...

    @classmethod
    @property
    def TOP(cls) -> LightingDirection:
        ...

    @classmethod
    @property
    def TOP_RIGHT(cls) -> LightingDirection:
        ...

    @classmethod
    @property
    def RIGHT(cls) -> LightingDirection:
        ...

    @classmethod
    @property
    def BOTTOM_RIGHT(cls) -> LightingDirection:
        ...

    @classmethod
    @property
    def BOTTOM(cls) -> LightingDirection:
        ...

    @classmethod
    @property
    def BOTTOM_LEFT(cls) -> LightingDirection:
        ...

    @classmethod
    @property
    def LEFT(cls) -> LightingDirection:
        ...

    ...

class LineAlignment:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> LineAlignment:
        ...

    @classmethod
    @property
    def CENTER(cls) -> LineAlignment:
        ...

    @classmethod
    @property
    def INSET(cls) -> LineAlignment:
        ...

    ...

class LineArrowheadLength:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> LineArrowheadLength:
        ...

    @classmethod
    @property
    def SHORT(cls) -> LineArrowheadLength:
        ...

    @classmethod
    @property
    def MEDIUM(cls) -> LineArrowheadLength:
        ...

    @classmethod
    @property
    def LONG(cls) -> LineArrowheadLength:
        ...

    ...

class LineArrowheadStyle:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> LineArrowheadStyle:
        ...

    @classmethod
    @property
    def NONE(cls) -> LineArrowheadStyle:
        ...

    @classmethod
    @property
    def TRIANGLE(cls) -> LineArrowheadStyle:
        ...

    @classmethod
    @property
    def STEALTH(cls) -> LineArrowheadStyle:
        ...

    @classmethod
    @property
    def DIAMOND(cls) -> LineArrowheadStyle:
        ...

    @classmethod
    @property
    def OVAL(cls) -> LineArrowheadStyle:
        ...

    @classmethod
    @property
    def OPEN(cls) -> LineArrowheadStyle:
        ...

    ...

class LineArrowheadWidth:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> LineArrowheadWidth:
        ...

    @classmethod
    @property
    def NARROW(cls) -> LineArrowheadWidth:
        ...

    @classmethod
    @property
    def MEDIUM(cls) -> LineArrowheadWidth:
        ...

    @classmethod
    @property
    def WIDE(cls) -> LineArrowheadWidth:
        ...

    ...

class LineCapStyle:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> LineCapStyle:
        ...

    @classmethod
    @property
    def ROUND(cls) -> LineCapStyle:
        ...

    @classmethod
    @property
    def SQUARE(cls) -> LineCapStyle:
        ...

    @classmethod
    @property
    def FLAT(cls) -> LineCapStyle:
        ...

    ...

class LineDashStyle:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> LineDashStyle:
        ...

    @classmethod
    @property
    def SOLID(cls) -> LineDashStyle:
        ...

    @classmethod
    @property
    def DOT(cls) -> LineDashStyle:
        ...

    @classmethod
    @property
    def DASH(cls) -> LineDashStyle:
        ...

    @classmethod
    @property
    def LARGE_DASH(cls) -> LineDashStyle:
        ...

    @classmethod
    @property
    def DASH_DOT(cls) -> LineDashStyle:
        ...

    @classmethod
    @property
    def LARGE_DASH_DOT(cls) -> LineDashStyle:
        ...

    @classmethod
    @property
    def LARGE_DASH_DOT_DOT(cls) -> LineDashStyle:
        ...

    @classmethod
    @property
    def SYSTEM_DASH(cls) -> LineDashStyle:
        ...

    @classmethod
    @property
    def SYSTEM_DOT(cls) -> LineDashStyle:
        ...

    @classmethod
    @property
    def SYSTEM_DASH_DOT(cls) -> LineDashStyle:
        ...

    @classmethod
    @property
    def SYSTEM_DASH_DOT_DOT(cls) -> LineDashStyle:
        ...

    @classmethod
    @property
    def CUSTOM(cls) -> LineDashStyle:
        ...

    ...

class LineJoinStyle:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> LineJoinStyle:
        ...

    @classmethod
    @property
    def ROUND(cls) -> LineJoinStyle:
        ...

    @classmethod
    @property
    def BEVEL(cls) -> LineJoinStyle:
        ...

    @classmethod
    @property
    def MITER(cls) -> LineJoinStyle:
        ...

    ...

class LineSketchType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> LineSketchType:
        ...

    @classmethod
    @property
    def NONE(cls) -> LineSketchType:
        ...

    @classmethod
    @property
    def CURVED(cls) -> LineSketchType:
        ...

    @classmethod
    @property
    def FREEHAND(cls) -> LineSketchType:
        ...

    @classmethod
    @property
    def SCRIBBLE(cls) -> LineSketchType:
        ...

    ...

class LineStyle:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> LineStyle:
        ...

    @classmethod
    @property
    def SINGLE(cls) -> LineStyle:
        ...

    @classmethod
    @property
    def THIN_THIN(cls) -> LineStyle:
        ...

    @classmethod
    @property
    def THICK_THIN(cls) -> LineStyle:
        ...

    @classmethod
    @property
    def THIN_THICK(cls) -> LineStyle:
        ...

    @classmethod
    @property
    def THICK_BETWEEN_THIN(cls) -> LineStyle:
        ...

    ...

class LoadFormat:
    @classmethod
    @property
    def AUTO(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def PPT(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def PPS(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def PPTX(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def PPSX(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def ODP(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def POTX(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def PPTM(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def PPSM(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def POTM(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def OTP(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def PPT95(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def POT(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def FODP(cls) -> LoadFormat:
        ...

    @classmethod
    @property
    def UNKNOWN(cls) -> LoadFormat:
        ...

    ...

class LoadingStreamBehavior:
    @classmethod
    @property
    def READ_STREAM_AND_RELEASE(cls) -> LoadingStreamBehavior:
        ...

    @classmethod
    @property
    def KEEP_LOCKED(cls) -> LoadingStreamBehavior:
        ...

    ...

class MaterialPresetType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def CLEAR(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def DK_EDGE(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def FLAT(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def LEGACY_MATTE(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def LEGACY_METAL(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def LEGACY_PLASTIC(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def LEGACY_WIREFRAME(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def MATTE(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def METAL(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def PLASTIC(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def POWDER(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def SOFT_EDGE(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def SOFTMETAL(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def TRANSLUCENT_POWDER(cls) -> MaterialPresetType:
        ...

    @classmethod
    @property
    def WARM_MATTE(cls) -> MaterialPresetType:
        ...

    ...

class ModernCommentStatus:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> ModernCommentStatus:
        ...

    @classmethod
    @property
    def ACTIVE(cls) -> ModernCommentStatus:
        ...

    @classmethod
    @property
    def RESOLVED(cls) -> ModernCommentStatus:
        ...

    @classmethod
    @property
    def CLOSED(cls) -> ModernCommentStatus:
        ...

    ...

class NullableBool:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> NullableBool:
        ...

    @classmethod
    @property
    def FALSE(cls) -> NullableBool:
        ...

    @classmethod
    @property
    def TRUE(cls) -> NullableBool:
        ...

    ...

class NumberedBulletStyle:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ALPHA_LC_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ALPHA_UC_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ARABIC_PAREN_RIGHT(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ARABIC_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ROMAN_LC_PAREN_BOTH(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ROMAN_LC_PAREN_RIGHT(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ROMAN_LC_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ROMAN_UC_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ALPHA_LC_PAREN_BOTH(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ALPHA_LC_PAREN_RIGHT(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ALPHA_UC_PAREN_BOTH(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ALPHA_UC_PAREN_RIGHT(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ARABIC_PAREN_BOTH(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ARABIC_PLAIN(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ROMAN_UC_PAREN_BOTH(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ROMAN_UC_PAREN_RIGHT(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_SIMP_CHIN_PLAIN(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_SIMP_CHIN_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_CIRCLE_NUM_DB_PLAIN(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_CIRCLE_NUM_WD_WHITE_PLAIN(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_CIRCLE_NUM_WD_BLACK_PLAIN(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_TRAD_CHIN_PLAIN(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_TRAD_CHIN_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ARABIC_ALPHA_DASH(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ARABIC_ABJAD_DASH(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_HEBREW_ALPHA_DASH(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_KANJI_KOREAN_PLAIN(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_KANJI_KOREAN_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ARABIC_DB_PLAIN(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_ARABIC_DB_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_THAI_ALPHA_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_THAI_ALPHA_PAREN_RIGHT(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_THAI_ALPHA_PAREN_BOTH(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_THAI_NUM_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_THAI_NUM_PAREN_RIGHT(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_THAI_NUM_PAREN_BOTH(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_HINDI_ALPHA_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_HINDI_NUM_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_KANJI_SIMP_CHIN_DB_PERIOD(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_HINDI_NUM_PAREN_RIGHT(cls) -> NumberedBulletStyle:
        ...

    @classmethod
    @property
    def BULLET_HINDI_ALPHA_1_PERIOD(cls) -> NumberedBulletStyle:
        ...

    ...

class Orientation:
    @classmethod
    @property
    def HORIZONTAL(cls) -> Orientation:
        ...

    @classmethod
    @property
    def VERTICAL(cls) -> Orientation:
        ...

    ...

class PPImageFormat:
    @classmethod
    @property
    def BMP(cls) -> PPImageFormat:
        ...

    @classmethod
    @property
    def EMF(cls) -> PPImageFormat:
        ...

    @classmethod
    @property
    def EXIF(cls) -> PPImageFormat:
        ...

    @classmethod
    @property
    def GIF(cls) -> PPImageFormat:
        ...

    @classmethod
    @property
    def ICON(cls) -> PPImageFormat:
        ...

    @classmethod
    @property
    def JPEG(cls) -> PPImageFormat:
        ...

    @classmethod
    @property
    def MEMORY_BMP(cls) -> PPImageFormat:
        ...

    @classmethod
    @property
    def PNG(cls) -> PPImageFormat:
        ...

    @classmethod
    @property
    def TIFF(cls) -> PPImageFormat:
        ...

    @classmethod
    @property
    def WMF(cls) -> PPImageFormat:
        ...

    ...

class PathCommandType:
    @classmethod
    @property
    def CLOSE(cls) -> PathCommandType:
        ...

    @classmethod
    @property
    def MOVE_TO(cls) -> PathCommandType:
        ...

    @classmethod
    @property
    def LINE_TO(cls) -> PathCommandType:
        ...

    @classmethod
    @property
    def ARC_TO(cls) -> PathCommandType:
        ...

    @classmethod
    @property
    def QUAD_BEZIER_TO(cls) -> PathCommandType:
        ...

    @classmethod
    @property
    def CUBIC_BEZIER_TO(cls) -> PathCommandType:
        ...

    ...

class PathFillModeType:
    @classmethod
    @property
    def NONE(cls) -> PathFillModeType:
        ...

    @classmethod
    @property
    def NORMAL(cls) -> PathFillModeType:
        ...

    @classmethod
    @property
    def LIGHTEN(cls) -> PathFillModeType:
        ...

    @classmethod
    @property
    def LIGHTEN_LESS(cls) -> PathFillModeType:
        ...

    @classmethod
    @property
    def DARKEN(cls) -> PathFillModeType:
        ...

    @classmethod
    @property
    def DARKEN_LESS(cls) -> PathFillModeType:
        ...

    ...

class PatternStyle:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def UNKNOWN(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PERCENT05(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PERCENT10(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PERCENT20(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PERCENT25(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PERCENT30(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PERCENT40(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PERCENT50(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PERCENT60(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PERCENT70(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PERCENT75(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PERCENT80(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PERCENT90(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DARK_HORIZONTAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DARK_VERTICAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DARK_DOWNWARD_DIAGONAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DARK_UPWARD_DIAGONAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def SMALL_CHECKER_BOARD(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def TRELLIS(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def LIGHT_HORIZONTAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def LIGHT_VERTICAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def LIGHT_DOWNWARD_DIAGONAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def LIGHT_UPWARD_DIAGONAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def SMALL_GRID(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DOTTED_DIAMOND(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def WIDE_DOWNWARD_DIAGONAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def WIDE_UPWARD_DIAGONAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DASHED_DOWNWARD_DIAGONAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DASHED_UPWARD_DIAGONAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def NARROW_VERTICAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def NARROW_HORIZONTAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DASHED_VERTICAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DASHED_HORIZONTAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def LARGE_CONFETTI(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def LARGE_GRID(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def HORIZONTAL_BRICK(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def LARGE_CHECKER_BOARD(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def SMALL_CONFETTI(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def ZIGZAG(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def SOLID_DIAMOND(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DIAGONAL_BRICK(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def OUTLINED_DIAMOND(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def PLAID(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def SPHERE(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def WEAVE(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DOTTED_GRID(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DIVOT(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def SHINGLE(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def WAVE(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def HORIZONTAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def VERTICAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def CROSS(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DOWNWARD_DIAGONAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def UPWARD_DIAGONAL(cls) -> PatternStyle:
        ...

    @classmethod
    @property
    def DIAGONAL_CROSS(cls) -> PatternStyle:
        ...

    ...

class PersistenceType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> PersistenceType:
        ...

    @classmethod
    @property
    def PERSIST_PROPERTY_BAG(cls) -> PersistenceType:
        ...

    @classmethod
    @property
    def PERSIST_STREAM(cls) -> PersistenceType:
        ...

    @classmethod
    @property
    def PERSIST_STREAM_INIT(cls) -> PersistenceType:
        ...

    @classmethod
    @property
    def PERSIST_STORAGE(cls) -> PersistenceType:
        ...

    ...

class PictureFillMode:
    @classmethod
    @property
    def TILE(cls) -> PictureFillMode:
        ...

    @classmethod
    @property
    def STRETCH(cls) -> PictureFillMode:
        ...

    ...

class PlaceholderSize:
    @classmethod
    @property
    def FULL(cls) -> PlaceholderSize:
        ...

    @classmethod
    @property
    def HALF(cls) -> PlaceholderSize:
        ...

    @classmethod
    @property
    def QUARTER(cls) -> PlaceholderSize:
        ...

    ...

class PlaceholderType:
    @classmethod
    @property
    def TITLE(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def BODY(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def CENTERED_TITLE(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def SUBTITLE(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def DATE_AND_TIME(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def SLIDE_NUMBER(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def FOOTER(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def HEADER(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def OBJECT(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def CHART(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def TABLE(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def CLIP_ART(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def DIAGRAM(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def MEDIA(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def SLIDE_IMAGE(cls) -> PlaceholderType:
        ...

    @classmethod
    @property
    def PICTURE(cls) -> PlaceholderType:
        ...

    ...

class PresentationLockingBehavior:
    @classmethod
    @property
    def LOAD_AND_RELEASE(cls) -> PresentationLockingBehavior:
        ...

    @classmethod
    @property
    def KEEP_LOCKED(cls) -> PresentationLockingBehavior:
        ...

    ...

class PresetColor:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def ALICE_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def ANTIQUE_WHITE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def AQUA(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def AQUAMARINE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def AZURE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def BEIGE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def BISQUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def BLACK(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def BLANCHED_ALMOND(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def BLUE_VIOLET(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def BROWN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def BURLY_WOOD(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def CADET_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def CHARTREUSE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def CHOCOLATE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def CORAL(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def CORNFLOWER_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def CORNSILK(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def CRIMSON(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def CYAN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_CYAN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_GOLDENROD(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_GRAY(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_KHAKI(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_MAGENTA(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_OLIVE_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_ORANGE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_ORCHID(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_RED(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_SALMON(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_SEA_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_SLATE_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_SLATE_GRAY(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_TURQUOISE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DARK_VIOLET(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DEEP_PINK(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DEEP_SKY_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DIM_GRAY(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def DODGER_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def FIREBRICK(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def FLORAL_WHITE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def FOREST_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def FUCHSIA(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def GAINSBORO(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def GHOST_WHITE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def GOLD(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def GOLDENROD(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def GRAY(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def GREEN_YELLOW(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def HONEYDEW(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def HOT_PINK(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def INDIAN_RED(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def INDIGO(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def IVORY(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def KHAKI(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LAVENDER(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LAVENDER_BLUSH(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LAWN_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LEMON_CHIFFON(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_CORAL(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_CYAN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_GOLDENROD_YELLOW(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_GRAY(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_PINK(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_SALMON(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_SEA_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_SKY_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_SLATE_GRAY(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_STEEL_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIGHT_YELLOW(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIME(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LIME_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def LINEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MAGENTA(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MAROON(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MEDIUM_AQUAMARINE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MEDIUM_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MEDIUM_ORCHID(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MEDIUM_PURPLE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MEDIUM_SEA_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MEDIUM_SLATE_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MEDIUM_SPRING_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MEDIUM_TURQUOISE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MEDIUM_VIOLET_RED(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MIDNIGHT_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MINT_CREAM(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MISTY_ROSE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def MOCCASIN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def NAVAJO_WHITE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def NAVY(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def OLD_LACE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def OLIVE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def OLIVE_DRAB(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def ORANGE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def ORANGE_RED(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def ORCHID(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def PALE_GOLDENROD(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def PALE_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def PALE_TURQUOISE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def PALE_VIOLET_RED(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def PAPAYA_WHIP(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def PEACH_PUFF(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def PERU(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def PINK(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def PLUM(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def POWDER_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def PURPLE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def RED(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def ROSY_BROWN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def ROYAL_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def SADDLE_BROWN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def SALMON(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def SANDY_BROWN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def SEA_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def SEA_SHELL(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def SIENNA(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def SILVER(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def SKY_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def SLATE_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def SLATE_GRAY(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def SNOW(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def SPRING_GREEN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def STEEL_BLUE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def TAN(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def TEAL(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def THISTLE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def TOMATO(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def TURQUOISE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def VIOLET(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def WHEAT(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def WHITE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def WHITE_SMOKE(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def YELLOW(cls) -> PresetColor:
        ...

    @classmethod
    @property
    def YELLOW_GREEN(cls) -> PresetColor:
        ...

    ...

class PresetShadowType:
    @classmethod
    @property
    def TOP_LEFT_DROP_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def TOP_LEFT_LARGE_DROP_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def BACK_LEFT_LONG_PERSPECTIVE_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def BACK_RIGHT_LONG_PERSPECTIVE_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def TOP_LEFT_DOUBLE_DROP_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def BOTTOM_RIGHT_SMALL_DROP_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def FRONT_LEFT_LONG_PERSPECTIVE_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def FRONT_RIGHT_LONG_PERSPECTIVE_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def OUTER_BOX_SHADOW_3D(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def INNER_BOX_SHADOW_3D(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def BACK_CENTER_PERSPECTIVE_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def TOP_RIGHT_DROP_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def FRONT_BOTTOM_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def BACK_LEFT_PERSPECTIVE_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def BACK_RIGHT_PERSPECTIVE_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def BOTTOM_LEFT_DROP_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def BOTTOM_RIGHT_DROP_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def FRONT_LEFT_PERSPECTIVE_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def FRONT_RIGHT_PERSPECTIVE_SHADOW(cls) -> PresetShadowType:
        ...

    @classmethod
    @property
    def TOP_LEFT_SMALL_DROP_SHADOW(cls) -> PresetShadowType:
        ...

    ...

class RectangleAlignment:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> RectangleAlignment:
        ...

    @classmethod
    @property
    def TOP_LEFT(cls) -> RectangleAlignment:
        ...

    @classmethod
    @property
    def TOP(cls) -> RectangleAlignment:
        ...

    @classmethod
    @property
    def TOP_RIGHT(cls) -> RectangleAlignment:
        ...

    @classmethod
    @property
    def LEFT(cls) -> RectangleAlignment:
        ...

    @classmethod
    @property
    def CENTER(cls) -> RectangleAlignment:
        ...

    @classmethod
    @property
    def RIGHT(cls) -> RectangleAlignment:
        ...

    @classmethod
    @property
    def BOTTOM_LEFT(cls) -> RectangleAlignment:
        ...

    @classmethod
    @property
    def BOTTOM(cls) -> RectangleAlignment:
        ...

    @classmethod
    @property
    def BOTTOM_RIGHT(cls) -> RectangleAlignment:
        ...

    ...

class ResourceLoadingAction:
    @classmethod
    @property
    def DEFAULT(cls) -> ResourceLoadingAction:
        ...

    @classmethod
    @property
    def SKIP(cls) -> ResourceLoadingAction:
        ...

    @classmethod
    @property
    def USER_PROVIDED(cls) -> ResourceLoadingAction:
        ...

    ...

class SchemeColor:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def BACKGROUND1(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def TEXT1(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def BACKGROUND2(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def TEXT2(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def ACCENT1(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def ACCENT2(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def ACCENT3(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def ACCENT4(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def ACCENT5(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def ACCENT6(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def HYPERLINK(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def FOLLOWED_HYPERLINK(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def STYLE_COLOR(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def DARK1(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def LIGHT1(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def DARK2(cls) -> SchemeColor:
        ...

    @classmethod
    @property
    def LIGHT2(cls) -> SchemeColor:
        ...

    ...

class ShapeElementFillSource:
    @classmethod
    @property
    def NO_FILL(cls) -> ShapeElementFillSource:
        ...

    @classmethod
    @property
    def SHAPE(cls) -> ShapeElementFillSource:
        ...

    @classmethod
    @property
    def LIGHTEN(cls) -> ShapeElementFillSource:
        ...

    @classmethod
    @property
    def LIGHTEN_LESS(cls) -> ShapeElementFillSource:
        ...

    @classmethod
    @property
    def DARKEN(cls) -> ShapeElementFillSource:
        ...

    @classmethod
    @property
    def DARKEN_LESS(cls) -> ShapeElementFillSource:
        ...

    ...

class ShapeElementStrokeSource:
    @classmethod
    @property
    def NO_STROKE(cls) -> ShapeElementStrokeSource:
        ...

    @classmethod
    @property
    def SHAPE(cls) -> ShapeElementStrokeSource:
        ...

    @classmethod
    @property
    def OWN_STROKE(cls) -> ShapeElementStrokeSource:
        ...

    ...

class ShapeThumbnailBounds:
    @classmethod
    @property
    def SLIDE(cls) -> ShapeThumbnailBounds:
        ...

    @classmethod
    @property
    def SHAPE(cls) -> ShapeThumbnailBounds:
        ...

    @classmethod
    @property
    def APPEARANCE(cls) -> ShapeThumbnailBounds:
        ...

    ...

class ShapeType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CUSTOM(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def LINE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def LINE_INVERSE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def TRIANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def RIGHT_TRIANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def RECTANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DIAMOND(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PARALLELOGRAM(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def TRAPEZOID(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def NON_ISOSCELES_TRAPEZOID(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PENTAGON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def HEXAGON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def HEPTAGON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def OCTAGON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DECAGON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DODECAGON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def FOUR_POINTED_STAR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def FIVE_POINTED_STAR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def SIX_POINTED_STAR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def SEVEN_POINTED_STAR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def EIGHT_POINTED_STAR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def TEN_POINTED_STAR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def TWELVE_POINTED_STAR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def SIXTEEN_POINTED_STAR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def TWENTY_FOUR_POINTED_STAR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def THIRTY_TWO_POINTED_STAR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def ROUND_CORNER_RECTANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def ONE_ROUND_CORNER_RECTANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def TWO_SAMESIDE_ROUND_CORNER_RECTANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def TWO_DIAGONAL_ROUND_CORNER_RECTANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def ONE_SNIP_ONE_ROUND_CORNER_RECTANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def ONE_SNIP_CORNER_RECTANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def TWO_SAMESIDE_SNIP_CORNER_RECTANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def TWO_DIAGONAL_SNIP_CORNER_RECTANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PLAQUE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def ELLIPSE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def TEARDROP(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def HOME_PLATE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CHEVRON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PIE_WEDGE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PIE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BLOCK_ARC(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DONUT(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def NO_SMOKING(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def RIGHT_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def LEFT_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def UP_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DOWN_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def STRIPED_RIGHT_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def NOTCHED_RIGHT_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BENT_UP_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def LEFT_RIGHT_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def UP_DOWN_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def LEFT_UP_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def LEFT_RIGHT_UP_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def QUAD_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_LEFT_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_RIGHT_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_UP_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_DOWN_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_LEFT_RIGHT_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_UP_DOWN_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_QUAD_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BENT_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def U_TURN_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CIRCULAR_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def LEFT_CIRCULAR_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def LEFT_RIGHT_CIRCULAR_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CURVED_RIGHT_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CURVED_LEFT_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CURVED_UP_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CURVED_DOWN_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def SWOOSH_ARROW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CUBE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CAN(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def LIGHTNING_BOLT(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def HEART(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def SUN(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def MOON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def SMILEY_FACE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def IRREGULAR_SEAL1(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def IRREGULAR_SEAL2(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def FOLDED_CORNER(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BEVEL(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def FRAME(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def HALF_FRAME(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CORNER(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DIAGONAL_STRIPE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CHORD(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CURVED_ARC(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def LEFT_BRACKET(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def RIGHT_BRACKET(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def LEFT_BRACE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def RIGHT_BRACE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BRACKET_PAIR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BRACE_PAIR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def STRAIGHT_CONNECTOR1(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BENT_CONNECTOR2(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BENT_CONNECTOR3(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BENT_CONNECTOR4(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BENT_CONNECTOR5(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CURVED_CONNECTOR2(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CURVED_CONNECTOR3(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CURVED_CONNECTOR4(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CURVED_CONNECTOR5(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT1(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT2(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT3(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_1_WITH_ACCENT(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_2_WITH_ACCENT(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_3_WITH_ACCENT(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_1_WITH_BORDER(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_2_WITH_BORDER(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_3_WITH_BORDER(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_1_WITH_BORDER_AND_ACCENT(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_2_WITH_BORDER_AND_ACCENT(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_3_WITH_BORDER_AND_ACCENT(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_WEDGE_RECTANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_WEDGE_ROUND_RECTANGLE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_WEDGE_ELLIPSE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CALLOUT_CLOUD(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CLOUD(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def RIBBON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def RIBBON2(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def ELLIPSE_RIBBON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def ELLIPSE_RIBBON2(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def LEFT_RIGHT_RIBBON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def VERTICAL_SCROLL(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def HORIZONTAL_SCROLL(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def WAVE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DOUBLE_WAVE(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PLUS(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PROCESS_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DECISION_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def INPUT_OUTPUT_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PREDEFINED_PROCESS_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def INTERNAL_STORAGE_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DOCUMENT_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def MULTI_DOCUMENT_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def TERMINATOR_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PREPARATION_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def MANUAL_INPUT_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def MANUAL_OPERATION_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CONNECTOR_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PUNCHED_CARD_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PUNCHED_TAPE_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def SUMMING_JUNCTION_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def OR_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def COLLATE_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def SORT_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def EXTRACT_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def MERGE_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def OFFLINE_STORAGE_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def ONLINE_STORAGE_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def MAGNETIC_TAPE_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def MAGNETIC_DISK_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def MAGNETIC_DRUM_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DISPLAY_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DELAY_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def ALTERNATE_PROCESS_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def OFF_PAGE_CONNECTOR_FLOW(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BLANK_BUTTON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def HOME_BUTTON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def HELP_BUTTON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def INFORMATION_BUTTON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def FORWARD_OR_NEXT_BUTTON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BACK_OR_PREVIOUS_BUTTON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def END_BUTTON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def BEGINNING_BUTTON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def RETURN_BUTTON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DOCUMENT_BUTTON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def SOUND_BUTTON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def MOVIE_BUTTON(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def GEAR6(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def GEAR9(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def FUNNEL(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PLUS_MATH(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def MINUS_MATH(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def MULTIPLY_MATH(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def DIVIDE_MATH(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def EQUAL_MATH(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def NOT_EQUAL_MATH(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CORNER_TABS(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def SQUARE_TABS(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def PLAQUE_TABS(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CHART_X(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CHART_STAR(cls) -> ShapeType:
        ...

    @classmethod
    @property
    def CHART_PLUS(cls) -> ShapeType:
        ...

    ...

class ShapesAlignmentType:
    @classmethod
    @property
    def ALIGN_LEFT(cls) -> ShapesAlignmentType:
        ...

    @classmethod
    @property
    def ALIGN_RIGHT(cls) -> ShapesAlignmentType:
        ...

    @classmethod
    @property
    def ALIGN_CENTER(cls) -> ShapesAlignmentType:
        ...

    @classmethod
    @property
    def ALIGN_TOP(cls) -> ShapesAlignmentType:
        ...

    @classmethod
    @property
    def ALIGN_MIDDLE(cls) -> ShapesAlignmentType:
        ...

    @classmethod
    @property
    def ALIGN_BOTTOM(cls) -> ShapesAlignmentType:
        ...

    @classmethod
    @property
    def DISTRIBUTE_HORIZONTALLY(cls) -> ShapesAlignmentType:
        ...

    @classmethod
    @property
    def DISTRIBUTE_VERTICALLY(cls) -> ShapesAlignmentType:
        ...

    ...

class SlideLayoutType:
    @classmethod
    @property
    def CUSTOM(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TITLE(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TEXT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TWO_COLUMN_TEXT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TABLE(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TEXT_AND_CHART(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def CHART_AND_TEXT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def DIAGRAM(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def CHART(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TEXT_AND_CLIP_ART(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def CLIP_ART_AND_TEXT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TITLE_ONLY(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def BLANK(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TEXT_AND_OBJECT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def OBJECT_AND_TEXT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def OBJECT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TITLE_AND_OBJECT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TEXT_AND_MEDIA(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def MEDIA_AND_TEXT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def OBJECT_OVER_TEXT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TEXT_OVER_OBJECT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TEXT_AND_TWO_OBJECTS(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TWO_OBJECTS_AND_TEXT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TWO_OBJECTS_OVER_TEXT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def FOUR_OBJECTS(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def VERTICAL_TEXT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def CLIP_ART_AND_VERTICAL_TEXT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def VERTICAL_TITLE_AND_TEXT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def VERTICAL_TITLE_AND_TEXT_OVER_CHART(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TWO_OBJECTS(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def OBJECT_AND_TWO_OBJECT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TWO_OBJECTS_AND_OBJECT(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def SECTION_HEADER(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TWO_TEXT_AND_TWO_OBJECTS(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def TITLE_OBJECT_AND_CAPTION(cls) -> SlideLayoutType:
        ...

    @classmethod
    @property
    def PICTURE_AND_CAPTION(cls) -> SlideLayoutType:
        ...

    ...

class SlideOrientation:
    @classmethod
    @property
    def LANDSCAPE(cls) -> SlideOrientation:
        ...

    @classmethod
    @property
    def PORTRAIT(cls) -> SlideOrientation:
        ...

    ...

class SlideSizeScaleType:
    @classmethod
    @property
    def DO_NOT_SCALE(cls) -> SlideSizeScaleType:
        ...

    @classmethod
    @property
    def ENSURE_FIT(cls) -> SlideSizeScaleType:
        ...

    @classmethod
    @property
    def MAXIMIZE(cls) -> SlideSizeScaleType:
        ...

    ...

class SlideSizeType:
    @classmethod
    @property
    def ON_SCREEN(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def LETTER_PAPER(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def A4_PAPER(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def SLIDE_35MM(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def OVERHEAD(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def BANNER(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def CUSTOM(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def LEDGER(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def A3_PAPER(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def B4_ISO_PAPER(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def B5_ISO_PAPER(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def B4_JIS_PAPER(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def B5_JIS_PAPER(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def HAGAKI_CARD(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def ON_SCREEN_16X9(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def ON_SCREEN_16X10(cls) -> SlideSizeType:
        ...

    @classmethod
    @property
    def WIDESCREEN(cls) -> SlideSizeType:
        ...

    ...

class SourceFormat:
    @classmethod
    @property
    def PPT(cls) -> SourceFormat:
        ...

    @classmethod
    @property
    def PPTX(cls) -> SourceFormat:
        ...

    @classmethod
    @property
    def ODP(cls) -> SourceFormat:
        ...

    ...

class SplitterBarStateType:
    @classmethod
    @property
    def MINIMIZED(cls) -> SplitterBarStateType:
        ...

    @classmethod
    @property
    def RESTORED(cls) -> SplitterBarStateType:
        ...

    @classmethod
    @property
    def MAXIMIZED(cls) -> SplitterBarStateType:
        ...

    ...

class SystemColor:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def SCROLL_BAR(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def BACKGROUND(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def ACTIVE_CAPTION(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def INACTIVE_CAPTION(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def MENU(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def WINDOW(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def WINDOW_FRAME(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def MENU_TEXT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def WINDOW_TEXT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def CAPTION_TEXT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def ACTIVE_BORDER(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def INACTIVE_BORDER(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def APP_WORKSPACE(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def HIGHLIGHT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def HIGHLIGHT_TEXT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def BTN_FACE(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def BTN_SHADOW(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def GRAY_TEXT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def BTN_TEXT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def INACTIVE_CAPTION_TEXT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def BTN_HIGHLIGHT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def THREE_D_DK_SHADOW(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def THREE_D_LIGHT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def INFO_TEXT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def INFO_BK(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def HOT_LIGHT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def GRADIENT_ACTIVE_CAPTION(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def GRADIENT_INACTIVE_CAPTION(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def MENU_HIGHLIGHT(cls) -> SystemColor:
        ...

    @classmethod
    @property
    def MENU_BAR(cls) -> SystemColor:
        ...

    ...

class TabAlignment:
    @classmethod
    @property
    def LEFT(cls) -> TabAlignment:
        ...

    @classmethod
    @property
    def CENTER(cls) -> TabAlignment:
        ...

    @classmethod
    @property
    def RIGHT(cls) -> TabAlignment:
        ...

    @classmethod
    @property
    def DECIMAL(cls) -> TabAlignment:
        ...

    ...

class TableStylePreset:
    @classmethod
    @property
    def CUSTOM(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def NONE(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_2_ACCENT_1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def NO_STYLE_NO_GRID(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def THEMED_STYLE_1_ACCENT_1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def THEMED_STYLE_1_ACCENT_2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def THEMED_STYLE_1_ACCENT_3(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def THEMED_STYLE_1_ACCENT_4(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def THEMED_STYLE_1_ACCENT_5(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def THEMED_STYLE_1_ACCENT_6(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def NO_STYLE_TABLE_GRID(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def THEMED_STYLE_2_ACCENT_1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def THEMED_STYLE_2_ACCENT_2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def THEMED_STYLE_2_ACCENT_3(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def THEMED_STYLE_2_ACCENT_4(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def THEMED_STYLE_2_ACCENT_5(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def THEMED_STYLE_2_ACCENT_6(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_1_ACCENT_1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_1_ACCENT_2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_1_ACCENT_3(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_1_ACCENT_4(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_2_ACCENT_5(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_1_ACCENT_6(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_2_ACCENT_1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_2_ACCENT_2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_2_ACCENT_3(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_2_ACCENT_3(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_2_ACCENT_4(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_2_ACCENT_5(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_2_ACCENT_6(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_2_ACCENT_4(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE3(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_3_ACCENT_1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_2_ACCENT_2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_3_ACCENT_2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_3_ACCENT_3(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_3_ACCENT_4(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_3_ACCENT_5(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_3_ACCENT_6(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_1_ACCENT_1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_1_ACCENT_2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_1_ACCENT_3(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_1_ACCENT_4(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_1_ACCENT_5(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_1_ACCENT_6(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_2_ACCENT_6(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE3(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_3_ACCENT_1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_3_ACCENT_2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_3_ACCENT_3(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_3_ACCENT_4(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_3_ACCENT_5(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_3_ACCENT_6(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE4(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_4_ACCENT_1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_4_ACCENT_2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_4_ACCENT_3(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_4_ACCENT_4(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_4_ACCENT_5(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def MEDIUM_STYLE_4_ACCENT_6(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def DARK_STYLE1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def DARK_STYLE_1_ACCENT_1(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def DARK_STYLE_1_ACCENT_2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def DARK_STYLE_1_ACCENT_3(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def DARK_STYLE_1_ACCENT_4(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def DARK_STYLE_1_ACCENT_5(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def DARK_STYLE_1_ACCENT_6(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def DARK_STYLE2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def DARK_STYLE_2_ACCENT_1_ACCENT_2(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def DARK_STYLE_2_ACCENT_3_ACCENT_4(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def DARK_STYLE_2_ACCENT_5_ACCENT_6(cls) -> TableStylePreset:
        ...

    @classmethod
    @property
    def LIGHT_STYLE_1_ACCENT_5(cls) -> TableStylePreset:
        ...

    ...

class TextAlignment:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> TextAlignment:
        ...

    @classmethod
    @property
    def LEFT(cls) -> TextAlignment:
        ...

    @classmethod
    @property
    def CENTER(cls) -> TextAlignment:
        ...

    @classmethod
    @property
    def RIGHT(cls) -> TextAlignment:
        ...

    @classmethod
    @property
    def JUSTIFY(cls) -> TextAlignment:
        ...

    @classmethod
    @property
    def JUSTIFY_LOW(cls) -> TextAlignment:
        ...

    @classmethod
    @property
    def DISTRIBUTED(cls) -> TextAlignment:
        ...

    ...

class TextAnchorType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> TextAnchorType:
        ...

    @classmethod
    @property
    def TOP(cls) -> TextAnchorType:
        ...

    @classmethod
    @property
    def CENTER(cls) -> TextAnchorType:
        ...

    @classmethod
    @property
    def BOTTOM(cls) -> TextAnchorType:
        ...

    @classmethod
    @property
    def JUSTIFIED(cls) -> TextAnchorType:
        ...

    @classmethod
    @property
    def DISTRIBUTED(cls) -> TextAnchorType:
        ...

    ...

class TextAutofitType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> TextAutofitType:
        ...

    @classmethod
    @property
    def NONE(cls) -> TextAutofitType:
        ...

    @classmethod
    @property
    def NORMAL(cls) -> TextAutofitType:
        ...

    @classmethod
    @property
    def SHAPE(cls) -> TextAutofitType:
        ...

    ...

class TextCapType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> TextCapType:
        ...

    @classmethod
    @property
    def NONE(cls) -> TextCapType:
        ...

    @classmethod
    @property
    def SMALL(cls) -> TextCapType:
        ...

    @classmethod
    @property
    def ALL(cls) -> TextCapType:
        ...

    ...

class TextExtractionArrangingMode:
    @classmethod
    @property
    def UNARRANGED(cls) -> TextExtractionArrangingMode:
        ...

    @classmethod
    @property
    def ARRANGED(cls) -> TextExtractionArrangingMode:
        ...

    ...

class TextShapeType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def NONE(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def PLAIN(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def STOP(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def TRIANGLE(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def TRIANGLE_INVERTED(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def CHEVRON(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def CHEVRON_INVERTED(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def RING_INSIDE(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def RING_OUTSIDE(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def ARCH_UP(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def ARCH_DOWN(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def CIRCLE(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def BUTTON(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def ARCH_UP_POUR(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def ARCH_DOWN_POUR(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def CIRCLE_POUR(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def BUTTON_POUR(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def CURVE_UP(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def CURVE_DOWN(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def CAN_UP(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def CAN_DOWN(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def WAVE1(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def WAVE2(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def DOUBLE_WAVE1(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def WAVE4(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def INFLATE(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def DEFLATE(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def INFLATE_BOTTOM(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def DEFLATE_BOTTOM(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def INFLATE_TOP(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def DEFLATE_TOP(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def DEFLATE_INFLATE(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def DEFLATE_INFLATE_DEFLATE(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def FADE_RIGHT(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def FADE_LEFT(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def FADE_UP(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def FADE_DOWN(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def SLANT_UP(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def SLANT_DOWN(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def CASCADE_UP(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def CASCADE_DOWN(cls) -> TextShapeType:
        ...

    @classmethod
    @property
    def CUSTOM(cls) -> TextShapeType:
        ...

    ...

class TextStrikethroughType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> TextStrikethroughType:
        ...

    @classmethod
    @property
    def NONE(cls) -> TextStrikethroughType:
        ...

    @classmethod
    @property
    def SINGLE(cls) -> TextStrikethroughType:
        ...

    @classmethod
    @property
    def DOUBLE(cls) -> TextStrikethroughType:
        ...

    ...

class TextUnderlineType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def NONE(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def WORDS(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def SINGLE(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def DOUBLE(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def HEAVY(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def DOTTED(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def HEAVY_DOTTED(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def DASHED(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def HEAVY_DASHED(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def LONG_DASHED(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def HEAVY_LONG_DASHED(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def DOT_DASH(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def HEAVY_DOT_DASH(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def DOT_DOT_DASH(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def HEAVY_DOT_DOT_DASH(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def WAVY(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def HEAVY_WAVY(cls) -> TextUnderlineType:
        ...

    @classmethod
    @property
    def DOUBLE_WAVY(cls) -> TextUnderlineType:
        ...

    ...

class TextVerticalOverflowType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> TextVerticalOverflowType:
        ...

    @classmethod
    @property
    def OVERFLOW(cls) -> TextVerticalOverflowType:
        ...

    @classmethod
    @property
    def ELLIPSIS(cls) -> TextVerticalOverflowType:
        ...

    @classmethod
    @property
    def CLIP(cls) -> TextVerticalOverflowType:
        ...

    ...

class TextVerticalType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> TextVerticalType:
        ...

    @classmethod
    @property
    def HORIZONTAL(cls) -> TextVerticalType:
        ...

    @classmethod
    @property
    def VERTICAL(cls) -> TextVerticalType:
        ...

    @classmethod
    @property
    def VERTICAL270(cls) -> TextVerticalType:
        ...

    @classmethod
    @property
    def WORD_ART_VERTICAL(cls) -> TextVerticalType:
        ...

    @classmethod
    @property
    def EAST_ASIAN_VERTICAL(cls) -> TextVerticalType:
        ...

    @classmethod
    @property
    def MONGOLIAN_VERTICAL(cls) -> TextVerticalType:
        ...

    @classmethod
    @property
    def WORD_ART_VERTICAL_RIGHT_TO_LEFT(cls) -> TextVerticalType:
        ...

    ...

class TileFlip:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> TileFlip:
        ...

    @classmethod
    @property
    def NO_FLIP(cls) -> TileFlip:
        ...

    @classmethod
    @property
    def FLIP_X(cls) -> TileFlip:
        ...

    @classmethod
    @property
    def FLIP_Y(cls) -> TileFlip:
        ...

    @classmethod
    @property
    def FLIP_BOTH(cls) -> TileFlip:
        ...

    ...

class VideoPlayModePreset:
    @classmethod
    @property
    def MIXED(cls) -> VideoPlayModePreset:
        ...

    @classmethod
    @property
    def AUTO(cls) -> VideoPlayModePreset:
        ...

    @classmethod
    @property
    def ON_CLICK(cls) -> VideoPlayModePreset:
        ...

    @classmethod
    @property
    def ALL_SLIDES(cls) -> VideoPlayModePreset:
        ...

    @classmethod
    @property
    def IN_CLICK_SEQUENCE(cls) -> VideoPlayModePreset:
        ...

    ...

class ViewType:
    @classmethod
    @property
    def NOT_DEFINED(cls) -> ViewType:
        ...

    @classmethod
    @property
    def SLIDE_VIEW(cls) -> ViewType:
        ...

    @classmethod
    @property
    def SLIDE_MASTER_VIEW(cls) -> ViewType:
        ...

    @classmethod
    @property
    def NOTES_VIEW(cls) -> ViewType:
        ...

    @classmethod
    @property
    def HANDOUT_VIEW(cls) -> ViewType:
        ...

    @classmethod
    @property
    def NOTES_MASTER_VIEW(cls) -> ViewType:
        ...

    @classmethod
    @property
    def OUTLINE_VIEW(cls) -> ViewType:
        ...

    @classmethod
    @property
    def SLIDE_SORTER_VIEW(cls) -> ViewType:
        ...

    @classmethod
    @property
    def SLIDE_THUMBNAIL_VIEW(cls) -> ViewType:
        ...

    ...

class ZoomImageType:
    @classmethod
    @property
    def PREVIEW(cls) -> ZoomImageType:
        ...

    @classmethod
    @property
    def COVER(cls) -> ZoomImageType:
        ...

    ...

class ZoomLayout:
    @classmethod
    @property
    def GRID_LAYOUT(cls) -> ZoomLayout:
        ...

    @classmethod
    @property
    def FIXED_LAYOUT(cls) -> ZoomLayout:
        ...

    ...

